"""
>>> add zip codes <<<

TroveFM is an online store and headless CMS.

Copyright (C) 2022  Brian Farrell

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

Contact: brian.farrell@me.com


Revision ID: 8c3423000743
Revises: f989260ff4b2
Create Date: 2022-04-25 16:02:34.352210
"""


import os
from typing import Tuple

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION
from sqlalchemy.sql import table

# revision identifiers, used by Alembic
revision = '8c3423000743'
down_revision = 'f989260ff4b2'
branch_labels = None
depends_on = None


zip_lookup = table(
    'zip_lookup',
    sa.Column("country_code", sa.VARCHAR(2)),
    sa.Column("zip_code", sa.VARCHAR(5), unique=True),
    sa.Column("place_name", sa.VARCHAR(180)),
    sa.Column("state", sa.VARCHAR(100)),
    sa.Column("state_ab", sa.VARCHAR(2)),
    sa.Column("county", sa.VARCHAR(50)),
    sa.Column("locality_code", sa.VARCHAR(5)),
    sa.Column("latitude", DOUBLE_PRECISION(asdecimal=True)),
    sa.Column("longitude", DOUBLE_PRECISION(asdecimal=True)),
    sa.Column("accuracy", sa.Integer)
)


def add_zip_code_test_data():
    op.bulk_insert(
        zip_lookup,
        [
            {'country_code': 'US', 'zip_code': '14610', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1452, 'longitude': -77.5495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22101', 'place_name': 'Mc Lean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9326, 'longitude': -77.1706, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22066', 'place_name': 'Great Falls', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 39.0039, 'longitude': -77.3083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20165', 'place_name': 'Sterling', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0472, 'longitude': -77.3866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10001', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7484, 'longitude': -73.9967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10024', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7864, 'longitude': -73.9764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10031', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8246, 'longitude': -73.9507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08540', 'place_name': 'Princeton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3666, 'longitude': -74.6408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20007', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9144, 'longitude': -77.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20018', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9277, 'longitude': -76.9762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90016', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0298, 'longitude': -118.3528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90210', 'place_name': 'Beverly Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0901, 'longitude': -118.4065, 'accuracy': 4},
        ]
    )


def add_zip_code_data():
    op.bulk_insert(
        zip_lookup,
        [
            {'country_code': 'US', 'zip_code': '99553', 'place_name': 'Akutan', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians East', 'locality_code': '13', 'latitude': 54.143, 'longitude': -165.7854, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99571', 'place_name': 'Cold Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians East', 'locality_code': '13', 'latitude': 55.1858, 'longitude': -162.7211, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99583', 'place_name': 'False Pass', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians East', 'locality_code': '13', 'latitude': 54.8542, 'longitude': -163.4113, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99612', 'place_name': 'King Cove', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians East', 'locality_code': '13', 'latitude': 55.0628, 'longitude': -162.3056, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99661', 'place_name': 'Sand Point', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians East', 'locality_code': '13', 'latitude': 55.3192, 'longitude': -160.4914, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99546', 'place_name': 'Adak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians West (CA)', 'locality_code': '16', 'latitude': 51.874, 'longitude': -176.634, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99547', 'place_name': 'Atka', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians West (CA)', 'locality_code': '16', 'latitude': 52.1961, 'longitude': -174.2006, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99591', 'place_name': 'Saint George Island', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians West (CA)', 'locality_code': '16', 'latitude': 56.5944, 'longitude': -169.6186, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99638', 'place_name': 'Nikolski', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians West (CA)', 'locality_code': '16', 'latitude': 52.9381, 'longitude': -168.8678, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99660', 'place_name': 'Saint Paul Island', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians West (CA)', 'locality_code': '16', 'latitude': 57.1842, 'longitude': -170.2764, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99685', 'place_name': 'Unalaska', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians West (CA)', 'locality_code': '16', 'latitude': 53.8871, 'longitude': -166.5199, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99692', 'place_name': 'Dutch Harbor', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Aleutians West (CA)', 'locality_code': '16', 'latitude': 53.8898, 'longitude': -166.5422, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99501', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2116, 'longitude': -149.8761, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99502', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1661, 'longitude': -149.96, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99503', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.19, 'longitude': -149.8938, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99504', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2037, 'longitude': -149.7447, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99505', 'place_name': 'Jber', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 59.8666, 'longitude': -158.5996, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99506', 'place_name': 'Jber', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 59.8666, 'longitude': -158.5996, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99507', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1535, 'longitude': -149.8289, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99508', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.206, 'longitude': -149.8101, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99509', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2181, 'longitude': -149.9003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99510', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1446, 'longitude': -149.8784, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99511', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.0683, 'longitude': -149.8005, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99513', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2149, 'longitude': -149.8862, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99514', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2181, 'longitude': -149.9003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99515', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1194, 'longitude': -149.8974, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99516', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1054, 'longitude': -149.78, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99517', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1901, 'longitude': -149.9361, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99518', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1549, 'longitude': -149.8866, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99519', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1089, 'longitude': -149.4403, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99520', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2181, 'longitude': -149.9003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99521', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2181, 'longitude': -149.9003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99522', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2181, 'longitude': -149.9003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99523', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2181, 'longitude': -149.9003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99524', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.2181, 'longitude': -149.9003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99529', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1515, 'longitude': -149.9443, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99530', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1515, 'longitude': -149.9443, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99540', 'place_name': 'Indian', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1089, 'longitude': -149.4403, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99567', 'place_name': 'Chugiak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.4098, 'longitude': -149.4537, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99577', 'place_name': 'Eagle River', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.3114, 'longitude': -149.5085, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99587', 'place_name': 'Girdwood', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 60.9577, 'longitude': -149.1406, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99599', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1872, 'longitude': -149.8804, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99695', 'place_name': 'Anchorage', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Anchorage Municipality', 'locality_code': '20', 'latitude': 61.1089, 'longitude': -149.4403, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99545', 'place_name': 'Kongiganak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 59.9599, 'longitude': -162.8919, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99551', 'place_name': 'Akiachak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.9094, 'longitude': -161.4314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99552', 'place_name': 'Akiak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.9122, 'longitude': -161.2139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99557', 'place_name': 'Aniak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 61.5783, 'longitude': -159.5222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99559', 'place_name': 'Bethel', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.7922, 'longitude': -161.7558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99561', 'place_name': 'Chefornak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.1537, 'longitude': -164.2103, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99575', 'place_name': 'Crooked Creek', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 61.8181, 'longitude': -158.0025, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99578', 'place_name': 'Eek', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.2151, 'longitude': -162.0323, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99589', 'place_name': 'Goodnews Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 59.1189, 'longitude': -161.5875, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99607', 'place_name': 'Kalskag', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 61.541, 'longitude': -160.3261, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99609', 'place_name': 'Kasigluk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.8956, 'longitude': -162.5181, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99614', 'place_name': 'Kipnuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 59.9232, 'longitude': -164.101, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99621', 'place_name': 'Kwethluk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.8122, 'longitude': -161.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99622', 'place_name': 'Kwigillingok', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 59.8644, 'longitude': -163.1342, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99626', 'place_name': 'Lower Kalskag', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 61.5138, 'longitude': -160.36, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99630', 'place_name': 'Mekoryuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.3657, 'longitude': -166.2836, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99634', 'place_name': 'Napakiak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.6967, 'longitude': -161.9519, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99637', 'place_name': 'Toksook Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.5338, 'longitude': -165.1037, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99641', 'place_name': 'Nunapitchuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.8969, 'longitude': -162.4594, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99651', 'place_name': 'Platinum', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 59.0131, 'longitude': -161.8164, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99655', 'place_name': 'Quinhagak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 59.7381, 'longitude': -161.8749, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99656', 'place_name': 'Red Devil', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 61.7611, 'longitude': -157.3125, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99668', 'place_name': 'Sleetmute', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 61.7025, 'longitude': -157.1697, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99679', 'place_name': 'Tuluksak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 61.1088, 'longitude': -160.9389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99680', 'place_name': 'Tuntutuliak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.3431, 'longitude': -162.6631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99681', 'place_name': 'Tununak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.5856, 'longitude': -165.2558, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99690', 'place_name': 'Nightmute', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bethel Census Area', 'locality_code': '50', 'latitude': 60.4794, 'longitude': -164.7239, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99613', 'place_name': 'King Salmon', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bristol Bay', 'locality_code': '60', 'latitude': 58.6883, 'longitude': -156.6614, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99633', 'place_name': 'Naknek', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bristol Bay', 'locality_code': '60', 'latitude': 58.783, 'longitude': -156.8992, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99670', 'place_name': 'South Naknek', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Bristol Bay', 'locality_code': '60', 'latitude': 58.6639, 'longitude': -156.9756, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99704', 'place_name': 'Clear', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Denali', 'locality_code': '68', 'latitude': 64.2966, 'longitude': -149.1608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99729', 'place_name': 'Cantwell', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Denali', 'locality_code': '68', 'latitude': 63.3955, 'longitude': -148.8973, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99743', 'place_name': 'Healy', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Denali', 'locality_code': '68', 'latitude': 63.9171, 'longitude': -149.0111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99744', 'place_name': 'Anderson', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Denali', 'locality_code': '68', 'latitude': 64.3442, 'longitude': -149.1869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99755', 'place_name': 'Denali National Park', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Denali', 'locality_code': '68', 'latitude': 63.5436, 'longitude': -149.9867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99555', 'place_name': 'Aleknagik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Dillingham (CA)', 'locality_code': '70', 'latitude': 59.2697, 'longitude': -158.6199, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99569', 'place_name': 'Clarks Point', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Dillingham (CA)', 'locality_code': '70', 'latitude': 58.8173, 'longitude': -158.5299, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99576', 'place_name': 'Dillingham', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Dillingham (CA)', 'locality_code': '70', 'latitude': 59.0402, 'longitude': -158.5231, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99580', 'place_name': 'Ekwok', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Dillingham (CA)', 'locality_code': '70', 'latitude': 59.3628, 'longitude': -157.4782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99628', 'place_name': 'Manokotak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Dillingham (CA)', 'locality_code': '70', 'latitude': 59.0096, 'longitude': -158.9897, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99636', 'place_name': 'New Stuyahok', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Dillingham (CA)', 'locality_code': '70', 'latitude': 59.4882, 'longitude': -157.2905, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99678', 'place_name': 'Togiak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Dillingham (CA)', 'locality_code': '70', 'latitude': 59.0619, 'longitude': -160.3764, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99701', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8378, 'longitude': -147.7164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99702', 'place_name': 'Eielson Afb', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.6735, 'longitude': -147.0805, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99703', 'place_name': 'Fort Wainwright', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8283, 'longitude': -147.6557, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99705', 'place_name': 'North Pole', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.7805, 'longitude': -147.3694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99706', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8521, 'longitude': -147.9377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99707', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8378, 'longitude': -147.7164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99708', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.9475, 'longitude': -147.8564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99709', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8544, 'longitude': -147.8469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99710', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8378, 'longitude': -147.7164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99711', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8378, 'longitude': -147.7164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99712', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.9109, 'longitude': -147.5105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99714', 'place_name': 'Salcha', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.5091, 'longitude': -146.953, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99716', 'place_name': 'Two Rivers', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8746, 'longitude': -146.8982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99725', 'place_name': 'Ester', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.871, 'longitude': -148.0949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99775', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8591, 'longitude': -147.8267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99790', 'place_name': 'Fairbanks', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Fairbanks North Star', 'locality_code': '90', 'latitude': 64.8378, 'longitude': -147.7164, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99827', 'place_name': 'Haines', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Haines', 'locality_code': '100', 'latitude': 59.2519, 'longitude': -135.542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99801', 'place_name': 'Juneau', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.3628, 'longitude': -134.5294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99802', 'place_name': 'Juneau', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.3019, 'longitude': -134.4197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99803', 'place_name': 'Juneau', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.3019, 'longitude': -134.4197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99811', 'place_name': 'Juneau', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.3019, 'longitude': -134.4197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99812', 'place_name': 'Juneau', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.3271, 'longitude': -134.4742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99821', 'place_name': 'Auke Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.4494, 'longitude': -134.7003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99824', 'place_name': 'Douglas', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.2756, 'longitude': -134.395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99850', 'place_name': 'Juneau', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Juneau City and Borough', 'locality_code': '110', 'latitude': 58.3019, 'longitude': -134.4197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99556', 'place_name': 'Anchor Point', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 59.8371, 'longitude': -151.7078, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99568', 'place_name': 'Clam Gulch', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.2311, 'longitude': -151.3936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99572', 'place_name': 'Cooper Landing', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.4767, 'longitude': -149.8235, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99603', 'place_name': 'Homer', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 59.5374, 'longitude': -151.2356, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99605', 'place_name': 'Hope', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.8726, 'longitude': -149.4683, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99610', 'place_name': 'Kasilof', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.3164, 'longitude': -151.2896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99611', 'place_name': 'Kenai', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.6145, 'longitude': -151.2546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99631', 'place_name': 'Moose Pass', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.6148, 'longitude': -149.4056, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99635', 'place_name': 'Nikiski', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.7007, 'longitude': -151.2766, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99639', 'place_name': 'Ninilchik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.0108, 'longitude': -151.6396, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99663', 'place_name': 'Seldovia', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 59.4495, 'longitude': -151.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99664', 'place_name': 'Seward', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.1329, 'longitude': -149.3985, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99669', 'place_name': 'Soldotna', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.4818, 'longitude': -151.1358, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99672', 'place_name': 'Sterling', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 60.5136, 'longitude': -150.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99682', 'place_name': 'Tyonek', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kenai Peninsula', 'locality_code': '122', 'latitude': 61.0681, 'longitude': -151.1369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99901', 'place_name': 'Ketchikan', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Ketchikan Gateway', 'locality_code': '130', 'latitude': 55.372, 'longitude': -131.6832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99928', 'place_name': 'Ward Cove', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Ketchikan Gateway', 'locality_code': '130', 'latitude': 55.3954, 'longitude': -131.6754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99950', 'place_name': 'Ketchikan', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Ketchikan Gateway', 'locality_code': '130', 'latitude': 55.3422, 'longitude': -131.6478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99550', 'place_name': 'Port Lions', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.8675, 'longitude': -152.8822, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99608', 'place_name': 'Karluk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.5689, 'longitude': -154.4551, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99615', 'place_name': 'Kodiak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.6036, 'longitude': -153.3751, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99619', 'place_name': 'Kodiak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.79, 'longitude': -152.4072, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99624', 'place_name': 'Larsen Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.54, 'longitude': -153.9786, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99643', 'place_name': 'Old Harbor', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.2028, 'longitude': -153.3039, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99644', 'place_name': 'Ouzinkie', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.9236, 'longitude': -152.5022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99697', 'place_name': 'Kodiak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kodiak Island', 'locality_code': '150', 'latitude': 57.79, 'longitude': -152.4072, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99554', 'place_name': 'Alakanuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 62.6944, 'longitude': -164.6475, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99563', 'place_name': 'Chevak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 61.529, 'longitude': -165.5905, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99581', 'place_name': 'Emmonak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 62.7818, 'longitude': -164.5335, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99585', 'place_name': 'Marshall', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 61.9287, 'longitude': -162.268, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99604', 'place_name': 'Hooper Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 61.527, 'longitude': -166.1151, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99620', 'place_name': 'Kotlik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 63.0295, 'longitude': -163.5542, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99632', 'place_name': 'Mountain Village', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 62.1123, 'longitude': -163.6644, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99650', 'place_name': 'Pilot Station', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 61.9462, 'longitude': -162.8747, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99657', 'place_name': 'Russian Mission', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 61.7744, 'longitude': -161.3939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99658', 'place_name': 'Saint Marys', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 62.1172, 'longitude': -163.2376, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99662', 'place_name': 'Scammon Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 61.845, 'longitude': -165.5819, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99666', 'place_name': 'Nunam Iqua', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Kusilvak', 'locality_code': '158', 'latitude': 62.5309, 'longitude': -164.8496, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99548', 'place_name': 'Chignik Lake', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 56.2448, 'longitude': -158.7578, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99549', 'place_name': 'Port Heiden', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 56.9643, 'longitude': -158.5664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99564', 'place_name': 'Chignik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 56.3016, 'longitude': -158.4157, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99565', 'place_name': 'Chignik Lagoon', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 58.2687, 'longitude': -156.6484, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99579', 'place_name': 'Egegik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 58.2062, 'longitude': -157.3422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99606', 'place_name': 'Iliamna', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 59.7525, 'longitude': -154.8236, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99625', 'place_name': 'Levelock', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 59.2905, 'longitude': -156.6503, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99640', 'place_name': 'Nondalton', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 59.9736, 'longitude': -154.8458, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99647', 'place_name': 'Pedro Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 59.8681, 'longitude': -154.0757, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99648', 'place_name': 'Perryville', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 55.9453, 'longitude': -159.2593, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99649', 'place_name': 'Pilot Point', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 57.5642, 'longitude': -157.5792, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99653', 'place_name': 'Port Alsworth', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Lake and Peninsula', 'locality_code': '164', 'latitude': 60.2025, 'longitude': -154.3128, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99623', 'place_name': 'Wasilla', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.5463, 'longitude': -149.5901, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99629', 'place_name': 'Wasilla', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.5841, 'longitude': -149.4436, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99645', 'place_name': 'Palmer', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.6303, 'longitude': -148.9872, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99652', 'place_name': 'Big Lake', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.5214, 'longitude': -149.9544, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99654', 'place_name': 'Wasilla', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.5923, 'longitude': -149.3959, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99667', 'place_name': 'Skwentna', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.9903, 'longitude': -151.3978, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99674', 'place_name': 'Sutton', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.7327, 'longitude': -148.7837, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99676', 'place_name': 'Talkeetna', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 62.2605, 'longitude': -150.1101, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99683', 'place_name': 'Trapper Creek', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 62.3167, 'longitude': -150.2314, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99687', 'place_name': 'Wasilla', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.5313, 'longitude': -149.4784, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99688', 'place_name': 'Willow', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.8966, 'longitude': -150.0038, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99694', 'place_name': 'Houston', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Matanuska-Susitna Borough', 'locality_code': '170', 'latitude': 61.6303, 'longitude': -149.8181, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99659', 'place_name': 'Saint Michael', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 63.4776, 'longitude': -162.1091, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99671', 'place_name': 'Stebbins', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 63.5222, 'longitude': -162.2881, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99684', 'place_name': 'Unalakleet', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 63.8835, 'longitude': -160.7884, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99739', 'place_name': 'Elim', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 64.6217, 'longitude': -162.2604, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99742', 'place_name': 'Gambell', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 63.7766, 'longitude': -171.7017, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99753', 'place_name': 'Koyuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 64.9319, 'longitude': -161.1569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99762', 'place_name': 'Nome', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 64.5011, 'longitude': -165.4064, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99769', 'place_name': 'Savoonga', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 63.6797, 'longitude': -170.4709, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99771', 'place_name': 'Shaktoolik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 64.3537, 'longitude': -161.1932, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99772', 'place_name': 'Shishmaref', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 66.2306, 'longitude': -166.1373, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99778', 'place_name': 'Teller', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 65.2402, 'longitude': -166.3833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99783', 'place_name': 'Wales', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 65.6092, 'longitude': -168.0875, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99784', 'place_name': 'White Mountain', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 64.6814, 'longitude': -163.4056, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99785', 'place_name': 'Brevig Mission', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Nome (CA)', 'locality_code': '180', 'latitude': 65.3342, 'longitude': -166.4786, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99721', 'place_name': 'Anaktuvuk Pass', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 68.1433, 'longitude': -151.7358, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99723', 'place_name': 'Barrow', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 71.2346, 'longitude': -156.8174, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99734', 'place_name': 'Prudhoe Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 70.2922, 'longitude': -148.6694, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99747', 'place_name': 'Kaktovik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 70.1319, 'longitude': -143.6239, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99759', 'place_name': 'Point Lay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 69.7439, 'longitude': -163.0084, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99766', 'place_name': 'Point Hope', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 68.3486, 'longitude': -166.7347, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99782', 'place_name': 'Wainwright', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 70.6369, 'longitude': -160.0383, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99789', 'place_name': 'Nuiqsut', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 70.1927, 'longitude': -150.9971, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99791', 'place_name': 'Atqasuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'North Slope', 'locality_code': '185', 'latitude': 70.4947, 'longitude': -157.4411, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99727', 'place_name': 'Buckland', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 65.9789, 'longitude': -161.1262, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99736', 'place_name': 'Deering', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 66.0737, 'longitude': -162.714, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99749', 'place_name': 'Kiana', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 66.975, 'longitude': -160.4228, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99750', 'place_name': 'Kivalina', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 67.7269, 'longitude': -164.5333, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99751', 'place_name': 'Kobuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 66.9072, 'longitude': -156.8811, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99752', 'place_name': 'Kotzebue', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 66.8985, 'longitude': -162.5981, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99761', 'place_name': 'Noatak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 67.5711, 'longitude': -162.9653, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99763', 'place_name': 'Noorvik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 66.8364, 'longitude': -161.0441, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99770', 'place_name': 'Selawik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 66.6039, 'longitude': -160.0069, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99773', 'place_name': 'Shungnak', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 66.8881, 'longitude': -157.1364, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99786', 'place_name': 'Ambler', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Northwest Arctic', 'locality_code': '188', 'latitude': 67.0861, 'longitude': -157.8514, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99903', 'place_name': 'Meyers Chuck', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.7408, 'longitude': -132.2564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99918', 'place_name': 'Coffman Cove', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.9524, 'longitude': -132.7503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99919', 'place_name': 'Thorne Bay', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.6609, 'longitude': -132.5138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99921', 'place_name': 'Craig', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.4732, 'longitude': -133.1171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99922', 'place_name': 'Hydaburg', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.2087, 'longitude': -132.8259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99923', 'place_name': 'Hyder', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.9169, 'longitude': -130.0247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99925', 'place_name': 'Klawock', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.5526, 'longitude': -133.0555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99926', 'place_name': 'Metlakatla', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 55.1215, 'longitude': -131.579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99927', 'place_name': 'Point Baker', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Prince of Wales-Hyder', 'locality_code': '198', 'latitude': 56.3528, 'longitude': -133.6211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99835', 'place_name': 'Sitka', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Sitka City and Borough', 'locality_code': '220', 'latitude': 57.0514, 'longitude': -135.3166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99689', 'place_name': 'Yakutat', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 59.812, 'longitude': -139.5505, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99820', 'place_name': 'Angoon', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 57.5005, 'longitude': -134.586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99825', 'place_name': 'Elfin Cove', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 58.1944, 'longitude': -136.3433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99826', 'place_name': 'Gustavus', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 58.4284, 'longitude': -135.7615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99829', 'place_name': 'Hoonah', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 58.0977, 'longitude': -135.4316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99832', 'place_name': 'Pelican', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 57.9608, 'longitude': -136.2275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99840', 'place_name': 'Skagway', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 59.4685, 'longitude': -135.3018, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99841', 'place_name': 'Tenakee Springs', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Skagway-Hoonah-Angoon', 'locality_code': '232', 'latitude': 57.7808, 'longitude': -135.2189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99731', 'place_name': 'Fort Greely', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Southeast Fairbanks Census Area', 'locality_code': '240', 'latitude': 63.952, 'longitude': -146.451, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99732', 'place_name': 'Chicken', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Southeast Fairbanks Census Area', 'locality_code': '240', 'latitude': 64.0733, 'longitude': -141.9361, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99737', 'place_name': 'Delta Junction', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Southeast Fairbanks Census Area', 'locality_code': '240', 'latitude': 64.0378, 'longitude': -145.7322, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99738', 'place_name': 'Eagle', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Southeast Fairbanks Census Area', 'locality_code': '240', 'latitude': 64.7881, 'longitude': -141.2, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99764', 'place_name': 'Northway', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Southeast Fairbanks Census Area', 'locality_code': '240', 'latitude': 62.9617, 'longitude': -141.9372, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99776', 'place_name': 'Tanacross', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Southeast Fairbanks Census Area', 'locality_code': '240', 'latitude': 63.3853, 'longitude': -143.3464, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99780', 'place_name': 'Tok', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Southeast Fairbanks Census Area', 'locality_code': '240', 'latitude': 63.3367, 'longitude': -142.9856, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99566', 'place_name': 'Chitina', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 61.5156, 'longitude': -144.4396, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99573', 'place_name': 'Copper Center', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 61.977, 'longitude': -145.3297, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99574', 'place_name': 'Cordova', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 60.5362, 'longitude': -145.7534, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99586', 'place_name': 'Gakona', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 62.3014, 'longitude': -145.3027, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99588', 'place_name': 'Glennallen', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 62.1039, 'longitude': -145.6617, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99677', 'place_name': 'Tatitlek', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 60.8906, 'longitude': -146.6703, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99686', 'place_name': 'Valdez', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 61.101, 'longitude': -146.9, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99693', 'place_name': 'Whittier', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Valdez-Cordova (CA)', 'locality_code': '261', 'latitude': 60.7734, 'longitude': -148.6839, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99830', 'place_name': 'Kake', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Wrangell-Petersburg (C', 'locality_code': '280', 'latitude': 56.9736, 'longitude': -133.936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99833', 'place_name': 'Petersburg', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Wrangell-Petersburg (C', 'locality_code': '280', 'latitude': 56.8271, 'longitude': -133.1607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99836', 'place_name': 'Port Alexander', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Wrangell-Petersburg (C', 'locality_code': '280', 'latitude': 56.2497, 'longitude': -134.6444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99929', 'place_name': 'Wrangell', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Wrangell-Petersburg (C', 'locality_code': '280', 'latitude': 56.4335, 'longitude': -132.3529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99558', 'place_name': 'Anvik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 62.6561, 'longitude': -160.2067, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99590', 'place_name': 'Grayling', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 62.9036, 'longitude': -160.0647, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99602', 'place_name': 'Holy Cross', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 62.1926, 'longitude': -159.8251, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99627', 'place_name': 'Mc Grath', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 62.9457, 'longitude': -155.5712, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99665', 'place_name': 'Shageluk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 62.6822, 'longitude': -159.5619, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99675', 'place_name': 'Takotna', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 62.9886, 'longitude': -156.0642, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99691', 'place_name': 'Nikolai', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 63.0133, 'longitude': -154.375, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99720', 'place_name': 'Allakaket', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 66.5656, 'longitude': -152.6456, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99722', 'place_name': 'Arctic Village', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 68.1269, 'longitude': -145.5378, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99724', 'place_name': 'Beaver', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 66.3594, 'longitude': -147.3964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99726', 'place_name': 'Bettles Field', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.2264, 'longitude': -151.0251, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99730', 'place_name': 'Central', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.4681, 'longitude': -144.7489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99733', 'place_name': 'Circle', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.8245, 'longitude': -144.0826, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99740', 'place_name': 'Fort Yukon', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 66.5647, 'longitude': -145.2739, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99741', 'place_name': 'Galena', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 64.7333, 'longitude': -156.9275, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99745', 'place_name': 'Hughes', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 66.0382, 'longitude': -154.2644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99746', 'place_name': 'Huslia', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.6899, 'longitude': -156.292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99748', 'place_name': 'Kaltag', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 64.3305, 'longitude': -158.7243, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99754', 'place_name': 'Koyukuk', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 64.8803, 'longitude': -157.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99756', 'place_name': 'Manley Hot Springs', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.0011, 'longitude': -150.6339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99757', 'place_name': 'Lake Minchumina', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 63.8828, 'longitude': -152.3122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99758', 'place_name': 'Minto', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.0584, 'longitude': -149.6912, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99760', 'place_name': 'Nenana', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 64.5577, 'longitude': -149.0867, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99765', 'place_name': 'Nulato', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 64.7194, 'longitude': -158.1031, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99767', 'place_name': 'Rampart', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.509, 'longitude': -150.1619, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99768', 'place_name': 'Ruby', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 64.7201, 'longitude': -155.5039, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99774', 'place_name': 'Stevens Village', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 66.0064, 'longitude': -149.0908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99777', 'place_name': 'Tanana', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 65.1719, 'longitude': -152.0789, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99781', 'place_name': 'Venetie', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 67.0104, 'longitude': -146.4137, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99788', 'place_name': 'Chalkyitsik', 'state': 'Alaska', 'state_ab': 'AK', 'county': 'Yukon-Koyukuk (CA)', 'locality_code': '290', 'latitude': 66.6544, 'longitude': -143.7222, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36003', 'place_name': 'Autaugaville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.4625, 'longitude': -86.7149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36006', 'place_name': 'Billingsley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.6596, 'longitude': -86.7178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36008', 'place_name': 'Booth', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.5016, 'longitude': -86.5727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36051', 'place_name': 'Marbury', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.6841, 'longitude': -86.4946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36066', 'place_name': 'Prattville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.4787, 'longitude': -86.43, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36067', 'place_name': 'Prattville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.4715, 'longitude': -86.4831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36068', 'place_name': 'Prattville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.464, 'longitude': -86.4597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36749', 'place_name': 'Jones', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Autauga', 'locality_code': '1', 'latitude': 32.5104, 'longitude': -86.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36507', 'place_name': 'Bay Minette', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.8635, 'longitude': -87.7644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36511', 'place_name': 'Bon Secour', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.3128, 'longitude': -87.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36526', 'place_name': 'Daphne', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.6197, 'longitude': -87.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36527', 'place_name': 'Spanish Fort', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.6959, 'longitude': -87.8867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36530', 'place_name': 'Elberta', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.3942, 'longitude': -87.589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36532', 'place_name': 'Fairhope', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.5012, 'longitude': -87.8835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36533', 'place_name': 'Fairhope', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.4841, 'longitude': -87.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36535', 'place_name': 'Foley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.4007, 'longitude': -87.6857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36536', 'place_name': 'Foley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.4222, 'longitude': -87.7064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36542', 'place_name': 'Gulf Shores', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.2717, 'longitude': -87.7589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36547', 'place_name': 'Gulf Shores', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.246, 'longitude': -87.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36549', 'place_name': 'Lillian', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.3972, 'longitude': -87.4745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36550', 'place_name': 'Little River', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 31.2246, 'longitude': -87.7548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36551', 'place_name': 'Loxley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.618, 'longitude': -87.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36555', 'place_name': 'Magnolia Springs', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.3996, 'longitude': -87.7761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36559', 'place_name': 'Montrose', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.5623, 'longitude': -87.9005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36561', 'place_name': 'Orange Beach', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.281, 'longitude': -87.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36562', 'place_name': 'Perdido', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 31.0403, 'longitude': -87.6667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36564', 'place_name': 'Point Clear', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.4741, 'longitude': -87.9192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36567', 'place_name': 'Robertsdale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.5616, 'longitude': -87.6373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36574', 'place_name': 'Seminole', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.5048, 'longitude': -87.4659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36576', 'place_name': 'Silverhill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.5222, 'longitude': -87.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36577', 'place_name': 'Spanish Fort', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.6749, 'longitude': -87.9153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36578', 'place_name': 'Stapleton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.7476, 'longitude': -87.7787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36579', 'place_name': 'Stockton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 31.0129, 'longitude': -87.8633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36580', 'place_name': 'Summerdale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Baldwin', 'locality_code': '3', 'latitude': 30.4752, 'longitude': -87.6992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36016', 'place_name': 'Clayton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Barbour', 'locality_code': '5', 'latitude': 31.8874, 'longitude': -85.4509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36017', 'place_name': 'Clio', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Barbour', 'locality_code': '5', 'latitude': 31.6852, 'longitude': -85.5904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36027', 'place_name': 'Eufaula', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Barbour', 'locality_code': '5', 'latitude': 31.9051, 'longitude': -85.1656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36048', 'place_name': 'Louisville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Barbour', 'locality_code': '5', 'latitude': 31.7943, 'longitude': -85.5581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36072', 'place_name': 'Eufaula', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Barbour', 'locality_code': '5', 'latitude': 31.8913, 'longitude': -85.1455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35034', 'place_name': 'Brent', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 32.9357, 'longitude': -87.2114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35035', 'place_name': 'Brierfield', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 33.0427, 'longitude': -86.9517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35042', 'place_name': 'Centreville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 32.9503, 'longitude': -87.1192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35074', 'place_name': 'Green Pond', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 33.2251, 'longitude': -87.1264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35184', 'place_name': 'West Blocton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 33.1424, 'longitude': -87.1369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35188', 'place_name': 'Woodstock', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 33.2068, 'longitude': -87.15, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36792', 'place_name': 'Randolph', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 32.8888, 'longitude': -86.907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36793', 'place_name': 'Lawley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bibb', 'locality_code': '7', 'latitude': 32.8646, 'longitude': -86.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35013', 'place_name': 'Allgood', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Blount', 'locality_code': '9', 'latitude': 33.9222, 'longitude': -86.4493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35031', 'place_name': 'Blountsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Blount', 'locality_code': '9', 'latitude': 34.0929, 'longitude': -86.5686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35049', 'place_name': 'Cleveland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Blount', 'locality_code': '9', 'latitude': 33.9778, 'longitude': -86.5598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35079', 'place_name': 'Hayden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Blount', 'locality_code': '9', 'latitude': 33.9534, 'longitude': -86.7455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35097', 'place_name': 'Locust Fork', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Blount', 'locality_code': '9', 'latitude': 33.905, 'longitude': -86.6261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35121', 'place_name': 'Oneonta', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Blount', 'locality_code': '9', 'latitude': 33.9259, 'longitude': -86.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35133', 'place_name': 'Remlap', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Blount', 'locality_code': '9', 'latitude': 33.8168, 'longitude': -86.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36029', 'place_name': 'Fitzpatrick', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bullock', 'locality_code': '11', 'latitude': 32.2165, 'longitude': -85.8888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36053', 'place_name': 'Midway', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bullock', 'locality_code': '11', 'latitude': 32.0955, 'longitude': -85.5315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36061', 'place_name': 'Perote', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bullock', 'locality_code': '11', 'latitude': 32.0928, 'longitude': -85.7046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36089', 'place_name': 'Union Springs', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Bullock', 'locality_code': '11', 'latitude': 32.1443, 'longitude': -85.7149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36015', 'place_name': 'Chapman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Butler', 'locality_code': '13', 'latitude': 31.6427, 'longitude': -86.7343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36030', 'place_name': 'Forest Home', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Butler', 'locality_code': '13', 'latitude': 31.8501, 'longitude': -86.8372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36033', 'place_name': 'Georgiana', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Butler', 'locality_code': '13', 'latitude': 31.6287, 'longitude': -86.734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36037', 'place_name': 'Greenville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Butler', 'locality_code': '13', 'latitude': 31.81, 'longitude': -86.6229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36456', 'place_name': 'Mc Kenzie', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Butler', 'locality_code': '13', 'latitude': 31.545, 'longitude': -86.7356, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36201', 'place_name': 'Anniston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.6539, 'longitude': -85.8382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36202', 'place_name': 'Anniston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7622, 'longitude': -85.8378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36203', 'place_name': 'Oxford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.5815, 'longitude': -85.8328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36204', 'place_name': 'Anniston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7622, 'longitude': -85.8378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36205', 'place_name': 'Anniston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7358, 'longitude': -85.7933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36206', 'place_name': 'Anniston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7191, 'longitude': -85.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36207', 'place_name': 'Anniston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.6803, 'longitude': -85.7137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36250', 'place_name': 'Alexandria', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7808, 'longitude': -85.8924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36253', 'place_name': 'Bynum', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7622, 'longitude': -85.8378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36254', 'place_name': 'Choccolocco', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.6573, 'longitude': -85.6991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36257', 'place_name': 'De Armanville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7622, 'longitude': -85.8378, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36260', 'place_name': 'Eastaboga', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.6031, 'longitude': -85.9608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36265', 'place_name': 'Jacksonville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.831, 'longitude': -85.7752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36271', 'place_name': 'Ohatchee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7788, 'longitude': -86.0254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36272', 'place_name': 'Piedmont', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.8389, 'longitude': -85.646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36277', 'place_name': 'Weaver', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.7563, 'longitude': -85.8107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36279', 'place_name': 'Wellington', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Calhoun', 'locality_code': '15', 'latitude': 33.8226, 'longitude': -85.8927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36852', 'place_name': 'Cusseta', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chambers', 'locality_code': '17', 'latitude': 32.7831, 'longitude': -85.2756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36854', 'place_name': 'Valley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chambers', 'locality_code': '17', 'latitude': 32.8113, 'longitude': -85.1749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36855', 'place_name': 'Five Points', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chambers', 'locality_code': '17', 'latitude': 33.0424, 'longitude': -85.3243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36862', 'place_name': 'Lafayette', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chambers', 'locality_code': '17', 'latitude': 32.9252, 'longitude': -85.4426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36863', 'place_name': 'Lanett', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chambers', 'locality_code': '17', 'latitude': 32.8616, 'longitude': -85.2161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35959', 'place_name': 'Cedar Bluff', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cherokee', 'locality_code': '19', 'latitude': 34.2417, 'longitude': -85.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35960', 'place_name': 'Centre', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cherokee', 'locality_code': '19', 'latitude': 34.1116, 'longitude': -85.6092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35973', 'place_name': 'Gaylesville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cherokee', 'locality_code': '19', 'latitude': 34.3573, 'longitude': -85.5589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35983', 'place_name': 'Leesburg', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cherokee', 'locality_code': '19', 'latitude': 34.1911, 'longitude': -85.7705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36275', 'place_name': 'Spring Garden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cherokee', 'locality_code': '19', 'latitude': 33.9778, 'longitude': -85.5521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35045', 'place_name': 'Clanton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chilton', 'locality_code': '21', 'latitude': 32.8355, 'longitude': -86.6425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35046', 'place_name': 'Clanton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chilton', 'locality_code': '21', 'latitude': 32.9229, 'longitude': -86.545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35085', 'place_name': 'Jemison', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chilton', 'locality_code': '21', 'latitude': 32.9805, 'longitude': -86.7181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35171', 'place_name': 'Thorsby', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chilton', 'locality_code': '21', 'latitude': 32.9157, 'longitude': -86.7158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36091', 'place_name': 'Verbena', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chilton', 'locality_code': '21', 'latitude': 32.7499, 'longitude': -86.5114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36750', 'place_name': 'Maplesville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chilton', 'locality_code': '21', 'latitude': 32.8045, 'longitude': -86.8717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36790', 'place_name': 'Stanton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Chilton', 'locality_code': '21', 'latitude': 32.7332, 'longitude': -86.8963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36904', 'place_name': 'Butler', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 32.0829, 'longitude': -88.2064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36908', 'place_name': 'Gilbertown', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 31.8666, 'longitude': -88.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36910', 'place_name': 'Jachin', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 32.2299, 'longitude': -88.1684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36912', 'place_name': 'Lisman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 32.2177, 'longitude': -88.3234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36913', 'place_name': 'Melvin', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 31.9304, 'longitude': -88.4589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36915', 'place_name': 'Needham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 31.9879, 'longitude': -88.3367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36916', 'place_name': 'Pennington', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 32.2094, 'longitude': -88.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36919', 'place_name': 'Silas', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 31.7668, 'longitude': -88.3091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36921', 'place_name': 'Toxey', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 31.9155, 'longitude': -88.151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36922', 'place_name': 'Ward', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 32.3038, 'longitude': -88.1476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36436', 'place_name': 'Dickinson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.7635, 'longitude': -87.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36446', 'place_name': 'Fulton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.7925, 'longitude': -87.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36451', 'place_name': 'Grove Hill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.7088, 'longitude': -87.7772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36482', 'place_name': 'Whatley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.6395, 'longitude': -87.6565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36524', 'place_name': 'Coffeeville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.7843, 'longitude': -88.0715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36540', 'place_name': 'Gainestown', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.4258, 'longitude': -87.6822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36545', 'place_name': 'Jackson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.5131, 'longitude': -87.8672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36727', 'place_name': 'Campbell', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.9213, 'longitude': -88.008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36784', 'place_name': 'Thomasville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clarke', 'locality_code': '25', 'latitude': 31.9067, 'longitude': -87.7598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35082', 'place_name': 'Hollins', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clay', 'locality_code': '27', 'latitude': 33.1162, 'longitude': -86.1386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36251', 'place_name': 'Ashland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clay', 'locality_code': '27', 'latitude': 33.2474, 'longitude': -85.829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36255', 'place_name': 'Cragford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clay', 'locality_code': '27', 'latitude': 33.2171, 'longitude': -85.7108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36258', 'place_name': 'Delta', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clay', 'locality_code': '27', 'latitude': 33.4573, 'longitude': -85.6793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36266', 'place_name': 'Lineville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clay', 'locality_code': '27', 'latitude': 33.3286, 'longitude': -85.7346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36267', 'place_name': 'Millerville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Clay', 'locality_code': '27', 'latitude': 33.1915, 'longitude': -85.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36261', 'place_name': 'Edwardsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cleburne', 'locality_code': '29', 'latitude': 33.7066, 'longitude': -85.5099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36262', 'place_name': 'Fruithurst', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cleburne', 'locality_code': '29', 'latitude': 33.7717, 'longitude': -85.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36264', 'place_name': 'Heflin', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cleburne', 'locality_code': '29', 'latitude': 33.6115, 'longitude': -85.5885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36269', 'place_name': 'Muscadine', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cleburne', 'locality_code': '29', 'latitude': 33.7529, 'longitude': -85.3789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36273', 'place_name': 'Ranburne', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cleburne', 'locality_code': '29', 'latitude': 33.5616, 'longitude': -85.3786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36323', 'place_name': 'Elba', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coffee', 'locality_code': '31', 'latitude': 31.4137, 'longitude': -86.0777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36330', 'place_name': 'Enterprise', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coffee', 'locality_code': '31', 'latitude': 31.3408, 'longitude': -85.8421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36331', 'place_name': 'Enterprise', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coffee', 'locality_code': '31', 'latitude': 31.2978, 'longitude': -85.9036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36346', 'place_name': 'Jack', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coffee', 'locality_code': '31', 'latitude': 31.5652, 'longitude': -85.971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36351', 'place_name': 'New Brockton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coffee', 'locality_code': '31', 'latitude': 31.369, 'longitude': -85.9404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36453', 'place_name': 'Kinston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coffee', 'locality_code': '31', 'latitude': 31.1926, 'longitude': -86.1514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35616', 'place_name': 'Cherokee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Colbert', 'locality_code': '33', 'latitude': 34.7442, 'longitude': -87.9724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35646', 'place_name': 'Leighton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Colbert', 'locality_code': '33', 'latitude': 34.711, 'longitude': -87.5221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35660', 'place_name': 'Sheffield', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Colbert', 'locality_code': '33', 'latitude': 34.7578, 'longitude': -87.6971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35661', 'place_name': 'Muscle Shoals', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Colbert', 'locality_code': '33', 'latitude': 34.7561, 'longitude': -87.6304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35662', 'place_name': 'Muscle Shoals', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Colbert', 'locality_code': '33', 'latitude': 34.7448, 'longitude': -87.6675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35674', 'place_name': 'Tuscumbia', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Colbert', 'locality_code': '33', 'latitude': 34.6874, 'longitude': -87.6833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36401', 'place_name': 'Evergreen', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Conecuh', 'locality_code': '35', 'latitude': 31.458, 'longitude': -86.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36429', 'place_name': 'Brooklyn', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Conecuh', 'locality_code': '35', 'latitude': 31.2627, 'longitude': -86.7711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36432', 'place_name': 'Castleberry', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Conecuh', 'locality_code': '35', 'latitude': 31.2991, 'longitude': -87.0225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36454', 'place_name': 'Lenox', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Conecuh', 'locality_code': '35', 'latitude': 31.3366, 'longitude': -87.1855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36473', 'place_name': 'Range', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Conecuh', 'locality_code': '35', 'latitude': 31.3058, 'longitude': -87.2137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36475', 'place_name': 'Repton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Conecuh', 'locality_code': '35', 'latitude': 31.4256, 'longitude': -87.172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35072', 'place_name': 'Goodwater', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coosa', 'locality_code': '37', 'latitude': 33.0746, 'longitude': -86.0781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35089', 'place_name': 'Kellyton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coosa', 'locality_code': '37', 'latitude': 32.9791, 'longitude': -86.0484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35136', 'place_name': 'Rockford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coosa', 'locality_code': '37', 'latitude': 32.878, 'longitude': -86.24, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35183', 'place_name': 'Weogufka', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coosa', 'locality_code': '37', 'latitude': 33.0238, 'longitude': -86.3042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36026', 'place_name': 'Equality', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Coosa', 'locality_code': '37', 'latitude': 32.8139, 'longitude': -86.1051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36038', 'place_name': 'Gantt', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.4068, 'longitude': -86.4841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36420', 'place_name': 'Andalusia', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.2971, 'longitude': -86.4905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36442', 'place_name': 'Florala', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.0172, 'longitude': -86.3385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36455', 'place_name': 'Lockhart', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.0105, 'longitude': -86.3497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36467', 'place_name': 'Opp', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.2799, 'longitude': -86.2571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36474', 'place_name': 'Red Level', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.4399, 'longitude': -86.6121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36476', 'place_name': 'River Falls', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.3533, 'longitude': -86.541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36483', 'place_name': 'Wing', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Covington', 'locality_code': '39', 'latitude': 31.0223, 'longitude': -86.6293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36009', 'place_name': 'Brantley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.571, 'longitude': -86.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36028', 'place_name': 'Dozier', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.5066, 'longitude': -86.3663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36034', 'place_name': 'Glenwood', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.6641, 'longitude': -86.171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36041', 'place_name': 'Highland Home', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.9283, 'longitude': -86.2971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36042', 'place_name': 'Honoraville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.8784, 'longitude': -86.3981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36049', 'place_name': 'Luverne', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.7074, 'longitude': -86.2566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36062', 'place_name': 'Petrey', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.8488, 'longitude': -86.2077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36071', 'place_name': 'Rutledge', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Crenshaw', 'locality_code': '41', 'latitude': 31.7062, 'longitude': -86.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35019', 'place_name': 'Baileyton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.2683, 'longitude': -86.6213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35033', 'place_name': 'Bremen', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 33.9737, 'longitude': -87.0043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35053', 'place_name': 'Crane Hill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.0821, 'longitude': -87.0484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35055', 'place_name': 'Cullman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.1761, 'longitude': -86.8298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35056', 'place_name': 'Cullman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.1748, 'longitude': -86.8436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35057', 'place_name': 'Cullman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.0878, 'longitude': -86.9447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35058', 'place_name': 'Cullman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.2098, 'longitude': -86.752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35070', 'place_name': 'Garden City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.0058, 'longitude': -86.7499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35077', 'place_name': 'Hanceville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.0516, 'longitude': -86.7848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35083', 'place_name': 'Holly Pond', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.1901, 'longitude': -86.6174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35087', 'place_name': 'Joppa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.2837, 'longitude': -86.5519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35098', 'place_name': 'Logan', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.1377, 'longitude': -87.0266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35179', 'place_name': 'Vinemont', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Cullman', 'locality_code': '43', 'latitude': 34.2621, 'longitude': -86.9125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36311', 'place_name': 'Ariton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.583, 'longitude': -85.7077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36317', 'place_name': 'Clopton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.6446, 'longitude': -85.3911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36322', 'place_name': 'Daleville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.2811, 'longitude': -85.7305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36350', 'place_name': 'Midland City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.3191, 'longitude': -85.4938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36352', 'place_name': 'Newton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.3311, 'longitude': -85.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36360', 'place_name': 'Ozark', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.4391, 'longitude': -85.6436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36361', 'place_name': 'Ozark', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.4591, 'longitude': -85.6405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36362', 'place_name': 'Fort Rucker', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.348, 'longitude': -85.7214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36371', 'place_name': 'Pinckard', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.3074, 'longitude': -85.5263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36374', 'place_name': 'Skipperville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dale', 'locality_code': '45', 'latitude': 31.5748, 'longitude': -85.537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36701', 'place_name': 'Selma', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.4197, 'longitude': -87.0245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36702', 'place_name': 'Selma', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.4074, 'longitude': -87.0211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36703', 'place_name': 'Selma', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.4156, 'longitude': -87.0135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36758', 'place_name': 'Plantersville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.6176, 'longitude': -86.9475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36759', 'place_name': 'Marion Junction', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.4266, 'longitude': -87.2702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36761', 'place_name': 'Minter', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.1899, 'longitude': -87.0633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36767', 'place_name': 'Orrville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.2949, 'longitude': -87.2214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36773', 'place_name': 'Safford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.3002, 'longitude': -87.3693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36775', 'place_name': 'Sardis', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.2844, 'longitude': -86.992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36785', 'place_name': 'Tyler', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Dallas', 'locality_code': '47', 'latitude': 32.3239, 'longitude': -86.8646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35961', 'place_name': 'Collinsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.268, 'longitude': -85.862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35962', 'place_name': 'Crossville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.2588, 'longitude': -86.0306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35963', 'place_name': 'Dawson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.3568, 'longitude': -85.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35967', 'place_name': 'Fort Payne', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.4368, 'longitude': -85.7124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35968', 'place_name': 'Fort Payne', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.4898, 'longitude': -85.7657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35971', 'place_name': 'Fyffe', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.4373, 'longitude': -85.9288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35974', 'place_name': 'Geraldine', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.3592, 'longitude': -86.024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35975', 'place_name': 'Groveoak', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.4359, 'longitude': -86.04, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '35978', 'place_name': 'Henagar', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.6186, 'longitude': -85.7274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35981', 'place_name': 'Ider', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.7351, 'longitude': -85.6416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35984', 'place_name': 'Mentone', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.5872, 'longitude': -85.5777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35986', 'place_name': 'Rainsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.4989, 'longitude': -85.8446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35988', 'place_name': 'Sylvania', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.559, 'longitude': -85.7921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35989', 'place_name': 'Valley Head', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'DeKalb', 'locality_code': '49', 'latitude': 34.5697, 'longitude': -85.6272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36020', 'place_name': 'Coosada', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.5056, 'longitude': -86.3322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36022', 'place_name': 'Deatsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.6082, 'longitude': -86.3958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36024', 'place_name': 'Eclectic', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.6542, 'longitude': -86.0316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36025', 'place_name': 'Elmore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.5454, 'longitude': -86.3161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36045', 'place_name': 'Kent', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.619, 'longitude': -85.9486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36054', 'place_name': 'Millbrook', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.4995, 'longitude': -86.3641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36078', 'place_name': 'Tallassee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.551, 'longitude': -85.8978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36080', 'place_name': 'Titus', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.69, 'longitude': -86.2393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36092', 'place_name': 'Wetumpka', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.5927, 'longitude': -86.2153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36093', 'place_name': 'Wetumpka', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Elmore', 'locality_code': '51', 'latitude': 32.5622, 'longitude': -86.0994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36426', 'place_name': 'Brewton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Escambia', 'locality_code': '53', 'latitude': 31.1294, 'longitude': -87.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36427', 'place_name': 'Brewton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Escambia', 'locality_code': '53', 'latitude': 31.1052, 'longitude': -87.0722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36441', 'place_name': 'Flomaton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Escambia', 'locality_code': '53', 'latitude': 31.0402, 'longitude': -87.2664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36502', 'place_name': 'Atmore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Escambia', 'locality_code': '53', 'latitude': 31.0572, 'longitude': -87.4873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36503', 'place_name': 'Atmore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Escambia', 'locality_code': '53', 'latitude': 31.0238, 'longitude': -87.4939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36504', 'place_name': 'Atmore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Escambia', 'locality_code': '53', 'latitude': 31.0158, 'longitude': -87.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36543', 'place_name': 'Huxford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Escambia', 'locality_code': '53', 'latitude': 31.2202, 'longitude': -87.4619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35901', 'place_name': 'Gadsden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 34.048, 'longitude': -85.9246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35902', 'place_name': 'Gadsden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 34.0143, 'longitude': -86.0066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35903', 'place_name': 'Gadsden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 33.9845, 'longitude': -85.9077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35904', 'place_name': 'Gadsden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 34.0217, 'longitude': -86.0495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35905', 'place_name': 'Gadsden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 33.9352, 'longitude': -85.9576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35906', 'place_name': 'Rainbow City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 33.9318, 'longitude': -86.0898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35907', 'place_name': 'Gadsden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 33.8979, 'longitude': -86.0245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35952', 'place_name': 'Altoona', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 34.071, 'longitude': -86.2096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35954', 'place_name': 'Attalla', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 34.0296, 'longitude': -86.0967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35972', 'place_name': 'Gallant', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 33.9976, 'longitude': -86.2346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35990', 'place_name': 'Walnut Grove', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Etowah', 'locality_code': '55', 'latitude': 34.0657, 'longitude': -86.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35542', 'place_name': 'Bankston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Fayette', 'locality_code': '57', 'latitude': 33.7008, 'longitude': -87.6897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35545', 'place_name': 'Belk', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Fayette', 'locality_code': '57', 'latitude': 33.6476, 'longitude': -87.9314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35546', 'place_name': 'Berry', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Fayette', 'locality_code': '57', 'latitude': 33.6945, 'longitude': -87.6226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35555', 'place_name': 'Fayette', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Fayette', 'locality_code': '57', 'latitude': 33.6974, 'longitude': -87.8346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35559', 'place_name': 'Glen Allen', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Fayette', 'locality_code': '57', 'latitude': 33.9151, 'longitude': -87.7417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35571', 'place_name': 'Hodges', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Franklin', 'locality_code': '59', 'latitude': 34.3417, 'longitude': -87.959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35581', 'place_name': 'Phil Campbell', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Franklin', 'locality_code': '59', 'latitude': 34.347, 'longitude': -87.7154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35582', 'place_name': 'Red Bay', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Franklin', 'locality_code': '59', 'latitude': 34.4513, 'longitude': -88.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35585', 'place_name': 'Spruce Pine', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Franklin', 'locality_code': '59', 'latitude': 34.4246, 'longitude': -87.8145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35593', 'place_name': 'Vina', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Franklin', 'locality_code': '59', 'latitude': 34.3712, 'longitude': -88.0774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35653', 'place_name': 'Russellville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Franklin', 'locality_code': '59', 'latitude': 34.5066, 'longitude': -87.7257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35654', 'place_name': 'Russellville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Franklin', 'locality_code': '59', 'latitude': 34.4675, 'longitude': -87.6478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36313', 'place_name': 'Bellwood', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.1732, 'longitude': -85.7933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36314', 'place_name': 'Black', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.0132, 'longitude': -85.7456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36316', 'place_name': 'Chancellor', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.1767, 'longitude': -85.8135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36318', 'place_name': 'Coffee Springs', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.1388, 'longitude': -85.9182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36340', 'place_name': 'Geneva', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.0414, 'longitude': -85.8847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36344', 'place_name': 'Hartford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.086, 'longitude': -85.7192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36349', 'place_name': 'Malvern', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.1212, 'longitude': -85.5592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36375', 'place_name': 'Slocomb', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.0956, 'longitude': -85.583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36477', 'place_name': 'Samson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Geneva', 'locality_code': '61', 'latitude': 31.1049, 'longitude': -86.0674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35443', 'place_name': 'Boligee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Greene', 'locality_code': '63', 'latitude': 32.7746, 'longitude': -88.0267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35448', 'place_name': 'Clinton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Greene', 'locality_code': '63', 'latitude': 32.9137, 'longitude': -87.9925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35462', 'place_name': 'Eutaw', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Greene', 'locality_code': '63', 'latitude': 32.8889, 'longitude': -87.9303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35469', 'place_name': 'Knoxville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Greene', 'locality_code': '63', 'latitude': 32.9824, 'longitude': -87.7919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35491', 'place_name': 'West Greene', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Greene', 'locality_code': '63', 'latitude': 32.9237, 'longitude': -88.0853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36740', 'place_name': 'Forkland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Greene', 'locality_code': '63', 'latitude': 32.6108, 'longitude': -87.8441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35441', 'place_name': 'Akron', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Hale', 'locality_code': '65', 'latitude': 32.8553, 'longitude': -87.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35474', 'place_name': 'Moundville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Hale', 'locality_code': '65', 'latitude': 32.9108, 'longitude': -87.5935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36742', 'place_name': 'Gallion', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Hale', 'locality_code': '65', 'latitude': 32.5298, 'longitude': -87.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36744', 'place_name': 'Greensboro', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Hale', 'locality_code': '65', 'latitude': 32.7167, 'longitude': -87.5905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36765', 'place_name': 'Newbern', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Hale', 'locality_code': '65', 'latitude': 32.5515, 'longitude': -87.5615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36776', 'place_name': 'Sawyerville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Hale', 'locality_code': '65', 'latitude': 32.7578, 'longitude': -87.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36310', 'place_name': 'Abbeville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Henry', 'locality_code': '67', 'latitude': 31.5755, 'longitude': -85.279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36345', 'place_name': 'Headland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Henry', 'locality_code': '67', 'latitude': 31.3534, 'longitude': -85.3323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36353', 'place_name': 'Newville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Henry', 'locality_code': '67', 'latitude': 31.4403, 'longitude': -85.3287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36373', 'place_name': 'Shorterville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Henry', 'locality_code': '67', 'latitude': 31.501, 'longitude': -85.1135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36301', 'place_name': 'Dothan', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.1481, 'longitude': -85.3718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36302', 'place_name': 'Dothan', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.2232, 'longitude': -85.3905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36303', 'place_name': 'Dothan', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.2668, 'longitude': -85.3971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36304', 'place_name': 'Dothan', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.156, 'longitude': -85.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36305', 'place_name': 'Dothan', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.2197, 'longitude': -85.4828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36312', 'place_name': 'Ashford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.1888, 'longitude': -85.2535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36319', 'place_name': 'Columbia', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.3352, 'longitude': -85.1455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36320', 'place_name': 'Cottonwood', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.0507, 'longitude': -85.3154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36321', 'place_name': 'Cowarts', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.2025, 'longitude': -85.3014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36343', 'place_name': 'Gordon', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.1002, 'longitude': -85.1234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36370', 'place_name': 'Pansey', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.1403, 'longitude': -85.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36376', 'place_name': 'Webb', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Houston', 'locality_code': '69', 'latitude': 31.2656, 'longitude': -85.2544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35740', 'place_name': 'Bridgeport', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.9446, 'longitude': -85.7277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35744', 'place_name': 'Dutton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.6046, 'longitude': -85.9067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35745', 'place_name': 'Estillfork', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.913, 'longitude': -86.1716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35746', 'place_name': 'Fackler', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.8259, 'longitude': -85.9846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35751', 'place_name': 'Hollytree', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.7955, 'longitude': -86.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35752', 'place_name': 'Hollywood', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.7304, 'longitude': -85.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35755', 'place_name': 'Langston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.5001, 'longitude': -86.1353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35764', 'place_name': 'Paint Rock', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.7031, 'longitude': -86.3068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35765', 'place_name': 'Pisgah', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.6809, 'longitude': -85.8478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35766', 'place_name': 'Princeton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.8713, 'longitude': -86.2513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35768', 'place_name': 'Scottsboro', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.7507, 'longitude': -86.1422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35769', 'place_name': 'Scottsboro', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.618, 'longitude': -86.0562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35771', 'place_name': 'Section', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.5433, 'longitude': -85.994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35772', 'place_name': 'Stevenson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.8769, 'longitude': -85.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35774', 'place_name': 'Trenton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.7632, 'longitude': -86.2295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35776', 'place_name': 'Woodville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.6689, 'longitude': -86.2296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35958', 'place_name': 'Bryant', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.945, 'longitude': -85.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35966', 'place_name': 'Flat Rock', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.8076, 'longitude': -85.7084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35979', 'place_name': 'Higdon', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jackson', 'locality_code': '71', 'latitude': 34.8391, 'longitude': -85.6196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35005', 'place_name': 'Adamsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5884, 'longitude': -86.9597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35006', 'place_name': 'Adger', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4343, 'longitude': -87.1675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35015', 'place_name': 'Alton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5793, 'longitude': -86.6375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35020', 'place_name': 'Bessemer', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.409, 'longitude': -86.9475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35021', 'place_name': 'Bessemer', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35022', 'place_name': 'Bessemer', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.3224, 'longitude': -86.9657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35023', 'place_name': 'Bessemer', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.468, 'longitude': -87.0924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35036', 'place_name': 'Brookside', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.6379, 'longitude': -86.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35048', 'place_name': 'Clay', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.7026, 'longitude': -86.5997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35060', 'place_name': 'Docena', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5589, 'longitude': -86.9294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35061', 'place_name': 'Dolomite', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4654, 'longitude': -86.9564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35064', 'place_name': 'Fairfield', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4735, 'longitude': -86.9183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35068', 'place_name': 'Fultondale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.6017, 'longitude': -86.8265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35071', 'place_name': 'Gardendale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.7189, 'longitude': -86.8225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35073', 'place_name': 'Graysville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.6539, 'longitude': -86.9803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35091', 'place_name': 'Kimberly', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.7684, 'longitude': -86.8084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35094', 'place_name': 'Leeds', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5283, 'longitude': -86.5748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35111', 'place_name': 'Mc Calla', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.2845, 'longitude': -87.1024, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '35116', 'place_name': 'Morris', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.7392, 'longitude': -86.7726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35117', 'place_name': 'Mount Olive', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.6768, 'longitude': -86.8717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35118', 'place_name': 'Mulga', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5363, 'longitude': -87.051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35119', 'place_name': 'New Castle', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.649, 'longitude': -86.7686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35123', 'place_name': 'Palmerdale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.7387, 'longitude': -86.6461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35126', 'place_name': 'Pinson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.7299, 'longitude': -86.6451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35127', 'place_name': 'Pleasant Grove', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4883, 'longitude': -86.9766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35139', 'place_name': 'Sayre', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.7111, 'longitude': -86.9759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35142', 'place_name': 'Shannon', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4069, 'longitude': -86.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35172', 'place_name': 'Trafford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.819, 'longitude': -86.7434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35173', 'place_name': 'Trussville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.6339, 'longitude': -86.5981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35180', 'place_name': 'Warrior', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.8529, 'longitude': -86.8198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35181', 'place_name': 'Watson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35201', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35202', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35203', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.521, 'longitude': -86.8066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35204', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5179, 'longitude': -86.8372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35205', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4951, 'longitude': -86.8059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35206', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5678, 'longitude': -86.7199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35207', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5594, 'longitude': -86.8153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35208', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4977, 'longitude': -86.8799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35209', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4653, 'longitude': -86.8082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35210', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5452, 'longitude': -86.6655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35211', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4816, 'longitude': -86.859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35212', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5409, 'longitude': -86.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35213', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5066, 'longitude': -86.7428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35214', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5554, 'longitude': -86.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35215', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.6493, 'longitude': -86.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35216', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4188, 'longitude': -86.7867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35217', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5887, 'longitude': -86.765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35218', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.506, 'longitude': -86.893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35219', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35220', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35221', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4523, 'longitude': -86.8935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35222', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5219, 'longitude': -86.7666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35223', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4995, 'longitude': -86.7268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35224', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5191, 'longitude': -86.9342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35226', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.3967, 'longitude': -86.8346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35228', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4558, 'longitude': -86.9118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35229', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4629, 'longitude': -86.7904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35231', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35232', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35233', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5062, 'longitude': -86.8003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35234', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5378, 'longitude': -86.8068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35235', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.6328, 'longitude': -86.6493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35236', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35237', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35238', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35243', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4459, 'longitude': -86.7502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35244', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.3538, 'longitude': -86.8254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35246', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35249', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35253', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35254', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35255', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35259', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35260', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35261', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35266', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.3729, 'longitude': -86.8531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35270', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5206, 'longitude': -86.8025, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '35282', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35283', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35285', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35287', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35288', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.4458, 'longitude': -86.9285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35290', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35291', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35292', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35293', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35294', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35295', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5207, 'longitude': -86.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35296', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35297', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35298', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Jefferson', 'locality_code': '73', 'latitude': 33.5446, 'longitude': -86.9292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35544', 'place_name': 'Beaverton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lamar', 'locality_code': '75', 'latitude': 33.9429, 'longitude': -88.0157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35552', 'place_name': 'Detroit', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lamar', 'locality_code': '75', 'latitude': 34.0282, 'longitude': -88.17, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35574', 'place_name': 'Kennedy', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lamar', 'locality_code': '75', 'latitude': 33.6153, 'longitude': -87.9948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35576', 'place_name': 'Millport', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lamar', 'locality_code': '75', 'latitude': 33.5401, 'longitude': -88.2, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35586', 'place_name': 'Sulligent', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lamar', 'locality_code': '75', 'latitude': 33.8549, 'longitude': -88.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35592', 'place_name': 'Vernon', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lamar', 'locality_code': '75', 'latitude': 33.7613, 'longitude': -88.0979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35610', 'place_name': 'Anderson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.9424, 'longitude': -87.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35617', 'place_name': 'Cloverdale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.9387, 'longitude': -87.7714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35630', 'place_name': 'Florence', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.8305, 'longitude': -87.656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35631', 'place_name': 'Florence', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.87, 'longitude': -87.7069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35632', 'place_name': 'Florence', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.87, 'longitude': -87.7069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35633', 'place_name': 'Florence', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.8825, 'longitude': -87.7398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35634', 'place_name': 'Florence', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.9186, 'longitude': -87.6136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35645', 'place_name': 'Killen', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.9016, 'longitude': -87.5082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35648', 'place_name': 'Lexington', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.9559, 'longitude': -87.3935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35652', 'place_name': 'Rogersville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.8495, 'longitude': -87.3237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35677', 'place_name': 'Waterloo', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lauderdale', 'locality_code': '77', 'latitude': 34.9357, 'longitude': -87.9624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35618', 'place_name': 'Courtland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lawrence', 'locality_code': '79', 'latitude': 34.6719, 'longitude': -87.3143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35643', 'place_name': 'Hillsboro', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lawrence', 'locality_code': '79', 'latitude': 34.6476, 'longitude': -87.1804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35650', 'place_name': 'Moulton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lawrence', 'locality_code': '79', 'latitude': 34.5058, 'longitude': -87.2224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35651', 'place_name': 'Mount Hope', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lawrence', 'locality_code': '79', 'latitude': 34.4793, 'longitude': -87.4769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35672', 'place_name': 'Town Creek', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lawrence', 'locality_code': '79', 'latitude': 34.6491, 'longitude': -87.4262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36801', 'place_name': 'Opelika', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.6454, 'longitude': -85.3783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36802', 'place_name': 'Opelika', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.5782, 'longitude': -85.349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36803', 'place_name': 'Opelika', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.6454, 'longitude': -85.3783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36804', 'place_name': 'Opelika', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.5768, 'longitude': -85.312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36830', 'place_name': 'Auburn', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.5475, 'longitude': -85.4682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36831', 'place_name': 'Auburn', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.6099, 'longitude': -85.4808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36832', 'place_name': 'Auburn', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.592, 'longitude': -85.5189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36849', 'place_name': 'Auburn University', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.6024, 'longitude': -85.4873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36865', 'place_name': 'Loachapoka', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.6043, 'longitude': -85.5933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36872', 'place_name': 'Valley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.5782, 'longitude': -85.349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36874', 'place_name': 'Salem', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.6212, 'longitude': -85.184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36877', 'place_name': 'Smiths Station', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.5401, 'longitude': -85.0985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36879', 'place_name': 'Waverly', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lee', 'locality_code': '81', 'latitude': 32.7632, 'longitude': -85.5144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35611', 'place_name': 'Athens', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.8036, 'longitude': -86.9707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35612', 'place_name': 'Athens', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.7749, 'longitude': -87.0305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35613', 'place_name': 'Athens', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.8317, 'longitude': -86.8867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35614', 'place_name': 'Athens', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.8474, 'longitude': -87.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35615', 'place_name': 'Belle Mina', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.6568, 'longitude': -86.8792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35620', 'place_name': 'Elkmont', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.929, 'longitude': -86.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35647', 'place_name': 'Lester', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.9596, 'longitude': -87.1006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35649', 'place_name': 'Mooresville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.6259, 'longitude': -86.8746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35671', 'place_name': 'Tanner', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.6796, 'longitude': -86.9625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35739', 'place_name': 'Ardmore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.9804, 'longitude': -86.8346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35742', 'place_name': 'Capshaw', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Limestone', 'locality_code': '83', 'latitude': 34.7731, 'longitude': -86.7928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36032', 'place_name': 'Fort Deposit', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lowndes', 'locality_code': '85', 'latitude': 31.996, 'longitude': -86.5761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36040', 'place_name': 'Hayneville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lowndes', 'locality_code': '85', 'latitude': 32.1957, 'longitude': -86.655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36047', 'place_name': 'Letohatchee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lowndes', 'locality_code': '85', 'latitude': 32.0862, 'longitude': -86.488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36752', 'place_name': 'Lowndesboro', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Lowndes', 'locality_code': '85', 'latitude': 32.2943, 'longitude': -86.6471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36031', 'place_name': 'Fort Davis', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Macon', 'locality_code': '87', 'latitude': 32.2507, 'longitude': -85.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36039', 'place_name': 'Hardaway', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Macon', 'locality_code': '87', 'latitude': 32.3129, 'longitude': -85.8838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36075', 'place_name': 'Shorter', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Macon', 'locality_code': '87', 'latitude': 32.3836, 'longitude': -85.9162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36083', 'place_name': 'Tuskegee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Macon', 'locality_code': '87', 'latitude': 32.4316, 'longitude': -85.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36087', 'place_name': 'Tuskegee Institute', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Macon', 'locality_code': '87', 'latitude': 32.4093, 'longitude': -85.738, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36088', 'place_name': 'Tuskegee Institute', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Macon', 'locality_code': '87', 'latitude': 32.4145, 'longitude': -85.7253, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36866', 'place_name': 'Notasulga', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Macon', 'locality_code': '87', 'latitude': 32.5437, 'longitude': -85.6871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35741', 'place_name': 'Brownsboro', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7167, 'longitude': -86.4687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35748', 'place_name': 'Gurley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.714, 'longitude': -86.394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35749', 'place_name': 'Harvest', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.8273, 'longitude': -86.7499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35750', 'place_name': 'Hazel Green', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.9496, 'longitude': -86.5935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35756', 'place_name': 'Madison', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.643, 'longitude': -86.8168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35757', 'place_name': 'Madison', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7782, 'longitude': -86.7442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35758', 'place_name': 'Madison', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7108, 'longitude': -86.7425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35759', 'place_name': 'Meridianville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.8618, 'longitude': -86.5789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35760', 'place_name': 'New Hope', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.5494, 'longitude': -86.3961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35761', 'place_name': 'New Market', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.9, 'longitude': -86.4487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35762', 'place_name': 'Normal', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.789, 'longitude': -86.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35763', 'place_name': 'Owens Cross Roads', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.6215, 'longitude': -86.4644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35767', 'place_name': 'Ryland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7698, 'longitude': -86.4808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35773', 'place_name': 'Toney', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.9116, 'longitude': -86.7, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35801', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7269, 'longitude': -86.5673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35802', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.6679, 'longitude': -86.5603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35803', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.6205, 'longitude': -86.551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35804', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7284, 'longitude': -86.5853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35805', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7059, 'longitude': -86.6165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35806', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7448, 'longitude': -86.6704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35807', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35808', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.6845, 'longitude': -86.6538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35809', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35810', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7784, 'longitude': -86.6091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35811', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7789, 'longitude': -86.5438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35812', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35813', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35814', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35815', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35816', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7389, 'longitude': -86.6249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35824', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.6583, 'longitude': -86.7295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35893', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7304, 'longitude': -86.5861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35894', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35895', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7304, 'longitude': -86.5861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35896', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7543, 'longitude': -86.6546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35897', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35898', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.734, 'longitude': -86.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35899', 'place_name': 'Huntsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Madison', 'locality_code': '89', 'latitude': 34.7339, 'longitude': -86.6456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36732', 'place_name': 'Demopolis', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.4908, 'longitude': -87.8397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36736', 'place_name': 'Dixons Mills', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.0672, 'longitude': -87.7454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36738', 'place_name': 'Faunsdale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.4233, 'longitude': -87.6181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36745', 'place_name': 'Jefferson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.414, 'longitude': -87.8986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36748', 'place_name': 'Linden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.3053, 'longitude': -87.7954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36754', 'place_name': 'Magnolia', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.1419, 'longitude': -87.6998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36763', 'place_name': 'Myrtlewood', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.2516, 'longitude': -87.9494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36764', 'place_name': 'Nanafalia', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.1129, 'longitude': -87.9881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36782', 'place_name': 'Sweet Water', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.0773, 'longitude': -87.9228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36783', 'place_name': 'Thomaston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marengo', 'locality_code': '91', 'latitude': 32.2538, 'longitude': -87.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35543', 'place_name': 'Bear Creek', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marion', 'locality_code': '93', 'latitude': 34.1649, 'longitude': -87.7396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35548', 'place_name': 'Brilliant', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marion', 'locality_code': '93', 'latitude': 34.0377, 'longitude': -87.7563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35563', 'place_name': 'Guin', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marion', 'locality_code': '93', 'latitude': 33.9676, 'longitude': -87.9024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35564', 'place_name': 'Hackleburg', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marion', 'locality_code': '93', 'latitude': 34.2678, 'longitude': -87.8608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35570', 'place_name': 'Hamilton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marion', 'locality_code': '93', 'latitude': 34.1534, 'longitude': -88.0085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35594', 'place_name': 'Winfield', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marion', 'locality_code': '93', 'latitude': 33.9303, 'longitude': -87.7972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35016', 'place_name': 'Arab', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.3283, 'longitude': -86.4896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35175', 'place_name': 'Union Grove', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.4093, 'longitude': -86.4628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35747', 'place_name': 'Grant', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.4959, 'longitude': -86.259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35950', 'place_name': 'Albertville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.2739, 'longitude': -86.2064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35951', 'place_name': 'Albertville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.3223, 'longitude': -86.1935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35956', 'place_name': 'Boaz', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.1437, 'longitude': -86.148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35957', 'place_name': 'Boaz', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.1921, 'longitude': -86.1941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35964', 'place_name': 'Douglas', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.1737, 'longitude': -86.3236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35976', 'place_name': 'Guntersville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.3449, 'longitude': -86.2752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35980', 'place_name': 'Horton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.19, 'longitude': -86.3173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36421', 'place_name': 'Andalusia', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 31.3247, 'longitude': -86.5067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36505', 'place_name': 'Axis', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.9394, 'longitude': -88.0159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36509', 'place_name': 'Bayou La Batre', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.408, 'longitude': -88.2507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36512', 'place_name': 'Bucks', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 31.0105, 'longitude': -88.0242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36521', 'place_name': 'Chunchula', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.9912, 'longitude': -88.1311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36522', 'place_name': 'Citronelle', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 31.0425, 'longitude': -88.2549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36523', 'place_name': 'Coden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.3903, 'longitude': -88.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36525', 'place_name': 'Creola', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.9013, 'longitude': -88.0174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36528', 'place_name': 'Dauphin Island', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.2521, 'longitude': -88.1096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36541', 'place_name': 'Grand Bay', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.4983, 'longitude': -88.3282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36544', 'place_name': 'Irvington', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.4802, 'longitude': -88.2396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36560', 'place_name': 'Mount Vernon', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 31.0974, 'longitude': -88.035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36568', 'place_name': 'Saint Elmo', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.5035, 'longitude': -88.2542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36571', 'place_name': 'Saraland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.8332, 'longitude': -88.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36572', 'place_name': 'Satsuma', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.8516, 'longitude': -88.0533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36575', 'place_name': 'Semmes', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.7544, 'longitude': -88.2667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36582', 'place_name': 'Theodore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.5444, 'longitude': -88.1807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36587', 'place_name': 'Wilmer', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.8137, 'longitude': -88.3332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36590', 'place_name': 'Theodore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.488, 'longitude': -88.2533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36601', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6944, 'longitude': -88.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36602', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6888, 'longitude': -88.0453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36603', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6921, 'longitude': -88.0562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36604', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.682, 'longitude': -88.0678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36605', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6341, 'longitude': -88.0846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36606', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6729, 'longitude': -88.1009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36607', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6975, 'longitude': -88.1029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36608', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6817, 'longitude': -88.2945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36609', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6605, 'longitude': -88.1618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36610', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.7309, 'longitude': -88.0789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36611', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.7705, 'longitude': -88.0781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36612', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.7518, 'longitude': -88.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36613', 'place_name': 'Eight Mile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.7951, 'longitude': -88.1823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36615', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6411, 'longitude': -88.0622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36616', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.671, 'longitude': -88.1267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36617', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.7145, 'longitude': -88.0918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36618', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.7322, 'longitude': -88.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36619', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.5928, 'longitude': -88.1946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36628', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6944, 'longitude': -88.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36633', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36640', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36641', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36644', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6944, 'longitude': -88.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36652', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6944, 'longitude': -88.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36660', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36663', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6944, 'longitude': -88.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36670', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36671', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36675', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6944, 'longitude': -88.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36685', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36688', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6962, 'longitude': -88.1821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36689', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6589, 'longitude': -88.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36691', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6944, 'longitude': -88.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36693', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6311, 'longitude': -88.1588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36695', 'place_name': 'Mobile', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Mobile', 'locality_code': '97', 'latitude': 30.6474, 'longitude': -88.2292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36425', 'place_name': 'Beatrice', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.7273, 'longitude': -87.1719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36439', 'place_name': 'Excel', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.4279, 'longitude': -87.3414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36444', 'place_name': 'Franklin', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.7238, 'longitude': -87.4412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36445', 'place_name': 'Frisco City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.4235, 'longitude': -87.3817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36449', 'place_name': 'Goodway', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.3368, 'longitude': -87.4258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36457', 'place_name': 'Megargel', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.3612, 'longitude': -87.4353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36458', 'place_name': 'Mexia', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.5147, 'longitude': -87.4084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36460', 'place_name': 'Monroeville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.5153, 'longitude': -87.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36461', 'place_name': 'Monroeville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.5221, 'longitude': -87.3411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36470', 'place_name': 'Perdue Hill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.5141, 'longitude': -87.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36471', 'place_name': 'Peterman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.59, 'longitude': -87.26, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36480', 'place_name': 'Uriah', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.3135, 'longitude': -87.5705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36481', 'place_name': 'Vredenburgh', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Monroe', 'locality_code': '99', 'latitude': 31.8085, 'longitude': -87.3164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36013', 'place_name': 'Cecil', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2937, 'longitude': -85.9827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36036', 'place_name': 'Grady', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.0194, 'longitude': -86.1292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36043', 'place_name': 'Hope Hull', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2243, 'longitude': -86.3932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36046', 'place_name': 'Lapine', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 31.9657, 'longitude': -86.2844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36052', 'place_name': 'Mathews', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.1283, 'longitude': -86.0413, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36057', 'place_name': 'Mount Meigs', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36064', 'place_name': 'Pike Road', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3357, 'longitude': -86.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36065', 'place_name': 'Pine Level', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.0726, 'longitude': -86.0606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36069', 'place_name': 'Ramer', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.0677, 'longitude': -86.2463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36101', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.357, 'longitude': -86.2578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36102', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36103', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3462, 'longitude': -86.2873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36104', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.373, 'longitude': -86.3081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36105', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3257, 'longitude': -86.3104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36106', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3543, 'longitude': -86.2673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36107', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3804, 'longitude': -86.2799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36108', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3417, 'longitude': -86.3529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36109', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3834, 'longitude': -86.2434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36110', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.4217, 'longitude': -86.275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36111', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3374, 'longitude': -86.2715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36112', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3808, 'longitude': -86.3491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36113', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3846, 'longitude': -86.3039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36114', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.404, 'longitude': -86.2539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36115', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.4076, 'longitude': -86.2474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36116', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3129, 'longitude': -86.2421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36117', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3736, 'longitude': -86.1833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36118', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36119', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36120', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36121', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36123', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.3668, 'longitude': -86.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36124', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36125', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36130', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36131', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36132', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36135', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36140', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36141', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36142', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36177', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36191', 'place_name': 'Montgomery', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Montgomery', 'locality_code': '101', 'latitude': 32.2334, 'longitude': -86.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35601', 'place_name': 'Decatur', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.5896, 'longitude': -86.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35602', 'place_name': 'Decatur', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.6059, 'longitude': -86.9833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35603', 'place_name': 'Decatur', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.5484, 'longitude': -87.0004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35609', 'place_name': 'Decatur', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.6059, 'longitude': -86.9833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35619', 'place_name': 'Danville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.3873, 'longitude': -87.1454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35621', 'place_name': 'Eva', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.3323, 'longitude': -86.7589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35622', 'place_name': 'Falkville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.3477, 'longitude': -86.9131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35640', 'place_name': 'Hartselle', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.4482, 'longitude': -86.9242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35670', 'place_name': 'Somerville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.4995, 'longitude': -86.8009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35673', 'place_name': 'Trinity', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.5918, 'longitude': -87.0913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35699', 'place_name': 'Decatur', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.6059, 'longitude': -86.9833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35754', 'place_name': 'Laceys Spring', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.4996, 'longitude': -86.6129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35775', 'place_name': 'Valhermoso Springs', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Morgan', 'locality_code': '103', 'latitude': 34.542, 'longitude': -86.6871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36756', 'place_name': 'Marion', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Perry', 'locality_code': '105', 'latitude': 32.6463, 'longitude': -87.3314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36786', 'place_name': 'Uniontown', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Perry', 'locality_code': '105', 'latitude': 32.447, 'longitude': -87.4934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35442', 'place_name': 'Aliceville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pickens', 'locality_code': '107', 'latitude': 33.1228, 'longitude': -88.1667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35447', 'place_name': 'Carrollton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pickens', 'locality_code': '107', 'latitude': 33.2485, 'longitude': -88.1321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35461', 'place_name': 'Ethelsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pickens', 'locality_code': '107', 'latitude': 33.4157, 'longitude': -88.2167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35466', 'place_name': 'Gordo', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pickens', 'locality_code': '107', 'latitude': 33.3469, 'longitude': -87.9005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35471', 'place_name': 'Mc Shan', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pickens', 'locality_code': '107', 'latitude': 33.2626, 'longitude': -88.0885, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '35481', 'place_name': 'Reform', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pickens', 'locality_code': '107', 'latitude': 33.3959, 'longitude': -88.0203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36005', 'place_name': 'Banks', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pike', 'locality_code': '109', 'latitude': 31.8368, 'longitude': -85.7998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36010', 'place_name': 'Brundidge', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pike', 'locality_code': '109', 'latitude': 31.7013, 'longitude': -85.8177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36035', 'place_name': 'Goshen', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pike', 'locality_code': '109', 'latitude': 31.7946, 'longitude': -86.1277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36079', 'place_name': 'Troy', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pike', 'locality_code': '109', 'latitude': 31.7595, 'longitude': -86.0107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36081', 'place_name': 'Troy', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pike', 'locality_code': '109', 'latitude': 31.7945, 'longitude': -85.9655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36082', 'place_name': 'Troy', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Pike', 'locality_code': '109', 'latitude': 31.8028, 'longitude': -85.9546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36263', 'place_name': 'Graham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Randolph', 'locality_code': '111', 'latitude': 33.463, 'longitude': -85.334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36274', 'place_name': 'Roanoke', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Randolph', 'locality_code': '111', 'latitude': 33.1512, 'longitude': -85.3722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36276', 'place_name': 'Wadley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Randolph', 'locality_code': '111', 'latitude': 33.1492, 'longitude': -85.5513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36278', 'place_name': 'Wedowee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Randolph', 'locality_code': '111', 'latitude': 33.3019, 'longitude': -85.4737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36280', 'place_name': 'Woodland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Randolph', 'locality_code': '111', 'latitude': 33.3743, 'longitude': -85.3997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36851', 'place_name': 'Cottonton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.1468, 'longitude': -85.0738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36856', 'place_name': 'Fort Mitchell', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.2965, 'longitude': -84.9972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36858', 'place_name': 'Hatchechubbee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.2845, 'longitude': -85.3029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36859', 'place_name': 'Holy Trinity', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.2298, 'longitude': -85.0082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36860', 'place_name': 'Hurtsboro', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.2454, 'longitude': -85.3959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36867', 'place_name': 'Phenix City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.4978, 'longitude': -85.0234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36868', 'place_name': 'Phenix City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.4646, 'longitude': -85.0206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36869', 'place_name': 'Phenix City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.4204, 'longitude': -85.0796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36870', 'place_name': 'Phenix City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.4781, 'longitude': -85.124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36871', 'place_name': 'Pittsview', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.1733, 'longitude': -85.1312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36875', 'place_name': 'Seale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Russell', 'locality_code': '113', 'latitude': 32.3053, 'longitude': -85.1677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35004', 'place_name': 'Moody', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.6035, 'longitude': -86.4668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35052', 'place_name': 'Cook Springs', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.5895, 'longitude': -86.3923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35054', 'place_name': 'Cropwell', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.5296, 'longitude': -86.3007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35112', 'place_name': 'Margaret', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.6862, 'longitude': -86.475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35120', 'place_name': 'Odenville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.6756, 'longitude': -86.409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35125', 'place_name': 'Pell City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.5979, 'longitude': -86.3432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35128', 'place_name': 'Pell City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.5873, 'longitude': -86.3366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35131', 'place_name': 'Ragland', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.7367, 'longitude': -86.1619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35135', 'place_name': 'Riverside', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.6166, 'longitude': -86.1996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35146', 'place_name': 'Springville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.7386, 'longitude': -86.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35182', 'place_name': 'Wattsville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.7068, 'longitude': -86.2567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35953', 'place_name': 'Ashville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.8374, 'longitude': -86.2552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35987', 'place_name': 'Steele', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'St. Clair', 'locality_code': '115', 'latitude': 33.9417, 'longitude': -86.2289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35007', 'place_name': 'Alabaster', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.1934, 'longitude': -86.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35040', 'place_name': 'Calera', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.1098, 'longitude': -86.756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35043', 'place_name': 'Chelsea', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.2982, 'longitude': -86.6563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35051', 'place_name': 'Columbiana', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.177, 'longitude': -86.6161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35078', 'place_name': 'Harpersville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.3234, 'longitude': -86.4424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35080', 'place_name': 'Helena', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.2663, 'longitude': -86.902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35114', 'place_name': 'Maylene', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.2317, 'longitude': -86.8727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35115', 'place_name': 'Montevallo', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.1248, 'longitude': -86.8622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35124', 'place_name': 'Pelham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.2932, 'longitude': -86.768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35137', 'place_name': 'Saginaw', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.2063, 'longitude': -86.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35143', 'place_name': 'Shelby', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.0785, 'longitude': -86.5536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35144', 'place_name': 'Siluria', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.2293, 'longitude': -86.825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35147', 'place_name': 'Sterrett', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.4461, 'longitude': -86.4917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35176', 'place_name': 'Vandiver', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.4807, 'longitude': -86.5013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35178', 'place_name': 'Vincent', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.401, 'longitude': -86.3994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35185', 'place_name': 'Westover', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.3356, 'longitude': -86.5437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35186', 'place_name': 'Wilsonville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.2293, 'longitude': -86.5299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35187', 'place_name': 'Wilton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.081, 'longitude': -86.8793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35242', 'place_name': 'Birmingham', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Shelby', 'locality_code': '117', 'latitude': 33.3813, 'longitude': -86.7046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35459', 'place_name': 'Emelle', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.755, 'longitude': -88.3057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35460', 'place_name': 'Epes', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.672, 'longitude': -88.1206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35464', 'place_name': 'Gainesville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.821, 'longitude': -88.1589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35470', 'place_name': 'Livingston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.5843, 'longitude': -88.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35477', 'place_name': 'Panola', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.8726, 'longitude': -88.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36901', 'place_name': 'Bellamy', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.449, 'longitude': -88.1336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36907', 'place_name': 'Cuba', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.411, 'longitude': -88.3611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36925', 'place_name': 'York', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 32.4728, 'longitude': -88.2683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35014', 'place_name': 'Alpine', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.404, 'longitude': -86.2339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35032', 'place_name': 'Bon Air', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.2649, 'longitude': -86.3364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35044', 'place_name': 'Childersburg', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.2459, 'longitude': -86.3641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35096', 'place_name': 'Lincoln', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.6059, 'longitude': -86.1112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35149', 'place_name': 'Sycamore', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.2512, 'longitude': -86.2025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35150', 'place_name': 'Sylacauga', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.1717, 'longitude': -86.2713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35151', 'place_name': 'Sylacauga', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.1756, 'longitude': -86.3574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35160', 'place_name': 'Talladega', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.4354, 'longitude': -86.1134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35161', 'place_name': 'Talladega', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.4202, 'longitude': -86.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36268', 'place_name': 'Munford', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Talladega', 'locality_code': '121', 'latitude': 33.541, 'longitude': -85.9363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35010', 'place_name': 'Alexander City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tallapoosa', 'locality_code': '123', 'latitude': 32.9164, 'longitude': -85.9368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35011', 'place_name': 'Alexander City', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tallapoosa', 'locality_code': '123', 'latitude': 32.9902, 'longitude': -85.958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36023', 'place_name': 'East Tallassee', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tallapoosa', 'locality_code': '123', 'latitude': 32.8002, 'longitude': -85.8034, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36256', 'place_name': 'Daviston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tallapoosa', 'locality_code': '123', 'latitude': 33.0335, 'longitude': -85.7538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36850', 'place_name': 'Camp Hill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tallapoosa', 'locality_code': '123', 'latitude': 32.7827, 'longitude': -85.6474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36853', 'place_name': 'Dadeville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tallapoosa', 'locality_code': '123', 'latitude': 32.8224, 'longitude': -85.7704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36861', 'place_name': 'Jacksons Gap', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tallapoosa', 'locality_code': '123', 'latitude': 32.8797, 'longitude': -85.8487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35401', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.1969, 'longitude': -87.5627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35402', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.3066, 'longitude': -87.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35403', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2045, 'longitude': -87.527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35404', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.1826, 'longitude': -87.4827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35405', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.1617, 'longitude': -87.5144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35406', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2722, 'longitude': -87.536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35407', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.3066, 'longitude': -87.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35440', 'place_name': 'Abernant', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.311, 'longitude': -87.1898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35444', 'place_name': 'Brookwood', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2775, 'longitude': -87.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35446', 'place_name': 'Buhl', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2306, 'longitude': -87.7547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35449', 'place_name': 'Coaling', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.1359, 'longitude': -87.3384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35452', 'place_name': 'Coker', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2934, 'longitude': -87.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35453', 'place_name': 'Cottondale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.1767, 'longitude': -87.3871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35456', 'place_name': 'Duncanville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.0618, 'longitude': -87.4422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35457', 'place_name': 'Echola', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.294, 'longitude': -87.7766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35458', 'place_name': 'Elrod', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2562, 'longitude': -87.7922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35463', 'place_name': 'Fosters', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.0843, 'longitude': -87.6975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35468', 'place_name': 'Kellerman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.3407, 'longitude': -87.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35473', 'place_name': 'Northport', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2723, 'longitude': -87.5825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35475', 'place_name': 'Northport', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.3992, 'longitude': -87.5599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35476', 'place_name': 'Northport', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2273, 'longitude': -87.5943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35478', 'place_name': 'Peterson', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.3066, 'longitude': -87.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35480', 'place_name': 'Ralph', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.1274, 'longitude': -87.7624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35482', 'place_name': 'Samantha', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.3066, 'longitude': -87.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35486', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.2098, 'longitude': -87.5692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35487', 'place_name': 'Tuscaloosa', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.3072, 'longitude': -87.5859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35490', 'place_name': 'Vance', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Tuscaloosa', 'locality_code': '125', 'latitude': 33.175, 'longitude': -87.2574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35038', 'place_name': 'Burnwell', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.7079, 'longitude': -87.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35062', 'place_name': 'Dora', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.7357, 'longitude': -87.0546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35063', 'place_name': 'Empire', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.8256, 'longitude': -87.0161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35130', 'place_name': 'Quinton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.6561, 'longitude': -87.1007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35148', 'place_name': 'Sumiton', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.768, 'longitude': -87.0445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35501', 'place_name': 'Jasper', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.8312, 'longitude': -87.2775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35502', 'place_name': 'Jasper', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.8312, 'longitude': -87.2775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35503', 'place_name': 'Jasper', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.9152, 'longitude': -87.3074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35504', 'place_name': 'Jasper', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.8927, 'longitude': -87.1667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35549', 'place_name': 'Carbon Hill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.9093, 'longitude': -87.5403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35550', 'place_name': 'Cordova', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.768, 'longitude': -87.1841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35554', 'place_name': 'Eldridge', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.9315, 'longitude': -87.6194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35560', 'place_name': 'Goodsprings', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.6795, 'longitude': -87.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35573', 'place_name': 'Kansas', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.9018, 'longitude': -87.552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35578', 'place_name': 'Nauvoo', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.9299, 'longitude': -87.4324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35579', 'place_name': 'Oakman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.7002, 'longitude': -87.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35580', 'place_name': 'Parrish', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.7213, 'longitude': -87.2658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35584', 'place_name': 'Sipsey', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.8201, 'longitude': -87.0779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35587', 'place_name': 'Townley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Walker', 'locality_code': '127', 'latitude': 33.847, 'longitude': -87.4372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36513', 'place_name': 'Calvert', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.1552, 'longitude': -88.01, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36518', 'place_name': 'Chatom', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.4876, 'longitude': -88.2699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36529', 'place_name': 'Deer Park', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.2168, 'longitude': -88.3172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36538', 'place_name': 'Frankville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.6468, 'longitude': -88.1332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36539', 'place_name': 'Fruitdale', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.3488, 'longitude': -88.3766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36548', 'place_name': 'Leroy', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.491, 'longitude': -87.9687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36553', 'place_name': 'Mc Intosh', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.2361, 'longitude': -88.0511, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36556', 'place_name': 'Malcolm', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.1913, 'longitude': -88.0075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36558', 'place_name': 'Millry', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.6269, 'longitude': -88.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36569', 'place_name': 'Saint Stephens', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.533, 'longitude': -88.0521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36581', 'place_name': 'Sunflower', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.3696, 'longitude': -88.0122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36583', 'place_name': 'Tibbie', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.4067, 'longitude': -88.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36584', 'place_name': 'Vinegar Bend', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.2584, 'longitude': -88.3865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36585', 'place_name': 'Wagarville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Washington', 'locality_code': '129', 'latitude': 31.4102, 'longitude': -88.0705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36435', 'place_name': 'Coy', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 31.8889, 'longitude': -87.3926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36720', 'place_name': 'Alberta', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 32.1585, 'longitude': -87.3468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36722', 'place_name': 'Arlington', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 32.0668, 'longitude': -87.5597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36723', 'place_name': 'Boykin', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 32.0779, 'longitude': -87.2814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36726', 'place_name': 'Camden', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 32.0047, 'longitude': -87.295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36728', 'place_name': 'Catherine', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 32.182, 'longitude': -87.4836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36741', 'place_name': 'Furman', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 32.0061, 'longitude': -86.9817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36751', 'place_name': 'Lower Peach Tree', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 31.8504, 'longitude': -87.5682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36753', 'place_name': 'Mc Williams', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 32.0481, 'longitude': -87.2623, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '36766', 'place_name': 'Oak Hill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 31.947, 'longitude': -87.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36768', 'place_name': 'Pine Apple', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 31.9265, 'longitude': -87.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '36769', 'place_name': 'Pine Hill', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Wilcox', 'locality_code': '131', 'latitude': 31.9735, 'longitude': -87.5771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35540', 'place_name': 'Addison', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.2056, 'longitude': -87.1948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35541', 'place_name': 'Arley', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.0632, 'longitude': -87.1828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35551', 'place_name': 'Delmar', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.1701, 'longitude': -87.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35553', 'place_name': 'Double Springs', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.1387, 'longitude': -87.3974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35565', 'place_name': 'Haleyville', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.2314, 'longitude': -87.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35572', 'place_name': 'Houston', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.118, 'longitude': -87.2618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35575', 'place_name': 'Lynn', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.053, 'longitude': -87.5398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '35577', 'place_name': 'Natural Bridge', 'state': 'Alabama', 'state_ab': 'AL', 'county': 'Winston', 'locality_code': '133', 'latitude': 34.0934, 'longitude': -87.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72003', 'place_name': 'Almyra', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.4146, 'longitude': -91.431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72026', 'place_name': 'Casscoe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.5095, 'longitude': -91.299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72038', 'place_name': 'Crocketts Bluff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.4528, 'longitude': -91.2692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72042', 'place_name': 'De Witt', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.2853, 'longitude': -91.3336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72048', 'place_name': 'Ethel', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.2435, 'longitude': -91.1398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72055', 'place_name': 'Gillett', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.1218, 'longitude': -91.38, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72073', 'place_name': 'Humphrey', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.4034, 'longitude': -91.679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72140', 'place_name': 'Saint Charles', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.3878, 'longitude': -91.1463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72160', 'place_name': 'Stuttgart', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.4854, 'longitude': -91.5487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72166', 'place_name': 'Tichnor', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Arkansas', 'locality_code': '1', 'latitude': 34.0893, 'longitude': -91.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71635', 'place_name': 'Crossett', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ashley', 'locality_code': '3', 'latitude': 33.156, 'longitude': -91.9975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71642', 'place_name': 'Fountain Hill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ashley', 'locality_code': '3', 'latitude': 33.3631, 'longitude': -91.9088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71646', 'place_name': 'Hamburg', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ashley', 'locality_code': '3', 'latitude': 33.2058, 'longitude': -91.8023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71658', 'place_name': 'Montrose', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ashley', 'locality_code': '3', 'latitude': 33.3075, 'longitude': -91.5228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71661', 'place_name': 'Parkdale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ashley', 'locality_code': '3', 'latitude': 33.1213, 'longitude': -91.5428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71663', 'place_name': 'Portland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ashley', 'locality_code': '3', 'latitude': 33.2318, 'longitude': -91.5139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71676', 'place_name': 'Wilmot', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ashley', 'locality_code': '3', 'latitude': 33.0576, 'longitude': -91.5723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72537', 'place_name': 'Gamaliel', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.4618, 'longitude': -92.2284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72544', 'place_name': 'Henderson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.4105, 'longitude': -92.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72617', 'place_name': 'Big Flat', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.0068, 'longitude': -92.3917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72623', 'place_name': 'Clarkridge', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.4724, 'longitude': -92.3296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72626', 'place_name': 'Cotter', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.2712, 'longitude': -92.5354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72635', 'place_name': 'Gassville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.3175, 'longitude': -92.4736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72642', 'place_name': 'Lakeview', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.373, 'longitude': -92.5422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72651', 'place_name': 'Midway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.3933, 'longitude': -92.4881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72653', 'place_name': 'Mountain Home', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.3312, 'longitude': -92.3753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72654', 'place_name': 'Mountain Home', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.3353, 'longitude': -92.3852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72658', 'place_name': 'Norfork', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.2066, 'longitude': -92.273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72659', 'place_name': 'Norfork', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Baxter', 'locality_code': '5', 'latitude': 36.2095, 'longitude': -92.2843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72711', 'place_name': 'Avoca', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4047, 'longitude': -94.0713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72712', 'place_name': 'Bentonville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.3577, 'longitude': -94.2224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72713', 'place_name': 'Bentonville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.3115, 'longitude': -94.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72714', 'place_name': 'Bella Vista', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4676, 'longitude': -94.2166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72715', 'place_name': 'Bella Vista', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4677, 'longitude': -94.3209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72716', 'place_name': 'Bentonville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.3729, 'longitude': -94.2088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72718', 'place_name': 'Cave Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.2738, 'longitude': -94.2183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72719', 'place_name': 'Centerton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.367, 'longitude': -94.3089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72722', 'place_name': 'Decatur', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.3347, 'longitude': -94.4534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72732', 'place_name': 'Garfield', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4288, 'longitude': -93.9512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72733', 'place_name': 'Gateway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4864, 'longitude': -93.9277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72734', 'place_name': 'Gentry', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.2652, 'longitude': -94.4751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72736', 'place_name': 'Gravette', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4155, 'longitude': -94.4779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72739', 'place_name': 'Hiwasse', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4416, 'longitude': -94.339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72745', 'place_name': 'Lowell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.2554, 'longitude': -94.1308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72747', 'place_name': 'Maysville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.3811, 'longitude': -94.5783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72751', 'place_name': 'Pea Ridge', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4539, 'longitude': -94.118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72756', 'place_name': 'Rogers', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.3363, 'longitude': -94.1148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72757', 'place_name': 'Rogers', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.332, 'longitude': -94.1185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72758', 'place_name': 'Rogers', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.3169, 'longitude': -94.1545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72761', 'place_name': 'Siloam Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.18, 'longitude': -94.528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72768', 'place_name': 'Sulphur Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Benton', 'locality_code': '7', 'latitude': 36.4794, 'longitude': -94.4521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72260', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 34.7399, 'longitude': -92.34, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72601', 'place_name': 'Harrison', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.2417, 'longitude': -93.1062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72602', 'place_name': 'Harrison', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.2298, 'longitude': -93.1077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72611', 'place_name': 'Alpena', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.2998, 'longitude': -93.2792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72615', 'place_name': 'Bergman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.3083, 'longitude': -93.0321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72630', 'place_name': 'Diamond City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.4645, 'longitude': -92.9202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72633', 'place_name': 'Everton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.1534, 'longitude': -92.915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72644', 'place_name': 'Lead Hill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.3848, 'longitude': -93.0039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72662', 'place_name': 'Omaha', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.4612, 'longitude': -93.1888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72682', 'place_name': 'Valley Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Boone', 'locality_code': '9', 'latitude': 36.1351, 'longitude': -92.7541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71631', 'place_name': 'Banks', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Bradley', 'locality_code': '11', 'latitude': 33.5497, 'longitude': -92.2604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71647', 'place_name': 'Hermitage', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Bradley', 'locality_code': '11', 'latitude': 33.39, 'longitude': -92.156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71651', 'place_name': 'Jersey', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Bradley', 'locality_code': '11', 'latitude': 33.3889, 'longitude': -92.2966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71671', 'place_name': 'Warren', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Bradley', 'locality_code': '11', 'latitude': 33.614, 'longitude': -92.0778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71744', 'place_name': 'Hampton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.5376, 'longitude': -92.5295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71745', 'place_name': 'Harrell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.5101, 'longitude': -92.3988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71766', 'place_name': 'Thornton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.7768, 'longitude': -92.4862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72613', 'place_name': 'Beaver', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Carroll', 'locality_code': '15', 'latitude': 36.4311, 'longitude': -93.6994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72616', 'place_name': 'Berryville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Carroll', 'locality_code': '15', 'latitude': 36.3519, 'longitude': -93.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72631', 'place_name': 'Eureka Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Carroll', 'locality_code': '15', 'latitude': 36.435, 'longitude': -93.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72632', 'place_name': 'Eureka Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Carroll', 'locality_code': '15', 'latitude': 36.4175, 'longitude': -93.7379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72638', 'place_name': 'Green Forest', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Carroll', 'locality_code': '15', 'latitude': 36.3224, 'longitude': -93.4059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72660', 'place_name': 'Oak Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Carroll', 'locality_code': '15', 'latitude': 36.4613, 'longitude': -93.4321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71638', 'place_name': 'Dermott', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Chicot', 'locality_code': '17', 'latitude': 33.5241, 'longitude': -91.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71640', 'place_name': 'Eudora', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Chicot', 'locality_code': '17', 'latitude': 33.1213, 'longitude': -91.2716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71653', 'place_name': 'Lake Village', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Chicot', 'locality_code': '17', 'latitude': 33.3274, 'longitude': -91.2825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71721', 'place_name': 'Beirne', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 33.8887, 'longitude': -93.2041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71728', 'place_name': 'Curtis', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 34.0103, 'longitude': -93.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71743', 'place_name': 'Gurdon', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 33.9125, 'longitude': -93.1417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71772', 'place_name': 'Whelen Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 33.8309, 'longitude': -93.1263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71920', 'place_name': 'Alpine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 34.229, 'longitude': -93.3791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71921', 'place_name': 'Amity', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 34.2594, 'longitude': -93.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71923', 'place_name': 'Arkadelphia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 34.1153, 'longitude': -93.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71962', 'place_name': 'Okolona', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 34.0551, 'longitude': -93.2897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71998', 'place_name': 'Arkadelphia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 34.1209, 'longitude': -93.0538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71999', 'place_name': 'Arkadelphia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clark', 'locality_code': '19', 'latitude': 34.1209, 'longitude': -93.0538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72422', 'place_name': 'Corning', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.4155, 'longitude': -90.587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72424', 'place_name': 'Datto', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.3897, 'longitude': -90.7231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72430', 'place_name': 'Greenway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.3348, 'longitude': -90.2253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72435', 'place_name': 'Knobel', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.3176, 'longitude': -90.599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72441', 'place_name': 'Mc Dougal', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.437, 'longitude': -90.3837, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '72453', 'place_name': 'Peach Orchard', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.283, 'longitude': -90.6702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72454', 'place_name': 'Piggott', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.387, 'longitude': -90.1926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72456', 'place_name': 'Pollard', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.4317, 'longitude': -90.2751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72461', 'place_name': 'Rector', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.2672, 'longitude': -90.2702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72464', 'place_name': 'Saint Francis', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.4534, 'longitude': -90.1454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72470', 'place_name': 'Success', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Clay', 'locality_code': '21', 'latitude': 36.4536, 'longitude': -90.7281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72044', 'place_name': 'Edgemont', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.6321, 'longitude': -92.157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72067', 'place_name': 'Higden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.5685, 'longitude': -92.1341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72130', 'place_name': 'Prim', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.6674, 'longitude': -92.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72131', 'place_name': 'Quitman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.405, 'longitude': -92.1333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72179', 'place_name': 'Wilburn', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.5106, 'longitude': -91.8648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72523', 'place_name': 'Concord', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.6414, 'longitude': -91.8333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72530', 'place_name': 'Drasco', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.6616, 'longitude': -91.9398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72543', 'place_name': 'Heber Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.5103, 'longitude': -92.0392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72545', 'place_name': 'Heber Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.5352, 'longitude': -92.0213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72546', 'place_name': 'Ida', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.5816, 'longitude': -91.9305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72581', 'place_name': 'Tumbling Shoals', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleburne', 'locality_code': '23', 'latitude': 35.547, 'longitude': -91.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71652', 'place_name': 'Kingsland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleveland', 'locality_code': '25', 'latitude': 33.86, 'longitude': -92.3014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71660', 'place_name': 'New Edinburg', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleveland', 'locality_code': '25', 'latitude': 33.7588, 'longitude': -92.1939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71665', 'place_name': 'Rison', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cleveland', 'locality_code': '25', 'latitude': 33.9453, 'longitude': -92.1188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71740', 'place_name': 'Emerson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Columbia', 'locality_code': '27', 'latitude': 33.0891, 'longitude': -93.1987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71752', 'place_name': 'Mc Neil', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Columbia', 'locality_code': '27', 'latitude': 33.3622, 'longitude': -93.193, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '71753', 'place_name': 'Magnolia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Columbia', 'locality_code': '27', 'latitude': 33.2647, 'longitude': -93.2392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71754', 'place_name': 'Magnolia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Columbia', 'locality_code': '27', 'latitude': 33.2426, 'longitude': -93.23, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71770', 'place_name': 'Waldo', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Columbia', 'locality_code': '27', 'latitude': 33.36, 'longitude': -93.2949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71861', 'place_name': 'Taylor', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Columbia', 'locality_code': '27', 'latitude': 33.108, 'longitude': -93.446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72027', 'place_name': 'Center Ridge', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.3981, 'longitude': -92.5582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72030', 'place_name': 'Cleveland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.3955, 'longitude': -92.702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72063', 'place_name': 'Hattieville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.2907, 'longitude': -92.7783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72080', 'place_name': 'Jerusalem', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.5699, 'longitude': -92.8251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72107', 'place_name': 'Menifee', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.1356, 'longitude': -92.5498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72110', 'place_name': 'Morrilton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.1692, 'longitude': -92.7354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72127', 'place_name': 'Plumerville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.1575, 'longitude': -92.6204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72156', 'place_name': 'Solgohachia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.2701, 'longitude': -92.6754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72157', 'place_name': 'Springfield', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Conway', 'locality_code': '29', 'latitude': 35.2749, 'longitude': -92.5457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72401', 'place_name': 'Jonesboro', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.833, 'longitude': -90.6965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72402', 'place_name': 'Jonesboro', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.8088, 'longitude': -90.6529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72403', 'place_name': 'Jonesboro', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.8305, 'longitude': -90.7039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72404', 'place_name': 'Jonesboro', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.7792, 'longitude': -90.766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72405', 'place_name': 'Jonesboro', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.7792, 'longitude': -90.766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72411', 'place_name': 'Bay', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.7456, 'longitude': -90.5507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72414', 'place_name': 'Black Oak', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.8368, 'longitude': -90.4005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72416', 'place_name': 'Bono', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.9086, 'longitude': -90.7848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72417', 'place_name': 'Brookland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.9165, 'longitude': -90.5762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72419', 'place_name': 'Caraway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.759, 'longitude': -90.3358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72421', 'place_name': 'Cash', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.8301, 'longitude': -90.941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72427', 'place_name': 'Egypt', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.864, 'longitude': -90.9428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72437', 'place_name': 'Lake City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.8171, 'longitude': -90.4423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72447', 'place_name': 'Monette', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.9002, 'longitude': -90.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72467', 'place_name': 'State University', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Craighead', 'locality_code': '31', 'latitude': 35.8422, 'longitude': -90.6735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72921', 'place_name': 'Alma', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.5, 'longitude': -94.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72932', 'place_name': 'Cedarville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.603, 'longitude': -94.3749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72934', 'place_name': 'Chester', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.6898, 'longitude': -94.202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72935', 'place_name': 'Dyer', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.4923, 'longitude': -94.1377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72946', 'place_name': 'Mountainburg', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.6464, 'longitude': -94.1497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72947', 'place_name': 'Mulberry', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.5172, 'longitude': -93.9885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72948', 'place_name': 'Natural Dam', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.6743, 'longitude': -94.4124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72952', 'place_name': 'Rudy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.5468, 'longitude': -94.2913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72955', 'place_name': 'Uniontown', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.5748, 'longitude': -94.4349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72956', 'place_name': 'Van Buren', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.454, 'longitude': -94.3278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72957', 'place_name': 'Van Buren', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crawford', 'locality_code': '33', 'latitude': 35.4368, 'longitude': -94.3483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72301', 'place_name': 'West Memphis', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.1484, 'longitude': -90.1779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72303', 'place_name': 'West Memphis', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.1465, 'longitude': -90.1845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72325', 'place_name': 'Clarkedale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.3093, 'longitude': -90.2362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72327', 'place_name': 'Crawfordsville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.2119, 'longitude': -90.3351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72331', 'place_name': 'Earle', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.2799, 'longitude': -90.4503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72332', 'place_name': 'Edmondson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.1042, 'longitude': -90.3133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72339', 'place_name': 'Gilmore', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.4057, 'longitude': -90.2714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72364', 'place_name': 'Marion', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.2077, 'longitude': -90.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72376', 'place_name': 'Proctor', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.0834, 'longitude': -90.255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72384', 'place_name': 'Turrell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Crittenden', 'locality_code': '35', 'latitude': 35.3439, 'longitude': -90.2978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72324', 'place_name': 'Cherry Valley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cross', 'locality_code': '37', 'latitude': 35.3991, 'longitude': -90.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72347', 'place_name': 'Hickory Ridge', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cross', 'locality_code': '37', 'latitude': 35.3995, 'longitude': -90.9823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72373', 'place_name': 'Parkin', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cross', 'locality_code': '37', 'latitude': 35.2586, 'longitude': -90.5564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72387', 'place_name': 'Vanndale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cross', 'locality_code': '37', 'latitude': 35.3245, 'longitude': -90.7712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72396', 'place_name': 'Wynne', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Cross', 'locality_code': '37', 'latitude': 35.233, 'longitude': -90.793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71725', 'place_name': 'Carthage', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Dallas', 'locality_code': '39', 'latitude': 34.0751, 'longitude': -92.5554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71742', 'place_name': 'Fordyce', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Dallas', 'locality_code': '39', 'latitude': 33.8176, 'longitude': -92.4225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71748', 'place_name': 'Ivan', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Dallas', 'locality_code': '39', 'latitude': 33.9118, 'longitude': -92.4246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71763', 'place_name': 'Sparkman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Dallas', 'locality_code': '39', 'latitude': 33.9143, 'longitude': -92.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71630', 'place_name': 'Arkansas City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 33.6143, 'longitude': -91.2325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71639', 'place_name': 'Dumas', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 33.8921, 'longitude': -91.4861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71654', 'place_name': 'Mc Gehee', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 33.6297, 'longitude': -91.3928, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '71662', 'place_name': 'Pickens', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 33.842, 'longitude': -91.5022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71666', 'place_name': 'Rohwer', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 33.7609, 'longitude': -91.2757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71670', 'place_name': 'Tillar', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 33.6981, 'longitude': -91.4433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71674', 'place_name': 'Watson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 33.8907, 'longitude': -91.2815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72379', 'place_name': 'Snow Lake', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Desha', 'locality_code': '41', 'latitude': 34.0665, 'longitude': -91.0071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71655', 'place_name': 'Monticello', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Drew', 'locality_code': '43', 'latitude': 33.625, 'longitude': -91.7948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71656', 'place_name': 'Monticello', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Drew', 'locality_code': '43', 'latitude': 33.629, 'longitude': -91.791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71657', 'place_name': 'Monticello', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Drew', 'locality_code': '43', 'latitude': 33.629, 'longitude': -91.791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71675', 'place_name': 'Wilmar', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Drew', 'locality_code': '43', 'latitude': 33.6213, 'longitude': -91.9257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71677', 'place_name': 'Winchester', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Drew', 'locality_code': '43', 'latitude': 33.7471, 'longitude': -91.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72032', 'place_name': 'Conway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.0842, 'longitude': -92.4236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72033', 'place_name': 'Conway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.1053, 'longitude': -92.3549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72034', 'place_name': 'Conway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.0823, 'longitude': -92.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72035', 'place_name': 'Conway', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.1053, 'longitude': -92.3549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72039', 'place_name': 'Damascus', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.3673, 'longitude': -92.4096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72047', 'place_name': 'Enola', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.2087, 'longitude': -92.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72058', 'place_name': 'Greenbrier', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.2295, 'longitude': -92.3578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72061', 'place_name': 'Guy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.3239, 'longitude': -92.2878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72106', 'place_name': 'Mayflower', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 34.9669, 'longitude': -92.4001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72111', 'place_name': 'Mount Vernon', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.2265, 'longitude': -92.124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72173', 'place_name': 'Vilonia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.0719, 'longitude': -92.1832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72181', 'place_name': 'Wooster', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Faulkner', 'locality_code': '45', 'latitude': 35.1645, 'longitude': -92.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72820', 'place_name': 'Alix', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Franklin', 'locality_code': '47', 'latitude': 35.41, 'longitude': -93.7286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72821', 'place_name': 'Altus', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Franklin', 'locality_code': '47', 'latitude': 35.4346, 'longitude': -93.7598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72928', 'place_name': 'Branch', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Franklin', 'locality_code': '47', 'latitude': 35.2971, 'longitude': -93.9454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72930', 'place_name': 'Cecil', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Franklin', 'locality_code': '47', 'latitude': 35.4252, 'longitude': -94.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72933', 'place_name': 'Charleston', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Franklin', 'locality_code': '47', 'latitude': 35.3115, 'longitude': -94.0337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72949', 'place_name': 'Ozark', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Franklin', 'locality_code': '47', 'latitude': 35.5246, 'longitude': -93.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72515', 'place_name': 'Bexar', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.2901, 'longitude': -92.055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72520', 'place_name': 'Camp', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.4025, 'longitude': -91.7262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72531', 'place_name': 'Elizabeth', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.3238, 'longitude': -92.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72538', 'place_name': 'Gepp', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.4364, 'longitude': -92.0995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72539', 'place_name': 'Glencoe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.2942, 'longitude': -91.7474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72554', 'place_name': 'Mammoth Spring', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.4076, 'longitude': -91.5757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72576', 'place_name': 'Salem', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.3766, 'longitude': -91.8759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72578', 'place_name': 'Sturkie', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.4747, 'longitude': -91.8891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72583', 'place_name': 'Viola', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Fulton', 'locality_code': '49', 'latitude': 36.3924, 'longitude': -91.9932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71901', 'place_name': 'Hot Springs National Park', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.5268, 'longitude': -92.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71902', 'place_name': 'Hot Springs National Park', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.5814, 'longitude': -93.0994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71903', 'place_name': 'Hot Springs National Park', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.5814, 'longitude': -93.0994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71909', 'place_name': 'Hot Springs Village', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.6484, 'longitude': -92.983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71910', 'place_name': 'Hot Springs Village', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.672, 'longitude': -92.9988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71913', 'place_name': 'Hot Springs National Park', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.5317, 'longitude': -93.0638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71914', 'place_name': 'Hot Springs National Park', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.5137, 'longitude': -92.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71949', 'place_name': 'Jessieville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.7094, 'longitude': -93.0382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71956', 'place_name': 'Mountain Pine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.5976, 'longitude': -93.1539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71964', 'place_name': 'Pearcy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.4351, 'longitude': -93.242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71968', 'place_name': 'Royal', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.515, 'longitude': -93.2897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72087', 'place_name': 'Lonsdale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Garland', 'locality_code': '51', 'latitude': 34.5562, 'longitude': -92.834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72057', 'place_name': 'Grapevine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Grant', 'locality_code': '53', 'latitude': 34.1309, 'longitude': -92.3109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72084', 'place_name': 'Leola', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Grant', 'locality_code': '53', 'latitude': 34.1856, 'longitude': -92.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72128', 'place_name': 'Poyen', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Grant', 'locality_code': '53', 'latitude': 34.3023, 'longitude': -92.6095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72129', 'place_name': 'Prattsville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Grant', 'locality_code': '53', 'latitude': 34.3079, 'longitude': -92.5131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72150', 'place_name': 'Sheridan', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Grant', 'locality_code': '53', 'latitude': 34.3165, 'longitude': -92.3657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72412', 'place_name': 'Beech Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Greene', 'locality_code': '55', 'latitude': 36.1281, 'longitude': -90.6914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72425', 'place_name': 'Delaplaine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Greene', 'locality_code': '55', 'latitude': 36.1995, 'longitude': -90.7345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72436', 'place_name': 'Lafe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Greene', 'locality_code': '55', 'latitude': 36.2359, 'longitude': -90.4811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72443', 'place_name': 'Marmaduke', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Greene', 'locality_code': '55', 'latitude': 36.1951, 'longitude': -90.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72450', 'place_name': 'Paragould', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Greene', 'locality_code': '55', 'latitude': 36.06, 'longitude': -90.5251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72451', 'place_name': 'Paragould', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Greene', 'locality_code': '55', 'latitude': 36.0584, 'longitude': -90.4973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72474', 'place_name': 'Walcott', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Greene', 'locality_code': '55', 'latitude': 36.0413, 'longitude': -90.6718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71801', 'place_name': 'Hope', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.6736, 'longitude': -93.6068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71802', 'place_name': 'Hope', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.6671, 'longitude': -93.5916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71825', 'place_name': 'Blevins', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.8718, 'longitude': -93.5771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71831', 'place_name': 'Columbus', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.7935, 'longitude': -93.807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71838', 'place_name': 'Fulton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.6299, 'longitude': -93.8086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71847', 'place_name': 'Mc Caskill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.923, 'longitude': -93.6266, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '71855', 'place_name': 'Ozan', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.9028, 'longitude': -93.7714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71862', 'place_name': 'Washington', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hempstead', 'locality_code': '57', 'latitude': 33.7546, 'longitude': -93.6735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71929', 'place_name': 'Bismarck', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hot Spring', 'locality_code': '59', 'latitude': 34.311, 'longitude': -93.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71933', 'place_name': 'Bonnerdale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hot Spring', 'locality_code': '59', 'latitude': 34.3848, 'longitude': -93.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71941', 'place_name': 'Donaldson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hot Spring', 'locality_code': '59', 'latitude': 34.2212, 'longitude': -92.9094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71942', 'place_name': 'Friendship', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hot Spring', 'locality_code': '59', 'latitude': 34.2235, 'longitude': -93.0024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72019', 'place_name': 'Benton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hot Spring', 'locality_code': '59', 'latitude': 34.604, 'longitude': -92.6259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72104', 'place_name': 'Malvern', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hot Spring', 'locality_code': '59', 'latitude': 34.3557, 'longitude': -92.8292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72105', 'place_name': 'Jones Mill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Hot Spring', 'locality_code': '59', 'latitude': 34.4374, 'longitude': -92.8943, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '71833', 'place_name': 'Dierks', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Howard', 'locality_code': '61', 'latitude': 34.1323, 'longitude': -94.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71851', 'place_name': 'Mineral Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Howard', 'locality_code': '61', 'latitude': 33.8639, 'longitude': -93.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71852', 'place_name': 'Nashville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Howard', 'locality_code': '61', 'latitude': 33.9576, 'longitude': -93.8707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71859', 'place_name': 'Saratoga', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Howard', 'locality_code': '61', 'latitude': 33.7599, 'longitude': -93.8767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71971', 'place_name': 'Umpire', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Howard', 'locality_code': '61', 'latitude': 34.2921, 'longitude': -94.0314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72165', 'place_name': 'Thida', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.5762, 'longitude': -91.4539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72501', 'place_name': 'Batesville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.7826, 'longitude': -91.6352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72503', 'place_name': 'Batesville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.7346, 'longitude': -91.5343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72522', 'place_name': 'Charlotte', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.8184, 'longitude': -91.4387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72524', 'place_name': 'Cord', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.8184, 'longitude': -91.3375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72526', 'place_name': 'Cushman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.8729, 'longitude': -91.754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72527', 'place_name': 'Desha', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.7411, 'longitude': -91.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72534', 'place_name': 'Floral', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.6023, 'longitude': -91.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72550', 'place_name': 'Locust Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.7177, 'longitude': -91.7414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72553', 'place_name': 'Magness', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.6941, 'longitude': -91.4753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72562', 'place_name': 'Newark', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.7118, 'longitude': -91.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72564', 'place_name': 'Oil Trough', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.6131, 'longitude': -91.4703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72568', 'place_name': 'Pleasant Plains', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.5893, 'longitude': -91.632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72571', 'place_name': 'Rosie', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.6638, 'longitude': -91.534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72575', 'place_name': 'Salado', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.6919, 'longitude': -91.5989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72579', 'place_name': 'Sulphur Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Independence', 'locality_code': '63', 'latitude': 35.7545, 'longitude': -91.5073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72512', 'place_name': 'Horseshoe Bend', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.2025, 'longitude': -91.7553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72517', 'place_name': 'Brockwell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.1358, 'longitude': -91.9513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72519', 'place_name': 'Calico Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.1202, 'longitude': -92.1867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72528', 'place_name': 'Dolph', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.2229, 'longitude': -92.1177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72536', 'place_name': 'Franklin', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.1703, 'longitude': -91.776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72540', 'place_name': 'Guion', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 35.9266, 'longitude': -91.9103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72556', 'place_name': 'Melbourne', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.0635, 'longitude': -91.9079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72561', 'place_name': 'Mount Pleasant', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 35.9759, 'longitude': -91.785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72565', 'place_name': 'Oxford', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.2114, 'longitude': -91.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72566', 'place_name': 'Pineville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.1677, 'longitude': -92.1073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72573', 'place_name': 'Sage', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.0688, 'longitude': -91.791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72584', 'place_name': 'Violet Hill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.163, 'longitude': -91.8471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72585', 'place_name': 'Wideman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.1865, 'longitude': -92.0088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72587', 'place_name': 'Wiseman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Izard', 'locality_code': '65', 'latitude': 36.2345, 'longitude': -91.8154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72005', 'place_name': 'Amagon', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.562, 'longitude': -91.1104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72014', 'place_name': 'Beedeville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.4291, 'longitude': -91.1057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72043', 'place_name': 'Diaz', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.6336, 'longitude': -91.2592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72075', 'place_name': 'Jacksonport', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.6414, 'longitude': -91.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72112', 'place_name': 'Newport', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.5988, 'longitude': -91.2571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72169', 'place_name': 'Tupelo', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.3844, 'longitude': -91.2232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72431', 'place_name': 'Grubbs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.6498, 'longitude': -91.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72471', 'place_name': 'Swifton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.8274, 'longitude': -91.1264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72473', 'place_name': 'Tuckerman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jackson', 'locality_code': '67', 'latitude': 35.7307, 'longitude': -91.2003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71601', 'place_name': 'Pine Bluff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.209, 'longitude': -91.9859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71602', 'place_name': 'White Hall', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.274, 'longitude': -92.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71603', 'place_name': 'Pine Bluff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.1897, 'longitude': -92.0448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71611', 'place_name': 'Pine Bluff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.2615, 'longitude': -91.9551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71612', 'place_name': 'White Hall', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.274, 'longitude': -92.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71613', 'place_name': 'Pine Bluff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.1579, 'longitude': -92.0713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71659', 'place_name': 'Moscow', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.1465, 'longitude': -91.7951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72004', 'place_name': 'Altheimer', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.3062, 'longitude': -91.8289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72079', 'place_name': 'Jefferson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.3934, 'longitude': -92.2029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72132', 'place_name': 'Redfield', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.4526, 'longitude': -92.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72133', 'place_name': 'Reydell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.1715, 'longitude': -91.5656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72152', 'place_name': 'Sherrill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.3581, 'longitude': -91.9933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72168', 'place_name': 'Tucker', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.4414, 'longitude': -91.9163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72175', 'place_name': 'Wabbaseka', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.3936, 'longitude': -91.7549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72182', 'place_name': 'Wright', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Jefferson', 'locality_code': '69', 'latitude': 34.4291, 'longitude': -92.0599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72830', 'place_name': 'Clarksville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.4908, 'longitude': -93.4911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72832', 'place_name': 'Coal Hill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.4371, 'longitude': -93.672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72839', 'place_name': 'Hagarville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.6155, 'longitude': -93.2726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72840', 'place_name': 'Hartman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.4436, 'longitude': -93.6142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72845', 'place_name': 'Knoxville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.3749, 'longitude': -93.3618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72846', 'place_name': 'Lamar', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.4349, 'longitude': -93.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72852', 'place_name': 'Oark', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.7095, 'longitude': -93.5585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72854', 'place_name': 'Ozone', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Johnson', 'locality_code': '71', 'latitude': 35.6575, 'longitude': -93.4311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71826', 'place_name': 'Bradley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lafayette', 'locality_code': '73', 'latitude': 33.107, 'longitude': -93.6275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71827', 'place_name': 'Buckner', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lafayette', 'locality_code': '73', 'latitude': 33.3753, 'longitude': -93.447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71839', 'place_name': 'Garland City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lafayette', 'locality_code': '73', 'latitude': 33.3352, 'longitude': -93.7316, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '71845', 'place_name': 'Lewisville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lafayette', 'locality_code': '73', 'latitude': 33.3736, 'longitude': -93.5953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71860', 'place_name': 'Stamps', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lafayette', 'locality_code': '73', 'latitude': 33.3569, 'longitude': -93.5013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72410', 'place_name': 'Alicia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 35.9423, 'longitude': -91.081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72415', 'place_name': 'Black Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.1149, 'longitude': -91.1176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72433', 'place_name': 'Hoxie', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.0326, 'longitude': -90.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72434', 'place_name': 'Imboden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.1976, 'longitude': -91.1854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72440', 'place_name': 'Lynn', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 35.9813, 'longitude': -91.2676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72445', 'place_name': 'Minturn', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 35.9728, 'longitude': -91.0235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72457', 'place_name': 'Portia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.0865, 'longitude': -91.0673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72458', 'place_name': 'Powhatan', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.08, 'longitude': -91.1482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72459', 'place_name': 'Ravenden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.2029, 'longitude': -91.2593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72465', 'place_name': 'Sedgwick', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 35.9643, 'longitude': -90.8954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72466', 'place_name': 'Smithville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.0908, 'longitude': -91.2745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72469', 'place_name': 'Strawberry', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 35.9673, 'longitude': -91.2935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72476', 'place_name': 'Walnut Ridge', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 36.0244, 'longitude': -90.9288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72572', 'place_name': 'Saffell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lawrence', 'locality_code': '75', 'latitude': 35.8781, 'longitude': -91.3004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72311', 'place_name': 'Aubrey', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lee', 'locality_code': '77', 'latitude': 34.7195, 'longitude': -90.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72320', 'place_name': 'Brickeys', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lee', 'locality_code': '77', 'latitude': 34.8548, 'longitude': -90.5377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72341', 'place_name': 'Haynes', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lee', 'locality_code': '77', 'latitude': 34.8838, 'longitude': -90.7666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72352', 'place_name': 'La Grange', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lee', 'locality_code': '77', 'latitude': 34.7697, 'longitude': -90.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72360', 'place_name': 'Marianna', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lee', 'locality_code': '77', 'latitude': 34.7759, 'longitude': -90.7785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72368', 'place_name': 'Moro', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lee', 'locality_code': '77', 'latitude': 34.803, 'longitude': -91.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71643', 'place_name': 'Gould', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lincoln', 'locality_code': '79', 'latitude': 34.0345, 'longitude': -91.5768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71644', 'place_name': 'Grady', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lincoln', 'locality_code': '79', 'latitude': 34.1032, 'longitude': -91.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71667', 'place_name': 'Star City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lincoln', 'locality_code': '79', 'latitude': 33.9405, 'longitude': -91.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71678', 'place_name': 'Yorktown', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lincoln', 'locality_code': '79', 'latitude': 33.9787, 'longitude': -91.6991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71820', 'place_name': 'Alleene', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Little River', 'locality_code': '81', 'latitude': 33.7944, 'longitude': -94.2681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71822', 'place_name': 'Ashdown', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Little River', 'locality_code': '81', 'latitude': 33.6787, 'longitude': -94.1351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71836', 'place_name': 'Foreman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Little River', 'locality_code': '81', 'latitude': 33.7176, 'longitude': -94.3881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71853', 'place_name': 'Ogden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Little River', 'locality_code': '81', 'latitude': 33.5826, 'longitude': -94.0427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71865', 'place_name': 'Wilton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Little River', 'locality_code': '81', 'latitude': 33.7475, 'longitude': -94.1518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71866', 'place_name': 'Winthrop', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Little River', 'locality_code': '81', 'latitude': 33.8583, 'longitude': -94.3952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72826', 'place_name': 'Blue Mountain', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.1304, 'longitude': -93.7116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72835', 'place_name': 'Delaware', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.278, 'longitude': -93.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72851', 'place_name': 'New Blaine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.3189, 'longitude': -93.4446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72855', 'place_name': 'Paris', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.2941, 'longitude': -93.7265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72863', 'place_name': 'Scranton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.3585, 'longitude': -93.5454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72865', 'place_name': 'Subiaco', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.3153, 'longitude': -93.5991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72927', 'place_name': 'Booneville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.1364, 'longitude': -93.9274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72943', 'place_name': 'Magazine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.1587, 'longitude': -93.8003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72951', 'place_name': 'Ratcliff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.2917, 'longitude': -93.8899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72007', 'place_name': 'Austin', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.9921, 'longitude': -91.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72023', 'place_name': 'Cabot', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.9457, 'longitude': -92.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72024', 'place_name': 'Carlisle', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.7933, 'longitude': -91.7459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72037', 'place_name': 'Coy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.5387, 'longitude': -91.874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72046', 'place_name': 'England', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.5575, 'longitude': -91.9484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72072', 'place_name': 'Humnoke', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.4857, 'longitude': -91.7624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72083', 'place_name': 'Keo', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.6041, 'longitude': -92.0078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72086', 'place_name': 'Lonoke', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.7832, 'longitude': -91.9214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72176', 'place_name': 'Ward', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Lonoke', 'locality_code': '85', 'latitude': 34.9532, 'longitude': -91.9004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72721', 'place_name': 'Combs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 35.8607, 'longitude': -93.8112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72738', 'place_name': 'Hindsville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 36.1422, 'longitude': -93.8633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72740', 'place_name': 'Huntsville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 36.1043, 'longitude': -93.7279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72742', 'place_name': 'Kingston', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 36.0485, 'longitude': -93.5044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72752', 'place_name': 'Pettigrew', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 35.8346, 'longitude': -93.6181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72760', 'place_name': 'Saint Paul', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 35.8496, 'longitude': -93.7347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72773', 'place_name': 'Wesley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 36.0114, 'longitude': -93.8526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72776', 'place_name': 'Witter', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Madison', 'locality_code': '87', 'latitude': 35.9356, 'longitude': -93.621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72619', 'place_name': 'Bull Shoals', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Marion', 'locality_code': '89', 'latitude': 36.371, 'longitude': -92.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72634', 'place_name': 'Flippin', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Marion', 'locality_code': '89', 'latitude': 36.2682, 'longitude': -92.578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72661', 'place_name': 'Oakland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Marion', 'locality_code': '89', 'latitude': 36.4442, 'longitude': -92.5832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72668', 'place_name': 'Peel', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Marion', 'locality_code': '89', 'latitude': 36.435, 'longitude': -92.7615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72672', 'place_name': 'Pyatt', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Marion', 'locality_code': '89', 'latitude': 36.2486, 'longitude': -92.8416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72677', 'place_name': 'Summit', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Marion', 'locality_code': '89', 'latitude': 36.2523, 'longitude': -92.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72687', 'place_name': 'Yellville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Marion', 'locality_code': '89', 'latitude': 36.2253, 'longitude': -92.7245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71834', 'place_name': 'Doddridge', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Miller', 'locality_code': '91', 'latitude': 33.1054, 'longitude': -93.9543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71837', 'place_name': 'Fouke', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Miller', 'locality_code': '91', 'latitude': 33.3025, 'longitude': -93.901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71840', 'place_name': 'Genoa', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Miller', 'locality_code': '91', 'latitude': 33.3837, 'longitude': -93.9096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71854', 'place_name': 'Texarkana', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Miller', 'locality_code': '91', 'latitude': 33.431, 'longitude': -93.8765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72310', 'place_name': 'Armorel', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.9201, 'longitude': -89.7981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72313', 'place_name': 'Bassett', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.5365, 'longitude': -90.1268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72315', 'place_name': 'Blytheville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.9273, 'longitude': -89.919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72316', 'place_name': 'Blytheville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.9273, 'longitude': -89.919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72319', 'place_name': 'Gosnell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.9598, 'longitude': -89.972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72321', 'place_name': 'Burdette', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.8173, 'longitude': -89.9393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72329', 'place_name': 'Driver', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.6253, 'longitude': -90.0138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72330', 'place_name': 'Dyess', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.5954, 'longitude': -90.2157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72338', 'place_name': 'Frenchmans Bayou', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.4591, 'longitude': -90.1884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72350', 'place_name': 'Joiner', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.5052, 'longitude': -90.1478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72351', 'place_name': 'Keiser', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.6737, 'longitude': -90.0963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72358', 'place_name': 'Luxora', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.7608, 'longitude': -89.922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72370', 'place_name': 'Osceola', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.7019, 'longitude': -89.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72391', 'place_name': 'West Ridge', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.6831, 'longitude': -90.2626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72395', 'place_name': 'Wilson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.566, 'longitude': -90.0427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72426', 'place_name': 'Dell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.8554, 'longitude': -90.0418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72428', 'place_name': 'Etowah', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.7337, 'longitude': -90.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72438', 'place_name': 'Leachville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.9332, 'longitude': -90.1955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72442', 'place_name': 'Manila', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Mississippi', 'locality_code': '93', 'latitude': 35.8439, 'longitude': -90.1806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72021', 'place_name': 'Brinkley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Monroe', 'locality_code': '95', 'latitude': 34.8781, 'longitude': -91.1886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72029', 'place_name': 'Clarendon', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Monroe', 'locality_code': '95', 'latitude': 34.6601, 'longitude': -91.2564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72069', 'place_name': 'Holly Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Monroe', 'locality_code': '95', 'latitude': 34.5993, 'longitude': -91.1844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72108', 'place_name': 'Monroe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Monroe', 'locality_code': '95', 'latitude': 34.7348, 'longitude': -91.1046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72134', 'place_name': 'Roe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Monroe', 'locality_code': '95', 'latitude': 34.6286, 'longitude': -91.3771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71935', 'place_name': 'Caddo Gap', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.3913, 'longitude': -93.7637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71957', 'place_name': 'Mount Ida', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.5612, 'longitude': -93.5749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71960', 'place_name': 'Norman', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.4596, 'longitude': -93.6743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71961', 'place_name': 'Oden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.6113, 'longitude': -93.8211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71965', 'place_name': 'Pencil Bluff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.6399, 'longitude': -93.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71966', 'place_name': 'Oden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.619, 'longitude': -93.7769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71969', 'place_name': 'Sims', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.6462, 'longitude': -93.6741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71970', 'place_name': 'Story', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 34.6687, 'longitude': -93.5376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71722', 'place_name': 'Bluff City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Nevada', 'locality_code': '99', 'latitude': 33.7038, 'longitude': -93.1588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71828', 'place_name': 'Cale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Nevada', 'locality_code': '99', 'latitude': 33.7008, 'longitude': -93.2941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71835', 'place_name': 'Emmet', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Nevada', 'locality_code': '99', 'latitude': 33.6929, 'longitude': -93.4232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71857', 'place_name': 'Prescott', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Nevada', 'locality_code': '99', 'latitude': 33.804, 'longitude': -93.3725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71858', 'place_name': 'Rosston', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Nevada', 'locality_code': '99', 'latitude': 33.5926, 'longitude': -93.2766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71864', 'place_name': 'Willisville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Nevada', 'locality_code': '99', 'latitude': 33.7008, 'longitude': -93.2941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72624', 'place_name': 'Compton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 36.0979, 'longitude': -93.3099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72628', 'place_name': 'Deer', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 35.853, 'longitude': -93.3174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72640', 'place_name': 'Hasty', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 36.0152, 'longitude': -93.046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72641', 'place_name': 'Jasper', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 36.0038, 'longitude': -93.2048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72648', 'place_name': 'Marble Falls', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 36.0695, 'longitude': -93.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72655', 'place_name': 'Mount Judea', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 35.9407, 'longitude': -93.0654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72666', 'place_name': 'Parthenon', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 35.9451, 'longitude': -93.2677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72670', 'place_name': 'Ponca', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 36.0242, 'longitude': -93.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72683', 'place_name': 'Vendor', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 35.9473, 'longitude': -93.0774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72685', 'place_name': 'Western Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Newton', 'locality_code': '101', 'latitude': 36.083, 'longitude': -92.9716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71701', 'place_name': 'Camden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ouachita', 'locality_code': '103', 'latitude': 33.5948, 'longitude': -92.8513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71711', 'place_name': 'Camden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ouachita', 'locality_code': '103', 'latitude': 33.589, 'longitude': -92.8426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71720', 'place_name': 'Bearden', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ouachita', 'locality_code': '103', 'latitude': 33.7298, 'longitude': -92.618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71726', 'place_name': 'Chidester', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ouachita', 'locality_code': '103', 'latitude': 33.6652, 'longitude': -92.9969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71751', 'place_name': 'Louann', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ouachita', 'locality_code': '103', 'latitude': 33.4169, 'longitude': -92.777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71764', 'place_name': 'Stephens', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Ouachita', 'locality_code': '103', 'latitude': 33.455, 'longitude': -93.0214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72001', 'place_name': 'Adona', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Perry', 'locality_code': '105', 'latitude': 35.047, 'longitude': -92.9033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72016', 'place_name': 'Bigelow', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Perry', 'locality_code': '105', 'latitude': 34.9847, 'longitude': -92.6308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72025', 'place_name': 'Casa', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Perry', 'locality_code': '105', 'latitude': 35.0322, 'longitude': -93.047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72070', 'place_name': 'Houston', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Perry', 'locality_code': '105', 'latitude': 35.0362, 'longitude': -92.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72125', 'place_name': 'Perry', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Perry', 'locality_code': '105', 'latitude': 35.0443, 'longitude': -92.7958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72126', 'place_name': 'Perryville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Perry', 'locality_code': '105', 'latitude': 34.9701, 'longitude': -92.8472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72312', 'place_name': 'Barton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.5467, 'longitude': -90.7679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72328', 'place_name': 'Crumrod', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.1335, 'longitude': -90.9751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72333', 'place_name': 'Elaine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.3118, 'longitude': -90.8939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72342', 'place_name': 'Helena', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.5325, 'longitude': -90.6298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72353', 'place_name': 'Lambrook', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.3286, 'longitude': -90.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72355', 'place_name': 'Lexa', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.5979, 'longitude': -90.7523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72366', 'place_name': 'Marvell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.5485, 'longitude': -90.9413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72367', 'place_name': 'Mellwood', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.2198, 'longitude': -90.9504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72369', 'place_name': 'Oneida', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.4542, 'longitude': -90.7684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72374', 'place_name': 'Poplar Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.5394, 'longitude': -90.8813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72383', 'place_name': 'Turner', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.4762, 'longitude': -91.0187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72389', 'place_name': 'Wabash', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.3466, 'longitude': -90.8869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72390', 'place_name': 'West Helena', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Phillips', 'locality_code': '107', 'latitude': 34.5496, 'longitude': -90.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71922', 'place_name': 'Antoine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pike', 'locality_code': '109', 'latitude': 34.0362, 'longitude': -93.4207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71940', 'place_name': 'Delight', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pike', 'locality_code': '109', 'latitude': 34.0238, 'longitude': -93.5247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71943', 'place_name': 'Glenwood', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pike', 'locality_code': '109', 'latitude': 34.3192, 'longitude': -93.5559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71950', 'place_name': 'Kirby', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pike', 'locality_code': '109', 'latitude': 34.2513, 'longitude': -93.741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71952', 'place_name': 'Langley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pike', 'locality_code': '109', 'latitude': 34.314, 'longitude': -93.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71958', 'place_name': 'Murfreesboro', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pike', 'locality_code': '109', 'latitude': 34.1017, 'longitude': -93.7109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71959', 'place_name': 'Newhope', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pike', 'locality_code': '109', 'latitude': 34.2273, 'longitude': -93.8905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72354', 'place_name': 'Lepanto', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.6069, 'longitude': -90.3359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72365', 'place_name': 'Marked Tree', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.5349, 'longitude': -90.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72377', 'place_name': 'Rivervale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.674, 'longitude': -90.3401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72386', 'place_name': 'Tyronza', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.4865, 'longitude': -90.3519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72429', 'place_name': 'Fisher', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.514, 'longitude': -90.955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72432', 'place_name': 'Harrisburg', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.5722, 'longitude': -90.7038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72472', 'place_name': 'Trumann', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.5882, 'longitude': -90.562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72475', 'place_name': 'Waldenburg', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.5631, 'longitude': -90.9207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72479', 'place_name': 'Weiner', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Poinsett', 'locality_code': '111', 'latitude': 35.6291, 'longitude': -90.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71932', 'place_name': 'Board Camp', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Polk', 'locality_code': '113', 'latitude': 34.5372, 'longitude': -94.0972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71937', 'place_name': 'Cove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Polk', 'locality_code': '113', 'latitude': 34.4192, 'longitude': -94.3923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71944', 'place_name': 'Grannis', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Polk', 'locality_code': '113', 'latitude': 34.237, 'longitude': -94.3255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71945', 'place_name': 'Hatfield', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Polk', 'locality_code': '113', 'latitude': 34.4877, 'longitude': -94.3714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71953', 'place_name': 'Mena', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Polk', 'locality_code': '113', 'latitude': 34.5814, 'longitude': -94.221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71972', 'place_name': 'Vandervoort', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Polk', 'locality_code': '113', 'latitude': 34.3941, 'longitude': -94.2535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71973', 'place_name': 'Wickes', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Polk', 'locality_code': '113', 'latitude': 34.3088, 'longitude': -94.3403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72679', 'place_name': 'Tilly', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.7341, 'longitude': -92.8391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72801', 'place_name': 'Russellville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.2842, 'longitude': -93.1315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72802', 'place_name': 'Russellville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.3067, 'longitude': -93.0712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72811', 'place_name': 'Russellville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.2784, 'longitude': -93.1338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72812', 'place_name': 'Russellville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.4231, 'longitude': -93.0544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72823', 'place_name': 'Atkins', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.2449, 'longitude': -92.9507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72837', 'place_name': 'Dover', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.4074, 'longitude': -93.1355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72843', 'place_name': 'Hector', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.5499, 'longitude': -92.9616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72847', 'place_name': 'London', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.3744, 'longitude': -93.2736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72856', 'place_name': 'Pelsor', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.7854, 'longitude': -93.0812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72858', 'place_name': 'Pottsville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pope', 'locality_code': '115', 'latitude': 35.2398, 'longitude': -93.0564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72017', 'place_name': 'Biscoe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Prairie', 'locality_code': '117', 'latitude': 34.8733, 'longitude': -91.3945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72040', 'place_name': 'Des Arc', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Prairie', 'locality_code': '117', 'latitude': 34.9751, 'longitude': -91.5113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72041', 'place_name': 'De Valls Bluff', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Prairie', 'locality_code': '117', 'latitude': 34.7447, 'longitude': -91.4982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72064', 'place_name': 'Hazen', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Prairie', 'locality_code': '117', 'latitude': 34.7838, 'longitude': -91.5767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72066', 'place_name': 'Hickory Plains', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Prairie', 'locality_code': '117', 'latitude': 34.9901, 'longitude': -91.7368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72170', 'place_name': 'Ulm', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Prairie', 'locality_code': '117', 'latitude': 34.5772, 'longitude': -91.4633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72002', 'place_name': 'Alexander', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.6313, 'longitude': -92.4727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72053', 'place_name': 'College Station', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7093, 'longitude': -92.2283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72065', 'place_name': 'Hensley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.5208, 'longitude': -92.2758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72076', 'place_name': 'Jacksonville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.919, 'longitude': -92.1419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72078', 'place_name': 'Jacksonville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8662, 'longitude': -92.1101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72099', 'place_name': 'Little Rock Air Force Base', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.9074, 'longitude': -92.1397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72103', 'place_name': 'Mabelvale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.6478, 'longitude': -92.3849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72113', 'place_name': 'Maumelle', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8491, 'longitude': -92.4059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72114', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7666, 'longitude': -92.2629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72115', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7695, 'longitude': -92.2671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72116', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8059, 'longitude': -92.2305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72117', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7658, 'longitude': -92.1524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72118', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8337, 'longitude': -92.3289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72119', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8017, 'longitude': -92.2598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72120', 'place_name': 'Sherwood', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8807, 'longitude': -92.2303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72124', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72135', 'place_name': 'Roland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8829, 'longitude': -92.5192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72142', 'place_name': 'Scott', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.6942, 'longitude': -92.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72164', 'place_name': 'Sweet Home', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.6873, 'longitude': -92.2399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72180', 'place_name': 'Woodson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.5338, 'longitude': -92.2089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72183', 'place_name': 'Wrightsville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.6012, 'longitude': -92.1938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72190', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72199', 'place_name': 'North Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8272, 'longitude': -92.2847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72201', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7483, 'longitude': -92.2819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72202', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7363, 'longitude': -92.2741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72203', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8835, 'longitude': -92.3908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72204', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7269, 'longitude': -92.344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72205', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.751, 'longitude': -92.3455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72206', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.6836, 'longitude': -92.2776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72207', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7721, 'longitude': -92.3565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72209', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.6725, 'longitude': -92.3529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72210', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7076, 'longitude': -92.466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72211', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7413, 'longitude': -92.4222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72212', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7871, 'longitude': -92.4222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72214', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7621, 'longitude': -92.2282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72215', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72216', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8178, 'longitude': -92.2357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72217', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8302, 'longitude': -92.1702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72219', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72221', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72222', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72223', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7902, 'longitude': -92.5044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72225', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72227', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7757, 'longitude': -92.3724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72231', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.8019, 'longitude': -92.1894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72255', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7464, 'longitude': -92.2894, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '72295', 'place_name': 'Little Rock', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Pulaski', 'locality_code': '119', 'latitude': 34.7519, 'longitude': -92.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72413', 'place_name': 'Biggers', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Randolph', 'locality_code': '121', 'latitude': 36.2844, 'longitude': -90.8538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72444', 'place_name': 'Maynard', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Randolph', 'locality_code': '121', 'latitude': 36.4386, 'longitude': -90.8749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72449', 'place_name': 'O Kean', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Randolph', 'locality_code': '121', 'latitude': 36.1797, 'longitude': -90.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72455', 'place_name': 'Pocahontas', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Randolph', 'locality_code': '121', 'latitude': 36.2829, 'longitude': -90.9968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72460', 'place_name': 'Ravenden Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Randolph', 'locality_code': '121', 'latitude': 36.3104, 'longitude': -91.2094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72462', 'place_name': 'Reyno', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Randolph', 'locality_code': '121', 'latitude': 36.3744, 'longitude': -90.7676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72478', 'place_name': 'Warm Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Randolph', 'locality_code': '121', 'latitude': 36.4803, 'longitude': -91.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72322', 'place_name': 'Caldwell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 35.0562, 'longitude': -90.8288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72326', 'place_name': 'Colt', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 35.0881, 'longitude': -90.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72335', 'place_name': 'Forrest City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 35.0091, 'longitude': -90.7886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72336', 'place_name': 'Forrest City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 35.0081, 'longitude': -90.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72340', 'place_name': 'Goodwin', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 34.9358, 'longitude': -91.0292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72346', 'place_name': 'Heth', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 35.0973, 'longitude': -90.4586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72348', 'place_name': 'Hughes', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 34.9454, 'longitude': -90.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72359', 'place_name': 'Madison', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 35.0252, 'longitude': -90.7086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72372', 'place_name': 'Palestine', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 34.9663, 'longitude': -90.9049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72392', 'place_name': 'Wheatley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 34.9207, 'longitude': -91.1086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72394', 'place_name': 'Widener', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'St. Francis', 'locality_code': '123', 'latitude': 35.0592, 'longitude': -90.6293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72011', 'place_name': 'Bauxite', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.5091, 'longitude': -92.4828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72015', 'place_name': 'Benton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.4933, 'longitude': -92.5896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72018', 'place_name': 'Benton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.5645, 'longitude': -92.5868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72022', 'place_name': 'Bryant', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.6068, 'longitude': -92.492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72089', 'place_name': 'Bryant', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.5959, 'longitude': -92.489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72122', 'place_name': 'Paron', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.7853, 'longitude': -92.7482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72158', 'place_name': 'Benton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.635, 'longitude': -92.6597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72167', 'place_name': 'Traskwood', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Saline', 'locality_code': '125', 'latitude': 34.4508, 'longitude': -92.6547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72841', 'place_name': 'Harvey', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Scott', 'locality_code': '127', 'latitude': 34.8762, 'longitude': -93.764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72926', 'place_name': 'Boles', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Scott', 'locality_code': '127', 'latitude': 34.7654, 'longitude': -94.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72944', 'place_name': 'Mansfield', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Scott', 'locality_code': '127', 'latitude': 35.0432, 'longitude': -94.2204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72950', 'place_name': 'Parks', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Scott', 'locality_code': '127', 'latitude': 34.8003, 'longitude': -93.9509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72958', 'place_name': 'Waldron', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Scott', 'locality_code': '127', 'latitude': 34.9026, 'longitude': -94.0772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72636', 'place_name': 'Gilbert', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Searcy', 'locality_code': '129', 'latitude': 35.9879, 'longitude': -92.7163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72639', 'place_name': 'Harriet', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Searcy', 'locality_code': '129', 'latitude': 35.9991, 'longitude': -92.5042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72645', 'place_name': 'Leslie', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Searcy', 'locality_code': '129', 'latitude': 35.8272, 'longitude': -92.5663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72650', 'place_name': 'Marshall', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Searcy', 'locality_code': '129', 'latitude': 35.9267, 'longitude': -92.6402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72669', 'place_name': 'Pindall', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Searcy', 'locality_code': '129', 'latitude': 36.0675, 'longitude': -92.8864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72675', 'place_name': 'Saint Joe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Searcy', 'locality_code': '129', 'latitude': 35.9877, 'longitude': -92.7928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72686', 'place_name': 'Witts Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Searcy', 'locality_code': '129', 'latitude': 35.7681, 'longitude': -92.8668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72901', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3653, 'longitude': -94.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72902', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3862, 'longitude': -94.4091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72903', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3427, 'longitude': -94.3784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72904', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.4051, 'longitude': -94.3872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72905', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3859, 'longitude': -94.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72906', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3859, 'longitude': -94.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72908', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3219, 'longitude': -94.4028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72913', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3859, 'longitude': -94.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72914', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3859, 'longitude': -94.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72916', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.2502, 'longitude': -94.3703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72917', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3859, 'longitude': -94.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72918', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3859, 'longitude': -94.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72919', 'place_name': 'Fort Smith', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3859, 'longitude': -94.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72923', 'place_name': 'Barling', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.333, 'longitude': -94.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72936', 'place_name': 'Greenwood', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.1955, 'longitude': -94.253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72937', 'place_name': 'Hackett', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.1945, 'longitude': -94.3983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72938', 'place_name': 'Hartford', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.0222, 'longitude': -94.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72940', 'place_name': 'Huntington', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.0963, 'longitude': -94.3313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72941', 'place_name': 'Lavaca', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.3661, 'longitude': -94.1917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72945', 'place_name': 'Midland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sebastian', 'locality_code': '131', 'latitude': 35.0932, 'longitude': -94.3533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71823', 'place_name': 'Ben Lomond', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sevier', 'locality_code': '133', 'latitude': 33.8115, 'longitude': -94.1251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71832', 'place_name': 'De Queen', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sevier', 'locality_code': '133', 'latitude': 34.0442, 'longitude': -94.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71841', 'place_name': 'Gillham', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sevier', 'locality_code': '133', 'latitude': 34.157, 'longitude': -94.3165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71842', 'place_name': 'Horatio', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sevier', 'locality_code': '133', 'latitude': 33.9392, 'longitude': -94.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71846', 'place_name': 'Lockesburg', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sevier', 'locality_code': '133', 'latitude': 33.9306, 'longitude': -94.1276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72482', 'place_name': 'Williford', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.2453, 'longitude': -91.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72513', 'place_name': 'Ash Flat', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.2201, 'longitude': -91.6421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72521', 'place_name': 'Cave City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 35.9517, 'longitude': -91.5444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72525', 'place_name': 'Cherokee Village', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.311, 'longitude': -91.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72529', 'place_name': 'Cherokee Village', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.3011, 'longitude': -91.5281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72532', 'place_name': 'Evening Shade', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.0855, 'longitude': -91.598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72542', 'place_name': 'Hardy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.3227, 'longitude': -91.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72569', 'place_name': 'Poughkeepsie', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.0767, 'longitude': -91.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72577', 'place_name': 'Sidney', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Sharp', 'locality_code': '135', 'latitude': 36.0664, 'longitude': -91.642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72051', 'place_name': 'Fox', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.7682, 'longitude': -92.3043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72533', 'place_name': 'Fifty Six', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.992, 'longitude': -92.2182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72555', 'place_name': 'Marcella', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.7756, 'longitude': -91.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72560', 'place_name': 'Mountain View', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.8208, 'longitude': -92.0389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72567', 'place_name': 'Pleasant Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.8265, 'longitude': -91.8958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72657', 'place_name': 'Timbo', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.919, 'longitude': -92.1272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72663', 'place_name': 'Onia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.9403, 'longitude': -92.3459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72680', 'place_name': 'Timbo', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Stone', 'locality_code': '137', 'latitude': 35.8845, 'longitude': -92.2913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71724', 'place_name': 'Calion', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.3261, 'longitude': -92.5464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71730', 'place_name': 'El Dorado', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.2073, 'longitude': -92.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71731', 'place_name': 'El Dorado', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.2076, 'longitude': -92.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71747', 'place_name': 'Huttig', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.0459, 'longitude': -92.1942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71749', 'place_name': 'Junction City', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.0163, 'longitude': -92.7243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71750', 'place_name': 'Lawson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.1968, 'longitude': -92.4829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71758', 'place_name': 'Mount Holly', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.3085, 'longitude': -92.9443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71759', 'place_name': 'Norphlet', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.316, 'longitude': -92.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71762', 'place_name': 'Smackover', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.3398, 'longitude': -92.7442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71765', 'place_name': 'Strong', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Union', 'locality_code': '139', 'latitude': 33.1195, 'longitude': -92.3621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72013', 'place_name': 'Bee Branch', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Van Buren', 'locality_code': '141', 'latitude': 35.4683, 'longitude': -92.3779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72028', 'place_name': 'Choctaw', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Van Buren', 'locality_code': '141', 'latitude': 35.5773, 'longitude': -92.5456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72031', 'place_name': 'Clinton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Van Buren', 'locality_code': '141', 'latitude': 35.6045, 'longitude': -92.4758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72088', 'place_name': 'Fairfield Bay', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Van Buren', 'locality_code': '141', 'latitude': 35.6027, 'longitude': -92.2742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72141', 'place_name': 'Scotland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Van Buren', 'locality_code': '141', 'latitude': 35.508, 'longitude': -92.5867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72153', 'place_name': 'Shirley', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Van Buren', 'locality_code': '141', 'latitude': 35.6498, 'longitude': -92.3143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72629', 'place_name': 'Dennard', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Van Buren', 'locality_code': '141', 'latitude': 35.7252, 'longitude': -92.5575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72701', 'place_name': 'Fayetteville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.052, 'longitude': -94.1534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72702', 'place_name': 'Fayetteville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.0626, 'longitude': -94.1574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72703', 'place_name': 'Fayetteville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.0992, 'longitude': -94.1716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72704', 'place_name': 'Fayetteville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.0877, 'longitude': -94.3093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72717', 'place_name': 'Canehill', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.8477, 'longitude': -94.4441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72727', 'place_name': 'Elkins', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.0177, 'longitude': -94.0073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72728', 'place_name': 'Elm Springs', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.21, 'longitude': -94.2546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72729', 'place_name': 'Evansville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.7823, 'longitude': -94.4638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72730', 'place_name': 'Farmington', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.0436, 'longitude': -94.2539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72735', 'place_name': 'Goshen', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.0876, 'longitude': -93.9666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72737', 'place_name': 'Greenland', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.9942, 'longitude': -94.1752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72741', 'place_name': 'Johnson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.1329, 'longitude': -94.1655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72744', 'place_name': 'Lincoln', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.9569, 'longitude': -94.4272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72749', 'place_name': 'Morrow', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.8654, 'longitude': -94.4432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72753', 'place_name': 'Prairie Grove', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.9918, 'longitude': -94.3169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72762', 'place_name': 'Springdale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.1835, 'longitude': -94.1762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72764', 'place_name': 'Springdale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.1716, 'longitude': -94.0428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72765', 'place_name': 'Springdale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.1725, 'longitude': -94.1535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72766', 'place_name': 'Springdale', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.1867, 'longitude': -94.1288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72769', 'place_name': 'Summers', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.0138, 'longitude': -94.5, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72770', 'place_name': 'Tontitown', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 36.15, 'longitude': -94.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72774', 'place_name': 'West Fork', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.9082, 'longitude': -94.2304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72959', 'place_name': 'Winslow', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Washington', 'locality_code': '143', 'latitude': 35.8312, 'longitude': -94.1187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72010', 'place_name': 'Bald Knob', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.3113, 'longitude': -91.5502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72012', 'place_name': 'Beebe', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.0937, 'longitude': -91.9074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72020', 'place_name': 'Bradford', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.4277, 'longitude': -91.519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72045', 'place_name': 'El Paso', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.1142, 'longitude': -92.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72052', 'place_name': 'Garner', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.1443, 'longitude': -91.7772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72060', 'place_name': 'Griffithville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.1144, 'longitude': -91.6242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72068', 'place_name': 'Higginson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.1903, 'longitude': -91.7108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72081', 'place_name': 'Judsonia', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.325, 'longitude': -91.6491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72082', 'place_name': 'Kensett', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.2388, 'longitude': -91.6731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72085', 'place_name': 'Letona', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.3617, 'longitude': -91.8293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72102', 'place_name': 'Mc Rae', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.1132, 'longitude': -91.8216, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '72121', 'place_name': 'Pangburn', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.4216, 'longitude': -91.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72136', 'place_name': 'Romance', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.2155, 'longitude': -92.0699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72137', 'place_name': 'Rose Bud', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.3214, 'longitude': -92.062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72139', 'place_name': 'Russell', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.3609, 'longitude': -91.5071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72143', 'place_name': 'Searcy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.2436, 'longitude': -91.7317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72145', 'place_name': 'Searcy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.2774, 'longitude': -91.7326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72149', 'place_name': 'Searcy', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.2474, 'longitude': -91.7314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72178', 'place_name': 'West Point', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'White', 'locality_code': '145', 'latitude': 35.2032, 'longitude': -91.6064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72006', 'place_name': 'Augusta', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Woodruff', 'locality_code': '147', 'latitude': 35.2788, 'longitude': -91.3527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72036', 'place_name': 'Cotton Plant', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Woodruff', 'locality_code': '147', 'latitude': 35.0178, 'longitude': -91.229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72059', 'place_name': 'Gregory', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Woodruff', 'locality_code': '147', 'latitude': 35.1554, 'longitude': -91.3432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72074', 'place_name': 'Hunter', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Woodruff', 'locality_code': '147', 'latitude': 35.0529, 'longitude': -91.1262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72101', 'place_name': 'Mc Crory', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Woodruff', 'locality_code': '147', 'latitude': 35.2473, 'longitude': -91.1793, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '72123', 'place_name': 'Patterson', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Woodruff', 'locality_code': '147', 'latitude': 35.2588, 'longitude': -91.237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72824', 'place_name': 'Belleville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 35.1038, 'longitude': -93.4518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72827', 'place_name': 'Bluffton', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 34.9016, 'longitude': -93.5919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72828', 'place_name': 'Briggsville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 34.9161, 'longitude': -93.5157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72829', 'place_name': 'Centerville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 35.1018, 'longitude': -93.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72833', 'place_name': 'Danville', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 35.0495, 'longitude': -93.3929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72834', 'place_name': 'Dardanelle', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 35.1955, 'longitude': -93.1873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72838', 'place_name': 'Gravelly', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 34.8881, 'longitude': -93.6802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72842', 'place_name': 'Havana', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 35.0832, 'longitude': -93.5955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72853', 'place_name': 'Ola', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 35.0309, 'longitude': -93.2136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72857', 'place_name': 'Plainview', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 34.9668, 'longitude': -93.3099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72860', 'place_name': 'Rover', 'state': 'Arkansas', 'state_ab': 'AR', 'county': 'Yell', 'locality_code': '149', 'latitude': 34.9475, 'longitude': -93.4017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85920', 'place_name': 'Alpine', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 33.8279, 'longitude': -109.1283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85924', 'place_name': 'Concho', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 34.4458, 'longitude': -109.6741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85925', 'place_name': 'Eagar', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 34.1077, 'longitude': -109.294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85927', 'place_name': 'Greer', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 34.0052, 'longitude': -109.4664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85930', 'place_name': 'Mcnary', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 34.0754, 'longitude': -109.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85932', 'place_name': 'Nutrioso', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 33.9531, 'longitude': -109.2092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85936', 'place_name': 'Saint Johns', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 34.501, 'longitude': -109.3796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85938', 'place_name': 'Springerville', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 34.1702, 'longitude': -109.3315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85940', 'place_name': 'Vernon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 34.2575, 'longitude': -109.6929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86028', 'place_name': 'Petrified Forest Natl Pk', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.2375, 'longitude': -109.5229, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86502', 'place_name': 'Chambers', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.2375, 'longitude': -109.5229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86503', 'place_name': 'Chinle', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.1304, 'longitude': -109.6037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86504', 'place_name': 'Fort Defiance', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.7445, 'longitude': -109.0765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86505', 'place_name': 'Ganado', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.7114, 'longitude': -109.542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86506', 'place_name': 'Houck', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.2831, 'longitude': -109.207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86507', 'place_name': 'Lukachukai', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.4181, 'longitude': -109.2446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86508', 'place_name': 'Lupton', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.3539, 'longitude': -109.0537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86511', 'place_name': 'Saint Michaels', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.6447, 'longitude': -109.0956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86512', 'place_name': 'Sanders', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.2164, 'longitude': -109.3337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86514', 'place_name': 'Teec Nos Pos', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.7797, 'longitude': -109.359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86515', 'place_name': 'Window Rock', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.6676, 'longitude': -109.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86535', 'place_name': 'Dennehotso', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.7773, 'longitude': -109.861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86538', 'place_name': 'Many Farms', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.4083, 'longitude': -109.634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86540', 'place_name': 'Nazlini', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.8964, 'longitude': -109.4487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86544', 'place_name': 'Red Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 35.2375, 'longitude': -109.5229, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86545', 'place_name': 'Rock Point', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.7181, 'longitude': -109.6259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86547', 'place_name': 'Round Rock', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.5131, 'longitude': -109.4734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86556', 'place_name': 'Tsaile', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Apache', 'locality_code': '1', 'latitude': 36.3071, 'longitude': -109.2176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85602', 'place_name': 'Benson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.9883, 'longitude': -110.2941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85603', 'place_name': 'Bisbee', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.4086, 'longitude': -109.9117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85605', 'place_name': 'Bowie', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 32.3265, 'longitude': -109.487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85606', 'place_name': 'Cochise', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 32.0979, 'longitude': -109.9239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85607', 'place_name': 'Douglas', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.3511, 'longitude': -109.5447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85608', 'place_name': 'Douglas', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.4151, 'longitude': -109.596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85609', 'place_name': 'Dragoon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 32.0281, 'longitude': -110.0387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85610', 'place_name': 'Elfrida', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.7139, 'longitude': -109.6193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85613', 'place_name': 'Fort Huachuca', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.5587, 'longitude': -110.3441, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85615', 'place_name': 'Hereford', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.4035, 'longitude': -110.2047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85616', 'place_name': 'Huachuca City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.6639, 'longitude': -110.3334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85617', 'place_name': 'Mc Neal', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.5121, 'longitude': -109.8438, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85620', 'place_name': 'Naco', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.3373, 'longitude': -109.9413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85625', 'place_name': 'Pearce', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.8885, 'longitude': -109.6119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85626', 'place_name': 'Pirtleville', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.3572, 'longitude': -109.5635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85627', 'place_name': 'Pomerene', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.9995, 'longitude': -110.2862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85630', 'place_name': 'Saint David', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.8973, 'longitude': -110.2154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85632', 'place_name': 'San Simon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 32.0423, 'longitude': -109.1748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85635', 'place_name': 'Sierra Vista', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.5365, 'longitude': -110.2666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85636', 'place_name': 'Sierra Vista', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.6687, 'longitude': -110.2801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85638', 'place_name': 'Tombstone', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.7216, 'longitude': -110.0584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85643', 'place_name': 'Willcox', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 32.373, 'longitude': -109.8631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85644', 'place_name': 'Willcox', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 32.2529, 'longitude': -109.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85650', 'place_name': 'Sierra Vista', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.4892, 'longitude': -110.2153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85655', 'place_name': 'Douglas', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.3447, 'longitude': -109.5468, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85670', 'place_name': 'Fort Huachuca', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.8801, 'longitude': -109.7543, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85671', 'place_name': 'Sierra Vista', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Cochise', 'locality_code': '3', 'latitude': 31.5545, 'longitude': -110.3037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85931', 'place_name': 'Forest Lakes', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 34.4513, 'longitude': -110.8644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86001', 'place_name': 'Flagstaff', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.1859, 'longitude': -111.662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86002', 'place_name': 'Flagstaff', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.1981, 'longitude': -111.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86003', 'place_name': 'Flagstaff', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.1981, 'longitude': -111.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86004', 'place_name': 'Flagstaff', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.2257, 'longitude': -111.5741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86005', 'place_name': 'Flagstaff', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.1545, 'longitude': -111.6789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86011', 'place_name': 'Flagstaff', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.1981, 'longitude': -111.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86015', 'place_name': 'Bellemont', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.2381, 'longitude': -111.8335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86016', 'place_name': 'Gray Mountain', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.7504, 'longitude': -111.6188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86017', 'place_name': 'Munds Park', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 34.9412, 'longitude': -111.641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86018', 'place_name': 'Parks', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.2563, 'longitude': -111.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86020', 'place_name': 'Cameron', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.9922, 'longitude': -111.5038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86022', 'place_name': 'Fredonia', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.9044, 'longitude': -112.4979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86023', 'place_name': 'Grand Canyon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.9421, 'longitude': -112.1309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86024', 'place_name': 'Happy Jack', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 34.6616, 'longitude': -111.3404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86035', 'place_name': 'Leupp', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.3365, 'longitude': -110.9927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86036', 'place_name': 'Marble Canyon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.737, 'longitude': -111.8229, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86038', 'place_name': 'Mormon Lake', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 34.9083, 'longitude': -111.463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86040', 'place_name': 'Page', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.9147, 'longitude': -111.4558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86044', 'place_name': 'Tonalea', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.7093, 'longitude': -110.8411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86045', 'place_name': 'Tuba City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.1037, 'longitude': -111.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86046', 'place_name': 'Williams', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 35.5434, 'longitude': -112.1707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86052', 'place_name': 'North Rim', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.2105, 'longitude': -112.0613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86053', 'place_name': 'Kaibeto', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.4025, 'longitude': -111.3518, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86336', 'place_name': 'Sedona', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 34.8266, 'longitude': -111.7506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86339', 'place_name': 'Sedona', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 34.8697, 'longitude': -111.761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86351', 'place_name': 'Sedona', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 34.7784, 'longitude': -111.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86435', 'place_name': 'Supai', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Coconino', 'locality_code': '5', 'latitude': 36.2242, 'longitude': -112.6932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85135', 'place_name': 'Hayden', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.0041, 'longitude': -110.7868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85192', 'place_name': 'Winkelman', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.0057, 'longitude': -110.7727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85501', 'place_name': 'Globe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.4024, 'longitude': -110.7892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85502', 'place_name': 'Globe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.3942, 'longitude': -110.7865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85532', 'place_name': 'Claypool', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.4154, 'longitude': -110.8149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85539', 'place_name': 'Miami', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.3992, 'longitude': -110.8687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85541', 'place_name': 'Payson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 34.2198, 'longitude': -111.2878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85542', 'place_name': 'Peridot', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.3103, 'longitude': -110.4554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85544', 'place_name': 'Pine', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 34.3435, 'longitude': -111.5353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85545', 'place_name': 'Roosevelt', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.6358, 'longitude': -110.9749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85547', 'place_name': 'Payson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 34.2575, 'longitude': -111.2878, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85550', 'place_name': 'San Carlos', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.3456, 'longitude': -110.455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85553', 'place_name': 'Tonto Basin', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 33.8317, 'longitude': -111.2946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85554', 'place_name': 'Young', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Gila', 'locality_code': '7', 'latitude': 34.1014, 'longitude': -110.9637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85530', 'place_name': 'Bylas', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 33.1265, 'longitude': -110.117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85531', 'place_name': 'Central', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 32.8692, 'longitude': -109.7878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85535', 'place_name': 'Eden', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 32.9612, 'longitude': -109.8954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85536', 'place_name': 'Fort Thomas', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 33.0333, 'longitude': -109.9717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85543', 'place_name': 'Pima', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 32.9097, 'longitude': -109.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85546', 'place_name': 'Safford', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 32.8295, 'longitude': -109.6266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85548', 'place_name': 'Safford', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 32.797, 'longitude': -109.7522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85551', 'place_name': 'Solomon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 32.8126, 'longitude': -109.634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85552', 'place_name': 'Thatcher', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Graham', 'locality_code': '9', 'latitude': 32.8504, 'longitude': -109.7461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85533', 'place_name': 'Clifton', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Greenlee', 'locality_code': '11', 'latitude': 33.1323, 'longitude': -109.2462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85534', 'place_name': 'Duncan', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Greenlee', 'locality_code': '11', 'latitude': 32.881, 'longitude': -109.2157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85540', 'place_name': 'Morenci', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Greenlee', 'locality_code': '11', 'latitude': 33.0787, 'longitude': -109.3654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85922', 'place_name': 'Blue', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Greenlee', 'locality_code': '11', 'latitude': 33.6512, 'longitude': -109.0685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85325', 'place_name': 'Bouse', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 33.9578, 'longitude': -114.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85328', 'place_name': 'Cibola', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 33.3164, 'longitude': -114.665, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85334', 'place_name': 'Ehrenberg', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 33.6177, 'longitude': -114.5077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85344', 'place_name': 'Parker', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 34.15, 'longitude': -114.2891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85346', 'place_name': 'Quartzsite', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 33.7292, 'longitude': -114.1925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85348', 'place_name': 'Salome', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 33.7481, 'longitude': -113.5715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85357', 'place_name': 'Wenden', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 34.0422, 'longitude': -113.458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85359', 'place_name': 'Quartzsite', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 33.6669, 'longitude': -114.2396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85371', 'place_name': 'Poston', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'La Paz', 'locality_code': '12', 'latitude': 33.9906, 'longitude': -114.3963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85001', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85002', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85003', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4511, 'longitude': -112.0774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85004', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4557, 'longitude': -112.0686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85005', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85006', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.465, 'longitude': -112.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85007', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4523, 'longitude': -112.0893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85008', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4665, 'longitude': -111.9984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85009', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4564, 'longitude': -112.1284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85010', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85011', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85012', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5097, 'longitude': -112.0678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85013', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5085, 'longitude': -112.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85014', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5103, 'longitude': -112.0556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85015', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5082, 'longitude': -112.1011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85016', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5021, 'longitude': -112.0305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85017', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5153, 'longitude': -112.1212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85018', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4958, 'longitude': -111.9883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85019', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5123, 'longitude': -112.1417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85020', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5623, 'longitude': -112.0559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85021', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.56, 'longitude': -112.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85022', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6315, 'longitude': -112.052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85023', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6324, 'longitude': -112.1118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85024', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6617, 'longitude': -112.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85025', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85026', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85027', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6819, 'longitude': -112.0996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85028', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5851, 'longitude': -112.0087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85029', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5961, 'longitude': -112.1199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85030', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85031', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4939, 'longitude': -112.1696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85032', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6238, 'longitude': -112.0044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85033', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4944, 'longitude': -112.2132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85034', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4413, 'longitude': -112.0421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85035', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4724, 'longitude': -112.1832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85036', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85037', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4913, 'longitude': -112.2468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85038', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85039', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85040', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4061, 'longitude': -112.0265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85041', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3889, 'longitude': -112.0954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85042', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3794, 'longitude': -112.0283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85043', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4491, 'longitude': -112.1972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85044', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3291, 'longitude': -111.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85045', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3022, 'longitude': -112.1226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85046', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85048', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.316, 'longitude': -112.0669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85050', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6863, 'longitude': -111.9963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85051', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5591, 'longitude': -112.1332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85053', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6299, 'longitude': -112.1316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85054', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6731, 'longitude': -111.9461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85060', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85061', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85062', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85063', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85064', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85065', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85066', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85067', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85068', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85069', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85070', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85071', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85072', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85073', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85074', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85075', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85076', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85078', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85079', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85080', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85082', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85083', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7352, 'longitude': -112.1294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85085', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7529, 'longitude': -112.0893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85086', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.8155, 'longitude': -112.1202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85087', 'place_name': 'New River', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.9235, 'longitude': -112.1279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85097', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85098', 'place_name': 'Phoenix', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4484, 'longitude': -112.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85127', 'place_name': 'Chandler Heights', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.2125, 'longitude': -111.697, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85142', 'place_name': 'Queen Creek', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.2487, 'longitude': -111.6343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85190', 'place_name': 'Tortilla Flat', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5264, 'longitude': -111.3892, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85201', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4317, 'longitude': -111.8469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85202', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3851, 'longitude': -111.8724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85203', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.437, 'longitude': -111.8057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85204', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3992, 'longitude': -111.7896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85205', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4368, 'longitude': -111.7129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85206', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4026, 'longitude': -111.7242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85207', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4321, 'longitude': -111.6426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85208', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3984, 'longitude': -111.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85209', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3782, 'longitude': -111.6406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85210', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3887, 'longitude': -111.8428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85211', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4663, 'longitude': -111.8373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85212', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3425, 'longitude': -111.6353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85213', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4367, 'longitude': -111.7731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85214', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4125, 'longitude': -111.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85215', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4707, 'longitude': -111.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85216', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4125, 'longitude': -111.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85224', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3301, 'longitude': -111.8632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85225', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3105, 'longitude': -111.8239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85226', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3092, 'longitude': -111.9198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85233', 'place_name': 'Gilbert', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3354, 'longitude': -111.8153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85234', 'place_name': 'Gilbert', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3527, 'longitude': -111.7809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85236', 'place_name': 'Higley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3024, 'longitude': -111.6969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85244', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3213, 'longitude': -111.8888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85246', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3062, 'longitude': -111.8413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85248', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.2509, 'longitude': -111.8593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85249', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.2414, 'longitude': -111.7745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85250', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5218, 'longitude': -111.9049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85251', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4936, 'longitude': -111.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85252', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4995, 'longitude': -111.8684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85253', 'place_name': 'Paradise Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5494, 'longitude': -111.9565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85254', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6165, 'longitude': -111.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85255', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6968, 'longitude': -111.8892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85256', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4858, 'longitude': -111.8533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85257', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4669, 'longitude': -111.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85258', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5647, 'longitude': -111.8931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85259', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5879, 'longitude': -111.8404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85260', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6013, 'longitude': -111.8867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85261', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5092, 'longitude': -111.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85262', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7752, 'longitude': -111.7791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85263', 'place_name': 'Rio Verde', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7225, 'longitude': -111.6757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85264', 'place_name': 'Fort Mcdowell', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6118, 'longitude': -111.6806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85266', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7669, 'longitude': -111.9182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85267', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5092, 'longitude': -111.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85268', 'place_name': 'Fountain Hills', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6085, 'longitude': -111.7237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85269', 'place_name': 'Fountain Hills', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6117, 'longitude': -111.7174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85271', 'place_name': 'Scottsdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5092, 'longitude': -111.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85274', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4125, 'longitude': -111.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85275', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4125, 'longitude': -111.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85277', 'place_name': 'Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4125, 'longitude': -111.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85280', 'place_name': 'Tempe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4014, 'longitude': -111.9313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85281', 'place_name': 'Tempe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4227, 'longitude': -111.9261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85282', 'place_name': 'Tempe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3917, 'longitude': -111.9249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85283', 'place_name': 'Tempe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3665, 'longitude': -111.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85284', 'place_name': 'Tempe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3363, 'longitude': -111.9197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85285', 'place_name': 'Tempe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4148, 'longitude': -111.9093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85286', 'place_name': 'Chandler', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.2711, 'longitude': -111.8311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85287', 'place_name': 'Tempe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4285, 'longitude': -111.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85295', 'place_name': 'Gilbert', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3054, 'longitude': -111.7408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85296', 'place_name': 'Gilbert', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3354, 'longitude': -111.7406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85297', 'place_name': 'Gilbert', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.2781, 'longitude': -111.7096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85298', 'place_name': 'Gilbert', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.2522, 'longitude': -111.7022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85299', 'place_name': 'Gilbert', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3528, 'longitude': -111.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85301', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5311, 'longitude': -112.1767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85302', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5675, 'longitude': -112.1753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85303', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5262, 'longitude': -112.2149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85304', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5943, 'longitude': -112.1746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85305', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5291, 'longitude': -112.2482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85306', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6239, 'longitude': -112.1776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85307', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5376, 'longitude': -112.3137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85308', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6539, 'longitude': -112.1694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85309', 'place_name': 'Luke Air Force Base', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5387, 'longitude': -112.186, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85310', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7047, 'longitude': -112.1641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85311', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5387, 'longitude': -112.186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85312', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5387, 'longitude': -112.186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85318', 'place_name': 'Glendale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5387, 'longitude': -112.186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85320', 'place_name': 'Aguila', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.9186, 'longitude': -113.2134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85322', 'place_name': 'Arlington', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3133, 'longitude': -112.7891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85323', 'place_name': 'Avondale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4321, 'longitude': -112.3438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85326', 'place_name': 'Buckeye', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3703, 'longitude': -112.5838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85327', 'place_name': 'Cave Creek', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.8333, 'longitude': -111.9508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85329', 'place_name': 'Cashion', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4353, 'longitude': -112.2979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85331', 'place_name': 'Cave Creek', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.8851, 'longitude': -111.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85335', 'place_name': 'El Mirage', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6082, 'longitude': -112.3241, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85337', 'place_name': 'Gila Bend', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 32.9306, 'longitude': -112.7468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85338', 'place_name': 'Goodyear', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4368, 'longitude': -112.3834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85339', 'place_name': 'Laveen', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3436, 'longitude': -112.1716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85340', 'place_name': 'Litchfield Park', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5098, 'longitude': -112.4135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85342', 'place_name': 'Morristown', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.8567, 'longitude': -112.6232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85343', 'place_name': 'Palo Verde', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.3481, 'longitude': -112.6774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85345', 'place_name': 'Peoria', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5761, 'longitude': -112.2344, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85351', 'place_name': 'Sun City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6061, 'longitude': -112.2797, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85353', 'place_name': 'Tolleson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4347, 'longitude': -112.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85354', 'place_name': 'Tonopah', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4228, 'longitude': -112.9528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85355', 'place_name': 'Waddell', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5673, 'longitude': -112.4387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85358', 'place_name': 'Wickenburg', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.9686, 'longitude': -112.7296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85361', 'place_name': 'Wittmann', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7637, 'longitude': -112.6142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85363', 'place_name': 'Youngtown', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5908, 'longitude': -112.3013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85372', 'place_name': 'Sun City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5975, 'longitude': -112.2718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85373', 'place_name': 'Sun City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6588, 'longitude': -112.3214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85374', 'place_name': 'Surprise', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.63, 'longitude': -112.3314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85375', 'place_name': 'Sun City West', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6856, 'longitude': -112.3659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85376', 'place_name': 'Sun City West', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.662, 'longitude': -112.3413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85377', 'place_name': 'Carefree', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.824, 'longitude': -111.913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85378', 'place_name': 'Surprise', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6306, 'longitude': -112.3332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85379', 'place_name': 'Surprise', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6021, 'longitude': -112.3736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85380', 'place_name': 'Peoria', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5806, 'longitude': -112.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85381', 'place_name': 'Peoria', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6048, 'longitude': -112.2237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85382', 'place_name': 'Peoria', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6308, 'longitude': -112.2072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85383', 'place_name': 'Peoria', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7169, 'longitude': -112.238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85385', 'place_name': 'Peoria', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.5806, 'longitude': -112.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85387', 'place_name': 'Surprise', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.7129, 'longitude': -112.4375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85388', 'place_name': 'Surprise', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.6134, 'longitude': -112.4512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85390', 'place_name': 'Wickenburg', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.8944, 'longitude': -112.8603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85392', 'place_name': 'Avondale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.4777, 'longitude': -112.3093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85395', 'place_name': 'Goodyear', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.479, 'longitude': -112.3947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85396', 'place_name': 'Buckeye', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Maricopa', 'locality_code': '13', 'latitude': 33.468, 'longitude': -112.4787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85360', 'place_name': 'Wikieup', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.7033, 'longitude': -113.6113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86021', 'place_name': 'Colorado City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 36.9903, 'longitude': -112.9758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86401', 'place_name': 'Kingman', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.1328, 'longitude': -113.7033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86402', 'place_name': 'Kingman', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.2632, 'longitude': -114.0637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86403', 'place_name': 'Lake Havasu City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.4814, 'longitude': -114.3483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86404', 'place_name': 'Lake Havasu City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.5575, 'longitude': -114.3307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86405', 'place_name': 'Lake Havasu City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.4839, 'longitude': -114.3225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86406', 'place_name': 'Lake Havasu City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.4228, 'longitude': -114.125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86409', 'place_name': 'Kingman', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.2633, 'longitude': -114.0223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86411', 'place_name': 'Hackberry', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.3692, 'longitude': -113.7272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86412', 'place_name': 'Hualapai', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.3972, 'longitude': -113.8432, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86413', 'place_name': 'Golden Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.3002, 'longitude': -114.2215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86426', 'place_name': 'Fort Mohave', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.0052, 'longitude': -114.5687, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86427', 'place_name': 'Fort Mohave', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.0043, 'longitude': -114.5812, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86429', 'place_name': 'Bullhead City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.1715, 'longitude': -114.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86430', 'place_name': 'Bullhead City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.1473, 'longitude': -114.5433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86431', 'place_name': 'Chloride', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.3896, 'longitude': -114.2221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86432', 'place_name': 'Littlefield', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 36.8872, 'longitude': -113.9297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86433', 'place_name': 'Oatman', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.0285, 'longitude': -114.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86434', 'place_name': 'Peach Springs', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.5378, 'longitude': -113.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86436', 'place_name': 'Topock', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.7784, 'longitude': -114.4817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86437', 'place_name': 'Valentine', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.3788, 'longitude': -113.6141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86438', 'place_name': 'Yucca', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.8722, 'longitude': -114.1494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86439', 'place_name': 'Bullhead City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.1478, 'longitude': -114.5683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86440', 'place_name': 'Mohave Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.8929, 'longitude': -114.5951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86441', 'place_name': 'Dolan Springs', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.5692, 'longitude': -114.3777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86442', 'place_name': 'Bullhead City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.106, 'longitude': -114.5947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86443', 'place_name': 'Temple Bar Marina', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.2106, 'longitude': -114.1792, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86444', 'place_name': 'Meadview', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.9822, 'longitude': -114.0775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86445', 'place_name': 'Willow Beach', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 35.7759, 'longitude': -114.5001, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86446', 'place_name': 'Mohave Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Mohave', 'locality_code': '15', 'latitude': 34.8499, 'longitude': -114.5917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85901', 'place_name': 'Show Low', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.2998, 'longitude': -110, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85902', 'place_name': 'Show Low', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.2981, 'longitude': -110.0352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85911', 'place_name': 'Cibecue', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.0448, 'longitude': -110.4854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85912', 'place_name': 'White Mountain Lake', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.2666, 'longitude': -110.2031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85923', 'place_name': 'Clay Springs', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.3617, 'longitude': -110.2954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85926', 'place_name': 'Fort Apache', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 33.7906, 'longitude': -109.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85928', 'place_name': 'Heber', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.41, 'longitude': -110.5883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85929', 'place_name': 'Lakeside', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.1662, 'longitude': -109.9869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85933', 'place_name': 'Overgaard', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.4086, 'longitude': -110.56, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85934', 'place_name': 'Pinedale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.3003, 'longitude': -110.2457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85935', 'place_name': 'Pinetop', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.1175, 'longitude': -109.9197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85937', 'place_name': 'Snowflake', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.4959, 'longitude': -110.0807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85939', 'place_name': 'Taylor', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.439, 'longitude': -110.0858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85941', 'place_name': 'Whiteriver', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 33.8021, 'longitude': -109.9937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85942', 'place_name': 'Woodruff', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.7814, 'longitude': -110.0435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86025', 'place_name': 'Holbrook', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.9085, 'longitude': -110.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86029', 'place_name': 'Sun Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.9806, 'longitude': -110.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86030', 'place_name': 'Hotevilla', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 35.9278, 'longitude': -110.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86031', 'place_name': 'Indian Wells', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 35.4056, 'longitude': -110.0848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86032', 'place_name': 'Joseph City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 34.9814, 'longitude': -110.3373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86033', 'place_name': 'Kayenta', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 36.6883, 'longitude': -110.2652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86034', 'place_name': 'Keams Canyon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 35.8082, 'longitude': -110.2845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86039', 'place_name': 'Kykotsmovi Village', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 35.8742, 'longitude': -110.6235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86042', 'place_name': 'Polacca', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 35.8617, 'longitude': -110.3875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86043', 'place_name': 'Second Mesa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 35.7933, 'longitude': -110.5051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86047', 'place_name': 'Winslow', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 35.0242, 'longitude': -110.6974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86054', 'place_name': 'Shonto', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 36.6159, 'longitude': -110.6477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86510', 'place_name': 'Pinon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 36.1002, 'longitude': -110.2211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86520', 'place_name': 'Blue Gap', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Navajo', 'locality_code': '17', 'latitude': 36.1708, 'longitude': -109.9465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85321', 'place_name': 'Ajo', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2295, 'longitude': -112.6542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85341', 'place_name': 'Lukeville', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.8826, 'longitude': -112.8157, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85601', 'place_name': 'Arivaca', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.5885, 'longitude': -111.316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85614', 'place_name': 'Green Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.8543, 'longitude': -111.0003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85619', 'place_name': 'Mount Lemmon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.3763, 'longitude': -110.7605, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85622', 'place_name': 'Green Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.8269, 'longitude': -111.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85629', 'place_name': 'Sahuarita', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.9452, 'longitude': -111.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85633', 'place_name': 'Sasabe', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.4887, 'longitude': -111.5421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85634', 'place_name': 'Sells', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.0315, 'longitude': -112.0065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85639', 'place_name': 'Topawa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.814, 'longitude': -111.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85641', 'place_name': 'Vail', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.0027, 'longitude': -110.7053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85652', 'place_name': 'Cortaro', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.4201, 'longitude': -111.1132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85653', 'place_name': 'Marana', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.4047, 'longitude': -111.2736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85654', 'place_name': 'Rillito', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.4148, 'longitude': -111.1562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85701', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2139, 'longitude': -110.9694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85702', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85703', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85704', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.3379, 'longitude': -110.9855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85705', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2691, 'longitude': -110.9845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85706', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.1392, 'longitude': -110.9451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85707', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.1696, 'longitude': -110.8751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85708', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.18, 'longitude': -110.8693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85709', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2008, 'longitude': -110.898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85710', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2138, 'longitude': -110.824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85711', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2127, 'longitude': -110.8829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85712', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.25, 'longitude': -110.8869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85713', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.1941, 'longitude': -110.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85714', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.1707, 'longitude': -110.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85715', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2519, 'longitude': -110.82, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85716', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2468, 'longitude': -110.9222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85717', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85718', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.3112, 'longitude': -110.9179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85719', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2474, 'longitude': -110.9491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85720', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85721', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2338, 'longitude': -110.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85722', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85723', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85724', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2406, 'longitude': -110.9443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85725', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85726', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2027, 'longitude': -110.9453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85728', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85730', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.181, 'longitude': -110.819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85731', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85732', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85733', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85734', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.0651, 'longitude': -110.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85735', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.093, 'longitude': -111.3472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85736', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 31.9011, 'longitude': -111.3702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85737', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.4142, 'longitude': -110.9466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85738', 'place_name': 'Catalina', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.5056, 'longitude': -110.9211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85739', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.465, 'longitude': -110.8922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85740', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85741', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.3472, 'longitude': -111.0419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85742', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.4076, 'longitude': -111.065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85743', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.3366, 'longitude': -111.1771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85744', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85745', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2434, 'longitude': -111.0179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85746', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.1422, 'longitude': -111.0506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85747', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.0984, 'longitude': -110.7272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85748', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.215, 'longitude': -110.7758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85749', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2733, 'longitude': -110.7658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85750', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2974, 'longitude': -110.8404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85751', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85752', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85754', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85755', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.4227, 'longitude': -110.9768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85756', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.0839, 'longitude': -110.9004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85757', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.1336, 'longitude': -111.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85775', 'place_name': 'Tucson', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pima', 'locality_code': '19', 'latitude': 32.2217, 'longitude': -110.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85117', 'place_name': 'Apache Junction', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.3284, 'longitude': -111.327, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85118', 'place_name': 'Gold Canyon', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.3284, 'longitude': -111.3502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85119', 'place_name': 'Apache Junction', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.4001, 'longitude': -111.5028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85120', 'place_name': 'Apache Junction', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.3931, 'longitude': -111.5768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85121', 'place_name': 'Bapchule', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.1405, 'longitude': -111.9128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85122', 'place_name': 'Casa Grande', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.8905, 'longitude': -111.754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85123', 'place_name': 'Arizona City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.7559, 'longitude': -111.671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85128', 'place_name': 'Coolidge', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.9574, 'longitude': -111.5344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85130', 'place_name': 'Casa Grande', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.8151, 'longitude': -111.7054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85131', 'place_name': 'Eloy', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.7509, 'longitude': -111.5833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85132', 'place_name': 'Florence', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.9969, 'longitude': -111.3612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85137', 'place_name': 'Kearny', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.0594, 'longitude': -110.9123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85138', 'place_name': 'Maricopa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.0073, 'longitude': -111.9324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85139', 'place_name': 'Maricopa', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.9576, 'longitude': -112.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85140', 'place_name': 'San Tan Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.1911, 'longitude': -111.528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85141', 'place_name': 'Picacho', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.6686, 'longitude': -111.4549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85143', 'place_name': 'San Tan Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.1911, 'longitude': -111.528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85145', 'place_name': 'Red Rock', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.58, 'longitude': -111.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85147', 'place_name': 'Sacaton', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.1234, 'longitude': -111.7384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85172', 'place_name': 'Stanfield', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.8823, 'longitude': -111.966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85173', 'place_name': 'Superior', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.2887, 'longitude': -111.0985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85178', 'place_name': 'Apache Junction', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 33.405, 'longitude': -111.547, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85191', 'place_name': 'Valley Farms', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.9827, 'longitude': -111.4429, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85193', 'place_name': 'Casa Grande', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.8554, 'longitude': -111.7973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85194', 'place_name': 'Casa Grande', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.8984, 'longitude': -111.6261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85618', 'place_name': 'Mammoth', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.7239, 'longitude': -110.644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85623', 'place_name': 'Oracle', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.6005, 'longitude': -110.7961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85631', 'place_name': 'San Manuel', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.6209, 'longitude': -110.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85658', 'place_name': 'Marana', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Pinal', 'locality_code': '21', 'latitude': 32.4305, 'longitude': -111.1459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85611', 'place_name': 'Elgin', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.6598, 'longitude': -110.5254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85621', 'place_name': 'Nogales', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.377, 'longitude': -110.9435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85624', 'place_name': 'Patagonia', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.5353, 'longitude': -110.6968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85628', 'place_name': 'Nogales', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.532, 'longitude': -110.9093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85637', 'place_name': 'Sonoita', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.6731, 'longitude': -110.6188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85640', 'place_name': 'Tumacacori', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.5696, 'longitude': -111.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85645', 'place_name': 'Amado', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.6723, 'longitude': -111.0986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85646', 'place_name': 'Tubac', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.6126, 'longitude': -111.0459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85648', 'place_name': 'Rio Rico', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.5084, 'longitude': -111.0757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85662', 'place_name': 'Nogales', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Santa Cruz', 'locality_code': '23', 'latitude': 31.532, 'longitude': -110.9093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85324', 'place_name': 'Black Canyon City', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.0755, 'longitude': -112.134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85332', 'place_name': 'Congress', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.1764, 'longitude': -112.768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85362', 'place_name': 'Yarnell', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.2508, 'longitude': -112.7567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86301', 'place_name': 'Prescott', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5917, 'longitude': -112.4265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86302', 'place_name': 'Prescott', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5749, 'longitude': -112.4915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86303', 'place_name': 'Prescott', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.4958, 'longitude': -112.3783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86304', 'place_name': 'Prescott', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5967, 'longitude': -112.4907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86305', 'place_name': 'Prescott', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.8185, 'longitude': -112.9584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86312', 'place_name': 'Prescott Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.6683, 'longitude': -112.3078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86313', 'place_name': 'Prescott', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7067, 'longitude': -112.3977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86314', 'place_name': 'Prescott Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.6019, 'longitude': -112.3264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86315', 'place_name': 'Prescott Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7055, 'longitude': -112.2639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86320', 'place_name': 'Ash Fork', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 35.215, 'longitude': -112.5027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86321', 'place_name': 'Bagdad', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5785, 'longitude': -113.1755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86322', 'place_name': 'Camp Verde', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5697, 'longitude': -111.8551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86323', 'place_name': 'Chino Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7757, 'longitude': -112.4731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86324', 'place_name': 'Clarkdale', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7711, 'longitude': -112.0579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86325', 'place_name': 'Cornville', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7256, 'longitude': -111.9086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86326', 'place_name': 'Cottonwood', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7055, 'longitude': -112.0091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86327', 'place_name': 'Dewey', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5368, 'longitude': -112.2567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86329', 'place_name': 'Humboldt', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5009, 'longitude': -112.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86331', 'place_name': 'Jerome', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7486, 'longitude': -112.1086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86332', 'place_name': 'Kirkland', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.4541, 'longitude': -112.8966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86333', 'place_name': 'Mayer', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.3655, 'longitude': -112.1296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86334', 'place_name': 'Paulden', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 35.0313, 'longitude': -112.5441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86335', 'place_name': 'Rimrock', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.638, 'longitude': -111.7842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86337', 'place_name': 'Seligman', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 35.3212, 'longitude': -112.9548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86338', 'place_name': 'Skull Valley', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.5053, 'longitude': -112.6855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86340', 'place_name': 'Sedona', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7067, 'longitude': -112.3977, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86341', 'place_name': 'Sedona', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.7766, 'longitude': -111.7679, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '86342', 'place_name': 'Lake Montezuma', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.6417, 'longitude': -111.7872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '86343', 'place_name': 'Crown King', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yavapai', 'locality_code': '25', 'latitude': 34.2241, 'longitude': -112.334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85333', 'place_name': 'Dateland', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.8679, 'longitude': -113.4631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85336', 'place_name': 'Gadsden', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.5545, 'longitude': -114.785, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85347', 'place_name': 'Roll', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.7517, 'longitude': -113.9891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85349', 'place_name': 'San Luis', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.487, 'longitude': -114.7822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85350', 'place_name': 'Somerton', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.5634, 'longitude': -114.7127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85352', 'place_name': 'Tacna', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.6934, 'longitude': -113.9763, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '85356', 'place_name': 'Wellton', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.6935, 'longitude': -114.1561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85364', 'place_name': 'Yuma', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.7015, 'longitude': -114.6424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85365', 'place_name': 'Yuma', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.7093, 'longitude': -114.4905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85366', 'place_name': 'Yuma', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.61, 'longitude': -114.6312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85367', 'place_name': 'Yuma', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.6566, 'longitude': -114.4042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '85369', 'place_name': 'Yuma', 'state': 'Arizona', 'state_ab': 'AZ', 'county': 'Yuma', 'locality_code': '27', 'latitude': 32.7253, 'longitude': -114.6244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94501', 'place_name': 'Alameda', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7706, 'longitude': -122.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94502', 'place_name': 'Alameda', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7351, 'longitude': -122.2431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94536', 'place_name': 'Fremont', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.5605, 'longitude': -121.9999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94537', 'place_name': 'Fremont', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6802, 'longitude': -121.9215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94538', 'place_name': 'Fremont', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.5308, 'longitude': -121.9712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94539', 'place_name': 'Fremont', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.5176, 'longitude': -121.9287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94540', 'place_name': 'Hayward', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6802, 'longitude': -121.9215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94541', 'place_name': 'Hayward', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.674, 'longitude': -122.0894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94542', 'place_name': 'Hayward', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6586, 'longitude': -122.0472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94543', 'place_name': 'Hayward', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6688, 'longitude': -122.0808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94544', 'place_name': 'Hayward', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6374, 'longitude': -122.067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94545', 'place_name': 'Hayward', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6332, 'longitude': -122.0971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94546', 'place_name': 'Castro Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7015, 'longitude': -122.0782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94550', 'place_name': 'Livermore', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.683, 'longitude': -121.763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94551', 'place_name': 'Livermore', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7526, 'longitude': -121.77, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94552', 'place_name': 'Castro Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7131, 'longitude': -122.0381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94555', 'place_name': 'Fremont', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.5735, 'longitude': -122.0469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94557', 'place_name': 'Hayward', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6802, 'longitude': -121.9215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94560', 'place_name': 'Newark', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.5368, 'longitude': -122.032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94566', 'place_name': 'Pleasanton', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6658, 'longitude': -121.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94568', 'place_name': 'Dublin', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7166, 'longitude': -121.9226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94577', 'place_name': 'San Leandro', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7205, 'longitude': -122.1587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94578', 'place_name': 'San Leandro', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7024, 'longitude': -122.124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94579', 'place_name': 'San Leandro', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6892, 'longitude': -122.1507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94580', 'place_name': 'San Lorenzo', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6787, 'longitude': -122.1295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94586', 'place_name': 'Sunol', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6094, 'longitude': -121.8986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94587', 'place_name': 'Union City', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.5895, 'longitude': -122.0497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94588', 'place_name': 'Pleasanton', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.6873, 'longitude': -121.8957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94601', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7806, 'longitude': -122.2166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94602', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8011, 'longitude': -122.2104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94603', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7402, 'longitude': -122.171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94604', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94605', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7641, 'longitude': -122.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94606', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7957, 'longitude': -122.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94607', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8071, 'longitude': -122.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94608', 'place_name': 'Emeryville', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8365, 'longitude': -122.2804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94609', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8361, 'longitude': -122.2637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94610', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8126, 'longitude': -122.2443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94611', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8471, 'longitude': -122.2223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94612', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8085, 'longitude': -122.2668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94613', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7811, 'longitude': -122.1866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94614', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7277, 'longitude': -122.2046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94615', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8067, 'longitude': -122.3004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94617', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8078, 'longitude': -122.2717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94618', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8431, 'longitude': -122.2402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94619', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7878, 'longitude': -122.1884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94620', 'place_name': 'Piedmont', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8244, 'longitude': -122.2316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94621', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.7589, 'longitude': -122.1853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94622', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.799, 'longitude': -122.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94623', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94624', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94649', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94659', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94660', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94661', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94662', 'place_name': 'Emeryville', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8313, 'longitude': -122.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94666', 'place_name': 'Oakland', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8044, 'longitude': -122.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94701', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8606, 'longitude': -122.2967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94702', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8656, 'longitude': -122.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94703', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.863, 'longitude': -122.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94704', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8664, 'longitude': -122.257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94705', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8571, 'longitude': -122.25, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94706', 'place_name': 'Albany', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.89, 'longitude': -122.2954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94707', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8927, 'longitude': -122.2761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94708', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8918, 'longitude': -122.2604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94709', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8784, 'longitude': -122.2655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94710', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8696, 'longitude': -122.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94712', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8716, 'longitude': -122.2727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94720', 'place_name': 'Berkeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Alameda', 'locality_code': '1', 'latitude': 37.8738, 'longitude': -122.2549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95646', 'place_name': 'Kirkwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Alpine', 'locality_code': '3', 'latitude': 38.6918, 'longitude': -120.0736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96120', 'place_name': 'Markleeville', 'state': 'California', 'state_ab': 'CA', 'county': 'Alpine', 'locality_code': '3', 'latitude': 38.7713, 'longitude': -119.8327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95601', 'place_name': 'Amador City', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.4194, 'longitude': -120.823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95629', 'place_name': 'Fiddletown', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.5234, 'longitude': -120.6763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95640', 'place_name': 'Ione', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.3324, 'longitude': -120.9418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95642', 'place_name': 'Jackson', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.3545, 'longitude': -120.7573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95644', 'place_name': 'Kit Carson', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.6707, 'longitude': -120.1135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95654', 'place_name': 'Martell', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.3515, 'longitude': -120.7752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95665', 'place_name': 'Pine Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.4049, 'longitude': -120.6544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95666', 'place_name': 'Pioneer', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.4319, 'longitude': -120.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95669', 'place_name': 'Plymouth', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.4916, 'longitude': -120.8819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95675', 'place_name': 'River Pines', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.5463, 'longitude': -120.743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95685', 'place_name': 'Sutter Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.4175, 'longitude': -120.7951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95689', 'place_name': 'Volcano', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.4765, 'longitude': -120.6017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95699', 'place_name': 'Drytown', 'state': 'California', 'state_ab': 'CA', 'county': 'Amador', 'locality_code': '5', 'latitude': 38.4411, 'longitude': -120.8533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95914', 'place_name': 'Bangor', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.3885, 'longitude': -121.4052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95916', 'place_name': 'Berry Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.6776, 'longitude': -121.3689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95917', 'place_name': 'Biggs', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.4162, 'longitude': -121.7189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95926', 'place_name': 'Chico', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.7458, 'longitude': -121.8444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95927', 'place_name': 'Chico', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.8117, 'longitude': -121.9398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95928', 'place_name': 'Chico', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.7224, 'longitude': -121.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95929', 'place_name': 'Chico', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.7301, 'longitude': -121.8414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95930', 'place_name': 'Clipper Mills', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.5327, 'longitude': -121.1575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95938', 'place_name': 'Durham', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.633, 'longitude': -121.7886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95940', 'place_name': 'Feather Falls', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.622, 'longitude': -121.2669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95941', 'place_name': 'Forbestown', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.521, 'longitude': -121.2423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95942', 'place_name': 'Forest Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.8821, 'longitude': -121.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95948', 'place_name': 'Gridley', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.3532, 'longitude': -121.7137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95954', 'place_name': 'Magalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.8912, 'longitude': -121.58, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95958', 'place_name': 'Nelson', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.5522, 'longitude': -121.7644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95965', 'place_name': 'Oroville', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.6054, 'longitude': -121.5751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95966', 'place_name': 'Oroville', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.4877, 'longitude': -121.4698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95967', 'place_name': 'Paradise', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.7155, 'longitude': -121.6551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95968', 'place_name': 'Palermo', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.4361, 'longitude': -121.5454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95969', 'place_name': 'Paradise', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.7555, 'longitude': -121.6069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95973', 'place_name': 'Chico', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.8032, 'longitude': -121.8673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95974', 'place_name': 'Richvale', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.4959, 'longitude': -121.748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95976', 'place_name': 'Chico', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.7346, 'longitude': -121.8331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95978', 'place_name': 'Stirling City', 'state': 'California', 'state_ab': 'CA', 'county': 'Butte', 'locality_code': '7', 'latitude': 39.9077, 'longitude': -121.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95221', 'place_name': 'Altaville', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.0838, 'longitude': -120.5608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95222', 'place_name': 'Angels Camp', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.071, 'longitude': -120.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95223', 'place_name': 'Arnold', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.3086, 'longitude': -120.268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95224', 'place_name': 'Avery', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.2044, 'longitude': -120.3688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95225', 'place_name': 'Burson', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.1838, 'longitude': -120.8894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95226', 'place_name': 'Campo Seco', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.2271, 'longitude': -120.8533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95228', 'place_name': 'Copperopolis', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 37.944, 'longitude': -120.6423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95229', 'place_name': 'Douglas Flat', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.1144, 'longitude': -120.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95232', 'place_name': 'Glencoe', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.3554, 'longitude': -120.5778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95233', 'place_name': 'Hathaway Pines', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.1919, 'longitude': -120.3644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95245', 'place_name': 'Mokelumne Hill', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.3152, 'longitude': -120.5591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95246', 'place_name': 'Mountain Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.2328, 'longitude': -120.4994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95247', 'place_name': 'Murphys', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.1345, 'longitude': -120.4516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95248', 'place_name': 'Rail Road Flat', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.3405, 'longitude': -120.5161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95249', 'place_name': 'San Andreas', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.1904, 'longitude': -120.6441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95251', 'place_name': 'Vallecito', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.1013, 'longitude': -120.4676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95252', 'place_name': 'Valley Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.162, 'longitude': -120.8572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95254', 'place_name': 'Wallace', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.1983, 'longitude': -120.9793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95255', 'place_name': 'West Point', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.4197, 'longitude': -120.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95257', 'place_name': 'Wilseyville', 'state': 'California', 'state_ab': 'CA', 'county': 'Calaveras', 'locality_code': '9', 'latitude': 38.3793, 'longitude': -120.4627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95912', 'place_name': 'Arbuckle', 'state': 'California', 'state_ab': 'CA', 'county': 'Colusa', 'locality_code': '11', 'latitude': 39.0138, 'longitude': -122.0274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95932', 'place_name': 'Colusa', 'state': 'California', 'state_ab': 'CA', 'county': 'Colusa', 'locality_code': '11', 'latitude': 39.2345, 'longitude': -122.0277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95950', 'place_name': 'Grimes', 'state': 'California', 'state_ab': 'CA', 'county': 'Colusa', 'locality_code': '11', 'latitude': 39.0744, 'longitude': -121.8927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95955', 'place_name': 'Maxwell', 'state': 'California', 'state_ab': 'CA', 'county': 'Colusa', 'locality_code': '11', 'latitude': 39.3163, 'longitude': -122.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95970', 'place_name': 'Princeton', 'state': 'California', 'state_ab': 'CA', 'county': 'Colusa', 'locality_code': '11', 'latitude': 39.4168, 'longitude': -122.0519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95979', 'place_name': 'Stonyford', 'state': 'California', 'state_ab': 'CA', 'county': 'Colusa', 'locality_code': '11', 'latitude': 39.3176, 'longitude': -122.5393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95987', 'place_name': 'Williams', 'state': 'California', 'state_ab': 'CA', 'county': 'Colusa', 'locality_code': '11', 'latitude': 39.1337, 'longitude': -122.2162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94505', 'place_name': 'Discovery Bay', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8989, 'longitude': -121.6054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94506', 'place_name': 'Danville', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8321, 'longitude': -121.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94507', 'place_name': 'Alamo', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8537, 'longitude': -122.0229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94509', 'place_name': 'Antioch', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9939, 'longitude': -121.8089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94511', 'place_name': 'Bethel Island', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 38.0266, 'longitude': -121.6425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94513', 'place_name': 'Brentwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9324, 'longitude': -121.6894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94514', 'place_name': 'Byron', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8254, 'longitude': -121.6236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94516', 'place_name': 'Canyon', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8339, 'longitude': -122.165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94517', 'place_name': 'Clayton', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9154, 'longitude': -121.91, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94518', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9504, 'longitude': -122.0263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94519', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9841, 'longitude': -122.0119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94520', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9823, 'longitude': -122.0362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94521', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9575, 'longitude': -121.975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94522', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.978, 'longitude': -122.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94523', 'place_name': 'Pleasant Hill', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.954, 'longitude': -122.0737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94524', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.978, 'longitude': -122.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94525', 'place_name': 'Crockett', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 38.0519, 'longitude': -122.2177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94526', 'place_name': 'Danville', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.814, 'longitude': -121.966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94527', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9535, 'longitude': -121.9578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94528', 'place_name': 'Diablo', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8387, 'longitude': -121.9667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94529', 'place_name': 'Concord', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.978, 'longitude': -122.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94530', 'place_name': 'El Cerrito', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9156, 'longitude': -122.2985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94531', 'place_name': 'Antioch', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9658, 'longitude': -121.7758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94547', 'place_name': 'Hercules', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 38.0066, 'longitude': -122.2637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94548', 'place_name': 'Knightsen', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9726, 'longitude': -121.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94549', 'place_name': 'Lafayette', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8961, 'longitude': -122.1119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94553', 'place_name': 'Martinez', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9864, 'longitude': -122.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94556', 'place_name': 'Moraga', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8437, 'longitude': -122.1242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94561', 'place_name': 'Oakley', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.994, 'longitude': -121.7036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94563', 'place_name': 'Orinda', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8787, 'longitude': -122.1728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94564', 'place_name': 'Pinole', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9969, 'longitude': -122.2875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94565', 'place_name': 'Pittsburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 38.0031, 'longitude': -121.9172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94569', 'place_name': 'Port Costa', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 38.046, 'longitude': -122.1866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94570', 'place_name': 'Moraga', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.7772, 'longitude': -121.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94572', 'place_name': 'Rodeo', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 38.0307, 'longitude': -122.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94575', 'place_name': 'Moraga', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.7772, 'longitude': -121.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94582', 'place_name': 'San Ramon', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.7636, 'longitude': -121.9155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94583', 'place_name': 'San Ramon', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.7562, 'longitude': -121.9522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94595', 'place_name': 'Walnut Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.8753, 'longitude': -122.0703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94596', 'place_name': 'Walnut Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9053, 'longitude': -122.0549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94597', 'place_name': 'Walnut Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9182, 'longitude': -122.0717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94598', 'place_name': 'Walnut Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9194, 'longitude': -122.0259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94801', 'place_name': 'Richmond', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.94, 'longitude': -122.362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94802', 'place_name': 'Richmond', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9358, 'longitude': -122.3477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94803', 'place_name': 'El Sobrante', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9693, 'longitude': -122.2901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94804', 'place_name': 'Richmond', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9265, 'longitude': -122.3342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94805', 'place_name': 'Richmond', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9417, 'longitude': -122.3238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94806', 'place_name': 'San Pablo', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9724, 'longitude': -122.3369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94807', 'place_name': 'Richmond', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9358, 'longitude': -122.3477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94808', 'place_name': 'Richmond', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9358, 'longitude': -122.3477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94820', 'place_name': 'El Sobrante', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9771, 'longitude': -122.2952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94850', 'place_name': 'Richmond', 'state': 'California', 'state_ab': 'CA', 'county': 'Contra Costa', 'locality_code': '13', 'latitude': 37.9358, 'longitude': -122.3477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95531', 'place_name': 'Crescent City', 'state': 'California', 'state_ab': 'CA', 'county': 'Del Norte', 'locality_code': '15', 'latitude': 41.7817, 'longitude': -124.1332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95532', 'place_name': 'Crescent City', 'state': 'California', 'state_ab': 'CA', 'county': 'Del Norte', 'locality_code': '15', 'latitude': 41.7561, 'longitude': -124.2005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95538', 'place_name': 'Fort Dick', 'state': 'California', 'state_ab': 'CA', 'county': 'Del Norte', 'locality_code': '15', 'latitude': 41.8679, 'longitude': -124.149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95543', 'place_name': 'Gasquet', 'state': 'California', 'state_ab': 'CA', 'county': 'Del Norte', 'locality_code': '15', 'latitude': 41.9056, 'longitude': -123.831, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95548', 'place_name': 'Klamath', 'state': 'California', 'state_ab': 'CA', 'county': 'Del Norte', 'locality_code': '15', 'latitude': 41.5804, 'longitude': -124.0387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95567', 'place_name': 'Smith River', 'state': 'California', 'state_ab': 'CA', 'county': 'Del Norte', 'locality_code': '15', 'latitude': 41.9404, 'longitude': -124.1587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95613', 'place_name': 'Coloma', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8, 'longitude': -120.8891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95614', 'place_name': 'Cool', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8923, 'longitude': -120.9802, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95619', 'place_name': 'Diamond Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.6865, 'longitude': -120.8145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95623', 'place_name': 'El Dorado', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.633, 'longitude': -120.8498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95633', 'place_name': 'Garden Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8665, 'longitude': -120.8567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95634', 'place_name': 'Georgetown', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.9185, 'longitude': -120.7599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95635', 'place_name': 'Greenwood', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.9143, 'longitude': -120.9001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95636', 'place_name': 'Grizzly Flats', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.6489, 'longitude': -120.5098, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95651', 'place_name': 'Lotus', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8278, 'longitude': -120.9238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95656', 'place_name': 'Mount Aukum', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.55, 'longitude': -120.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95664', 'place_name': 'Pilot Hill', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8135, 'longitude': -121.0308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95667', 'place_name': 'Placerville', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.7195, 'longitude': -120.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95672', 'place_name': 'Rescue', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.7194, 'longitude': -120.9945, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95682', 'place_name': 'Shingle Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.6465, 'longitude': -120.9641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95684', 'place_name': 'Somerset', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.5953, 'longitude': -120.5949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95709', 'place_name': 'Camino', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.747, 'longitude': -120.6743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95720', 'place_name': 'Kyburz', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.7825, 'longitude': -120.2569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95721', 'place_name': 'Echo Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8338, 'longitude': -120.0416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95726', 'place_name': 'Pollock Pines', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.7708, 'longitude': -120.5427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95735', 'place_name': 'Twin Bridges', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8092, 'longitude': -120.1242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95762', 'place_name': 'El Dorado Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.685, 'longitude': -121.068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96142', 'place_name': 'Tahoma', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 39.0644, 'longitude': -120.1357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96150', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.917, 'longitude': -119.9865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96151', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.9039, 'longitude': -119.995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96152', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.9271, 'longitude': -119.999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96154', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8753, 'longitude': -120.0188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96155', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8449, 'longitude': -120.043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96156', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.9352, 'longitude': -119.9676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96157', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.9344, 'longitude': -119.9767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96158', 'place_name': 'South Lake Tahoe', 'state': 'California', 'state_ab': 'CA', 'county': 'El Dorado', 'locality_code': '17', 'latitude': 38.8981, 'longitude': -119.9984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93210', 'place_name': 'Coalinga', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.1624, 'longitude': -120.3489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93234', 'place_name': 'Huron', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.2371, 'longitude': -120.102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93242', 'place_name': 'Laton', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.4378, 'longitude': -119.7156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93602', 'place_name': 'Auberry', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 37.0726, 'longitude': -119.4572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93605', 'place_name': 'Big Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 37.2032, 'longitude': -119.2492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93606', 'place_name': 'Biola', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8032, 'longitude': -120.0185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93607', 'place_name': 'Burrel', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.5898, 'longitude': -119.8994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93608', 'place_name': 'Cantua Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.4921, 'longitude': -120.3353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93609', 'place_name': 'Caruthers', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.5358, 'longitude': -119.8446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93611', 'place_name': 'Clovis', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8253, 'longitude': -119.6802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93612', 'place_name': 'Clovis', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8149, 'longitude': -119.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93613', 'place_name': 'Clovis', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8252, 'longitude': -119.7029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93616', 'place_name': 'Del Rey', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6543, 'longitude': -119.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93621', 'place_name': 'Dunlap', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7446, 'longitude': -119.0899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93622', 'place_name': 'Firebaugh', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8651, 'longitude': -120.47, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93624', 'place_name': 'Five Points', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.3386, 'longitude': -120.1118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93625', 'place_name': 'Fowler', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6282, 'longitude': -119.671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93626', 'place_name': 'Friant', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 37.0422, 'longitude': -119.6807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93627', 'place_name': 'Helm', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.5316, 'longitude': -120.0982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93628', 'place_name': 'Hume', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7515, 'longitude': -118.9575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93630', 'place_name': 'Kerman', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7306, 'longitude': -120.0724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93631', 'place_name': 'Kingsburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.508, 'longitude': -119.5433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93634', 'place_name': 'Lakeshore', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 37.253, 'longitude': -119.1748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93640', 'place_name': 'Mendota', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7424, 'longitude': -120.4093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93641', 'place_name': 'Miramonte', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6894, 'longitude': -119.0477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93642', 'place_name': 'Mono Hot Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 37.3266, 'longitude': -119.0176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93646', 'place_name': 'Orange Cove', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6255, 'longitude': -119.3204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93648', 'place_name': 'Parlier', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6103, 'longitude': -119.5375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93649', 'place_name': 'Piedra', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8417, 'longitude': -119.3496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93650', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8411, 'longitude': -119.801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93651', 'place_name': 'Prather', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.9938, 'longitude': -119.5268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93652', 'place_name': 'Raisin City', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6024, 'longitude': -119.904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93654', 'place_name': 'Reedley', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6044, 'longitude': -119.4378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93656', 'place_name': 'Riverdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.4295, 'longitude': -119.872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93657', 'place_name': 'Sanger', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7243, 'longitude': -119.5478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93660', 'place_name': 'San Joaquin', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6059, 'longitude': -120.1889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93662', 'place_name': 'Selma', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.5695, 'longitude': -119.617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93664', 'place_name': 'Shaver Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 37.1397, 'longitude': -119.273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93667', 'place_name': 'Tollhouse', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.9943, 'longitude': -119.3914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93668', 'place_name': 'Tranquillity', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6584, 'longitude': -120.2617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93675', 'place_name': 'Squaw Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7071, 'longitude': -119.1814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93701', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7487, 'longitude': -119.7867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93702', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.74, 'longitude': -119.7532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93703', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7684, 'longitude': -119.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93704', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7991, 'longitude': -119.8016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93705', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7863, 'longitude': -119.8286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93706', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6486, 'longitude': -119.9987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93707', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93708', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93709', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93710', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8236, 'longitude': -119.7621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93711', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8303, 'longitude': -119.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93712', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93714', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93715', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93716', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93717', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93718', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93720', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8579, 'longitude': -119.7655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93721', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7377, 'longitude': -119.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93722', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7918, 'longitude': -119.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93723', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7863, 'longitude': -119.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93724', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93725', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.6207, 'longitude': -119.7308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93726', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7949, 'longitude': -119.7604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93727', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7528, 'longitude': -119.7061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93728', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7581, 'longitude': -119.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93729', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93730', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.8878, 'longitude': -119.7589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93737', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7477, 'longitude': -119.7724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93740', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93741', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93744', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93745', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93747', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93750', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93755', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93760', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93761', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93764', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93765', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93771', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93772', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93773', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93774', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93775', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93776', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93777', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93778', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93779', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93786', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93790', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93791', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93792', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93793', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93794', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93844', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93888', 'place_name': 'Fresno', 'state': 'California', 'state_ab': 'CA', 'county': 'Fresno', 'locality_code': '19', 'latitude': 36.7464, 'longitude': -119.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95913', 'place_name': 'Artois', 'state': 'California', 'state_ab': 'CA', 'county': 'Glenn', 'locality_code': '21', 'latitude': 39.6197, 'longitude': -122.1927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95920', 'place_name': 'Butte City', 'state': 'California', 'state_ab': 'CA', 'county': 'Glenn', 'locality_code': '21', 'latitude': 39.4568, 'longitude': -121.9515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95939', 'place_name': 'Elk Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Glenn', 'locality_code': '21', 'latitude': 39.5306, 'longitude': -122.6124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95943', 'place_name': 'Glenn', 'state': 'California', 'state_ab': 'CA', 'county': 'Glenn', 'locality_code': '21', 'latitude': 39.6069, 'longitude': -122.0384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95951', 'place_name': 'Hamilton City', 'state': 'California', 'state_ab': 'CA', 'county': 'Glenn', 'locality_code': '21', 'latitude': 39.7386, 'longitude': -122.0085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95963', 'place_name': 'Orland', 'state': 'California', 'state_ab': 'CA', 'county': 'Glenn', 'locality_code': '21', 'latitude': 39.7314, 'longitude': -122.2534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95988', 'place_name': 'Willows', 'state': 'California', 'state_ab': 'CA', 'county': 'Glenn', 'locality_code': '21', 'latitude': 39.5353, 'longitude': -122.2597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95501', 'place_name': 'Eureka', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.7938, 'longitude': -124.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95502', 'place_name': 'Eureka', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.7965, 'longitude': -124.1737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95503', 'place_name': 'Eureka', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.7592, 'longitude': -124.1593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95511', 'place_name': 'Alderpoint', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.1676, 'longitude': -123.6192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95514', 'place_name': 'Blocksburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.2987, 'longitude': -123.6576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95518', 'place_name': 'Arcata', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.8685, 'longitude': -124.0856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95519', 'place_name': 'Mckinleyville', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.9465, 'longitude': -124.0834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95521', 'place_name': 'Arcata', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.8742, 'longitude': -124.0765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95524', 'place_name': 'Bayside', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.8266, 'longitude': -124.0552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95525', 'place_name': 'Blue Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.9374, 'longitude': -123.8913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95526', 'place_name': 'Bridgeville', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.4693, 'longitude': -123.7998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95528', 'place_name': 'Carlotta', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.507, 'longitude': -123.9743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95534', 'place_name': 'Cutten', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.7965, 'longitude': -124.1737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95536', 'place_name': 'Ferndale', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.5259, 'longitude': -124.2514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95537', 'place_name': 'Fields Landing', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.7268, 'longitude': -124.2174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95540', 'place_name': 'Fortuna', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.5835, 'longitude': -124.1473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95542', 'place_name': 'Garberville', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.0864, 'longitude': -123.7991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95545', 'place_name': 'Honeydew', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.2421, 'longitude': -124.0972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95546', 'place_name': 'Hoopa', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 41.0504, 'longitude': -123.6742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95547', 'place_name': 'Hydesville', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.5485, 'longitude': -124.0847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95549', 'place_name': 'Kneeland', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.6405, 'longitude': -123.8826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95550', 'place_name': 'Korbel', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.7775, 'longitude': -123.8486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95551', 'place_name': 'Loleta', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.6589, 'longitude': -124.2251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95553', 'place_name': 'Miranda', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.2397, 'longitude': -123.8077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95554', 'place_name': 'Myers Flat', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.2841, 'longitude': -123.7945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95555', 'place_name': 'Orick', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 41.3596, 'longitude': -124.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95556', 'place_name': 'Orleans', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 41.3115, 'longitude': -123.5399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95558', 'place_name': 'Petrolia', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.2868, 'longitude': -124.2271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95559', 'place_name': 'Phillipsville', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.2008, 'longitude': -123.7735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95560', 'place_name': 'Redway', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.1201, 'longitude': -123.8234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95562', 'place_name': 'Rio Dell', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.4987, 'longitude': -124.1102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95564', 'place_name': 'Samoa', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.8037, 'longitude': -124.1936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95565', 'place_name': 'Scotia', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.4583, 'longitude': -124.0517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95569', 'place_name': 'Redcrest', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.3437, 'longitude': -123.9095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95570', 'place_name': 'Trinidad', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 41.0593, 'longitude': -124.1431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95571', 'place_name': 'Weott', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.3218, 'longitude': -123.9217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95573', 'place_name': 'Willow Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.9484, 'longitude': -123.6276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95589', 'place_name': 'Whitethorn', 'state': 'California', 'state_ab': 'CA', 'county': 'Humboldt', 'locality_code': '23', 'latitude': 40.0231, 'longitude': -124.0139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92222', 'place_name': 'Bard', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.7822, 'longitude': -114.5619, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92227', 'place_name': 'Brawley', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.9792, 'longitude': -115.5296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92231', 'place_name': 'Calexico', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.6832, 'longitude': -115.5028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92232', 'place_name': 'Calexico', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.6789, 'longitude': -115.4989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92233', 'place_name': 'Calipatria', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 33.167, 'longitude': -115.5114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92243', 'place_name': 'El Centro', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.7893, 'longitude': -115.5665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92244', 'place_name': 'El Centro', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.7948, 'longitude': -115.6927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92249', 'place_name': 'Heber', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.7218, 'longitude': -115.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92250', 'place_name': 'Holtville', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.8104, 'longitude': -115.3775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92251', 'place_name': 'Imperial', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.847, 'longitude': -115.573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92257', 'place_name': 'Niland', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 33.3784, 'longitude': -115.6965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92259', 'place_name': 'Ocotillo', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.7387, 'longitude': -115.9942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92266', 'place_name': 'Palo Verde', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 33.3696, 'longitude': -114.7355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92273', 'place_name': 'Seeley', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.7941, 'longitude': -115.6948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92275', 'place_name': 'Salton City', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 33.3092, 'longitude': -115.9578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92281', 'place_name': 'Westmorland', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 33.038, 'longitude': -115.5914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92283', 'place_name': 'Winterhaven', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 32.9818, 'longitude': -114.6854, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92331', 'place_name': 'Fontana', 'state': 'California', 'state_ab': 'CA', 'county': 'Imperial', 'locality_code': '25', 'latitude': 34.0922, 'longitude': -117.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92328', 'place_name': 'Death Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 36.4672, 'longitude': -116.8937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92384', 'place_name': 'Shoshone', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 35.973, 'longitude': -116.2711, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92389', 'place_name': 'Tecopa', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 35.9021, 'longitude': -116.1544, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93513', 'place_name': 'Big Pine', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 37.1679, 'longitude': -118.2916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93514', 'place_name': 'Bishop', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 37.5014, 'longitude': -118.4048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93515', 'place_name': 'Bishop', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 37.3635, 'longitude': -118.3951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93522', 'place_name': 'Darwin', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 36.2948, 'longitude': -117.5957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93526', 'place_name': 'Independence', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 36.8396, 'longitude': -118.2048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93530', 'place_name': 'Keeler', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 36.4886, 'longitude': -117.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93542', 'place_name': 'Little Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 35.9366, 'longitude': -117.9067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93545', 'place_name': 'Lone Pine', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 36.5798, 'longitude': -118.0578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93549', 'place_name': 'Olancha', 'state': 'California', 'state_ab': 'CA', 'county': 'Inyo', 'locality_code': '27', 'latitude': 36.23, 'longitude': -117.9552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93203', 'place_name': 'Arvin', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.1966, 'longitude': -118.8336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93205', 'place_name': 'Bodfish', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.587, 'longitude': -118.4847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93206', 'place_name': 'Buttonwillow', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.4033, 'longitude': -119.4659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93215', 'place_name': 'Delano', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.7715, 'longitude': -119.2459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93216', 'place_name': 'Delano', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.7688, 'longitude': -119.2471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93220', 'place_name': 'Edison', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3475, 'longitude': -118.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93222', 'place_name': 'Pine Mountain Club', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 34.8469, 'longitude': -119.1568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93224', 'place_name': 'Fellows', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.1786, 'longitude': -119.5412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93225', 'place_name': 'Frazier Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 34.8265, 'longitude': -119.0355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93226', 'place_name': 'Glennville', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.7377, 'longitude': -118.7169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93238', 'place_name': 'Kernville', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.755, 'longitude': -118.4047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93240', 'place_name': 'Lake Isabella', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.669, 'longitude': -118.457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93241', 'place_name': 'Lamont', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2571, 'longitude': -118.9124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93243', 'place_name': 'Lebec', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 34.8818, 'longitude': -118.8566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93249', 'place_name': 'Lost Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.6163, 'longitude': -119.6943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93250', 'place_name': 'Mc Farland', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.6758, 'longitude': -119.2272, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93251', 'place_name': 'Mc Kittrick', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3031, 'longitude': -119.6366, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93252', 'place_name': 'Maricopa', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.0589, 'longitude': -119.401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93255', 'place_name': 'Onyx', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.6824, 'longitude': -118.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93263', 'place_name': 'Shafter', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.497, 'longitude': -119.2801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93268', 'place_name': 'Taft', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.1482, 'longitude': -119.4557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93276', 'place_name': 'Tupman', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2992, 'longitude': -119.3584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93280', 'place_name': 'Wasco', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.648, 'longitude': -119.4487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93283', 'place_name': 'Weldon', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.6391, 'longitude': -118.2859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93285', 'place_name': 'Wofford Heights', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.7246, 'longitude': -118.4559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93287', 'place_name': 'Woody', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.7068, 'longitude': -118.8439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93301', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3866, 'longitude': -119.0171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93302', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3733, 'longitude': -119.0187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93303', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93304', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3396, 'longitude': -119.0218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93305', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3855, 'longitude': -118.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93306', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3867, 'longitude': -118.9391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93307', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3275, 'longitude': -118.9839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93308', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.4244, 'longitude': -119.0433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93309', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3384, 'longitude': -119.0627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93311', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3039, 'longitude': -119.1056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93312', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3935, 'longitude': -119.1205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93313', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2974, 'longitude': -119.0509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93314', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3863, 'longitude': -119.17, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93380', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93383', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93384', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3733, 'longitude': -119.0187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93385', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93386', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93387', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93388', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93389', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93390', 'place_name': 'Bakersfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2944, 'longitude': -118.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93501', 'place_name': 'Mojave', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.0478, 'longitude': -118.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93502', 'place_name': 'Mojave', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.0525, 'longitude': -118.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93504', 'place_name': 'California City', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.1871, 'longitude': -117.8854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93505', 'place_name': 'California City', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.1278, 'longitude': -117.9651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93516', 'place_name': 'Boron', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.0037, 'longitude': -117.6629, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93518', 'place_name': 'Caliente', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3701, 'longitude': -118.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93519', 'place_name': 'Cantil', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3089, 'longitude': -117.9684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93523', 'place_name': 'Edwards', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 34.9261, 'longitude': -117.9351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93524', 'place_name': 'Edwards', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 34.932, 'longitude': -117.9071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93527', 'place_name': 'Inyokern', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.6397, 'longitude': -117.857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93528', 'place_name': 'Johannesburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3708, 'longitude': -117.6427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93531', 'place_name': 'Keene', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.2375, 'longitude': -118.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93554', 'place_name': 'Randsburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.3866, 'longitude': -117.7159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93555', 'place_name': 'Ridgecrest', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.6225, 'longitude': -117.6709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93556', 'place_name': 'Ridgecrest', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.6225, 'longitude': -117.6709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93560', 'place_name': 'Rosamond', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 34.8664, 'longitude': -118.3409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93561', 'place_name': 'Tehachapi', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.1322, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93581', 'place_name': 'Tehachapi', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 35.1322, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93596', 'place_name': 'Boron', 'state': 'California', 'state_ab': 'CA', 'county': 'Kern', 'locality_code': '29', 'latitude': 34.9994, 'longitude': -117.6498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93202', 'place_name': 'Armona', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.3095, 'longitude': -119.7053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93204', 'place_name': 'Avenal', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 35.9877, 'longitude': -120.1227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93212', 'place_name': 'Corcoran', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.0865, 'longitude': -119.5607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93230', 'place_name': 'Hanford', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.3314, 'longitude': -119.6491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93232', 'place_name': 'Hanford', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.3275, 'longitude': -119.6457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93239', 'place_name': 'Kettleman City', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.0083, 'longitude': -119.9618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93245', 'place_name': 'Lemoore', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.2682, 'longitude': -119.8173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93246', 'place_name': 'Lemoore', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.1389, 'longitude': -119.8947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93266', 'place_name': 'Stratford', 'state': 'California', 'state_ab': 'CA', 'county': 'Kings', 'locality_code': '31', 'latitude': 36.179, 'longitude': -119.8236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95422', 'place_name': 'Clearlake', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 38.9576, 'longitude': -122.636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95423', 'place_name': 'Clearlake Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.0664, 'longitude': -122.6558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95424', 'place_name': 'Clearlake Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 38.9666, 'longitude': -122.65, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95426', 'place_name': 'Cobb', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 38.8155, 'longitude': -122.7132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95435', 'place_name': 'Finley', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.0043, 'longitude': -122.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95443', 'place_name': 'Glenhaven', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.0263, 'longitude': -122.733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95451', 'place_name': 'Kelseyville', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 38.9421, 'longitude': -122.7777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95453', 'place_name': 'Lakeport', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.047, 'longitude': -122.9328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95457', 'place_name': 'Lower Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 38.8915, 'longitude': -122.5914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95458', 'place_name': 'Lucerne', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.0783, 'longitude': -122.7846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95461', 'place_name': 'Middletown', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 38.7824, 'longitude': -122.6487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95464', 'place_name': 'Nice', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.1194, 'longitude': -122.8315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95467', 'place_name': 'Hidden Valley Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 38.8036, 'longitude': -122.5407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95485', 'place_name': 'Upper Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.1804, 'longitude': -122.9144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95493', 'place_name': 'Witter Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Lake', 'locality_code': '33', 'latitude': 39.1821, 'longitude': -122.9711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96009', 'place_name': 'Bieber', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 41.1315, 'longitude': -121.1286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96068', 'place_name': 'Nubieber', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 41.0957, 'longitude': -121.183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96109', 'place_name': 'Doyle', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.0008, 'longitude': -120.1077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96113', 'place_name': 'Herlong', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.1485, 'longitude': -120.1713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96114', 'place_name': 'Janesville', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.2963, 'longitude': -120.5098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96117', 'place_name': 'Litchfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.4073, 'longitude': -120.4092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96119', 'place_name': 'Madeline', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.9766, 'longitude': -120.5548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96121', 'place_name': 'Milford', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.1828, 'longitude': -120.3895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96123', 'place_name': 'Ravendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.7985, 'longitude': -120.3652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96127', 'place_name': 'Susanville', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.4163, 'longitude': -120.653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96128', 'place_name': 'Standish', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.3509, 'longitude': -120.4068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96130', 'place_name': 'Susanville', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.3983, 'longitude': -120.6464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96132', 'place_name': 'Termo', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.9509, 'longitude': -120.613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96136', 'place_name': 'Wendel', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.3406, 'longitude': -120.2824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96137', 'place_name': 'Westwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Lassen', 'locality_code': '35', 'latitude': 40.3038, 'longitude': -121.0226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90001', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9731, 'longitude': -118.2479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90002', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9497, 'longitude': -118.2462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90003', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9653, 'longitude': -118.2727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90004', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0762, 'longitude': -118.3029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90005', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0585, 'longitude': -118.3012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90006', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0493, 'longitude': -118.2917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90007', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0294, 'longitude': -118.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90008', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0116, 'longitude': -118.3411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90009', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90010', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0606, 'longitude': -118.3027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90011', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0079, 'longitude': -118.2582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90012', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0614, 'longitude': -118.2385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90013', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0448, 'longitude': -118.2434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90014', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0443, 'longitude': -118.2509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90015', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0434, 'longitude': -118.2716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90016', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0298, 'longitude': -118.3528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90017', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0559, 'longitude': -118.2666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90018', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.029, 'longitude': -118.3152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90019', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0482, 'longitude': -118.3343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90020', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0665, 'longitude': -118.3022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90021', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0333, 'longitude': -118.2447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90022', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0245, 'longitude': -118.1561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90023', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0245, 'longitude': -118.1975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90024', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0637, 'longitude': -118.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90025', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0447, 'longitude': -118.4487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90026', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0766, 'longitude': -118.2646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90027', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.104, 'longitude': -118.2925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90028', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1005, 'longitude': -118.3254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90029', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.09, 'longitude': -118.2944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90030', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90031', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0783, 'longitude': -118.2113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90032', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0818, 'longitude': -118.1753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90033', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0487, 'longitude': -118.2084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90034', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.029, 'longitude': -118.4005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90035', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0531, 'longitude': -118.3806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90036', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0699, 'longitude': -118.3492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90037', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.003, 'longitude': -118.2863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90038', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0898, 'longitude': -118.3215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90039', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1121, 'longitude': -118.2594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90040', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9909, 'longitude': -118.1532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90041', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1339, 'longitude': -118.2082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90042', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1145, 'longitude': -118.1929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90043', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9871, 'longitude': -118.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90044', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9551, 'longitude': -118.2901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90045', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9631, 'longitude': -118.3941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90046', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1074, 'longitude': -118.3652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90047', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9569, 'longitude': -118.3073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90048', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0737, 'longitude': -118.372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90049', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.066, 'longitude': -118.474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90050', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90051', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90052', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90053', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90054', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90055', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90056', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9853, 'longitude': -118.3707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90057', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0622, 'longitude': -118.2763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90058', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9994, 'longitude': -118.2133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90059', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9293, 'longitude': -118.2463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90060', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90061', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9245, 'longitude': -118.2716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90062', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0032, 'longitude': -118.3073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90063', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0451, 'longitude': -118.1859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90064', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0353, 'longitude': -118.4259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90065', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1073, 'longitude': -118.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90066', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.003, 'longitude': -118.4298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90067', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0551, 'longitude': -118.4095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90068', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1156, 'longitude': -118.3305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90069', 'place_name': 'West Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0906, 'longitude': -118.3788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90070', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90071', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0529, 'longitude': -118.2549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90072', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90073', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90074', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90075', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90076', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90077', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1112, 'longitude': -118.4502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90078', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90079', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90080', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90081', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90082', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90083', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90084', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90086', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90087', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90088', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90089', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90090', 'place_name': 'Dodgertown', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0725, 'longitude': -118.2418, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '90091', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90093', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90094', 'place_name': 'Playa Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9728, 'longitude': -118.4276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90095', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90096', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90099', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90134', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0522, 'longitude': -118.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90189', 'place_name': 'Los Angeles', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0515, 'longitude': -118.2559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90201', 'place_name': 'Bell Gardens', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9653, 'longitude': -118.1515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90202', 'place_name': 'Bell', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9775, 'longitude': -118.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90209', 'place_name': 'Beverly Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0736, 'longitude': -118.4004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90210', 'place_name': 'Beverly Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0901, 'longitude': -118.4065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90211', 'place_name': 'Beverly Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0652, 'longitude': -118.383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90212', 'place_name': 'Beverly Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0619, 'longitude': -118.3995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90213', 'place_name': 'Beverly Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0736, 'longitude': -118.4004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90220', 'place_name': 'Compton', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8748, 'longitude': -118.2402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90221', 'place_name': 'Compton', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8796, 'longitude': -118.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90222', 'place_name': 'Compton', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9099, 'longitude': -118.2357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90223', 'place_name': 'Compton', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8958, 'longitude': -118.2201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90224', 'place_name': 'Compton', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90230', 'place_name': 'Culver City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9949, 'longitude': -118.3991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90231', 'place_name': 'Culver City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0211, 'longitude': -118.3965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90232', 'place_name': 'Culver City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0168, 'longitude': -118.3973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90233', 'place_name': 'Culver City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0211, 'longitude': -118.3965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90239', 'place_name': 'Downey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.94, 'longitude': -118.1326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90240', 'place_name': 'Downey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9581, 'longitude': -118.1174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90241', 'place_name': 'Downey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9416, 'longitude': -118.1306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90242', 'place_name': 'Downey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9218, 'longitude': -118.1395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90245', 'place_name': 'El Segundo', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9243, 'longitude': -118.4119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90247', 'place_name': 'Gardena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8925, 'longitude': -118.2961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90248', 'place_name': 'Gardena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8766, 'longitude': -118.2835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90249', 'place_name': 'Gardena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8998, 'longitude': -118.3199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90250', 'place_name': 'Hawthorne', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9143, 'longitude': -118.3493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90251', 'place_name': 'Hawthorne', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9164, 'longitude': -118.3526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90254', 'place_name': 'Hermosa Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8643, 'longitude': -118.3955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90255', 'place_name': 'Huntington Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9769, 'longitude': -118.2161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90260', 'place_name': 'Lawndale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8879, 'longitude': -118.351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90261', 'place_name': 'Lawndale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8872, 'longitude': -118.3526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90262', 'place_name': 'Lynwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9241, 'longitude': -118.2013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90263', 'place_name': 'Malibu', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.005, 'longitude': -118.8101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90264', 'place_name': 'Malibu', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.005, 'longitude': -118.8101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90265', 'place_name': 'Malibu', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0402, 'longitude': -118.7351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90266', 'place_name': 'Manhattan Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8896, 'longitude': -118.3996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90267', 'place_name': 'Manhattan Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90270', 'place_name': 'Maywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.989, 'longitude': -118.1877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90272', 'place_name': 'Pacific Palisades', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0481, 'longitude': -118.5265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90274', 'place_name': 'Palos Verdes Peninsula', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7669, 'longitude': -118.3806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90275', 'place_name': 'Rancho Palos Verdes', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7515, 'longitude': -118.367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90277', 'place_name': 'Redondo Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8307, 'longitude': -118.3832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90278', 'place_name': 'Redondo Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8707, 'longitude': -118.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90280', 'place_name': 'South Gate', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9462, 'longitude': -118.2013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90290', 'place_name': 'Topanga', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1076, 'longitude': -118.6023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90291', 'place_name': 'Venice', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9938, 'longitude': -118.4635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90292', 'place_name': 'Marina Del Rey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9779, 'longitude': -118.4525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90293', 'place_name': 'Playa Del Rey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9577, 'longitude': -118.4373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90294', 'place_name': 'Venice', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9908, 'longitude': -118.4601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90295', 'place_name': 'Marina Del Rey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90296', 'place_name': 'Playa Del Rey', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90301', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.955, 'longitude': -118.3556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90302', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9745, 'longitude': -118.3548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90303', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9377, 'longitude': -118.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90304', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9379, 'longitude': -118.3586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90305', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9583, 'longitude': -118.3259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90306', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9617, 'longitude': -118.3531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90307', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90308', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9617, 'longitude': -118.3531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90309', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90310', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90311', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9617, 'longitude': -118.3531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90312', 'place_name': 'Inglewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9617, 'longitude': -118.3531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90401', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0176, 'longitude': -118.4907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90402', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0349, 'longitude': -118.503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90403', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0287, 'longitude': -118.4924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90404', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0268, 'longitude': -118.4733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90405', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.01, 'longitude': -118.4717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90406', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0195, 'longitude': -118.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90407', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0195, 'longitude': -118.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90408', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0195, 'longitude': -118.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90409', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0195, 'longitude': -118.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90410', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0195, 'longitude': -118.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90411', 'place_name': 'Santa Monica', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0195, 'longitude': -118.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90501', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8268, 'longitude': -118.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90502', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8286, 'longitude': -118.292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90503', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8397, 'longitude': -118.3542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90504', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8708, 'longitude': -118.3295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90505', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8106, 'longitude': -118.3507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90506', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90507', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90508', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90509', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90510', 'place_name': 'Torrance', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90601', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0011, 'longitude': -118.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90602', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9693, 'longitude': -118.0337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90603', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9432, 'longitude': -117.9927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90604', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9299, 'longitude': -118.0121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90605', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9413, 'longitude': -118.0356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90606', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9777, 'longitude': -118.0658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90607', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9792, 'longitude': -118.0328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90608', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9792, 'longitude': -118.0328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90609', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9792, 'longitude': -118.0328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90610', 'place_name': 'Whittier', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9792, 'longitude': -118.0328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90637', 'place_name': 'La Mirada', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9172, 'longitude': -118.012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90638', 'place_name': 'La Mirada', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9067, 'longitude': -118.0101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90639', 'place_name': 'La Mirada', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9058, 'longitude': -118.0182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90640', 'place_name': 'Montebello', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0133, 'longitude': -118.113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90650', 'place_name': 'Norwalk', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9056, 'longitude': -118.0818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90651', 'place_name': 'Norwalk', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9022, 'longitude': -118.0817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90652', 'place_name': 'Norwalk', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9022, 'longitude': -118.0817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90660', 'place_name': 'Pico Rivera', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9886, 'longitude': -118.0883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90661', 'place_name': 'Pico Rivera', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9831, 'longitude': -118.0967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90662', 'place_name': 'Pico Rivera', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9831, 'longitude': -118.0967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90670', 'place_name': 'Santa Fe Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9464, 'longitude': -118.0838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90671', 'place_name': 'Santa Fe Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9472, 'longitude': -118.0853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90701', 'place_name': 'Artesia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8654, 'longitude': -118.0731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90702', 'place_name': 'Artesia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8658, 'longitude': -118.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90703', 'place_name': 'Cerritos', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8669, 'longitude': -118.0686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90704', 'place_name': 'Avalon', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.332, 'longitude': -118.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90706', 'place_name': 'Bellflower', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8867, 'longitude': -118.1265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90707', 'place_name': 'Bellflower', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8817, 'longitude': -118.117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90710', 'place_name': 'Harbor City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.797, 'longitude': -118.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90711', 'place_name': 'Lakewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90712', 'place_name': 'Lakewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8512, 'longitude': -118.1457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90713', 'place_name': 'Lakewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8473, 'longitude': -118.1115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90714', 'place_name': 'Lakewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8512, 'longitude': -118.1339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90715', 'place_name': 'Lakewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8405, 'longitude': -118.0767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90716', 'place_name': 'Hawaiian Gardens', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8296, 'longitude': -118.073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90717', 'place_name': 'Lomita', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7938, 'longitude': -118.3172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90723', 'place_name': 'Paramount', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8969, 'longitude': -118.1632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90731', 'place_name': 'San Pedro', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7339, 'longitude': -118.2914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90732', 'place_name': 'San Pedro', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.742, 'longitude': -118.3121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90733', 'place_name': 'San Pedro', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90734', 'place_name': 'San Pedro', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90744', 'place_name': 'Wilmington', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7855, 'longitude': -118.2645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90745', 'place_name': 'Carson', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.823, 'longitude': -118.2684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90746', 'place_name': 'Carson', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8584, 'longitude': -118.2554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90747', 'place_name': 'Carson', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8671, 'longitude': -118.2538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90748', 'place_name': 'Wilmington', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.78, 'longitude': -118.2626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90749', 'place_name': 'Carson', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90755', 'place_name': 'Signal Hill', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8029, 'longitude': -118.1677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90801', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.767, 'longitude': -118.1892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90802', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7706, 'longitude': -118.182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90803', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7619, 'longitude': -118.1341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90804', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7857, 'longitude': -118.1357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90805', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8635, 'longitude': -118.1801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90806', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8045, 'longitude': -118.1876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90807', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8315, 'longitude': -118.1811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90808', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8241, 'longitude': -118.1103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90809', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90810', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8193, 'longitude': -118.2325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90813', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.782, 'longitude': -118.1835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90814', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7716, 'longitude': -118.148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90815', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7939, 'longitude': -118.1192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90822', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7927, 'longitude': -118.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90831', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7678, 'longitude': -118.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90832', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.767, 'longitude': -118.1892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90833', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7678, 'longitude': -118.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90834', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7678, 'longitude': -118.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90835', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7678, 'longitude': -118.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90840', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7843, 'longitude': -118.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90842', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90844', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.767, 'longitude': -118.1892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90846', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8249, 'longitude': -118.1504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90847', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90848', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90853', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90895', 'place_name': 'Carson', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.8392, 'longitude': -118.2202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90899', 'place_name': 'Long Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.767, 'longitude': -118.1892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91001', 'place_name': 'Altadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1912, 'longitude': -118.1392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91003', 'place_name': 'Altadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1897, 'longitude': -118.1312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91006', 'place_name': 'Arcadia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1324, 'longitude': -118.0264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91007', 'place_name': 'Arcadia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1243, 'longitude': -118.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91008', 'place_name': 'Duarte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.149, 'longitude': -117.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91009', 'place_name': 'Duarte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1395, 'longitude': -117.9773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91010', 'place_name': 'Duarte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1407, 'longitude': -117.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91011', 'place_name': 'La Canada Flintridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2217, 'longitude': -118.2051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91012', 'place_name': 'La Canada Flintridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1992, 'longitude': -118.1879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91016', 'place_name': 'Monrovia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.144, 'longitude': -118.0014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91017', 'place_name': 'Monrovia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1481, 'longitude': -117.999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91020', 'place_name': 'Montrose', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2114, 'longitude': -118.2305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91021', 'place_name': 'Montrose', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2064, 'longitude': -118.2242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91023', 'place_name': 'Mount Wilson', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2264, 'longitude': -118.0662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91024', 'place_name': 'Sierra Madre', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1651, 'longitude': -118.0519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91025', 'place_name': 'Sierra Madre', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1617, 'longitude': -118.0528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91030', 'place_name': 'South Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1109, 'longitude': -118.1547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91031', 'place_name': 'South Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1161, 'longitude': -118.1503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91040', 'place_name': 'Sunland', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2618, 'longitude': -118.3371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91041', 'place_name': 'Sunland', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2669, 'longitude': -118.3023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91042', 'place_name': 'Tujunga', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2544, 'longitude': -118.2849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91043', 'place_name': 'Tujunga', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2522, 'longitude': -118.2884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91046', 'place_name': 'Verdugo City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2114, 'longitude': -118.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91066', 'place_name': 'Arcadia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1397, 'longitude': -118.0353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91077', 'place_name': 'Arcadia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1397, 'longitude': -118.0353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91101', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1468, 'longitude': -118.1391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91102', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91103', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1669, 'longitude': -118.1551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91104', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1678, 'longitude': -118.1261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91105', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1355, 'longitude': -118.1636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91106', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1435, 'longitude': -118.1266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91107', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.151, 'longitude': -118.0889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91108', 'place_name': 'San Marino', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1207, 'longitude': -118.1117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91109', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91110', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91114', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91115', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91116', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91117', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91118', 'place_name': 'San Marino', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1214, 'longitude': -118.1065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91121', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91123', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91124', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91125', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91126', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91129', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91182', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91184', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91185', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91188', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91189', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91199', 'place_name': 'Pasadena', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1478, 'longitude': -118.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91201', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1716, 'longitude': -118.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91202', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1652, 'longitude': -118.2656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91203', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1517, 'longitude': -118.2636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91204', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1379, 'longitude': -118.2599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91205', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1378, 'longitude': -118.2425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91206', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1556, 'longitude': -118.2322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91207', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1649, 'longitude': -118.2451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91208', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1921, 'longitude': -118.235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91209', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1425, 'longitude': -118.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91210', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1425, 'longitude': -118.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91214', 'place_name': 'La Crescenta', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2316, 'longitude': -118.2457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91221', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1425, 'longitude': -118.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91222', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1425, 'longitude': -118.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91224', 'place_name': 'La Crescenta', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2242, 'longitude': -118.2401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91225', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1425, 'longitude': -118.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91226', 'place_name': 'Glendale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1425, 'longitude': -118.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91301', 'place_name': 'Agoura Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1227, 'longitude': -118.7573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91302', 'place_name': 'Calabasas', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1419, 'longitude': -118.6641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91303', 'place_name': 'Canoga Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1993, 'longitude': -118.5983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91304', 'place_name': 'Canoga Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2197, 'longitude': -118.6111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91305', 'place_name': 'Canoga Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2011, 'longitude': -118.5981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91306', 'place_name': 'Winnetka', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2092, 'longitude': -118.5749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91307', 'place_name': 'West Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1963, 'longitude': -118.6389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91308', 'place_name': 'West Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1973, 'longitude': -118.644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91309', 'place_name': 'Canoga Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2011, 'longitude': -118.5981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91310', 'place_name': 'Castaic', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4889, 'longitude': -118.6229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91311', 'place_name': 'Chatsworth', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2583, 'longitude': -118.5914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91313', 'place_name': 'Chatsworth', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2572, 'longitude': -118.6012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91316', 'place_name': 'Encino', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1655, 'longitude': -118.5175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91321', 'place_name': 'Newhall', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3795, 'longitude': -118.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91322', 'place_name': 'Newhall', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3847, 'longitude': -118.5309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91324', 'place_name': 'Northridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2367, 'longitude': -118.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91325', 'place_name': 'Northridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2353, 'longitude': -118.5188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91326', 'place_name': 'Porter Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2619, 'longitude': -118.582, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '91327', 'place_name': 'Northridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2283, 'longitude': -118.5368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91328', 'place_name': 'Northridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2283, 'longitude': -118.5368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91329', 'place_name': 'Northridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2283, 'longitude': -118.5368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91330', 'place_name': 'Northridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2283, 'longitude': -118.5368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91331', 'place_name': 'Pacoima', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2556, 'longitude': -118.4208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91333', 'place_name': 'Pacoima', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2625, 'longitude': -118.427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91334', 'place_name': 'Pacoima', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2625, 'longitude': -118.427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91335', 'place_name': 'Reseda', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2007, 'longitude': -118.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91337', 'place_name': 'Reseda', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2011, 'longitude': -118.5365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91340', 'place_name': 'San Fernando', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2875, 'longitude': -118.4352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91341', 'place_name': 'San Fernando', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2819, 'longitude': -118.439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91342', 'place_name': 'Sylmar', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3054, 'longitude': -118.4322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91343', 'place_name': 'North Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2366, 'longitude': -118.4758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91344', 'place_name': 'Granada Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2771, 'longitude': -118.4992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91345', 'place_name': 'Mission Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2619, 'longitude': -118.4587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91346', 'place_name': 'Mission Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2572, 'longitude': -118.467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91350', 'place_name': 'Santa Clarita', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4336, 'longitude': -118.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91351', 'place_name': 'Canyon Country', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4262, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91352', 'place_name': 'Sun Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2209, 'longitude': -118.3699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91353', 'place_name': 'Sun Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2175, 'longitude': -118.3704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91354', 'place_name': 'Valencia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4466, 'longitude': -118.5374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91355', 'place_name': 'Valencia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3985, 'longitude': -118.5535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91356', 'place_name': 'Tarzana', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1671, 'longitude': -118.5414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91357', 'place_name': 'Tarzana', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1733, 'longitude': -118.554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91364', 'place_name': 'Woodland Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1557, 'longitude': -118.6, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91365', 'place_name': 'Woodland Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1683, 'longitude': -118.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91367', 'place_name': 'Woodland Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1767, 'longitude': -118.6159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91371', 'place_name': 'Woodland Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1683, 'longitude': -118.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91372', 'place_name': 'Calabasas', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1578, 'longitude': -118.6384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91376', 'place_name': 'Agoura Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1364, 'longitude': -118.7745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91380', 'place_name': 'Santa Clarita', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3917, 'longitude': -118.5426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91381', 'place_name': 'Stevenson Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3775, 'longitude': -118.6131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91382', 'place_name': 'Santa Clarita', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3917, 'longitude': -118.5426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91383', 'place_name': 'Santa Clarita', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3917, 'longitude': -118.5426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91384', 'place_name': 'Castaic', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4827, 'longitude': -118.6254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91385', 'place_name': 'Valencia', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4436, 'longitude': -118.6095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91386', 'place_name': 'Canyon Country', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4233, 'longitude': -118.472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91387', 'place_name': 'Canyon Country', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4132, 'longitude': -118.426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91390', 'place_name': 'Santa Clarita', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4684, 'longitude': -118.5261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91392', 'place_name': 'Sylmar', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3078, 'longitude': -118.4492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91393', 'place_name': 'North Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2364, 'longitude': -118.4847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91394', 'place_name': 'Granada Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2647, 'longitude': -118.5231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91395', 'place_name': 'Mission Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2572, 'longitude': -118.467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91396', 'place_name': 'Winnetka', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2133, 'longitude': -118.572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91401', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1802, 'longitude': -118.4324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91402', 'place_name': 'Panorama City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2262, 'longitude': -118.447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91403', 'place_name': 'Sherman Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1514, 'longitude': -118.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91404', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91405', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2001, 'longitude': -118.4456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91406', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2006, 'longitude': -118.4868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91407', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91408', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91409', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91410', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91411', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1781, 'longitude': -118.4574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91412', 'place_name': 'Panorama City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2247, 'longitude': -118.4498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91413', 'place_name': 'Sherman Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1511, 'longitude': -118.4492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91416', 'place_name': 'Encino', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1592, 'longitude': -118.5012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91423', 'place_name': 'Sherman Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1526, 'longitude': -118.4322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91426', 'place_name': 'Encino', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1592, 'longitude': -118.5012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91436', 'place_name': 'Encino', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.151, 'longitude': -118.4882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91470', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91482', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91495', 'place_name': 'Sherman Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1511, 'longitude': -118.4492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91496', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91499', 'place_name': 'Van Nuys', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1867, 'longitude': -118.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91501', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1862, 'longitude': -118.3009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91502', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1745, 'longitude': -118.3059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91503', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91504', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2001, 'longitude': -118.3264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91505', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.169, 'longitude': -118.3442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91506', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1717, 'longitude': -118.3231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91507', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91508', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91510', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91521', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91522', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91523', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91526', 'place_name': 'Burbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1808, 'longitude': -118.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91601', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1687, 'longitude': -118.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91602', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.151, 'longitude': -118.3663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91603', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1722, 'longitude': -118.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91604', 'place_name': 'Studio City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.143, 'longitude': -118.3913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91605', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2057, 'longitude': -118.4001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91606', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1872, 'longitude': -118.3865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91607', 'place_name': 'Valley Village', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1672, 'longitude': -118.3989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91608', 'place_name': 'Universal City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1383, 'longitude': -118.3528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91609', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1722, 'longitude': -118.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91610', 'place_name': 'Toluca Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.7866, 'longitude': -118.2987, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '91611', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1722, 'longitude': -118.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91612', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1722, 'longitude': -118.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91614', 'place_name': 'Studio City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1486, 'longitude': -118.3965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91615', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1722, 'longitude': -118.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91616', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1722, 'longitude': -118.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91617', 'place_name': 'Valley Village', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1649, 'longitude': -118.3965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91618', 'place_name': 'North Hollywood', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1722, 'longitude': -118.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91702', 'place_name': 'Azusa', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1248, 'longitude': -117.9031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91706', 'place_name': 'Baldwin Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0964, 'longitude': -117.9682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91711', 'place_name': 'Claremont', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1092, 'longitude': -117.7183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91714', 'place_name': 'City Of Industry', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0197, 'longitude': -117.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91715', 'place_name': 'City Of Industry', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0197, 'longitude': -117.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91716', 'place_name': 'City Of Industry', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0197, 'longitude': -117.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91722', 'place_name': 'Covina', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0972, 'longitude': -117.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91723', 'place_name': 'Covina', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.086, 'longitude': -117.8843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91724', 'place_name': 'Covina', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0938, 'longitude': -117.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91731', 'place_name': 'El Monte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0791, 'longitude': -118.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91732', 'place_name': 'El Monte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0705, 'longitude': -118.0149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91733', 'place_name': 'South El Monte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0557, 'longitude': -118.0444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91734', 'place_name': 'El Monte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0686, 'longitude': -118.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91735', 'place_name': 'El Monte', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0686, 'longitude': -118.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91740', 'place_name': 'Glendora', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1287, 'longitude': -117.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91741', 'place_name': 'Glendora', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1537, 'longitude': -117.8437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91744', 'place_name': 'La Puente', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0289, 'longitude': -117.9373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91745', 'place_name': 'Hacienda Heights', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9977, 'longitude': -117.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91746', 'place_name': 'La Puente', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0443, 'longitude': -117.9862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91747', 'place_name': 'La Puente', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.02, 'longitude': -117.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91748', 'place_name': 'Rowland Heights', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 33.9818, 'longitude': -117.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91749', 'place_name': 'La Puente', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.02, 'longitude': -117.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91750', 'place_name': 'La Verne', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1159, 'longitude': -117.7708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91754', 'place_name': 'Monterey Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0534, 'longitude': -118.1271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91755', 'place_name': 'Monterey Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.048, 'longitude': -118.115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91756', 'place_name': 'Monterey Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0625, 'longitude': -118.1228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91759', 'place_name': 'Mount Baldy', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.2361, 'longitude': -117.6601, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '91765', 'place_name': 'Diamond Bar', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0066, 'longitude': -117.8098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91766', 'place_name': 'Pomona', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0418, 'longitude': -117.7569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91767', 'place_name': 'Pomona', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0812, 'longitude': -117.7362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91768', 'place_name': 'Pomona', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0662, 'longitude': -117.7763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91769', 'place_name': 'Pomona', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0553, 'longitude': -117.7523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91770', 'place_name': 'Rosemead', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0658, 'longitude': -118.0853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91771', 'place_name': 'Rosemead', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0806, 'longitude': -118.0728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91772', 'place_name': 'Rosemead', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0806, 'longitude': -118.0728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91773', 'place_name': 'San Dimas', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1023, 'longitude': -117.8169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91775', 'place_name': 'San Gabriel', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1155, 'longitude': -118.0857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91776', 'place_name': 'San Gabriel', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.089, 'longitude': -118.0955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91778', 'place_name': 'San Gabriel', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0961, 'longitude': -118.1058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91780', 'place_name': 'Temple City', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.1016, 'longitude': -118.0537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91788', 'place_name': 'Walnut', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0203, 'longitude': -117.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91789', 'place_name': 'Walnut', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0183, 'longitude': -117.8546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91790', 'place_name': 'West Covina', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0673, 'longitude': -117.9366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91791', 'place_name': 'West Covina', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0653, 'longitude': -117.8978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91792', 'place_name': 'West Covina', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0229, 'longitude': -117.8975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91793', 'place_name': 'West Covina', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0686, 'longitude': -117.939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91801', 'place_name': 'Alhambra', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0914, 'longitude': -118.1293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91802', 'place_name': 'Alhambra', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0953, 'longitude': -118.127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91803', 'place_name': 'Alhambra', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0745, 'longitude': -118.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91804', 'place_name': 'Alhambra', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0953, 'longitude': -118.127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91896', 'place_name': 'Alhambra', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0953, 'longitude': -118.127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91899', 'place_name': 'Alhambra', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.0953, 'longitude': -118.127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93510', 'place_name': 'Acton', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4835, 'longitude': -118.1959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93532', 'place_name': 'Lake Hughes', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.6847, 'longitude': -118.5442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93534', 'place_name': 'Lancaster', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.6909, 'longitude': -118.1491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93535', 'place_name': 'Lancaster', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.7131, 'longitude': -117.8783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93536', 'place_name': 'Lancaster', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.7471, 'longitude': -118.3687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93539', 'place_name': 'Lancaster', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.698, 'longitude': -118.1367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93543', 'place_name': 'Littlerock', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4891, 'longitude': -117.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93544', 'place_name': 'Llano', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.493, 'longitude': -117.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93550', 'place_name': 'Palmdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4133, 'longitude': -118.0917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93551', 'place_name': 'Palmdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.6017, 'longitude': -118.231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93552', 'place_name': 'Palmdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.5715, 'longitude': -118.0231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93553', 'place_name': 'Pearblossom', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.4225, 'longitude': -117.9055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93563', 'place_name': 'Valyermo', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.3966, 'longitude': -117.7604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93584', 'place_name': 'Lancaster', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.698, 'longitude': -118.1367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93586', 'place_name': 'Lancaster', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.698, 'longitude': -118.1367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93590', 'place_name': 'Palmdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.5794, 'longitude': -118.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93591', 'place_name': 'Palmdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.6019, 'longitude': -117.8123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93599', 'place_name': 'Palmdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Los Angeles', 'locality_code': '37', 'latitude': 34.5794, 'longitude': -118.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93601', 'place_name': 'Ahwahnee', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.4076, 'longitude': -119.7233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93604', 'place_name': 'Bass Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.3244, 'longitude': -119.5568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93610', 'place_name': 'Chowchilla', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.1014, 'longitude': -120.2691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93614', 'place_name': 'Coarsegold', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.2214, 'longitude': -119.7455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93637', 'place_name': 'Madera', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 36.9403, 'longitude': -120.082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93638', 'place_name': 'Madera', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.0402, 'longitude': -120.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93639', 'place_name': 'Madera', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 36.9613, 'longitude': -120.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93643', 'place_name': 'North Fork', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.2125, 'longitude': -119.5143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93644', 'place_name': 'Oakhurst', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.3476, 'longitude': -119.6449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93645', 'place_name': 'O Neals', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.1639, 'longitude': -119.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93653', 'place_name': 'Raymond', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.279, 'longitude': -119.8766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93669', 'place_name': 'Wishon', 'state': 'California', 'state_ab': 'CA', 'county': 'Madera', 'locality_code': '39', 'latitude': 37.281, 'longitude': -119.557, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '94901', 'place_name': 'San Rafael', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9691, 'longitude': -122.5105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94903', 'place_name': 'San Rafael', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0339, 'longitude': -122.5855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94904', 'place_name': 'Greenbrae', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9479, 'longitude': -122.5363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94912', 'place_name': 'San Rafael', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9735, 'longitude': -122.5311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94913', 'place_name': 'San Rafael', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9735, 'longitude': -122.5311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94914', 'place_name': 'Kentfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9521, 'longitude': -122.5572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94915', 'place_name': 'San Rafael', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0739, 'longitude': -122.5594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94920', 'place_name': 'Belvedere Tiburon', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.8843, 'longitude': -122.4637, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '94924', 'place_name': 'Bolinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9079, 'longitude': -122.6947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94925', 'place_name': 'Corte Madera', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9223, 'longitude': -122.5132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94929', 'place_name': 'Dillon Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.2508, 'longitude': -122.9653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94930', 'place_name': 'Fairfax', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9883, 'longitude': -122.5937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94933', 'place_name': 'Forest Knolls', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0122, 'longitude': -122.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94937', 'place_name': 'Inverness', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.1126, 'longitude': -122.8877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94938', 'place_name': 'Lagunitas', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0139, 'longitude': -122.7016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94939', 'place_name': 'Larkspur', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9367, 'longitude': -122.5362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94940', 'place_name': 'Marshall', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.1762, 'longitude': -122.89, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94941', 'place_name': 'Mill Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.8958, 'longitude': -122.5339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94942', 'place_name': 'Mill Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.906, 'longitude': -122.545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94945', 'place_name': 'Novato', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.1163, 'longitude': -122.5714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94946', 'place_name': 'Nicasio', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0546, 'longitude': -122.6964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94947', 'place_name': 'Novato', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0973, 'longitude': -122.5837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94948', 'place_name': 'Novato', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.1489, 'longitude': -122.5737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94949', 'place_name': 'Novato', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0618, 'longitude': -122.5404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94950', 'place_name': 'Olema', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0467, 'longitude': -122.7699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94956', 'place_name': 'Point Reyes Station', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0691, 'longitude': -122.8069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94957', 'place_name': 'Ross', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9624, 'longitude': -122.555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94960', 'place_name': 'San Anselmo', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9846, 'longitude': -122.5711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94963', 'place_name': 'San Geronimo', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0133, 'longitude': -122.6639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94964', 'place_name': 'San Quentin', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9416, 'longitude': -122.4844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94965', 'place_name': 'Sausalito', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.8601, 'longitude': -122.4946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94966', 'place_name': 'Sausalito', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.8591, 'longitude': -122.4853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94970', 'place_name': 'Stinson Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.902, 'longitude': -122.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94971', 'place_name': 'Tomales', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.2427, 'longitude': -122.9145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94973', 'place_name': 'Woodacre', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.0069, 'longitude': -122.6382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94974', 'place_name': 'San Quentin', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9413, 'longitude': -122.485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94976', 'place_name': 'Corte Madera', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9255, 'longitude': -122.5275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94977', 'place_name': 'Larkspur', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9341, 'longitude': -122.5353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94978', 'place_name': 'Fairfax', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9871, 'longitude': -122.5889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94979', 'place_name': 'San Anselmo', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 37.9746, 'longitude': -122.5616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94998', 'place_name': 'Novato', 'state': 'California', 'state_ab': 'CA', 'county': 'Marin', 'locality_code': '41', 'latitude': 38.1173, 'longitude': -122.5684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93623', 'place_name': 'Fish Camp', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.4785, 'longitude': -119.6404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95306', 'place_name': 'Catheys Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.4404, 'longitude': -120.1438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95311', 'place_name': 'Coulterville', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.7197, 'longitude': -120.1197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95318', 'place_name': 'El Portal', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.6747, 'longitude': -119.7841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95325', 'place_name': 'Hornitos', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.4676, 'longitude': -120.2793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95338', 'place_name': 'Mariposa', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.4931, 'longitude': -119.9219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95345', 'place_name': 'Midpines', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.5757, 'longitude': -119.9601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95389', 'place_name': 'Yosemite National Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Mariposa', 'locality_code': '43', 'latitude': 37.7314, 'longitude': -119.6489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95410', 'place_name': 'Albion', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.2131, 'longitude': -123.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95415', 'place_name': 'Boonville', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.0197, 'longitude': -123.3856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95417', 'place_name': 'Branscomb', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.6949, 'longitude': -123.5527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95418', 'place_name': 'Calpella', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.2214, 'longitude': -123.2154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95420', 'place_name': 'Caspar', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.3629, 'longitude': -123.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95427', 'place_name': 'Comptche', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.2767, 'longitude': -123.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95428', 'place_name': 'Covelo', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.82, 'longitude': -123.0585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95429', 'place_name': 'Dos Rios', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.7168, 'longitude': -123.3533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95432', 'place_name': 'Elk', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.1593, 'longitude': -123.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95437', 'place_name': 'Fort Bragg', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.4402, 'longitude': -123.7703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95445', 'place_name': 'Gualala', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 38.8251, 'longitude': -123.5399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95449', 'place_name': 'Hopland', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 38.938, 'longitude': -123.0703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95454', 'place_name': 'Laytonville', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.6627, 'longitude': -123.4929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95456', 'place_name': 'Little River', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.2707, 'longitude': -123.7883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95459', 'place_name': 'Manchester', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.0097, 'longitude': -123.6523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95460', 'place_name': 'Mendocino', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.3173, 'longitude': -123.7739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95463', 'place_name': 'Navarro', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.185, 'longitude': -123.5268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95466', 'place_name': 'Philo', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.0657, 'longitude': -123.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95468', 'place_name': 'Point Arena', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 38.9152, 'longitude': -123.6, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95469', 'place_name': 'Potter Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.3932, 'longitude': -123.0647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95470', 'place_name': 'Redwood Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.2779, 'longitude': -123.2243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95481', 'place_name': 'Talmage', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.1269, 'longitude': -123.1658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95482', 'place_name': 'Ukiah', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.1552, 'longitude': -123.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95488', 'place_name': 'Westport', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.6843, 'longitude': -123.7686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95490', 'place_name': 'Willits', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.4493, 'longitude': -123.3679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95494', 'place_name': 'Yorkville', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 38.9235, 'longitude': -123.2973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95585', 'place_name': 'Leggett', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.8481, 'longitude': -123.6615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95587', 'place_name': 'Piercy', 'state': 'California', 'state_ab': 'CA', 'county': 'Mendocino', 'locality_code': '45', 'latitude': 39.9465, 'longitude': -123.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93620', 'place_name': 'Dos Palos', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.0025, 'longitude': -120.6333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93635', 'place_name': 'Los Banos', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.0627, 'longitude': -120.8544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93636', 'place_name': 'Madera', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 36.9528, 'longitude': -119.8806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93661', 'place_name': 'Santa Rita Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.1869, 'longitude': -120.6504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93665', 'place_name': 'South Dos Palos', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 36.9644, 'longitude': -120.6532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95301', 'place_name': 'Atwater', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.3489, 'longitude': -120.6028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95303', 'place_name': 'Ballico', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.4548, 'longitude': -120.6931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95312', 'place_name': 'Cressey', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.4197, 'longitude': -120.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95315', 'place_name': 'Delhi', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.4273, 'longitude': -120.7752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95317', 'place_name': 'El Nido', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.1391, 'longitude': -120.5251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95322', 'place_name': 'Gustine', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.2001, 'longitude': -121.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95324', 'place_name': 'Hilmar', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.4002, 'longitude': -120.8723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95333', 'place_name': 'Le Grand', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.2496, 'longitude': -120.2667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95334', 'place_name': 'Livingston', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.3763, 'longitude': -120.7252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95340', 'place_name': 'Merced', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.2983, 'longitude': -120.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95341', 'place_name': 'Merced', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.2308, 'longitude': -120.5144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95343', 'place_name': 'Merced', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.3082, 'longitude': -120.48, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95344', 'place_name': 'Merced', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.3082, 'longitude': -120.48, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95348', 'place_name': 'Merced', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.3302, 'longitude': -120.508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95365', 'place_name': 'Planada', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.2908, 'longitude': -120.3185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95369', 'place_name': 'Snelling', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.5354, 'longitude': -120.378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95374', 'place_name': 'Stevinson', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.3283, 'longitude': -120.8764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95388', 'place_name': 'Winton', 'state': 'California', 'state_ab': 'CA', 'county': 'Merced', 'locality_code': '47', 'latitude': 37.4014, 'longitude': -120.6045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96006', 'place_name': 'Adin', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.2175, 'longitude': -120.9432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96015', 'place_name': 'Canby', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.4664, 'longitude': -120.9218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96054', 'place_name': 'Lookout', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.2347, 'longitude': -121.2156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96101', 'place_name': 'Alturas', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.4767, 'longitude': -120.5456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96104', 'place_name': 'Cedarville', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.4759, 'longitude': -120.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96108', 'place_name': 'Davis Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.7336, 'longitude': -120.3741, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96110', 'place_name': 'Eagleville', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.3163, 'longitude': -120.1158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96112', 'place_name': 'Fort Bidwell', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.8644, 'longitude': -120.162, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96115', 'place_name': 'Lake City', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.6682, 'longitude': -120.1814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96116', 'place_name': 'Likely', 'state': 'California', 'state_ab': 'CA', 'county': 'Modoc', 'locality_code': '49', 'latitude': 41.2329, 'longitude': -120.5079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93512', 'place_name': 'Benton', 'state': 'California', 'state_ab': 'CA', 'county': 'Mono', 'locality_code': '51', 'latitude': 37.8926, 'longitude': -118.5647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93517', 'place_name': 'Bridgeport', 'state': 'California', 'state_ab': 'CA', 'county': 'Mono', 'locality_code': '51', 'latitude': 38.2566, 'longitude': -119.208, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93529', 'place_name': 'June Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Mono', 'locality_code': '51', 'latitude': 37.7773, 'longitude': -119.0825, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93541', 'place_name': 'Lee Vining', 'state': 'California', 'state_ab': 'CA', 'county': 'Mono', 'locality_code': '51', 'latitude': 37.989, 'longitude': -119.1234, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93546', 'place_name': 'Mammoth Lakes', 'state': 'California', 'state_ab': 'CA', 'county': 'Mono', 'locality_code': '51', 'latitude': 37.6094, 'longitude': -118.8656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96107', 'place_name': 'Coleville', 'state': 'California', 'state_ab': 'CA', 'county': 'Mono', 'locality_code': '51', 'latitude': 38.5029, 'longitude': -119.4828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96133', 'place_name': 'Topaz', 'state': 'California', 'state_ab': 'CA', 'county': 'Mono', 'locality_code': '51', 'latitude': 38.6415, 'longitude': -119.5122, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93426', 'place_name': 'Bradley', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 35.8093, 'longitude': -120.9728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93450', 'place_name': 'San Ardo', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 35.9857, 'longitude': -120.8612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93901', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6677, 'longitude': -121.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93902', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6777, 'longitude': -121.6555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93905', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6811, 'longitude': -121.6176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93906', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.7103, 'longitude': -121.6438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93907', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.7563, 'longitude': -121.6703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93908', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6011, 'longitude': -121.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93912', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6777, 'longitude': -121.6555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93915', 'place_name': 'Salinas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6777, 'longitude': -121.6555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93920', 'place_name': 'Big Sur', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.2458, 'longitude': -121.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93921', 'place_name': 'Carmel By The Sea', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.5552, 'longitude': -121.9233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93922', 'place_name': 'Carmel', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.5433, 'longitude': -121.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93923', 'place_name': 'Carmel', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.5457, 'longitude': -121.8949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93924', 'place_name': 'Carmel Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.4787, 'longitude': -121.7244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93925', 'place_name': 'Chualar', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.595, 'longitude': -121.432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93926', 'place_name': 'Gonzales', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.49, 'longitude': -121.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93927', 'place_name': 'Greenfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.3202, 'longitude': -121.2451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93928', 'place_name': 'Jolon', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 35.9708, 'longitude': -121.176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93930', 'place_name': 'King City', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.2028, 'longitude': -121.1273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93932', 'place_name': 'Lockwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 35.95, 'longitude': -121.0626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93933', 'place_name': 'Marina', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6849, 'longitude': -121.7934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93940', 'place_name': 'Monterey', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.5802, 'longitude': -121.8443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93942', 'place_name': 'Monterey', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6002, 'longitude': -121.8947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93943', 'place_name': 'Monterey', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.597, 'longitude': -121.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93944', 'place_name': 'Monterey', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6062, 'longitude': -121.9089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93950', 'place_name': 'Pacific Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6167, 'longitude': -121.922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93953', 'place_name': 'Pebble Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.5907, 'longitude': -121.942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93954', 'place_name': 'San Lucas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.1289, 'longitude': -121.0205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93955', 'place_name': 'Seaside', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6217, 'longitude': -121.7935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93960', 'place_name': 'Soledad', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.4196, 'longitude': -121.3243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93962', 'place_name': 'Spreckels', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.6261, 'longitude': -121.6555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95004', 'place_name': 'Aromas', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.8769, 'longitude': -121.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95012', 'place_name': 'Castroville', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.7658, 'longitude': -121.758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95039', 'place_name': 'Moss Landing', 'state': 'California', 'state_ab': 'CA', 'county': 'Monterey', 'locality_code': '53', 'latitude': 36.8175, 'longitude': -121.7773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94503', 'place_name': 'American Canyon', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.1668, 'longitude': -122.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94508', 'place_name': 'Angwin', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.5769, 'longitude': -122.4477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94515', 'place_name': 'Calistoga', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.5823, 'longitude': -122.5814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94558', 'place_name': 'Napa', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.4549, 'longitude': -122.2564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94559', 'place_name': 'Napa', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.2904, 'longitude': -122.2841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94562', 'place_name': 'Oakville', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.4379, 'longitude': -122.3991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94567', 'place_name': 'Pope Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.6152, 'longitude': -122.4278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94573', 'place_name': 'Rutherford', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.4585, 'longitude': -122.4225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94574', 'place_name': 'Saint Helena', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.5138, 'longitude': -122.4619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94576', 'place_name': 'Deer Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.5494, 'longitude': -122.4764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94581', 'place_name': 'Napa', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.2971, 'longitude': -122.2855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94599', 'place_name': 'Yountville', 'state': 'California', 'state_ab': 'CA', 'county': 'Napa', 'locality_code': '55', 'latitude': 38.4016, 'longitude': -122.3608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95712', 'place_name': 'Chicago Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.143, 'longitude': -120.9666, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95724', 'place_name': 'Norden', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.318, 'longitude': -120.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95728', 'place_name': 'Soda Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.317, 'longitude': -120.4259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95924', 'place_name': 'Cedar Ridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.1988, 'longitude': -121.02, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95945', 'place_name': 'Grass Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.2081, 'longitude': -121.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95946', 'place_name': 'Penn Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.2019, 'longitude': -121.2026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95949', 'place_name': 'Grass Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.1193, 'longitude': -121.0938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95959', 'place_name': 'Nevada City', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.3017, 'longitude': -120.9717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95960', 'place_name': 'North San Juan', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.3765, 'longitude': -121.0891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95975', 'place_name': 'Rough And Ready', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.2286, 'longitude': -121.1509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95977', 'place_name': 'Smartsville', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.2076, 'longitude': -121.3001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95986', 'place_name': 'Washington', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.3569, 'longitude': -120.8, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96111', 'place_name': 'Floriston', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.3928, 'longitude': -120.0212, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96160', 'place_name': 'Truckee', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.328, 'longitude': -120.1833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96161', 'place_name': 'Truckee', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.3385, 'longitude': -120.1729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96162', 'place_name': 'Truckee', 'state': 'California', 'state_ab': 'CA', 'county': 'Nevada', 'locality_code': '57', 'latitude': 39.328, 'longitude': -120.1833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90620', 'place_name': 'Buena Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8439, 'longitude': -118.008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90621', 'place_name': 'Buena Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8772, 'longitude': -117.9893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90622', 'place_name': 'Buena Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8462, 'longitude': -118.0031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90623', 'place_name': 'La Palma', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8491, 'longitude': -118.0398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90624', 'place_name': 'Buena Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8584, 'longitude': -118.0033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90630', 'place_name': 'Cypress', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8181, 'longitude': -118.0357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90631', 'place_name': 'La Habra', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.9331, 'longitude': -117.9493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90632', 'place_name': 'La Habra', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.9143, 'longitude': -117.9547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90633', 'place_name': 'La Habra', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.9345, 'longitude': -117.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90680', 'place_name': 'Stanton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7991, 'longitude': -117.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90720', 'place_name': 'Los Alamitos', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7956, 'longitude': -118.0648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90721', 'place_name': 'Los Alamitos', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8023, 'longitude': -118.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90740', 'place_name': 'Seal Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7602, 'longitude': -118.0808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90742', 'place_name': 'Sunset Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7164, 'longitude': -118.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '90743', 'place_name': 'Surfside', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7264, 'longitude': -118.0833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92602', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7419, 'longitude': -117.7467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92603', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6245, 'longitude': -117.794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92604', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6899, 'longitude': -117.7868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92605', 'place_name': 'Huntington Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7151, 'longitude': -118.0077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92606', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6951, 'longitude': -117.8224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92607', 'place_name': 'Laguna Niguel', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5269, 'longitude': -117.7117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92609', 'place_name': 'El Toro', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.624, 'longitude': -117.6908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92610', 'place_name': 'Foothill Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6748, 'longitude': -117.6649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92612', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6607, 'longitude': -117.8264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92614', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6829, 'longitude': -117.8298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92615', 'place_name': 'Huntington Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6566, 'longitude': -117.9699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92616', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6519, 'longitude': -117.8361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92617', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6425, 'longitude': -117.8417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92618', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7074, 'longitude': -117.7054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92619', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6706, 'longitude': -117.7645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92620', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7009, 'longitude': -117.7564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92623', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6942, 'longitude': -117.8126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92624', 'place_name': 'Capistrano Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.46, 'longitude': -117.6632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92625', 'place_name': 'Corona Del Mar', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6021, 'longitude': -117.8743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92626', 'place_name': 'Costa Mesa', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6801, 'longitude': -117.9085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92627', 'place_name': 'Costa Mesa', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6483, 'longitude': -117.9155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92628', 'place_name': 'Costa Mesa', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6401, 'longitude': -117.9159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92629', 'place_name': 'Dana Point', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.4743, 'longitude': -117.6964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92630', 'place_name': 'Lake Forest', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6437, 'longitude': -117.6868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92637', 'place_name': 'Laguna Woods', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6103, 'longitude': -117.7253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92646', 'place_name': 'Huntington Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6654, 'longitude': -117.9686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92647', 'place_name': 'Huntington Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.721, 'longitude': -118.0033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92648', 'place_name': 'Huntington Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6773, 'longitude': -118.0051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92649', 'place_name': 'Huntington Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.718, 'longitude': -118.0505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92650', 'place_name': 'East Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6795, 'longitude': -117.7609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92651', 'place_name': 'Laguna Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5429, 'longitude': -117.7813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92652', 'place_name': 'Laguna Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.543, 'longitude': -117.7815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92653', 'place_name': 'Laguna Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5916, 'longitude': -117.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92654', 'place_name': 'Laguna Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6042, 'longitude': -117.7154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92655', 'place_name': 'Midway City', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7446, 'longitude': -117.984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92656', 'place_name': 'Aliso Viejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5701, 'longitude': -117.7086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92657', 'place_name': 'Newport Coast', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5943, 'longitude': -117.8334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92658', 'place_name': 'Newport Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6422, 'longitude': -117.8631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92659', 'place_name': 'Newport Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6222, 'longitude': -117.9235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92660', 'place_name': 'Newport Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6295, 'longitude': -117.8684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92661', 'place_name': 'Newport Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6045, 'longitude': -117.9021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92662', 'place_name': 'Newport Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6062, 'longitude': -117.8931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92663', 'place_name': 'Newport Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.621, 'longitude': -117.9321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92672', 'place_name': 'San Clemente', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.4361, 'longitude': -117.6231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92673', 'place_name': 'San Clemente', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.4615, 'longitude': -117.6375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92674', 'place_name': 'San Clemente', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.4409, 'longitude': -117.6211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92675', 'place_name': 'San Juan Capistrano', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5085, 'longitude': -117.6565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92676', 'place_name': 'Silverado', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7451, 'longitude': -117.6153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92677', 'place_name': 'Laguna Niguel', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5145, 'longitude': -117.7084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92678', 'place_name': 'Trabuco Canyon', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6643, 'longitude': -117.5896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92679', 'place_name': 'Trabuco Canyon', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6625, 'longitude': -117.5903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92683', 'place_name': 'Westminster', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7524, 'longitude': -117.9939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92684', 'place_name': 'Westminster', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7627, 'longitude': -118.0072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92685', 'place_name': 'Westminster', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7528, 'longitude': -117.9951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92688', 'place_name': 'Rancho Santa Margarita', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6512, 'longitude': -117.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92690', 'place_name': 'Mission Viejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6117, 'longitude': -117.643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92691', 'place_name': 'Mission Viejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6128, 'longitude': -117.6622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92692', 'place_name': 'Mission Viejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6144, 'longitude': -117.6433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92693', 'place_name': 'San Juan Capistrano', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.4977, 'longitude': -117.6651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92694', 'place_name': 'Ladera Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.5472, 'longitude': -117.6238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92697', 'place_name': 'Irvine', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6485, 'longitude': -117.8387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92698', 'place_name': 'Aliso Viejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.6686, 'longitude': -117.8386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92701', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7523, 'longitude': -117.8541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92702', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7365, 'longitude': -117.8714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92703', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7489, 'longitude': -117.9072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92704', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7249, 'longitude': -117.909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92705', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.754, 'longitude': -117.7919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92706', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7691, 'longitude': -117.8855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92707', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7086, 'longitude': -117.8701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92708', 'place_name': 'Fountain Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7102, 'longitude': -117.9503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92711', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7669, 'longitude': -117.8043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92712', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7496, 'longitude': -117.875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92728', 'place_name': 'Fountain Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.714, 'longitude': -117.9284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92735', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7188, 'longitude': -117.8546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92780', 'place_name': 'Tustin', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7364, 'longitude': -117.8229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92781', 'place_name': 'Tustin', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7369, 'longitude': -117.8181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92782', 'place_name': 'Tustin', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7346, 'longitude': -117.7869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92799', 'place_name': 'Santa Ana', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7205, 'longitude': -117.9098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92801', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8428, 'longitude': -117.9546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92802', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8085, 'longitude': -117.9228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92803', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8397, 'longitude': -117.9388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92804', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8186, 'longitude': -117.9729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92805', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8359, 'longitude': -117.9086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92806', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8356, 'longitude': -117.8681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92807', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8544, 'longitude': -117.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92808', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8579, 'longitude': -117.7513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92809', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8426, 'longitude': -117.9388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92811', 'place_name': 'Atwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8674, 'longitude': -117.831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92812', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.817, 'longitude': -117.9286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92814', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8173, 'longitude': -117.9607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92815', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8319, 'longitude': -117.9121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92816', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8401, 'longitude': -117.8867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92817', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8512, 'longitude': -117.7915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92821', 'place_name': 'Brea', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.9291, 'longitude': -117.8845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92822', 'place_name': 'Brea', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.9187, 'longitude': -117.8892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92823', 'place_name': 'Brea', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.923, 'longitude': -117.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92825', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8356, 'longitude': -117.9132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92831', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8873, 'longitude': -117.8946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92832', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.868, 'longitude': -117.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92833', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8766, 'longitude': -117.9551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92834', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8768, 'longitude': -117.897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92835', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8994, 'longitude': -117.9063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92836', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8755, 'longitude': -117.9038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92837', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8695, 'longitude': -117.9611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92838', 'place_name': 'Fullerton', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8934, 'longitude': -117.931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92840', 'place_name': 'Garden Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7869, 'longitude': -117.9273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92841', 'place_name': 'Garden Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7817, 'longitude': -117.9766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92842', 'place_name': 'Garden Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7783, 'longitude': -117.9456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92843', 'place_name': 'Garden Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7671, 'longitude': -117.929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92844', 'place_name': 'Garden Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7661, 'longitude': -117.9738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92845', 'place_name': 'Garden Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7787, 'longitude': -118.0267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92846', 'place_name': 'Garden Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.788, 'longitude': -118.0325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92850', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8442, 'longitude': -117.9555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92856', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7841, 'longitude': -117.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92857', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8317, 'longitude': -117.8491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92859', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8027, 'longitude': -117.7867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92861', 'place_name': 'Villa Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8205, 'longitude': -117.8104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92862', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7915, 'longitude': -117.714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92863', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8153, 'longitude': -117.8273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92864', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8143, 'longitude': -117.8308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92865', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8263, 'longitude': -117.8511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92866', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7877, 'longitude': -117.8423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92867', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.811, 'longitude': -117.8493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92868', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7875, 'longitude': -117.8776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92869', 'place_name': 'Orange', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.7868, 'longitude': -117.7934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92870', 'place_name': 'Placentia', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8744, 'longitude': -117.8543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92871', 'place_name': 'Placentia', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8829, 'longitude': -117.8557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92885', 'place_name': 'Yorba Linda', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8911, 'longitude': -117.8222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92886', 'place_name': 'Yorba Linda', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.9058, 'longitude': -117.7865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92887', 'place_name': 'Yorba Linda', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8841, 'longitude': -117.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92899', 'place_name': 'Anaheim', 'state': 'California', 'state_ab': 'CA', 'county': 'Orange', 'locality_code': '59', 'latitude': 33.8373, 'longitude': -117.8712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95602', 'place_name': 'Auburn', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.9829, 'longitude': -121.0944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95603', 'place_name': 'Auburn', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.9115, 'longitude': -121.08, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95604', 'place_name': 'Auburn', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.9029, 'longitude': -121.067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95631', 'place_name': 'Foresthill', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.0682, 'longitude': -120.7224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95648', 'place_name': 'Lincoln', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.8942, 'longitude': -121.2908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95650', 'place_name': 'Loomis', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.8071, 'longitude': -121.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95658', 'place_name': 'Newcastle', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.8763, 'longitude': -121.143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95661', 'place_name': 'Roseville', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.7346, 'longitude': -121.234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95663', 'place_name': 'Penryn', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.8567, 'longitude': -121.1791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95677', 'place_name': 'Rocklin', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.7877, 'longitude': -121.2366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95678', 'place_name': 'Roseville', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.7609, 'longitude': -121.2867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95681', 'place_name': 'Sheridan', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.9953, 'longitude': -121.368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95701', 'place_name': 'Alta', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.2441, 'longitude': -120.7531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95703', 'place_name': 'Applegate', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.0007, 'longitude': -120.9924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95713', 'place_name': 'Colfax', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.0783, 'longitude': -120.9549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95714', 'place_name': 'Dutch Flat', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.1978, 'longitude': -120.8262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95715', 'place_name': 'Emigrant Gap', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.2968, 'longitude': -120.6727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95717', 'place_name': 'Gold Run', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.171, 'longitude': -120.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95722', 'place_name': 'Meadow Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.0031, 'longitude': -121.0292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95736', 'place_name': 'Weimar', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.0375, 'longitude': -120.9713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95746', 'place_name': 'Granite Bay', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.7435, 'longitude': -121.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95747', 'place_name': 'Roseville', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.7703, 'longitude': -121.3372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95765', 'place_name': 'Rocklin', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 38.8136, 'longitude': -121.2677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96140', 'place_name': 'Carnelian Bay', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.2319, 'longitude': -120.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96141', 'place_name': 'Homewood', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.0786, 'longitude': -120.1734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96143', 'place_name': 'Kings Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.2401, 'longitude': -120.0233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96145', 'place_name': 'Tahoe City', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.1806, 'longitude': -120.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96146', 'place_name': 'Olympic Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.1752, 'longitude': -120.1954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96148', 'place_name': 'Tahoe Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'Placer', 'locality_code': '61', 'latitude': 39.2448, 'longitude': -120.0521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95915', 'place_name': 'Belden', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 40.006, 'longitude': -121.2491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95923', 'place_name': 'Canyon Dam', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.5645, 'longitude': -121.5751, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95934', 'place_name': 'Crescent Mills', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 40.0673, 'longitude': -120.9248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95947', 'place_name': 'Greenville', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 40.1699, 'longitude': -120.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95956', 'place_name': 'Meadow Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.9296, 'longitude': -121.0608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95971', 'place_name': 'Quincy', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.9284, 'longitude': -120.9698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95980', 'place_name': 'Storrie', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.9175, 'longitude': -121.3222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95983', 'place_name': 'Taylorsville', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 40.0357, 'longitude': -120.7353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95984', 'place_name': 'Twain', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 40.0509, 'longitude': -121.1268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96020', 'place_name': 'Chester', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 40.2975, 'longitude': -121.2273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96103', 'place_name': 'Blairsden Graeagle', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 40.1919, 'longitude': -120.1746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96105', 'place_name': 'Chilcoot', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.7977, 'longitude': -120.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96106', 'place_name': 'Clio', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.7546, 'longitude': -120.5951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96122', 'place_name': 'Portola', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.8105, 'longitude': -120.4691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96129', 'place_name': 'Beckwourth', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.7721, 'longitude': -120.4051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96135', 'place_name': 'Vinton', 'state': 'California', 'state_ab': 'CA', 'county': 'Plumas', 'locality_code': '63', 'latitude': 39.8043, 'longitude': -120.1783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91752', 'place_name': 'Mira Loma', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9938, 'longitude': -117.5236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92201', 'place_name': 'Indio', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7207, 'longitude': -116.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92202', 'place_name': 'Indio', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7529, 'longitude': -116.0556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92203', 'place_name': 'Indio', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7532, 'longitude': -116.2676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92210', 'place_name': 'Indian Wells', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7163, 'longitude': -116.3381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92211', 'place_name': 'Palm Desert', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7644, 'longitude': -116.3398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92220', 'place_name': 'Banning', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9282, 'longitude': -116.8899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92223', 'place_name': 'Beaumont', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9504, 'longitude': -116.9701, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92225', 'place_name': 'Blythe', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6103, 'longitude': -114.5963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92226', 'place_name': 'Blythe', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.5987, 'longitude': -114.6525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92230', 'place_name': 'Cabazon', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9086, 'longitude': -116.7739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92234', 'place_name': 'Cathedral City', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8098, 'longitude': -116.4665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92235', 'place_name': 'Cathedral City', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7797, 'longitude': -116.4653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92236', 'place_name': 'Coachella', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.675, 'longitude': -116.1772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92239', 'place_name': 'Desert Center', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.809, 'longitude': -115.3666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92240', 'place_name': 'Desert Hot Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9531, 'longitude': -116.5219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92241', 'place_name': 'Desert Hot Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8763, 'longitude': -116.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92247', 'place_name': 'La Quinta', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6736, 'longitude': -116.2951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92253', 'place_name': 'La Quinta', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6685, 'longitude': -116.3081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92254', 'place_name': 'Mecca', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.545, 'longitude': -116.0187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92255', 'place_name': 'Palm Desert', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7225, 'longitude': -116.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92258', 'place_name': 'North Palm Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9228, 'longitude': -116.5431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92260', 'place_name': 'Palm Desert', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7225, 'longitude': -116.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92261', 'place_name': 'Palm Desert', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6604, 'longitude': -116.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92262', 'place_name': 'Palm Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8414, 'longitude': -116.5347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92263', 'place_name': 'Palm Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7611, 'longitude': -116.5359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92264', 'place_name': 'Palm Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8018, 'longitude': -116.517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92270', 'place_name': 'Rancho Mirage', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7643, 'longitude': -116.4225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92274', 'place_name': 'Thermal', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.5578, 'longitude': -116.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92276', 'place_name': 'Thousand Palms', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8082, 'longitude': -116.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92282', 'place_name': 'Whitewater', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.989, 'longitude': -116.6566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92320', 'place_name': 'Calimesa', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9946, 'longitude': -117.043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92501', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9924, 'longitude': -117.3694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92502', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92503', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9208, 'longitude': -117.4589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92504', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9315, 'longitude': -117.4119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92505', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9228, 'longitude': -117.4867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92506', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9455, 'longitude': -117.3757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92507', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9761, 'longitude': -117.3389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92508', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8897, 'longitude': -117.3043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92509', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 34.0033, 'longitude': -117.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92513', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92514', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92515', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92516', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92517', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92518', 'place_name': 'March Air Reserve Base', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92519', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92521', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92522', 'place_name': 'Riverside', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9533, 'longitude': -117.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92530', 'place_name': 'Lake Elsinore', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6598, 'longitude': -117.3485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92531', 'place_name': 'Lake Elsinore', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6681, 'longitude': -117.3273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92532', 'place_name': 'Lake Elsinore', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6927, 'longitude': -117.303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92536', 'place_name': 'Aguanga', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.4473, 'longitude': -116.7997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92539', 'place_name': 'Anza', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.5688, 'longitude': -116.7135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92543', 'place_name': 'Hemet', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7416, 'longitude': -116.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92544', 'place_name': 'Hemet', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.739, 'longitude': -116.9243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92545', 'place_name': 'Hemet', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7399, 'longitude': -117.0151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92546', 'place_name': 'Hemet', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7476, 'longitude': -116.9731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92548', 'place_name': 'Homeland', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7453, 'longitude': -117.1118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92549', 'place_name': 'Idyllwild', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7304, 'longitude': -116.7107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92551', 'place_name': 'Moreno Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8814, 'longitude': -117.2261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92552', 'place_name': 'Moreno Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9375, 'longitude': -117.2306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92553', 'place_name': 'Moreno Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9157, 'longitude': -117.2351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92554', 'place_name': 'Moreno Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9375, 'longitude': -117.2306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92555', 'place_name': 'Moreno Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9377, 'longitude': -117.1851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92556', 'place_name': 'Moreno Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9375, 'longitude': -117.2306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92557', 'place_name': 'Moreno Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9553, 'longitude': -117.2457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92561', 'place_name': 'Mountain Center', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7042, 'longitude': -116.7259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92562', 'place_name': 'Murrieta', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.5631, 'longitude': -117.2738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92563', 'place_name': 'Murrieta', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.569, 'longitude': -117.1783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92564', 'place_name': 'Murrieta', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.5539, 'longitude': -117.2139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92567', 'place_name': 'Nuevo', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8123, 'longitude': -117.1048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92570', 'place_name': 'Perris', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7852, 'longitude': -117.3166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92571', 'place_name': 'Perris', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.811, 'longitude': -117.218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92572', 'place_name': 'Perris', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7825, 'longitude': -117.2286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92581', 'place_name': 'San Jacinto', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7839, 'longitude': -116.9586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92582', 'place_name': 'San Jacinto', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7883, 'longitude': -116.9819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92583', 'place_name': 'San Jacinto', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7967, 'longitude': -116.9324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92584', 'place_name': 'Menifee', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6647, 'longitude': -117.1743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92585', 'place_name': 'Sun City', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7467, 'longitude': -117.1721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92586', 'place_name': 'Sun City', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7044, 'longitude': -117.1969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92587', 'place_name': 'Quail Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.707, 'longitude': -117.245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92589', 'place_name': 'Temecula', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.4936, 'longitude': -117.1484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92590', 'place_name': 'Temecula', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.4903, 'longitude': -117.1824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92591', 'place_name': 'Temecula', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.5217, 'longitude': -117.1286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92592', 'place_name': 'Temecula', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.4983, 'longitude': -117.0958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92593', 'place_name': 'Temecula', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.4936, 'longitude': -117.1484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92595', 'place_name': 'Wildomar', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6021, 'longitude': -117.264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92596', 'place_name': 'Winchester', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.6243, 'longitude': -117.0885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92599', 'place_name': 'Perris', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7825, 'longitude': -117.2286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92860', 'place_name': 'Norco', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9247, 'longitude': -117.5517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92877', 'place_name': 'Corona', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8753, 'longitude': -117.5664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92878', 'place_name': 'Corona', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8753, 'longitude': -117.5664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92879', 'place_name': 'Corona', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8797, 'longitude': -117.5354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92880', 'place_name': 'Corona', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.9208, 'longitude': -117.6096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92881', 'place_name': 'Corona', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8241, 'longitude': -117.5198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92882', 'place_name': 'Corona', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.8419, 'longitude': -117.6043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92883', 'place_name': 'Corona', 'state': 'California', 'state_ab': 'CA', 'county': 'Riverside', 'locality_code': '65', 'latitude': 33.7541, 'longitude': -117.474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94203', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94204', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94205', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94206', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94207', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94208', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94209', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94211', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94229', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94230', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94232', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94234', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94235', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94236', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94237', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94239', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94240', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94244', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94245', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94247', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94248', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94249', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94250', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94252', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94254', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94256', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94257', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94258', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94259', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94261', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94262', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94263', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94267', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94268', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94269', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94271', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94273', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94274', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94277', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94278', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94279', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94280', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94282', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94283', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94284', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94285', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94286', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94287', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94288', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94289', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94290', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94291', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94293', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94294', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94295', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94296', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94297', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94298', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94299', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95608', 'place_name': 'Carmichael', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6284, 'longitude': -121.3287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95609', 'place_name': 'Carmichael', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6257, 'longitude': -121.3272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95610', 'place_name': 'Citrus Heights', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6946, 'longitude': -121.2692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95611', 'place_name': 'Citrus Heights', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.7072, 'longitude': -121.28, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95615', 'place_name': 'Courtland', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.3137, 'longitude': -121.563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95621', 'place_name': 'Citrus Heights', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6952, 'longitude': -121.3075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95624', 'place_name': 'Elk Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4232, 'longitude': -121.3599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95626', 'place_name': 'Elverta', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.7233, 'longitude': -121.4497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95628', 'place_name': 'Fair Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6554, 'longitude': -121.2611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95630', 'place_name': 'Folsom', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6709, 'longitude': -121.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95632', 'place_name': 'Galt', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.2691, 'longitude': -121.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95638', 'place_name': 'Herald', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.3119, 'longitude': -121.1729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95639', 'place_name': 'Hood', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.3702, 'longitude': -121.5143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95641', 'place_name': 'Isleton', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.157, 'longitude': -121.6066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95652', 'place_name': 'Mcclellan', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6621, 'longitude': -121.3955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95655', 'place_name': 'Mather', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5579, 'longitude': -121.291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95660', 'place_name': 'North Highlands', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6707, 'longitude': -121.3781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95662', 'place_name': 'Orangevale', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6845, 'longitude': -121.2256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95670', 'place_name': 'Rancho Cordova', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6072, 'longitude': -121.2761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95671', 'place_name': 'Represa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.7065, 'longitude': -121.1694, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95673', 'place_name': 'Rio Linda', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6895, 'longitude': -121.4479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95680', 'place_name': 'Ryde', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.2386, 'longitude': -121.5594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95683', 'place_name': 'Sloughhouse', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5143, 'longitude': -121.0964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95690', 'place_name': 'Walnut Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.2396, 'longitude': -121.5443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95693', 'place_name': 'Wilton', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.3983, 'longitude': -121.2303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95741', 'place_name': 'Rancho Cordova', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5891, 'longitude': -121.3016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95742', 'place_name': 'Rancho Cordova', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5981, 'longitude': -121.2153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95757', 'place_name': 'Elk Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4081, 'longitude': -121.4294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95758', 'place_name': 'Elk Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4243, 'longitude': -121.437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95759', 'place_name': 'Elk Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.407, 'longitude': -121.3752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95763', 'place_name': 'Folsom', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.678, 'longitude': -121.175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95811', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5762, 'longitude': -121.488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95812', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5822, 'longitude': -121.4943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95813', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6026, 'longitude': -121.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95814', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5804, 'longitude': -121.4922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95815', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6093, 'longitude': -121.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95816', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5728, 'longitude': -121.4675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95817', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5498, 'longitude': -121.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95818', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5568, 'longitude': -121.4929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95819', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5683, 'longitude': -121.4366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95820', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5347, 'longitude': -121.4451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95821', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6239, 'longitude': -121.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95822', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5091, 'longitude': -121.4935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95823', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4797, 'longitude': -121.4438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95824', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5178, 'longitude': -121.4419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95825', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5892, 'longitude': -121.4057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95826', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5539, 'longitude': -121.3693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95827', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5662, 'longitude': -121.3286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95828', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4826, 'longitude': -121.4006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95829', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4689, 'longitude': -121.344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95830', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4896, 'longitude': -121.2772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95831', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4962, 'longitude': -121.5297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95832', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.4695, 'longitude': -121.4883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95833', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6157, 'longitude': -121.5053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95834', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6383, 'longitude': -121.5072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95835', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6626, 'longitude': -121.4834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95836', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.7198, 'longitude': -121.5343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95837', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6817, 'longitude': -121.603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95838', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6406, 'longitude': -121.444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95840', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95841', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6627, 'longitude': -121.3406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95842', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6865, 'longitude': -121.3494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95843', 'place_name': 'Antelope', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.7159, 'longitude': -121.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95851', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6026, 'longitude': -121.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95852', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6026, 'longitude': -121.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95853', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6026, 'longitude': -121.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95860', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.6105, 'longitude': -121.3799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95864', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5878, 'longitude': -121.3769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95865', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.596, 'longitude': -121.3978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95866', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.596, 'longitude': -121.3978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95867', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95894', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5816, 'longitude': -121.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95899', 'place_name': 'Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Sacramento', 'locality_code': '67', 'latitude': 38.5383, 'longitude': -121.5549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95023', 'place_name': 'Hollister', 'state': 'California', 'state_ab': 'CA', 'county': 'San Benito', 'locality_code': '69', 'latitude': 36.8337, 'longitude': -121.3439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95024', 'place_name': 'Hollister', 'state': 'California', 'state_ab': 'CA', 'county': 'San Benito', 'locality_code': '69', 'latitude': 36.8586, 'longitude': -121.3982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95043', 'place_name': 'Paicines', 'state': 'California', 'state_ab': 'CA', 'county': 'San Benito', 'locality_code': '69', 'latitude': 36.4985, 'longitude': -120.9744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95045', 'place_name': 'San Juan Bautista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Benito', 'locality_code': '69', 'latitude': 36.8463, 'longitude': -121.5346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95075', 'place_name': 'Tres Pinos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Benito', 'locality_code': '69', 'latitude': 36.767, 'longitude': -121.3017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91701', 'place_name': 'Rancho Cucamonga', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1376, 'longitude': -117.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91708', 'place_name': 'Chino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 33.954, 'longitude': -117.6404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91709', 'place_name': 'Chino Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 33.9797, 'longitude': -117.7308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91710', 'place_name': 'Chino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0125, 'longitude': -117.6844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91729', 'place_name': 'Rancho Cucamonga', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1064, 'longitude': -117.5931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91730', 'place_name': 'Rancho Cucamonga', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.107, 'longitude': -117.5941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91737', 'place_name': 'Rancho Cucamonga', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1467, 'longitude': -117.5803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91739', 'place_name': 'Rancho Cucamonga', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1705, 'longitude': -117.5182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91743', 'place_name': 'Guasti', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.065, 'longitude': -117.5864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91758', 'place_name': 'Ontario', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0633, 'longitude': -117.6509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91761', 'place_name': 'Ontario', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0316, 'longitude': -117.6187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91762', 'place_name': 'Ontario', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0584, 'longitude': -117.6665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91763', 'place_name': 'Montclair', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0733, 'longitude': -117.6987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91764', 'place_name': 'Ontario', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0763, 'longitude': -117.6254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91784', 'place_name': 'Upland', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.141, 'longitude': -117.6581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91785', 'place_name': 'Upland', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1144, 'longitude': -117.6583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91786', 'place_name': 'Upland', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1144, 'longitude': -117.6583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92242', 'place_name': 'Earp', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1652, 'longitude': -114.3197, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92248', 'place_name': 'La Quinta', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 33.6736, 'longitude': -116.2951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92252', 'place_name': 'Joshua Tree', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1502, 'longitude': -116.3038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92256', 'place_name': 'Morongo Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0606, 'longitude': -116.5656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92267', 'place_name': 'Parker Dam', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2872, 'longitude': -114.143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92268', 'place_name': 'Pioneertown', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1887, 'longitude': -116.5048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92277', 'place_name': 'Twentynine Palms', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1455, 'longitude': -116.0601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92278', 'place_name': 'Twentynine Palms', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.238, 'longitude': -116.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92280', 'place_name': 'Vidal', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1561, 'longitude': -114.5656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92284', 'place_name': 'Yucca Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1559, 'longitude': -116.4313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92285', 'place_name': 'Landers', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.3103, 'longitude': -116.5241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92286', 'place_name': 'Yucca Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1803, 'longitude': -116.35, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92301', 'place_name': 'Adelanto', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.5841, 'longitude': -117.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92304', 'place_name': 'Amboy', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.5578, 'longitude': -115.7444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92305', 'place_name': 'Angelus Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1531, 'longitude': -116.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92307', 'place_name': 'Apple Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.5291, 'longitude': -117.2132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92308', 'place_name': 'Apple Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4698, 'longitude': -117.1927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92309', 'place_name': 'Baker', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.3606, 'longitude': -116.0638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92310', 'place_name': 'Fort Irwin', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.2625, 'longitude': -116.6966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92311', 'place_name': 'Barstow', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.8914, 'longitude': -117.0387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92312', 'place_name': 'Barstow', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.8986, 'longitude': -117.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92313', 'place_name': 'Grand Terrace', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.031, 'longitude': -117.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92314', 'place_name': 'Big Bear City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.261, 'longitude': -116.8131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92315', 'place_name': 'Big Bear Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.235, 'longitude': -116.9053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92316', 'place_name': 'Bloomington', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0662, 'longitude': -117.3993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92317', 'place_name': 'Blue Jay', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2112, 'longitude': -117.0796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92318', 'place_name': 'Bryn Mawr', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0483, 'longitude': -117.2309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92321', 'place_name': 'Cedar Glen', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2545, 'longitude': -117.1533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92322', 'place_name': 'Cedarpines Park', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2544, 'longitude': -117.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92323', 'place_name': 'Cima', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.2378, 'longitude': -115.4992, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92324', 'place_name': 'Colton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0315, 'longitude': -117.2874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92325', 'place_name': 'Crestline', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2433, 'longitude': -117.2811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92327', 'place_name': 'Daggett', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.8668, 'longitude': -116.8876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92329', 'place_name': 'Phelan', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4261, 'longitude': -117.5723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92332', 'place_name': 'Essex', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.5881, 'longitude': -115.5771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92333', 'place_name': 'Fawnskin', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2583, 'longitude': -116.9515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92334', 'place_name': 'Fontana', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0922, 'longitude': -117.435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92335', 'place_name': 'Fontana', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0794, 'longitude': -117.4551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92336', 'place_name': 'Fontana', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1173, 'longitude': -117.4378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92337', 'place_name': 'Fontana', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0498, 'longitude': -117.4706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92338', 'place_name': 'Ludlow', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.7211, 'longitude': -116.16, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92339', 'place_name': 'Forest Falls', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0937, 'longitude': -116.9362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92340', 'place_name': 'Hesperia', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4264, 'longitude': -117.3009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92341', 'place_name': 'Green Valley Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2348, 'longitude': -117.066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92342', 'place_name': 'Helendale', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.7499, 'longitude': -117.3367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92344', 'place_name': 'Hesperia', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4239, 'longitude': -117.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92345', 'place_name': 'Hesperia', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4222, 'longitude': -117.3025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92346', 'place_name': 'Highland', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1283, 'longitude': -117.2087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92347', 'place_name': 'Hinkley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.9279, 'longitude': -117.1809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92350', 'place_name': 'Loma Linda', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0483, 'longitude': -117.2612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92352', 'place_name': 'Lake Arrowhead', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2606, 'longitude': -117.2016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92354', 'place_name': 'Loma Linda', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0528, 'longitude': -117.2513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92356', 'place_name': 'Lucerne Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.447, 'longitude': -116.9189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92357', 'place_name': 'Loma Linda', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0483, 'longitude': -117.2612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92358', 'place_name': 'Lytle Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2558, 'longitude': -117.5186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92359', 'place_name': 'Mentone', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0774, 'longitude': -117.1126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92363', 'place_name': 'Needles', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.7824, 'longitude': -114.5871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92364', 'place_name': 'Nipton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.4667, 'longitude': -115.2722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92365', 'place_name': 'Newberry Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.885, 'longitude': -116.7464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92366', 'place_name': 'Mountain Pass', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.4703, 'longitude': -115.545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92368', 'place_name': 'Oro Grande', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.6178, 'longitude': -117.3327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92369', 'place_name': 'Patton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1358, 'longitude': -117.2239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92371', 'place_name': 'Phelan', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4449, 'longitude': -117.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92372', 'place_name': 'Pinon Hills', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4429, 'longitude': -117.6403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92373', 'place_name': 'Redlands', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0397, 'longitude': -117.1804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92374', 'place_name': 'Redlands', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.065, 'longitude': -117.1672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92375', 'place_name': 'Redlands', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0556, 'longitude': -117.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92376', 'place_name': 'Rialto', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1132, 'longitude': -117.3771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92377', 'place_name': 'Rialto', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1561, 'longitude': -117.4042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92378', 'place_name': 'Rimforest', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2297, 'longitude': -117.225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92382', 'place_name': 'Running Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2102, 'longitude': -117.1109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92385', 'place_name': 'Skyforest', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2353, 'longitude': -117.1792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92386', 'place_name': 'Sugarloaf', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2372, 'longitude': -116.8277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92391', 'place_name': 'Twin Peaks', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2379, 'longitude': -117.2348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92392', 'place_name': 'Victorville', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.4802, 'longitude': -117.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92393', 'place_name': 'Victorville', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.5361, 'longitude': -117.2912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92394', 'place_name': 'Victorville', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.5563, 'longitude': -117.3528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92395', 'place_name': 'Victorville', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.5016, 'longitude': -117.2944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92397', 'place_name': 'Wrightwood', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.3628, 'longitude': -117.6249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92398', 'place_name': 'Yermo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.905, 'longitude': -116.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92399', 'place_name': 'Yucaipa', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0282, 'longitude': -117.0489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92401', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1105, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92402', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92403', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92404', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1426, 'longitude': -117.2606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92405', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1446, 'longitude': -117.3013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92406', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92407', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.2166, 'longitude': -117.3908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92408', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.0831, 'longitude': -117.2711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92410', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1069, 'longitude': -117.2975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92411', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1214, 'longitude': -117.3172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92413', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92415', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92418', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92423', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92427', 'place_name': 'San Bernardino', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 34.1083, 'longitude': -117.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93558', 'place_name': 'Red Mountain', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.3479, 'longitude': -117.6214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93562', 'place_name': 'Trona', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.7481, 'longitude': -117.3808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93592', 'place_name': 'Trona', 'state': 'California', 'state_ab': 'CA', 'county': 'San Bernardino', 'locality_code': '71', 'latitude': 35.7627, 'longitude': -117.3728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91901', 'place_name': 'Alpine', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8282, 'longitude': -116.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91902', 'place_name': 'Bonita', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6671, 'longitude': -117.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91903', 'place_name': 'Alpine', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8351, 'longitude': -116.7664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91905', 'place_name': 'Boulevard', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6719, 'longitude': -116.32, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91906', 'place_name': 'Campo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6605, 'longitude': -116.4905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91908', 'place_name': 'Bonita', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6578, 'longitude': -117.03, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91909', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6401, 'longitude': -117.0842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91910', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6371, 'longitude': -117.0676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91911', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6084, 'longitude': -117.0565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91912', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6401, 'longitude': -117.0842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91913', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6513, 'longitude': -116.9852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91914', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6587, 'longitude': -116.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91915', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6315, 'longitude': -116.9408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91916', 'place_name': 'Descanso', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.873, 'longitude': -116.6027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91917', 'place_name': 'Dulzura', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6152, 'longitude': -116.7285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91921', 'place_name': 'Chula Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6401, 'longitude': -117.0842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91931', 'place_name': 'Guatay', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8497, 'longitude': -116.5583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91932', 'place_name': 'Imperial Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.5783, 'longitude': -117.1148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91933', 'place_name': 'Imperial Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.5839, 'longitude': -117.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91934', 'place_name': 'Jacumba', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6249, 'longitude': -116.1952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91935', 'place_name': 'Jamul', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7163, 'longitude': -116.8323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91941', 'place_name': 'La Mesa', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7604, 'longitude': -117.0115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91942', 'place_name': 'La Mesa', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7835, 'longitude': -117.0189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91943', 'place_name': 'La Mesa', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7678, 'longitude': -117.0231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91944', 'place_name': 'La Mesa', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7678, 'longitude': -117.0231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91945', 'place_name': 'Lemon Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7332, 'longitude': -117.0326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91946', 'place_name': 'Lemon Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7426, 'longitude': -117.0314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91948', 'place_name': 'Mount Laguna', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8676, 'longitude': -116.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91950', 'place_name': 'National City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6749, 'longitude': -117.0897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91951', 'place_name': 'National City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6781, 'longitude': -117.0992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91962', 'place_name': 'Pine Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.835, 'longitude': -116.5127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91963', 'place_name': 'Potrero', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6205, 'longitude': -116.6037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91976', 'place_name': 'Spring Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7448, 'longitude': -116.9989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91977', 'place_name': 'Spring Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.724, 'longitude': -116.9976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91978', 'place_name': 'Spring Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7329, 'longitude': -116.9596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91979', 'place_name': 'Spring Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7448, 'longitude': -116.9989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91980', 'place_name': 'Tecate', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.5889, 'longitude': -116.6192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91987', 'place_name': 'Tecate', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.5773, 'longitude': -116.6275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92003', 'place_name': 'Bonsall', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.294, 'longitude': -117.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92004', 'place_name': 'Borrego Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.2386, 'longitude': -116.3514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92007', 'place_name': 'Cardiff By The Sea', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.023, 'longitude': -117.2745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92008', 'place_name': 'Carlsbad', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1602, 'longitude': -117.325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92009', 'place_name': 'Carlsbad', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.0954, 'longitude': -117.2619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92010', 'place_name': 'Carlsbad', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1639, 'longitude': -117.3009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92011', 'place_name': 'Carlsbad', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1072, 'longitude': -117.2943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92013', 'place_name': 'Carlsbad', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1581, 'longitude': -117.3506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92014', 'place_name': 'Del Mar', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9665, 'longitude': -117.249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92018', 'place_name': 'Carlsbad', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1581, 'longitude': -117.3506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92019', 'place_name': 'El Cajon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7777, 'longitude': -116.9191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92020', 'place_name': 'El Cajon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7928, 'longitude': -116.9665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92021', 'place_name': 'El Cajon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8178, 'longitude': -116.9223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92022', 'place_name': 'El Cajon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7948, 'longitude': -116.9625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92023', 'place_name': 'Encinitas', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.036, 'longitude': -117.292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92024', 'place_name': 'Encinitas', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.0535, 'longitude': -117.2689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92025', 'place_name': 'Escondido', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1101, 'longitude': -117.07, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92026', 'place_name': 'Escondido', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1605, 'longitude': -117.0978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92027', 'place_name': 'Escondido', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1388, 'longitude': -117.052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92028', 'place_name': 'Fallbrook', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.369, 'longitude': -117.229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92029', 'place_name': 'Escondido', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.0895, 'longitude': -117.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92030', 'place_name': 'Escondido', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1192, 'longitude': -117.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92033', 'place_name': 'Escondido', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1192, 'longitude': -117.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92036', 'place_name': 'Julian', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.0534, 'longitude': -116.5658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92037', 'place_name': 'La Jolla', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8455, 'longitude': -117.2521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92038', 'place_name': 'La Jolla', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8473, 'longitude': -117.2742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92039', 'place_name': 'La Jolla', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8473, 'longitude': -117.2742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92040', 'place_name': 'Lakeside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8562, 'longitude': -116.9201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92046', 'place_name': 'Escondido', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1192, 'longitude': -117.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92049', 'place_name': 'Oceanside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1959, 'longitude': -117.3795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92051', 'place_name': 'Oceanside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1959, 'longitude': -117.3795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92052', 'place_name': 'Oceanside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1959, 'longitude': -117.3795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92054', 'place_name': 'Oceanside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.2072, 'longitude': -117.3573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92055', 'place_name': 'Camp Pendleton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.2433, 'longitude': -117.3768, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '92056', 'place_name': 'Oceanside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1968, 'longitude': -117.2831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92057', 'place_name': 'Oceanside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.2407, 'longitude': -117.3025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92058', 'place_name': 'Oceanside', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1959, 'longitude': -117.3795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92059', 'place_name': 'Pala', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.3777, 'longitude': -117.0717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92060', 'place_name': 'Palomar Mountain', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.3228, 'longitude': -116.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92061', 'place_name': 'Pauma Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.3063, 'longitude': -116.9596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92064', 'place_name': 'Poway', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9756, 'longitude': -117.0402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92065', 'place_name': 'Ramona', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.0293, 'longitude': -116.8535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92066', 'place_name': 'Ranchita', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.21, 'longitude': -116.5167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92067', 'place_name': 'Rancho Santa Fe', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.005, 'longitude': -117.2157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92068', 'place_name': 'San Luis Rey', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.232, 'longitude': -117.3236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92069', 'place_name': 'San Marcos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1444, 'longitude': -117.1697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92070', 'place_name': 'Santa Ysabel', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1476, 'longitude': -116.6963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92071', 'place_name': 'Santee', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8486, 'longitude': -116.9862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92072', 'place_name': 'Santee', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8384, 'longitude': -116.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92074', 'place_name': 'Poway', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9628, 'longitude': -117.0359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92075', 'place_name': 'Solana Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9937, 'longitude': -117.2598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92078', 'place_name': 'San Marcos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1193, 'longitude': -117.185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92079', 'place_name': 'San Marcos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1434, 'longitude': -117.1661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92081', 'place_name': 'Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1644, 'longitude': -117.2403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92082', 'place_name': 'Valley Center', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.249, 'longitude': -117.0122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92083', 'place_name': 'Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1978, 'longitude': -117.2482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92084', 'place_name': 'Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.2131, 'longitude': -117.2243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92085', 'place_name': 'Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.2, 'longitude': -117.2425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92086', 'place_name': 'Warner Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.3096, 'longitude': -116.6527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92088', 'place_name': 'Fallbrook', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.3764, 'longitude': -117.2511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92091', 'place_name': 'Rancho Santa Fe', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9623, 'longitude': -117.0462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92092', 'place_name': 'La Jolla', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8473, 'longitude': -117.2742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92093', 'place_name': 'La Jolla', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8473, 'longitude': -117.2742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92096', 'place_name': 'San Marcos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.1434, 'longitude': -117.1661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92101', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7185, 'longitude': -117.1593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92102', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7139, 'longitude': -117.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92103', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7466, 'longitude': -117.1636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92104', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7454, 'longitude': -117.1272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92105', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7423, 'longitude': -117.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92106', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7272, 'longitude': -117.2268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92107', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7425, 'longitude': -117.2433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92108', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7783, 'longitude': -117.1335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92109', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7969, 'longitude': -117.2405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92110', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7635, 'longitude': -117.2028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92111', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7972, 'longitude': -117.1708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92112', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92113', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.697, 'longitude': -117.1153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92114', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7059, 'longitude': -117.0524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92115', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7607, 'longitude': -117.0721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92116', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7624, 'longitude': -117.1242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92117', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8239, 'longitude': -117.1965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92118', 'place_name': 'Coronado', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6807, 'longitude': -117.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92119', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8036, 'longitude': -117.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92120', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7958, 'longitude': -117.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92121', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8919, 'longitude': -117.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92122', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8577, 'longitude': -117.2115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92123', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7973, 'longitude': -117.1392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92124', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8201, 'longitude': -117.0986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92126', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9161, 'longitude': -117.1402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92127', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.0279, 'longitude': -117.0856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92128', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.0067, 'longitude': -117.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92129', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9652, 'longitude': -117.1213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92130', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9555, 'longitude': -117.2252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92131', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.9123, 'longitude': -117.0898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92132', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6437, 'longitude': -117.1384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92134', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7242, 'longitude': -117.1466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92135', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92136', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6834, 'longitude': -117.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92137', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8538, 'longitude': -117.1197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92138', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92139', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6806, 'longitude': -117.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92140', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7434, 'longitude': -117.2004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92142', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92143', 'place_name': 'San Ysidro', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 33.2553, 'longitude': -116.5664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92145', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8891, 'longitude': -117.1005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92147', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92149', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92150', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92152', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92153', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92154', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.5753, 'longitude': -117.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92155', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6716, 'longitude': -117.1657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92158', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92159', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92160', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92161', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.8718, 'longitude': -117.2291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92163', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92165', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92166', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92167', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92168', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92169', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92170', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92171', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92172', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92173', 'place_name': 'San Ysidro', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.5626, 'longitude': -117.043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92174', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92175', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92176', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92177', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92178', 'place_name': 'Coronado', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.6859, 'longitude': -117.1831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92179', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92182', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7751, 'longitude': -117.0762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92186', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92187', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92190', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92191', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92192', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92193', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92195', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92196', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92197', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92198', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7153, 'longitude': -117.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '92199', 'place_name': 'San Diego', 'state': 'California', 'state_ab': 'CA', 'county': 'San Diego', 'locality_code': '73', 'latitude': 32.7516, 'longitude': -117.1918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94102', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7813, 'longitude': -122.4167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94103', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7725, 'longitude': -122.4147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94104', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7915, 'longitude': -122.4018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94105', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7864, 'longitude': -122.3892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94107', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7621, 'longitude': -122.3971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94108', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7929, 'longitude': -122.4079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94109', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7917, 'longitude': -122.4186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94110', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7509, 'longitude': -122.4153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94111', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7974, 'longitude': -122.4001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94112', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7195, 'longitude': -122.4411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94114', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7587, 'longitude': -122.433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94115', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7856, 'longitude': -122.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94116', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7441, 'longitude': -122.4863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94117', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7712, 'longitude': -122.4413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94118', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7812, 'longitude': -122.4614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94119', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94120', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94121', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7786, 'longitude': -122.4892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94122', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7593, 'longitude': -122.4836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94123', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7999, 'longitude': -122.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94124', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7309, 'longitude': -122.3886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94125', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94126', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94127', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7354, 'longitude': -122.4571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94129', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.8005, 'longitude': -122.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94130', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.8231, 'longitude': -122.3693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94131', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.745, 'longitude': -122.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94132', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7211, 'longitude': -122.4754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94133', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.8002, 'longitude': -122.4091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94134', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.719, 'longitude': -122.4096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94137', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94139', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94140', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94141', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94142', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94143', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7631, 'longitude': -122.4586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94144', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94145', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94146', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94147', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94151', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94158', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7694, 'longitude': -122.3867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94159', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94160', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94161', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94163', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94164', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94172', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94177', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94188', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'City and County of San Francisco', 'locality_code': '75', 'latitude': 37.7749, 'longitude': -122.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95201', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.958, 'longitude': -121.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95202', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9606, 'longitude': -121.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95203', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9532, 'longitude': -121.3116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95204', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9743, 'longitude': -121.3154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95205', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9625, 'longitude': -121.2624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95206', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9177, 'longitude': -121.3123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95207', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.0024, 'longitude': -121.3238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95208', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9304, 'longitude': -121.436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95209', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.0377, 'longitude': -121.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95210', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.025, 'longitude': -121.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95211', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9809, 'longitude': -121.311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95212', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.0315, 'longitude': -121.2589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95213', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9054, 'longitude': -121.2222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95214', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9053, 'longitude': -121.2262, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95215', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9551, 'longitude': -121.2041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95219', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.01, 'longitude': -121.3698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95220', 'place_name': 'Acampo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.2004, 'longitude': -121.2186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95227', 'place_name': 'Clements', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.1929, 'longitude': -121.0811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95230', 'place_name': 'Farmington', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9299, 'longitude': -121.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95231', 'place_name': 'French Camp', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.878, 'longitude': -121.2827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95234', 'place_name': 'Holt', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9344, 'longitude': -121.4261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95236', 'place_name': 'Linden', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.032, 'longitude': -121.0493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95237', 'place_name': 'Lockeford', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.1613, 'longitude': -121.1424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95240', 'place_name': 'Lodi', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.1222, 'longitude': -121.2555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95241', 'place_name': 'Lodi', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.1327, 'longitude': -121.2724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95242', 'place_name': 'Lodi', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.1308, 'longitude': -121.3345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95253', 'place_name': 'Victor', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.138, 'longitude': -121.205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95258', 'place_name': 'Woodbridge', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.1551, 'longitude': -121.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95267', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.0003, 'longitude': -121.3174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95269', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.0187, 'longitude': -121.3225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95296', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.9577, 'longitude': -121.2908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95297', 'place_name': 'Stockton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.0025, 'longitude': -121.324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95304', 'place_name': 'Tracy', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.7319, 'longitude': -121.4096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95320', 'place_name': 'Escalon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.7983, 'longitude': -121.0006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95330', 'place_name': 'Lathrop', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.8209, 'longitude': -121.2827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95336', 'place_name': 'Manteca', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.8134, 'longitude': -121.2132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95337', 'place_name': 'Manteca', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.7808, 'longitude': -121.2344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95366', 'place_name': 'Ripon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.7491, 'longitude': -121.1284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95376', 'place_name': 'Tracy', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.7383, 'longitude': -121.4345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95377', 'place_name': 'Tracy', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.6567, 'longitude': -121.4955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95378', 'place_name': 'Tracy', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.6761, 'longitude': -121.433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95385', 'place_name': 'Vernalis', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.6176, 'longitude': -121.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95391', 'place_name': 'Tracy', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 37.7695, 'longitude': -121.5397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95686', 'place_name': 'Thornton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Joaquin', 'locality_code': '77', 'latitude': 38.2261, 'longitude': -121.4236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93401', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.2635, 'longitude': -120.6509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93402', 'place_name': 'Los Osos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.3172, 'longitude': -120.8333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93403', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.2828, 'longitude': -120.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93405', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.2901, 'longitude': -120.6817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93406', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.2828, 'longitude': -120.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93407', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.2828, 'longitude': -120.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93408', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.2828, 'longitude': -120.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93409', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.2211, 'longitude': -120.6364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93410', 'place_name': 'San Luis Obispo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.3471, 'longitude': -120.4553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93412', 'place_name': 'Los Osos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.3111, 'longitude': -120.8324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93420', 'place_name': 'Arroyo Grande', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.1661, 'longitude': -120.4651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93421', 'place_name': 'Arroyo Grande', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.1186, 'longitude': -120.5907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93422', 'place_name': 'Atascadero', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.4754, 'longitude': -120.6638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93423', 'place_name': 'Atascadero', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.4282, 'longitude': -120.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93424', 'place_name': 'Avila Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.18, 'longitude': -120.7318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93428', 'place_name': 'Cambria', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.5566, 'longitude': -121.084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93430', 'place_name': 'Cayucos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.4446, 'longitude': -120.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93432', 'place_name': 'Creston', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.4779, 'longitude': -120.4361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93433', 'place_name': 'Grover Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.121, 'longitude': -120.6173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93435', 'place_name': 'Harmony', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.4919, 'longitude': -120.9763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93442', 'place_name': 'Morro Bay', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.3795, 'longitude': -120.8447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93443', 'place_name': 'Morro Bay', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.3658, 'longitude': -120.8499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93444', 'place_name': 'Nipomo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.0298, 'longitude': -120.4894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93445', 'place_name': 'Oceano', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.1019, 'longitude': -120.608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93446', 'place_name': 'Paso Robles', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.6406, 'longitude': -120.7003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93447', 'place_name': 'Paso Robles', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.7562, 'longitude': -120.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93448', 'place_name': 'Pismo Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.1428, 'longitude': -120.6413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93449', 'place_name': 'Pismo Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.1578, 'longitude': -120.6522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93451', 'place_name': 'San Miguel', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.9004, 'longitude': -120.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93452', 'place_name': 'San Simeon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.6668, 'longitude': -121.144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93453', 'place_name': 'Santa Margarita', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.3584, 'longitude': -120.2596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93461', 'place_name': 'Shandon', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.6513, 'longitude': -120.372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93465', 'place_name': 'Templeton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.5551, 'longitude': -120.7107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93475', 'place_name': 'Oceano', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.1004, 'longitude': -120.6111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93483', 'place_name': 'Grover Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Luis Obispo', 'locality_code': '79', 'latitude': 35.1216, 'longitude': -120.6213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94002', 'place_name': 'Belmont', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5174, 'longitude': -122.2927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94005', 'place_name': 'Brisbane', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6811, 'longitude': -122.4001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94010', 'place_name': 'Burlingame', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5671, 'longitude': -122.3676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94011', 'place_name': 'Burlingame', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5841, 'longitude': -122.3661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94014', 'place_name': 'Daly City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6875, 'longitude': -122.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94015', 'place_name': 'Daly City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6787, 'longitude': -122.478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94016', 'place_name': 'Daly City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.7058, 'longitude': -122.4619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94017', 'place_name': 'Daly City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.7058, 'longitude': -122.4619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94018', 'place_name': 'El Granada', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5101, 'longitude': -122.4734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94019', 'place_name': 'Half Moon Bay', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4791, 'longitude': -122.4459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94020', 'place_name': 'La Honda', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.2726, 'longitude': -122.2495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94021', 'place_name': 'Loma Mar', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.2708, 'longitude': -122.2807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94025', 'place_name': 'Menlo Park', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4396, 'longitude': -122.1864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94026', 'place_name': 'Menlo Park', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.3811, 'longitude': -122.3348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94027', 'place_name': 'Atherton', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4563, 'longitude': -122.2002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94028', 'place_name': 'Portola Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.3702, 'longitude': -122.2182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94030', 'place_name': 'Millbrae', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6004, 'longitude': -122.402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94037', 'place_name': 'Montara', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5428, 'longitude': -122.5052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94038', 'place_name': 'Moss Beach', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.531, 'longitude': -122.5068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94044', 'place_name': 'Pacifica', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6196, 'longitude': -122.4816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94060', 'place_name': 'Pescadero', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.2065, 'longitude': -122.3649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94061', 'place_name': 'Redwood City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4647, 'longitude': -122.2304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94062', 'place_name': 'Redwood City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4245, 'longitude': -122.296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94063', 'place_name': 'Redwood City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4815, 'longitude': -122.2091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94064', 'place_name': 'Redwood City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.3811, 'longitude': -122.3348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94065', 'place_name': 'Redwood City', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5331, 'longitude': -122.2486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94066', 'place_name': 'San Bruno', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6247, 'longitude': -122.429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94070', 'place_name': 'San Carlos', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4969, 'longitude': -122.2674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94074', 'place_name': 'San Gregorio', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.3255, 'longitude': -122.3556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94080', 'place_name': 'South San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6574, 'longitude': -122.4235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94083', 'place_name': 'South San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6547, 'longitude': -122.4077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94128', 'place_name': 'San Francisco', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.6216, 'longitude': -122.3929, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '94303', 'place_name': 'Palo Alto', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.4673, 'longitude': -122.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94401', 'place_name': 'San Mateo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5735, 'longitude': -122.3225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94402', 'place_name': 'San Mateo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5507, 'longitude': -122.3276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94403', 'place_name': 'San Mateo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5395, 'longitude': -122.2998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94404', 'place_name': 'San Mateo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5538, 'longitude': -122.27, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94497', 'place_name': 'San Mateo', 'state': 'California', 'state_ab': 'CA', 'county': 'San Mateo', 'locality_code': '81', 'latitude': 37.5347, 'longitude': -122.3259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93013', 'place_name': 'Carpinteria', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4036, 'longitude': -119.5183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93014', 'place_name': 'Carpinteria', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.3989, 'longitude': -119.5185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93067', 'place_name': 'Summerland', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4214, 'longitude': -119.5965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93101', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4197, 'longitude': -119.7078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93102', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93103', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4291, 'longitude': -119.6833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93105', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4369, 'longitude': -119.7285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93106', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4329, 'longitude': -119.8371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93107', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4218, 'longitude': -119.8637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93108', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4378, 'longitude': -119.6159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93109', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4038, 'longitude': -119.7194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93110', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4418, 'longitude': -119.7647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93111', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4453, 'longitude': -119.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93116', 'place_name': 'Goleta', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4358, 'longitude': -119.8276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93117', 'place_name': 'Goleta', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4296, 'longitude': -119.8612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93118', 'place_name': 'Goleta', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4358, 'longitude': -119.8276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93120', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93121', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93130', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93140', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93150', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93160', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93190', 'place_name': 'Santa Barbara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.4208, 'longitude': -119.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93199', 'place_name': 'Goleta', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.2628, 'longitude': -119.8486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93254', 'place_name': 'New Cuyama', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.9967, 'longitude': -119.8238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93427', 'place_name': 'Buellton', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.6209, 'longitude': -120.1922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93429', 'place_name': 'Casmalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.8458, 'longitude': -120.535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93434', 'place_name': 'Guadalupe', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.96, 'longitude': -120.5703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93436', 'place_name': 'Lompoc', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.6583, 'longitude': -120.4506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93437', 'place_name': 'Lompoc', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.7532, 'longitude': -120.5171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93438', 'place_name': 'Lompoc', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.6392, 'longitude': -120.4579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93440', 'place_name': 'Los Alamos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.7457, 'longitude': -120.2049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93441', 'place_name': 'Los Olivos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.6678, 'longitude': -120.1149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93454', 'place_name': 'Santa Maria', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.9545, 'longitude': -120.4325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93455', 'place_name': 'Santa Maria', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.8286, 'longitude': -120.4268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93456', 'place_name': 'Santa Maria', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.953, 'longitude': -120.4357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93457', 'place_name': 'Santa Maria', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.953, 'longitude': -120.4357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93458', 'place_name': 'Santa Maria', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.9535, 'longitude': -120.4957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93460', 'place_name': 'Santa Ynez', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.624, 'longitude': -120.0713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93463', 'place_name': 'Solvang', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.6488, 'longitude': -120.1701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93464', 'place_name': 'Solvang', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Barbara', 'locality_code': '83', 'latitude': 34.6744, 'longitude': -120.1115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94022', 'place_name': 'Los Altos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3814, 'longitude': -122.1258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94023', 'place_name': 'Los Altos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3852, 'longitude': -122.1141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94024', 'place_name': 'Los Altos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3547, 'longitude': -122.0862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94035', 'place_name': 'Mountain View', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3861, 'longitude': -122.0839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94039', 'place_name': 'Mountain View', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3861, 'longitude': -122.0839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94040', 'place_name': 'Mountain View', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3855, 'longitude': -122.088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94041', 'place_name': 'Mountain View', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3893, 'longitude': -122.0783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94042', 'place_name': 'Mountain View', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3861, 'longitude': -122.0839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94043', 'place_name': 'Mountain View', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4056, 'longitude': -122.0775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94085', 'place_name': 'Sunnyvale', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3886, 'longitude': -122.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94086', 'place_name': 'Sunnyvale', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3764, 'longitude': -122.0238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94087', 'place_name': 'Sunnyvale', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3502, 'longitude': -122.0349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94088', 'place_name': 'Sunnyvale', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3688, 'longitude': -122.0363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94089', 'place_name': 'Sunnyvale', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3983, 'longitude': -122.0006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94301', 'place_name': 'Palo Alto', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4443, 'longitude': -122.1497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94302', 'place_name': 'Palo Alto', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4419, 'longitude': -122.143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94304', 'place_name': 'Palo Alto', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4334, 'longitude': -122.1842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94305', 'place_name': 'Stanford', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4236, 'longitude': -122.1619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94306', 'place_name': 'Palo Alto', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.418, 'longitude': -122.1274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94309', 'place_name': 'Palo Alto', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4419, 'longitude': -122.143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95002', 'place_name': 'Alviso', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.426, 'longitude': -121.9736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95008', 'place_name': 'Campbell', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2803, 'longitude': -121.9539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95009', 'place_name': 'Campbell', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2872, 'longitude': -121.9488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95011', 'place_name': 'Campbell', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.294, 'longitude': -121.9571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95013', 'place_name': 'Coyote', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2123, 'longitude': -121.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95014', 'place_name': 'Cupertino', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.318, 'longitude': -122.0449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95015', 'place_name': 'Cupertino', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.323, 'longitude': -122.0527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95020', 'place_name': 'Gilroy', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.0139, 'longitude': -121.5773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95021', 'place_name': 'Gilroy', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.0095, 'longitude': -121.5705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95026', 'place_name': 'Holy City', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.1584, 'longitude': -121.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95030', 'place_name': 'Los Gatos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2296, 'longitude': -121.9834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95031', 'place_name': 'Los Gatos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.1574, 'longitude': -121.9676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95032', 'place_name': 'Los Gatos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2417, 'longitude': -121.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95033', 'place_name': 'Los Gatos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.1539, 'longitude': -121.9816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95035', 'place_name': 'Milpitas', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4352, 'longitude': -121.895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95036', 'place_name': 'Milpitas', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.424, 'longitude': -121.906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95037', 'place_name': 'Morgan Hill', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.1353, 'longitude': -121.6501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95038', 'place_name': 'Morgan Hill', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.1525, 'longitude': -121.6722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95042', 'place_name': 'New Almaden', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.1771, 'longitude': -121.8207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95044', 'place_name': 'Redwood Estates', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.1584, 'longitude': -121.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95046', 'place_name': 'San Martin', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.0911, 'longitude': -121.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95050', 'place_name': 'Santa Clara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3492, 'longitude': -121.953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95051', 'place_name': 'Santa Clara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3483, 'longitude': -121.9844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95052', 'place_name': 'Santa Clara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3522, 'longitude': -121.9583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95053', 'place_name': 'Santa Clara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3498, 'longitude': -121.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95054', 'place_name': 'Santa Clara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3924, 'longitude': -121.9623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95055', 'place_name': 'Santa Clara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3451, 'longitude': -121.9769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95056', 'place_name': 'Santa Clara', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3997, 'longitude': -121.9608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95070', 'place_name': 'Saratoga', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2713, 'longitude': -122.0227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95071', 'place_name': 'Saratoga', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2593, 'longitude': -122.0302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95101', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3894, 'longitude': -121.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95103', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3378, 'longitude': -121.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95106', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3378, 'longitude': -121.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95108', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3378, 'longitude': -121.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95109', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3378, 'longitude': -121.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95110', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3391, 'longitude': -121.9016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95111', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2827, 'longitude': -121.8265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95112', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3476, 'longitude': -121.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95113', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3329, 'longitude': -121.8916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95115', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3378, 'longitude': -121.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95116', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3518, 'longitude': -121.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95117', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3108, 'longitude': -121.9623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95118', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2568, 'longitude': -121.8896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95119', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2329, 'longitude': -121.7875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95120', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2144, 'longitude': -121.8574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95121', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3042, 'longitude': -121.8099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95122', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3293, 'longitude': -121.8339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95123', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2458, 'longitude': -121.8306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95124', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2563, 'longitude': -121.9229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95125', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.296, 'longitude': -121.8939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95126', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3249, 'longitude': -121.9153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95127', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3692, 'longitude': -121.8208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95128', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3163, 'longitude': -121.9356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95129', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3066, 'longitude': -122.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95130', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2886, 'longitude': -121.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95131', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3864, 'longitude': -121.88, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95132', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4031, 'longitude': -121.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95133', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3729, 'longitude': -121.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95134', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4087, 'longitude': -121.9406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95135', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2974, 'longitude': -121.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95136', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2685, 'longitude': -121.849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95138', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2602, 'longitude': -121.7709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95139', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2252, 'longitude': -121.7687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95140', 'place_name': 'Mount Hamilton', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3511, 'longitude': -121.6384, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95141', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3394, 'longitude': -121.895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95148', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3304, 'longitude': -121.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95150', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3866, 'longitude': -121.897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95151', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3198, 'longitude': -121.8262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95152', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.4022, 'longitude': -121.847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95153', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2488, 'longitude': -121.8459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95154', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2649, 'longitude': -121.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95155', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.31, 'longitude': -121.9011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95156', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3576, 'longitude': -121.8416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95157', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3008, 'longitude': -121.9777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95158', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2625, 'longitude': -121.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95159', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3179, 'longitude': -121.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95160', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2187, 'longitude': -121.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95161', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3894, 'longitude': -121.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95164', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3916, 'longitude': -121.9203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95170', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3103, 'longitude': -122.0093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95172', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.334, 'longitude': -121.8847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95173', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3352, 'longitude': -121.8938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95190', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3894, 'longitude': -121.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95191', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3262, 'longitude': -121.9158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95192', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3383, 'longitude': -121.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95193', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.2441, 'longitude': -121.8287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95194', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3894, 'longitude': -121.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95196', 'place_name': 'San Jose', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Clara', 'locality_code': '85', 'latitude': 37.3338, 'longitude': -121.8894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95001', 'place_name': 'Aptos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.979, 'longitude': -121.898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95003', 'place_name': 'Aptos', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9797, 'longitude': -121.8902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95005', 'place_name': 'Ben Lomond', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0882, 'longitude': -122.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95006', 'place_name': 'Boulder Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.1547, 'longitude': -122.1365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95007', 'place_name': 'Brookdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.1063, 'longitude': -122.105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95010', 'place_name': 'Capitola', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9767, 'longitude': -121.9555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95017', 'place_name': 'Davenport', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0423, 'longitude': -122.2137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95018', 'place_name': 'Felton', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0662, 'longitude': -122.0618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95019', 'place_name': 'Freedom', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9356, 'longitude': -121.7767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95041', 'place_name': 'Mount Hermon', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0511, 'longitude': -122.0575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95060', 'place_name': 'Santa Cruz', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0313, 'longitude': -122.1198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95061', 'place_name': 'Santa Cruz', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9741, 'longitude': -122.0308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95062', 'place_name': 'Santa Cruz', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9721, 'longitude': -121.9881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95063', 'place_name': 'Santa Cruz', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9792, 'longitude': -122.0088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95064', 'place_name': 'Santa Cruz', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9959, 'longitude': -122.0578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95065', 'place_name': 'Santa Cruz', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0089, 'longitude': -121.9849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95066', 'place_name': 'Scotts Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0597, 'longitude': -122.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95067', 'place_name': 'Scotts Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0511, 'longitude': -122.0136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95073', 'place_name': 'Soquel', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 37.0048, 'longitude': -121.9507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95076', 'place_name': 'Watsonville', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9102, 'longitude': -121.7569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95077', 'place_name': 'Watsonville', 'state': 'California', 'state_ab': 'CA', 'county': 'Santa Cruz', 'locality_code': '87', 'latitude': 36.9116, 'longitude': -121.7575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96001', 'place_name': 'Redding', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.5605, 'longitude': -122.4116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96002', 'place_name': 'Redding', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.5486, 'longitude': -122.3339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96003', 'place_name': 'Redding', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6278, 'longitude': -122.353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96007', 'place_name': 'Anderson', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.4574, 'longitude': -122.3282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96008', 'place_name': 'Bella Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.7409, 'longitude': -122.0725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96011', 'place_name': 'Big Bend', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.9749, 'longitude': -121.825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96013', 'place_name': 'Burney', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.8949, 'longitude': -121.655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96016', 'place_name': 'Cassel', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.9337, 'longitude': -121.5677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96017', 'place_name': 'Castella', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 41.1103, 'longitude': -122.3161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96019', 'place_name': 'Shasta Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6969, 'longitude': -122.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96022', 'place_name': 'Cottonwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.3691, 'longitude': -122.3375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96028', 'place_name': 'Fall River Mills', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 41.0393, 'longitude': -121.4606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96033', 'place_name': 'French Gulch', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.7035, 'longitude': -122.6229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96040', 'place_name': 'Hat Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.7677, 'longitude': -121.4637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96047', 'place_name': 'Igo', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.4318, 'longitude': -122.654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96049', 'place_name': 'Redding', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.7098, 'longitude': -122.3116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96051', 'place_name': 'Lakehead', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.9105, 'longitude': -122.4106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96056', 'place_name': 'Mcarthur', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 41.0502, 'longitude': -121.3991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96062', 'place_name': 'Millville', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.5653, 'longitude': -122.1111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96065', 'place_name': 'Montgomery Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.9124, 'longitude': -121.9233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96069', 'place_name': 'Oak Run', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6863, 'longitude': -122.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96070', 'place_name': 'Obrien', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.7352, 'longitude': -122.1944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96071', 'place_name': 'Old Station', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6256, 'longitude': -121.4585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96073', 'place_name': 'Palo Cedro', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.5767, 'longitude': -122.2398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96076', 'place_name': 'Platina', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.376, 'longitude': -122.937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96079', 'place_name': 'Shasta Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6866, 'longitude': -122.3348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96084', 'place_name': 'Round Mountain', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.794, 'longitude': -121.9419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96087', 'place_name': 'Shasta', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6109, 'longitude': -122.4968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96088', 'place_name': 'Shingletown', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.505, 'longitude': -121.8857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96089', 'place_name': 'Shasta Lake', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6579, 'longitude': -122.4273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96095', 'place_name': 'Whiskeytown', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6388, 'longitude': -122.5597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96096', 'place_name': 'Whitmore', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.6525, 'longitude': -121.8771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96099', 'place_name': 'Redding', 'state': 'California', 'state_ab': 'CA', 'county': 'Shasta', 'locality_code': '89', 'latitude': 40.7043, 'longitude': -122.3878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95910', 'place_name': 'Alleghany', 'state': 'California', 'state_ab': 'CA', 'county': 'Sierra', 'locality_code': '91', 'latitude': 39.4826, 'longitude': -120.8483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95936', 'place_name': 'Downieville', 'state': 'California', 'state_ab': 'CA', 'county': 'Sierra', 'locality_code': '91', 'latitude': 39.569, 'longitude': -120.8344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95944', 'place_name': 'Goodyears Bar', 'state': 'California', 'state_ab': 'CA', 'county': 'Sierra', 'locality_code': '91', 'latitude': 39.5399, 'longitude': -120.8844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96118', 'place_name': 'Loyalton', 'state': 'California', 'state_ab': 'CA', 'county': 'Sierra', 'locality_code': '91', 'latitude': 39.663, 'longitude': -120.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96124', 'place_name': 'Calpine', 'state': 'California', 'state_ab': 'CA', 'county': 'Sierra', 'locality_code': '91', 'latitude': 39.6139, 'longitude': -120.4046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96125', 'place_name': 'Sierra City', 'state': 'California', 'state_ab': 'CA', 'county': 'Sierra', 'locality_code': '91', 'latitude': 39.5936, 'longitude': -120.6269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96126', 'place_name': 'Sierraville', 'state': 'California', 'state_ab': 'CA', 'county': 'Sierra', 'locality_code': '91', 'latitude': 39.5825, 'longitude': -120.3711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95568', 'place_name': 'Somes Bar', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.4533, 'longitude': -123.4634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96014', 'place_name': 'Callahan', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.3833, 'longitude': -122.764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96023', 'place_name': 'Dorris', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.9194, 'longitude': -121.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96025', 'place_name': 'Dunsmuir', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.2124, 'longitude': -122.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96027', 'place_name': 'Etna', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.4463, 'longitude': -123.01, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96031', 'place_name': 'Forks Of Salmon', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.2191, 'longitude': -123.2363, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96032', 'place_name': 'Fort Jones', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.617, 'longitude': -122.8832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96034', 'place_name': 'Gazelle', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.5105, 'longitude': -122.5371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96037', 'place_name': 'Greenview', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.5403, 'longitude': -122.9366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96038', 'place_name': 'Grenada', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.6125, 'longitude': -122.5258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96039', 'place_name': 'Happy Camp', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.8018, 'longitude': -123.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96044', 'place_name': 'Hornbrook', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.9077, 'longitude': -122.5265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96050', 'place_name': 'Klamath River', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.8637, 'longitude': -122.8197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96057', 'place_name': 'Mccloud', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.2475, 'longitude': -122.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96058', 'place_name': 'Macdoel', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.883, 'longitude': -121.9445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96064', 'place_name': 'Montague', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.7243, 'longitude': -122.4638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96067', 'place_name': 'Mount Shasta', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.3174, 'longitude': -122.324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96085', 'place_name': 'Scott Bar', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.7736, 'longitude': -122.9882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96086', 'place_name': 'Seiad Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.8866, 'longitude': -123.2438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96094', 'place_name': 'Weed', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.4226, 'longitude': -122.3861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96097', 'place_name': 'Yreka', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.7206, 'longitude': -122.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96134', 'place_name': 'Tulelake', 'state': 'California', 'state_ab': 'CA', 'county': 'Siskiyou', 'locality_code': '93', 'latitude': 41.9316, 'longitude': -121.4347, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '94510', 'place_name': 'Benicia', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.0685, 'longitude': -122.1614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94512', 'place_name': 'Birds Landing', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.1504, 'longitude': -121.8443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94533', 'place_name': 'Fairfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.2671, 'longitude': -122.0357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94534', 'place_name': 'Fairfield', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.2423, 'longitude': -122.1314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94535', 'place_name': 'Travis Afb', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.2743, 'longitude': -121.9463, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '94571', 'place_name': 'Rio Vista', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.1637, 'longitude': -121.7016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94585', 'place_name': 'Suisun City', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.2408, 'longitude': -122.042, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '94589', 'place_name': 'Vallejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.1582, 'longitude': -122.2804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94590', 'place_name': 'Vallejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.1053, 'longitude': -122.2474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94591', 'place_name': 'Vallejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.0985, 'longitude': -122.2124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94592', 'place_name': 'Vallejo', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.0968, 'longitude': -122.2699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95620', 'place_name': 'Dixon', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.4403, 'longitude': -121.8088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95625', 'place_name': 'Elmira', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.3482, 'longitude': -121.91, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95687', 'place_name': 'Vacaville', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.3482, 'longitude': -121.9538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95688', 'place_name': 'Vacaville', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.3847, 'longitude': -121.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95696', 'place_name': 'Vacaville', 'state': 'California', 'state_ab': 'CA', 'county': 'Solano', 'locality_code': '95', 'latitude': 38.43, 'longitude': -122.0168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94922', 'place_name': 'Bodega', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3514, 'longitude': -122.9741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94923', 'place_name': 'Bodega Bay', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3309, 'longitude': -123.0373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94926', 'place_name': 'Rohnert Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3396, 'longitude': -122.7011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94927', 'place_name': 'Rohnert Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3396, 'longitude': -122.7011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94928', 'place_name': 'Rohnert Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.347, 'longitude': -122.6941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94931', 'place_name': 'Cotati', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3259, 'longitude': -122.7048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94951', 'place_name': 'Penngrove', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3153, 'longitude': -122.6483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94952', 'place_name': 'Petaluma', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2403, 'longitude': -122.6777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94953', 'place_name': 'Petaluma', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2324, 'longitude': -122.6367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94954', 'place_name': 'Petaluma', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2507, 'longitude': -122.6155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94955', 'place_name': 'Petaluma', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2324, 'longitude': -122.6367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94972', 'place_name': 'Valley Ford', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.318, 'longitude': -122.9242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94975', 'place_name': 'Petaluma', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2324, 'longitude': -122.6367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '94999', 'place_name': 'Petaluma', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2675, 'longitude': -122.6581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95401', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4432, 'longitude': -122.7547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95402', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4399, 'longitude': -122.7096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95403', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4822, 'longitude': -122.7473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95404', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4405, 'longitude': -122.7144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95405', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4386, 'longitude': -122.6727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95406', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4399, 'longitude': -122.7096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95407', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4089, 'longitude': -122.7339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95409', 'place_name': 'Santa Rosa', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4592, 'longitude': -122.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95412', 'place_name': 'Annapolis', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.7026, 'longitude': -123.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95416', 'place_name': 'Boyes Hot Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3141, 'longitude': -122.4843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95419', 'place_name': 'Camp Meeker', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.425, 'longitude': -122.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95421', 'place_name': 'Cazadero', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.5918, 'longitude': -123.1965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95425', 'place_name': 'Cloverdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.7931, 'longitude': -123.0074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95430', 'place_name': 'Duncans Mills', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4538, 'longitude': -123.055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95431', 'place_name': 'Eldridge', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3488, 'longitude': -122.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95433', 'place_name': 'El Verano', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2993, 'longitude': -122.4867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95436', 'place_name': 'Forestville', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4923, 'longitude': -122.9042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95439', 'place_name': 'Fulton', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4947, 'longitude': -122.7761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95441', 'place_name': 'Geyserville', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.7173, 'longitude': -122.8834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95442', 'place_name': 'Glen Ellen', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3662, 'longitude': -122.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95444', 'place_name': 'Graton', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4335, 'longitude': -122.8676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95446', 'place_name': 'Guerneville', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.5055, 'longitude': -122.9965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95448', 'place_name': 'Healdsburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.6184, 'longitude': -122.862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95450', 'place_name': 'Jenner', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4987, 'longitude': -123.1974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95452', 'place_name': 'Kenwood', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4168, 'longitude': -122.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95462', 'place_name': 'Monte Rio', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4706, 'longitude': -123.0172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95465', 'place_name': 'Occidental', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4087, 'longitude': -122.9954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95471', 'place_name': 'Rio Nido', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.521, 'longitude': -122.9769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95472', 'place_name': 'Sebastopol', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.3941, 'longitude': -122.8433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95473', 'place_name': 'Sebastopol', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4022, 'longitude': -122.8227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95476', 'place_name': 'Sonoma', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2849, 'longitude': -122.4696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95480', 'place_name': 'Stewarts Point', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.7082, 'longitude': -123.3478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95486', 'place_name': 'Villa Grande', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.4741, 'longitude': -123.0242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95487', 'place_name': 'Vineburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.2725, 'longitude': -122.4375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95492', 'place_name': 'Windsor', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.5443, 'longitude': -122.8073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95497', 'place_name': 'The Sea Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Sonoma', 'locality_code': '97', 'latitude': 38.7256, 'longitude': -123.4675, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95307', 'place_name': 'Ceres', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.5833, 'longitude': -120.9496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95313', 'place_name': 'Crows Landing', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.4218, 'longitude': -121.0411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95316', 'place_name': 'Denair', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.539, 'longitude': -120.7758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95319', 'place_name': 'Empire', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6382, 'longitude': -120.9005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95323', 'place_name': 'Hickman', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6156, 'longitude': -120.7011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95326', 'place_name': 'Hughson', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.5964, 'longitude': -120.8627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95328', 'place_name': 'Keyes', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.5591, 'longitude': -120.9148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95329', 'place_name': 'La Grange', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6899, 'longitude': -120.3851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95350', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6746, 'longitude': -121.0113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95351', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6236, 'longitude': -120.9966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95352', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6566, 'longitude': -121.0191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95353', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6424, 'longitude': -120.9999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95354', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6409, 'longitude': -120.9749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95355', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6717, 'longitude': -120.9482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95356', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.7005, 'longitude': -121.0252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95357', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6693, 'longitude': -120.8817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95358', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6237, 'longitude': -121.0438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95360', 'place_name': 'Newman', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.3097, 'longitude': -121.0805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95361', 'place_name': 'Oakdale', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.7741, 'longitude': -120.8377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95363', 'place_name': 'Patterson', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.4826, 'longitude': -121.1648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95367', 'place_name': 'Riverbank', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.7298, 'longitude': -120.942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95368', 'place_name': 'Salida', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.7083, 'longitude': -121.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95380', 'place_name': 'Turlock', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.4888, 'longitude': -120.8535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95381', 'place_name': 'Turlock', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.4994, 'longitude': -120.8428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95382', 'place_name': 'Turlock', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.5239, 'longitude': -120.8517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95386', 'place_name': 'Waterford', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.652, 'longitude': -120.7292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95387', 'place_name': 'Westley', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.5452, 'longitude': -121.2255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95397', 'place_name': 'Modesto', 'state': 'California', 'state_ab': 'CA', 'county': 'Stanislaus', 'locality_code': '99', 'latitude': 37.6566, 'longitude': -121.0191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95659', 'place_name': 'Nicolaus', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 38.8657, 'longitude': -121.557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95668', 'place_name': 'Pleasant Grove', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 38.8115, 'longitude': -121.4982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95674', 'place_name': 'Rio Oso', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 38.967, 'longitude': -121.4773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95676', 'place_name': 'Robbins', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 38.8702, 'longitude': -121.7052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95953', 'place_name': 'Live Oak', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 39.2601, 'longitude': -121.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95957', 'place_name': 'Meridian', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 39.052, 'longitude': -121.8061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95982', 'place_name': 'Sutter', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 39.1779, 'longitude': -121.7758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95991', 'place_name': 'Yuba City', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 39.1051, 'longitude': -121.6202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95992', 'place_name': 'Yuba City', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 39.023, 'longitude': -121.6116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95993', 'place_name': 'Yuba City', 'state': 'California', 'state_ab': 'CA', 'county': 'Sutter', 'locality_code': '101', 'latitude': 39.1237, 'longitude': -121.6611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96021', 'place_name': 'Corning', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 39.9296, 'longitude': -122.196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96029', 'place_name': 'Flournoy', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 39.9024, 'longitude': -122.4918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96035', 'place_name': 'Gerber', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.043, 'longitude': -122.1649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96055', 'place_name': 'Los Molinos', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.0497, 'longitude': -122.0992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96059', 'place_name': 'Manton', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.4331, 'longitude': -121.8365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96061', 'place_name': 'Mill Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.3263, 'longitude': -121.5228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96063', 'place_name': 'Mineral', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.3564, 'longitude': -121.571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96074', 'place_name': 'Paskenta', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 39.8772, 'longitude': -122.5814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96075', 'place_name': 'Paynes Creek', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.3514, 'longitude': -121.765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96078', 'place_name': 'Proberta', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.0815, 'longitude': -122.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96080', 'place_name': 'Red Bluff', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.1795, 'longitude': -122.2383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96090', 'place_name': 'Tehama', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 40.0271, 'longitude': -122.1233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96092', 'place_name': 'Vina', 'state': 'California', 'state_ab': 'CA', 'county': 'Tehama', 'locality_code': '103', 'latitude': 39.9272, 'longitude': -122.025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95527', 'place_name': 'Burnt Ranch', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.7897, 'longitude': -123.4113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95552', 'place_name': 'Mad River', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.3316, 'longitude': -123.3904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95563', 'place_name': 'Salyer', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.8558, 'longitude': -123.573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95595', 'place_name': 'Zenia', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.2147, 'longitude': -123.3911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96010', 'place_name': 'Big Bar', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.748, 'longitude': -123.229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96024', 'place_name': 'Douglas City', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.6342, 'longitude': -122.9239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96041', 'place_name': 'Hayfork', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.5504, 'longitude': -123.1634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96046', 'place_name': 'Hyampom', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.6137, 'longitude': -123.4488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96048', 'place_name': 'Junction City', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.7411, 'longitude': -123.0718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96052', 'place_name': 'Lewiston', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.746, 'longitude': -122.8426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96091', 'place_name': 'Trinity Center', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 41.0615, 'longitude': -122.7239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96093', 'place_name': 'Weaverville', 'state': 'California', 'state_ab': 'CA', 'county': 'Trinity', 'locality_code': '105', 'latitude': 40.7317, 'longitude': -122.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93201', 'place_name': 'Alpaugh', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.8877, 'longitude': -119.4873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93207', 'place_name': 'California Hot Springs', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.8818, 'longitude': -118.6561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93208', 'place_name': 'Camp Nelson', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.1427, 'longitude': -118.6093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93218', 'place_name': 'Ducor', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.8916, 'longitude': -119.0473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93219', 'place_name': 'Earlimart', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.8744, 'longitude': -119.281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93221', 'place_name': 'Exeter', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3041, 'longitude': -119.1293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93223', 'place_name': 'Farmersville', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3002, 'longitude': -119.2054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93227', 'place_name': 'Goshen', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3572, 'longitude': -119.4254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93235', 'place_name': 'Ivanhoe', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3856, 'longitude': -119.2189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93237', 'place_name': 'Kaweah', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.4727, 'longitude': -118.9029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93244', 'place_name': 'Lemon Cove', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.4969, 'longitude': -118.9941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93247', 'place_name': 'Lindsay', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.2096, 'longitude': -119.0884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93256', 'place_name': 'Pixley', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.9553, 'longitude': -119.2564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93257', 'place_name': 'Porterville', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.0686, 'longitude': -119.0315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93258', 'place_name': 'Porterville', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.0331, 'longitude': -119.0073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93260', 'place_name': 'Posey', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.8135, 'longitude': -118.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93261', 'place_name': 'Richgrove', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.805, 'longitude': -119.1315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93262', 'place_name': 'Sequoia National Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.6007, 'longitude': -118.711, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93265', 'place_name': 'Springville', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.1363, 'longitude': -118.7961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93267', 'place_name': 'Strathmore', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.1472, 'longitude': -119.0792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93270', 'place_name': 'Terra Bella', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 35.957, 'longitude': -119.0312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93271', 'place_name': 'Three Rivers', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.4377, 'longitude': -118.8875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93272', 'place_name': 'Tipton', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.0546, 'longitude': -119.3078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93274', 'place_name': 'Tulare', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.2022, 'longitude': -119.338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93275', 'place_name': 'Tulare', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.2077, 'longitude': -119.3473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93277', 'place_name': 'Visalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3114, 'longitude': -119.3065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93278', 'place_name': 'Visalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3302, 'longitude': -119.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93279', 'place_name': 'Visalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3302, 'longitude': -119.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93282', 'place_name': 'Waukena', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.1296, 'longitude': -119.5161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93286', 'place_name': 'Woodlake', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.4313, 'longitude': -119.0918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93290', 'place_name': 'Visalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3291, 'longitude': -119.2925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93291', 'place_name': 'Visalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3551, 'longitude': -119.301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93292', 'place_name': 'Visalia', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.3302, 'longitude': -119.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93603', 'place_name': 'Badger', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.6313, 'longitude': -119.0132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93615', 'place_name': 'Cutler', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.5243, 'longitude': -119.287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93618', 'place_name': 'Dinuba', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.5349, 'longitude': -119.3909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93619', 'place_name': 'Clovis', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.8432, 'longitude': -119.6518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93633', 'place_name': 'Kings Canyon National Pk', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.7341, 'longitude': -118.9588, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93647', 'place_name': 'Orosi', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.5464, 'longitude': -119.2815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93666', 'place_name': 'Sultana', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.5455, 'longitude': -119.3401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93670', 'place_name': 'Yettem', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.4718, 'longitude': -119.2594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93673', 'place_name': 'Traver', 'state': 'California', 'state_ab': 'CA', 'county': 'Tulare', 'locality_code': '107', 'latitude': 36.4552, 'longitude': -119.4848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95305', 'place_name': 'Big Oak Flat', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.8235, 'longitude': -120.2582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95309', 'place_name': 'Chinese Camp', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.8594, 'longitude': -120.4069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95310', 'place_name': 'Columbia', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 38.044, 'longitude': -120.3971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95321', 'place_name': 'Groveland', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.8298, 'longitude': -120.1037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95327', 'place_name': 'Jamestown', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.8906, 'longitude': -120.4717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95335', 'place_name': 'Long Barn', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 38.093, 'longitude': -120.1344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95346', 'place_name': 'Mi Wuk Village', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 38.0675, 'longitude': -120.1794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95347', 'place_name': 'Moccasin', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.8108, 'longitude': -120.2988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95364', 'place_name': 'Pinecrest', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 38.1889, 'longitude': -119.9924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95370', 'place_name': 'Sonora', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.9957, 'longitude': -120.3368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95372', 'place_name': 'Soulsbyville', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.9926, 'longitude': -120.2624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95373', 'place_name': 'Standard', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.9666, 'longitude': -120.3108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95375', 'place_name': 'Strawberry', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 38.2042, 'longitude': -120.0101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95379', 'place_name': 'Tuolumne', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 37.9678, 'longitude': -120.2357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95383', 'place_name': 'Twain Harte', 'state': 'California', 'state_ab': 'CA', 'county': 'Tuolumne', 'locality_code': '109', 'latitude': 38.0454, 'longitude': -120.2178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91319', 'place_name': 'Newbury Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1842, 'longitude': -118.9107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91320', 'place_name': 'Newbury Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1774, 'longitude': -118.9358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91358', 'place_name': 'Thousand Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1706, 'longitude': -118.8376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91359', 'place_name': 'Westlake Village', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1458, 'longitude': -118.8056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91360', 'place_name': 'Thousand Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2092, 'longitude': -118.8739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91361', 'place_name': 'Westlake Village', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1472, 'longitude': -118.8383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91362', 'place_name': 'Thousand Oaks', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1948, 'longitude': -118.8232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '91377', 'place_name': 'Oak Park', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.185, 'longitude': -118.7669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93001', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.3308, 'longitude': -119.3584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93002', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2783, 'longitude': -119.2932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93003', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2846, 'longitude': -119.2222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93004', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2788, 'longitude': -119.1651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93005', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2783, 'longitude': -119.2932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93006', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2783, 'longitude': -119.2932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93007', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2783, 'longitude': -119.2932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93009', 'place_name': 'Ventura', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.3562, 'longitude': -119.1462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93010', 'place_name': 'Camarillo', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2313, 'longitude': -119.0464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93011', 'place_name': 'Camarillo', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2164, 'longitude': -119.0376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93012', 'place_name': 'Camarillo', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2218, 'longitude': -118.9866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93015', 'place_name': 'Fillmore', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.3992, 'longitude': -118.9182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93016', 'place_name': 'Fillmore', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.3992, 'longitude': -118.9182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93020', 'place_name': 'Moorpark', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2856, 'longitude': -118.882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93021', 'place_name': 'Moorpark', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2784, 'longitude': -118.8771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93022', 'place_name': 'Oak View', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.402, 'longitude': -119.2982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93023', 'place_name': 'Ojai', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.4451, 'longitude': -119.2565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93024', 'place_name': 'Ojai', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.448, 'longitude': -119.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93030', 'place_name': 'Oxnard', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2141, 'longitude': -119.175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93031', 'place_name': 'Oxnard', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.0324, 'longitude': -119.1343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93032', 'place_name': 'Oxnard', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1975, 'longitude': -119.1771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93033', 'place_name': 'Oxnard', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1685, 'longitude': -119.1717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93034', 'place_name': 'Oxnard', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.0324, 'longitude': -119.1343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93035', 'place_name': 'Oxnard', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1822, 'longitude': -119.216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93036', 'place_name': 'Oxnard', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2351, 'longitude': -119.182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93040', 'place_name': 'Piru', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.4352, 'longitude': -118.7855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93041', 'place_name': 'Port Hueneme', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1626, 'longitude': -119.1973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93042', 'place_name': 'Point Mugu Nawc', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1134, 'longitude': -119.1124, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93043', 'place_name': 'Port Hueneme Cbc Base', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1621, 'longitude': -119.2074, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93044', 'place_name': 'Port Hueneme', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.1478, 'longitude': -119.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93060', 'place_name': 'Santa Paula', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.3547, 'longitude': -119.0713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93061', 'place_name': 'Santa Paula', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.3542, 'longitude': -119.0593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93062', 'place_name': 'Simi Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2694, 'longitude': -118.7815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93063', 'place_name': 'Simi Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.3046, 'longitude': -118.6844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93064', 'place_name': 'Brandeis', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2582, 'longitude': -118.7107, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '93065', 'place_name': 'Simi Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2656, 'longitude': -118.7653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93066', 'place_name': 'Somis', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2798, 'longitude': -119.0115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93094', 'place_name': 'Simi Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2694, 'longitude': -118.7815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '93099', 'place_name': 'Simi Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Ventura', 'locality_code': '111', 'latitude': 34.2694, 'longitude': -118.7815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95605', 'place_name': 'West Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5927, 'longitude': -121.5325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95606', 'place_name': 'Brooks', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.8065, 'longitude': -122.2039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95607', 'place_name': 'Capay', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.7209, 'longitude': -122.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95612', 'place_name': 'Clarksburg', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.3945, 'longitude': -121.5641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95616', 'place_name': 'Davis', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5538, 'longitude': -121.7418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95617', 'place_name': 'Davis', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5494, 'longitude': -121.7253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95618', 'place_name': 'Davis', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5449, 'longitude': -121.7405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95627', 'place_name': 'Esparto', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.7061, 'longitude': -122.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95637', 'place_name': 'Guinda', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.8407, 'longitude': -122.2036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95645', 'place_name': 'Knights Landing', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.8517, 'longitude': -121.7334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95653', 'place_name': 'Madison', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.6802, 'longitude': -121.9721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95679', 'place_name': 'Rumsey', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.8953, 'longitude': -122.3079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95691', 'place_name': 'West Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5673, 'longitude': -121.5516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95694', 'place_name': 'Winters', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5322, 'longitude': -121.9676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95695', 'place_name': 'Woodland', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.6816, 'longitude': -121.8052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95697', 'place_name': 'Yolo', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.7343, 'longitude': -121.8066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95698', 'place_name': 'Zamora', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.8204, 'longitude': -121.9191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95776', 'place_name': 'Woodland', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.6808, 'longitude': -121.7411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95798', 'place_name': 'West Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5805, 'longitude': -121.5291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95799', 'place_name': 'West Sacramento', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.5713, 'longitude': -121.5715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95937', 'place_name': 'Dunnigan', 'state': 'California', 'state_ab': 'CA', 'county': 'Yolo', 'locality_code': '113', 'latitude': 38.887, 'longitude': -121.9992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95692', 'place_name': 'Wheatland', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.0337, 'longitude': -121.4235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95901', 'place_name': 'Marysville', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.1663, 'longitude': -121.5105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95903', 'place_name': 'Beale Afb', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.1115, 'longitude': -121.3604, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '95918', 'place_name': 'Browns Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.2882, 'longitude': -121.3303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95919', 'place_name': 'Brownsville', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.4525, 'longitude': -121.2612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95922', 'place_name': 'Camptonville', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.4518, 'longitude': -121.0486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95925', 'place_name': 'Challenge', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.4685, 'longitude': -121.1936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95935', 'place_name': 'Dobbins', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.3662, 'longitude': -121.2256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95961', 'place_name': 'Olivehurst', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.0861, 'longitude': -121.5497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95962', 'place_name': 'Oregon House', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.3459, 'longitude': -121.2663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95972', 'place_name': 'Rackerby', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.4256, 'longitude': -121.3252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '95981', 'place_name': 'Strawberry Valley', 'state': 'California', 'state_ab': 'CA', 'county': 'Yuba', 'locality_code': '115', 'latitude': 39.687, 'longitude': -121.045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80011', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7378, 'longitude': -104.8152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80019', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7656, 'longitude': -104.7069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80022', 'place_name': 'Commerce City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8259, 'longitude': -104.9113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80024', 'place_name': 'Dupont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8445, 'longitude': -104.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80030', 'place_name': 'Westminster', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8302, 'longitude': -105.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80031', 'place_name': 'Westminster', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8753, 'longitude': -105.0345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80035', 'place_name': 'Westminster', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8367, 'longitude': -105.0372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80036', 'place_name': 'Westminster', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8367, 'longitude': -105.0372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80037', 'place_name': 'Commerce City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8083, 'longitude': -104.9339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80040', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7294, 'longitude': -104.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80042', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7294, 'longitude': -104.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80045', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7467, 'longitude': -104.8384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80102', 'place_name': 'Bennett', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7589, 'longitude': -104.4275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80136', 'place_name': 'Strasburg', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7814, 'longitude': -104.2683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80137', 'place_name': 'Watkins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7623, 'longitude': -104.5834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80221', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.838, 'longitude': -104.9988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80229', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8671, 'longitude': -104.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80233', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9015, 'longitude': -104.9407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80234', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9108, 'longitude': -105.0109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80241', 'place_name': 'Thornton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.868, 'longitude': -104.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80260', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8672, 'longitude': -105.0041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80601', 'place_name': 'Brighton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.943, 'longitude': -104.7866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80602', 'place_name': 'Brighton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9636, 'longitude': -104.9072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80603', 'place_name': 'Brighton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9515, 'longitude': -104.7746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80614', 'place_name': 'Eastlake', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9239, 'longitude': -104.9614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80640', 'place_name': 'Henderson', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8983, 'longitude': -104.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81101', 'place_name': 'Alamosa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Alamosa', 'locality_code': '3', 'latitude': 37.4703, 'longitude': -105.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81102', 'place_name': 'Alamosa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Alamosa', 'locality_code': '3', 'latitude': 37.476, 'longitude': -105.8818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81136', 'place_name': 'Hooper', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Alamosa', 'locality_code': '3', 'latitude': 37.7232, 'longitude': -105.8712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81146', 'place_name': 'Mosca', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Alamosa', 'locality_code': '3', 'latitude': 37.6358, 'longitude': -105.8069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80010', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.7368, 'longitude': -104.8646, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80012', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6987, 'longitude': -104.8377, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80013', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6575, 'longitude': -104.7846, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80014', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6662, 'longitude': -104.835, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80015', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6255, 'longitude': -104.7874, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80016', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6012, 'longitude': -104.7394, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80017', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6948, 'longitude': -104.7881, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80018', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.7102, 'longitude': -104.7071, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80041', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.7388, 'longitude': -104.4083, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80044', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.7388, 'longitude': -104.4083, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80046', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.7388, 'longitude': -104.4083, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80047', 'place_name': 'Aurora', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.7388, 'longitude': -104.4083, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80103', 'place_name': 'Byers', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6985, 'longitude': -104.2019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80105', 'place_name': 'Deer Trail', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.5931, 'longitude': -104.068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80110', 'place_name': 'Englewood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6463, 'longitude': -105.0092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80111', 'place_name': 'Englewood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6123, 'longitude': -104.8799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80112', 'place_name': 'Englewood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.5805, 'longitude': -104.9011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80113', 'place_name': 'Englewood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6405, 'longitude': -104.9614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80120', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.5994, 'longitude': -105.0044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80121', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6111, 'longitude': -104.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80122', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.5814, 'longitude': -104.9557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80150', 'place_name': 'Englewood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6478, 'longitude': -104.9878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80151', 'place_name': 'Englewood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6478, 'longitude': -104.9878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80155', 'place_name': 'Englewood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6478, 'longitude': -104.9878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80160', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6133, 'longitude': -105.0166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80161', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6133, 'longitude': -105.0166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80165', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6133, 'longitude': -105.0166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80166', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Arapahoe', 'locality_code': '5', 'latitude': 39.6133, 'longitude': -105.0166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81121', 'place_name': 'Arboles', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Archuleta', 'locality_code': '7', 'latitude': 37.0281, 'longitude': -107.4192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81128', 'place_name': 'Chromo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Archuleta', 'locality_code': '7', 'latitude': 37.0364, 'longitude': -106.8434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81147', 'place_name': 'Pagosa Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Archuleta', 'locality_code': '7', 'latitude': 37.2523, 'longitude': -107.0385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81157', 'place_name': 'Pagosa Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Archuleta', 'locality_code': '7', 'latitude': 37.2694, 'longitude': -107.0098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81029', 'place_name': 'Campo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Baca', 'locality_code': '9', 'latitude': 37.1195, 'longitude': -102.5464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81064', 'place_name': 'Pritchett', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Baca', 'locality_code': '9', 'latitude': 37.2723, 'longitude': -102.9145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81073', 'place_name': 'Springfield', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Baca', 'locality_code': '9', 'latitude': 37.4067, 'longitude': -102.6173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81084', 'place_name': 'Two Buttes', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Baca', 'locality_code': '9', 'latitude': 37.5214, 'longitude': -102.4332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81087', 'place_name': 'Vilas', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Baca', 'locality_code': '9', 'latitude': 37.373, 'longitude': -102.4437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81090', 'place_name': 'Walsh', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Baca', 'locality_code': '9', 'latitude': 37.3521, 'longitude': -102.2537, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '81038', 'place_name': 'Fort Lyon', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Bent', 'locality_code': '11', 'latitude': 37.9555, 'longitude': -103.0725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81044', 'place_name': 'Hasty', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Bent', 'locality_code': '11', 'latitude': 37.959, 'longitude': -103.015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81054', 'place_name': 'Las Animas', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Bent', 'locality_code': '11', 'latitude': 37.923, 'longitude': -103.0884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81057', 'place_name': 'Mc Clave', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Bent', 'locality_code': '11', 'latitude': 38.085, 'longitude': -102.8869, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80020', 'place_name': 'Broomfield', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9245, 'longitude': -105.0609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80025', 'place_name': 'Eldorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9324, 'longitude': -105.288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80026', 'place_name': 'Lafayette', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.998, 'longitude': -105.0963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80027', 'place_name': 'Louisville', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9789, 'longitude': -105.1456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80038', 'place_name': 'Broomfield', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9205, 'longitude': -105.0867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80301', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.0497, 'longitude': -105.2143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80302', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.0172, 'longitude': -105.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80303', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9914, 'longitude': -105.2392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80304', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.0375, 'longitude': -105.2771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80305', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9807, 'longitude': -105.2531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80306', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.1022, 'longitude': -105.3847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80307', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.0878, 'longitude': -105.3735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80308', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.0277, 'longitude': -105.3868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80309', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.015, 'longitude': -105.2705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80310', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.015, 'longitude': -105.2705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80314', 'place_name': 'Boulder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.0878, 'longitude': -105.3735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80455', 'place_name': 'Jamestown', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.1155, 'longitude': -105.3886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80466', 'place_name': 'Nederland', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9703, 'longitude': -105.4813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80471', 'place_name': 'Pinecliffe', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 39.9319, 'longitude': -105.4283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80481', 'place_name': 'Ward', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.0726, 'longitude': -105.508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80501', 'place_name': 'Longmont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.1779, 'longitude': -105.1009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80502', 'place_name': 'Longmont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.1672, 'longitude': -105.1019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80503', 'place_name': 'Longmont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.1559, 'longitude': -105.1624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80510', 'place_name': 'Allenspark', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.2268, 'longitude': -105.5201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80533', 'place_name': 'Hygiene', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.1815, 'longitude': -105.2327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80540', 'place_name': 'Lyons', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.2357, 'longitude': -105.3231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80544', 'place_name': 'Niwot', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Boulder', 'locality_code': '13', 'latitude': 40.1039, 'longitude': -105.1708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80023', 'place_name': 'Broomfield', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Broomfield', 'locality_code': '14', 'latitude': 39.9619, 'longitude': -105.0148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81201', 'place_name': 'Salida', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Chaffee', 'locality_code': '15', 'latitude': 38.5259, 'longitude': -105.9978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81211', 'place_name': 'Buena Vista', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Chaffee', 'locality_code': '15', 'latitude': 38.838, 'longitude': -106.1471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81227', 'place_name': 'Monarch', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Chaffee', 'locality_code': '15', 'latitude': 38.553, 'longitude': -106.2946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81228', 'place_name': 'Granite', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Chaffee', 'locality_code': '15', 'latitude': 39.0307, 'longitude': -106.2566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81236', 'place_name': 'Nathrop', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Chaffee', 'locality_code': '15', 'latitude': 38.7103, 'longitude': -106.1166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81242', 'place_name': 'Poncha Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Chaffee', 'locality_code': '15', 'latitude': 38.5128, 'longitude': -106.0772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80802', 'place_name': 'Arapahoe', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Cheyenne', 'locality_code': '17', 'latitude': 38.8417, 'longitude': -102.194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80810', 'place_name': 'Cheyenne Wells', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Cheyenne', 'locality_code': '17', 'latitude': 38.8198, 'longitude': -102.3582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80825', 'place_name': 'Kit Carson', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Cheyenne', 'locality_code': '17', 'latitude': 38.804, 'longitude': -102.8198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80862', 'place_name': 'Wild Horse', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Cheyenne', 'locality_code': '17', 'latitude': 38.8041, 'longitude': -103.0798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80436', 'place_name': 'Dumont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Clear Creek', 'locality_code': '19', 'latitude': 39.7647, 'longitude': -105.6003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80438', 'place_name': 'Empire', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Clear Creek', 'locality_code': '19', 'latitude': 39.7614, 'longitude': -105.6844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80444', 'place_name': 'Georgetown', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Clear Creek', 'locality_code': '19', 'latitude': 39.7061, 'longitude': -105.6975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80452', 'place_name': 'Idaho Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Clear Creek', 'locality_code': '19', 'latitude': 39.7402, 'longitude': -105.5983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80476', 'place_name': 'Silver Plume', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Clear Creek', 'locality_code': '19', 'latitude': 39.6996, 'longitude': -105.7507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81120', 'place_name': 'Antonito', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Conejos', 'locality_code': '21', 'latitude': 37.0855, 'longitude': -106.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81124', 'place_name': 'Capulin', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Conejos', 'locality_code': '21', 'latitude': 37.2839, 'longitude': -106.1114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81129', 'place_name': 'Conejos', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Conejos', 'locality_code': '21', 'latitude': 37.1011, 'longitude': -106.0265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81140', 'place_name': 'La Jara', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Conejos', 'locality_code': '21', 'latitude': 37.2907, 'longitude': -106.0054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81141', 'place_name': 'Manassa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Conejos', 'locality_code': '21', 'latitude': 37.1755, 'longitude': -105.9278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81148', 'place_name': 'Romeo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Conejos', 'locality_code': '21', 'latitude': 37.1721, 'longitude': -105.9858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81151', 'place_name': 'Sanford', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Conejos', 'locality_code': '21', 'latitude': 37.2583, 'longitude': -105.9047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81123', 'place_name': 'Blanca', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Costilla', 'locality_code': '23', 'latitude': 37.4317, 'longitude': -105.5178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81126', 'place_name': 'Chama', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Costilla', 'locality_code': '23', 'latitude': 37.162, 'longitude': -105.3783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81133', 'place_name': 'Fort Garland', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Costilla', 'locality_code': '23', 'latitude': 37.427, 'longitude': -105.4049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81138', 'place_name': 'Jaroso', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Costilla', 'locality_code': '23', 'latitude': 37.0028, 'longitude': -105.6242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81152', 'place_name': 'San Luis', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Costilla', 'locality_code': '23', 'latitude': 37.1066, 'longitude': -105.4781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81033', 'place_name': 'Crowley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Crowley', 'locality_code': '25', 'latitude': 38.1931, 'longitude': -103.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81034', 'place_name': 'Crowley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Crowley', 'locality_code': '25', 'latitude': 38.1931, 'longitude': -103.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81062', 'place_name': 'Olney Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Crowley', 'locality_code': '25', 'latitude': 38.2019, 'longitude': -103.941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81063', 'place_name': 'Ordway', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Crowley', 'locality_code': '25', 'latitude': 38.2095, 'longitude': -103.8003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81076', 'place_name': 'Sugar City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Crowley', 'locality_code': '25', 'latitude': 38.2444, 'longitude': -103.6556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81252', 'place_name': 'Westcliffe', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Custer', 'locality_code': '27', 'latitude': 38.123, 'longitude': -105.4332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81253', 'place_name': 'Wetmore', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Custer', 'locality_code': '27', 'latitude': 38.1217, 'longitude': -105.1477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81410', 'place_name': 'Austin', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.7975, 'longitude': -107.9738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81413', 'place_name': 'Cedaredge', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.9119, 'longitude': -107.9268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81414', 'place_name': 'Cory', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.7887, 'longitude': -107.9862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81415', 'place_name': 'Crawford', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.6941, 'longitude': -107.6149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81416', 'place_name': 'Delta', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.7349, 'longitude': -108.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81418', 'place_name': 'Eckert', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.845, 'longitude': -107.9625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81419', 'place_name': 'Hotchkiss', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.8124, 'longitude': -107.7472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81420', 'place_name': 'Lazear', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.7817, 'longitude': -107.7808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81428', 'place_name': 'Paonia', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Delta', 'locality_code': '29', 'latitude': 38.865, 'longitude': -107.5985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80201', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7263, 'longitude': -104.8568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80202', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7491, 'longitude': -104.9946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80203', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7313, 'longitude': -104.9811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80204', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.734, 'longitude': -105.0259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80205', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.759, 'longitude': -104.9661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80206', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7331, 'longitude': -104.9524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80207', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7584, 'longitude': -104.9177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80208', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80209', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7074, 'longitude': -104.9686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80210', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.679, 'longitude': -104.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80211', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7665, 'longitude': -105.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80212', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7683, 'longitude': -105.0493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80216', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7835, 'longitude': -104.9669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80217', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80218', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7327, 'longitude': -104.9717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80219', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.6956, 'longitude': -105.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80220', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7312, 'longitude': -104.9129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80222', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.671, 'longitude': -104.9279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80223', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7002, 'longitude': -105.0028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80224', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.688, 'longitude': -104.9108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80227', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.6667, 'longitude': -105.0854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80230', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7218, 'longitude': -104.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80231', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.6793, 'longitude': -104.8843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80235', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.6472, 'longitude': -105.0795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80236', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.6535, 'longitude': -105.0376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80237', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.6431, 'longitude': -104.8987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80238', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80239', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7878, 'longitude': -104.8288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80243', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80244', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80246', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7086, 'longitude': -104.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80247', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.6971, 'longitude': -104.8819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80248', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80249', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7783, 'longitude': -104.7557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80250', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80251', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80252', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80256', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7474, 'longitude': -104.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80257', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80259', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7462, 'longitude': -104.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80261', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7379, 'longitude': -104.985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80262', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.731, 'longitude': -104.9384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80263', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80264', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7426, 'longitude': -104.9863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80265', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80266', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7472, 'longitude': -104.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80271', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80273', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7273, 'longitude': -104.9875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80274', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7439, 'longitude': -104.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80281', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7439, 'longitude': -104.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80290', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7436, 'longitude': -104.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80291', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7439, 'longitude': -104.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80293', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7458, 'longitude': -104.9907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80294', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7491, 'longitude': -104.989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80299', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Denver', 'locality_code': '31', 'latitude': 39.7392, 'longitude': -104.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81320', 'place_name': 'Cahone', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Dolores', 'locality_code': '33', 'latitude': 37.7182, 'longitude': -108.7917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81324', 'place_name': 'Dove Creek', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Dolores', 'locality_code': '33', 'latitude': 37.7632, 'longitude': -108.9181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81332', 'place_name': 'Rico', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Dolores', 'locality_code': '33', 'latitude': 37.6905, 'longitude': -108.0324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80104', 'place_name': 'Castle Rock', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.3722, 'longitude': -104.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80108', 'place_name': 'Castle Rock', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.4455, 'longitude': -104.853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80109', 'place_name': 'Castle Rock', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.3643, 'longitude': -104.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80116', 'place_name': 'Franktown', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.3728, 'longitude': -104.7256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80118', 'place_name': 'Larkspur', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.2011, 'longitude': -104.8546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80124', 'place_name': 'Lone Tree', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.5517, 'longitude': -104.8863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80125', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.4845, 'longitude': -105.0561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80126', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.5437, 'longitude': -104.9691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80129', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.5397, 'longitude': -105.0109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80130', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.5414, 'longitude': -104.9218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80131', 'place_name': 'Louviers', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.4764, 'longitude': -105.0075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80134', 'place_name': 'Parker', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.4895, 'longitude': -104.8447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80135', 'place_name': 'Sedalia', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.3113, 'longitude': -105.0676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80138', 'place_name': 'Parker', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.5102, 'longitude': -104.7216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80163', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Douglas', 'locality_code': '35', 'latitude': 39.3479, 'longitude': -104.9947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80423', 'place_name': 'Bond', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.8691, 'longitude': -106.6763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80426', 'place_name': 'Burns', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.8739, 'longitude': -106.8856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80463', 'place_name': 'Mc Coy', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.9134, 'longitude': -106.7309, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '81620', 'place_name': 'Avon', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.6313, 'longitude': -106.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81621', 'place_name': 'Basalt', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.3535, 'longitude': -106.9988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81631', 'place_name': 'Eagle', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.6341, 'longitude': -106.7588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81632', 'place_name': 'Edwards', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.6382, 'longitude': -106.6206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81637', 'place_name': 'Gypsum', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.6618, 'longitude': -106.9671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81645', 'place_name': 'Minturn', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.5805, 'longitude': -106.4176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81649', 'place_name': 'Red Cliff', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.5122, 'longitude': -106.3681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81655', 'place_name': 'Wolcott', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.7028, 'longitude': -106.6786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81657', 'place_name': 'Vail', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.6512, 'longitude': -106.3234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81658', 'place_name': 'Vail', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Eagle', 'locality_code': '37', 'latitude': 39.6242, 'longitude': -106.4973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80101', 'place_name': 'Agate', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Elbert', 'locality_code': '39', 'latitude': 39.4203, 'longitude': -103.9846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80106', 'place_name': 'Elbert', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Elbert', 'locality_code': '39', 'latitude': 39.0969, 'longitude': -104.5746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80107', 'place_name': 'Elizabeth', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Elbert', 'locality_code': '39', 'latitude': 39.3836, 'longitude': -104.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80117', 'place_name': 'Kiowa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Elbert', 'locality_code': '39', 'latitude': 39.324, 'longitude': -104.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80830', 'place_name': 'Matheson', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Elbert', 'locality_code': '39', 'latitude': 39.132, 'longitude': -103.9132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80835', 'place_name': 'Simla', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Elbert', 'locality_code': '39', 'latitude': 39.2087, 'longitude': -104.0702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80132', 'place_name': 'Monument', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 39.1007, 'longitude': -104.8542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80133', 'place_name': 'Palmer Lake', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 39.1205, 'longitude': -104.9148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80808', 'place_name': 'Calhan', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9648, 'longitude': -104.3553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80809', 'place_name': 'Cascade', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8967, 'longitude': -104.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80817', 'place_name': 'Fountain', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.6996, 'longitude': -104.7005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80819', 'place_name': 'Green Mountain Falls', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9389, 'longitude': -105.0094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80829', 'place_name': 'Manitou Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.855, 'longitude': -104.9058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80831', 'place_name': 'Peyton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9541, 'longitude': -104.5472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80832', 'place_name': 'Ramah', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 39.0736, 'longitude': -104.1247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80833', 'place_name': 'Rush', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.7642, 'longitude': -104.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80840', 'place_name': 'Usaf Academy', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 39.0896, 'longitude': -103.8188, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80841', 'place_name': 'Usaf Academy', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 39.0896, 'longitude': -103.8188, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80864', 'place_name': 'Yoder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.7753, 'longitude': -104.2184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80901', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80902', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.7536, 'longitude': -104.8063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80903', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8388, 'longitude': -104.8145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80904', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8533, 'longitude': -104.8595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80905', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8377, 'longitude': -104.837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80906', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.7902, 'longitude': -104.8199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80907', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.876, 'longitude': -104.817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80908', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 39.0237, 'longitude': -104.6933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80909', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.852, 'longitude': -104.7735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80910', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8152, 'longitude': -104.7703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80911', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.7457, 'longitude': -104.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80912', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80913', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.73, 'longitude': -104.7536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80914', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8192, 'longitude': -104.7012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80915', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8558, 'longitude': -104.7134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80916', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8076, 'longitude': -104.7403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80917', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.886, 'longitude': -104.7399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80918', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9129, 'longitude': -104.7734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80919', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9268, 'longitude': -104.8464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80920', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9497, 'longitude': -104.767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80921', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 39.0487, 'longitude': -104.814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80922', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.905, 'longitude': -104.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80923', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9189, 'longitude': -104.7045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80924', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9676, 'longitude': -104.7211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80925', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.7378, 'longitude': -104.6459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80926', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.6981, 'longitude': -104.8505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80927', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9286, 'longitude': -104.6583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80928', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.6233, 'longitude': -104.457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80929', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.7968, 'longitude': -104.6079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80930', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8289, 'longitude': -104.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80931', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80932', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80933', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80934', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80935', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80936', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80937', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80938', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.9047, 'longitude': -104.6634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80939', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8776, 'longitude': -104.6774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80941', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80942', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80944', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80946', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80947', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80949', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80950', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80951', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8881, 'longitude': -104.6556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80960', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80962', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80970', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80977', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80995', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80997', 'place_name': 'Colorado Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'El Paso', 'locality_code': '41', 'latitude': 38.8339, 'longitude': -104.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81212', 'place_name': 'Canon City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.4451, 'longitude': -105.2178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81215', 'place_name': 'Canon City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.4776, 'longitude': -105.4766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81221', 'place_name': 'Coal Creek', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.3611, 'longitude': -105.1483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81222', 'place_name': 'Coaldale', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.3824, 'longitude': -105.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81223', 'place_name': 'Cotopaxi', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.3703, 'longitude': -105.6881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81226', 'place_name': 'Florence', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.385, 'longitude': -105.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81232', 'place_name': 'Hillside', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.2653, 'longitude': -105.6117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81233', 'place_name': 'Howard', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.41, 'longitude': -105.7698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81240', 'place_name': 'Penrose', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.4336, 'longitude': -105.0113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81244', 'place_name': 'Rockvale', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.3697, 'longitude': -105.1639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81290', 'place_name': 'Florence', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Fremont', 'locality_code': '43', 'latitude': 38.3903, 'longitude': -105.1186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81601', 'place_name': 'Glenwood Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.5296, 'longitude': -107.3252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81602', 'place_name': 'Glenwood Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.5505, 'longitude': -107.3248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81623', 'place_name': 'Carbondale', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.2511, 'longitude': -107.2044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81635', 'place_name': 'Parachute', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.4519, 'longitude': -108.0529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81636', 'place_name': 'Battlement Mesa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.4305, 'longitude': -108.0239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81647', 'place_name': 'New Castle', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.5709, 'longitude': -107.5428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81650', 'place_name': 'Rifle', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.5491, 'longitude': -107.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81652', 'place_name': 'Silt', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Garfield', 'locality_code': '45', 'latitude': 39.5028, 'longitude': -107.6657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80422', 'place_name': 'Black Hawk', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gilpin', 'locality_code': '47', 'latitude': 39.816, 'longitude': -105.4753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80427', 'place_name': 'Central City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gilpin', 'locality_code': '47', 'latitude': 39.8019, 'longitude': -105.5142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80474', 'place_name': 'Rollinsville', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gilpin', 'locality_code': '47', 'latitude': 39.9172, 'longitude': -105.5011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80442', 'place_name': 'Fraser', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 39.945, 'longitude': -105.8172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80446', 'place_name': 'Granby', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 40.0739, 'longitude': -105.9285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80447', 'place_name': 'Grand Lake', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 40.2289, 'longitude': -105.8605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80451', 'place_name': 'Hot Sulphur Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 40.0712, 'longitude': -106.0693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80459', 'place_name': 'Kremmling', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 40.0632, 'longitude': -106.3955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80468', 'place_name': 'Parshall', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 39.9539, 'longitude': -106.093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80478', 'place_name': 'Tabernash', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 39.9797, 'longitude': -105.8615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80482', 'place_name': 'Winter Park', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Grand', 'locality_code': '49', 'latitude': 39.8939, 'longitude': -105.7845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81210', 'place_name': 'Almont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.82, 'longitude': -106.6603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81224', 'place_name': 'Crested Butte', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.8691, 'longitude': -106.9619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81225', 'place_name': 'Crested Butte', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.9006, 'longitude': -106.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81230', 'place_name': 'Gunnison', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.5511, 'longitude': -106.931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81231', 'place_name': 'Gunnison', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.5458, 'longitude': -106.9253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81237', 'place_name': 'Ohio City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.5908, 'longitude': -106.6028, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '81239', 'place_name': 'Parlin', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.5371, 'longitude': -106.6352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81241', 'place_name': 'Pitkin', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.6179, 'longitude': -106.5146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81243', 'place_name': 'Powderhorn', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.2822, 'longitude': -107.1084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81434', 'place_name': 'Somerset', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Gunnison', 'locality_code': '51', 'latitude': 38.9468, 'longitude': -107.3781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81235', 'place_name': 'Lake City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Hinsdale', 'locality_code': '53', 'latitude': 37.9868, 'longitude': -107.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81040', 'place_name': 'Gardner', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Huerfano', 'locality_code': '55', 'latitude': 37.7878, 'longitude': -105.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81055', 'place_name': 'La Veta', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Huerfano', 'locality_code': '55', 'latitude': 37.5117, 'longitude': -105.0575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81089', 'place_name': 'Walsenburg', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Huerfano', 'locality_code': '55', 'latitude': 37.6465, 'longitude': -104.7798, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80430', 'place_name': 'Coalmont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jackson', 'locality_code': '57', 'latitude': 40.5383, 'longitude': -106.5321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80434', 'place_name': 'Cowdrey', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jackson', 'locality_code': '57', 'latitude': 40.8597, 'longitude': -106.3131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80473', 'place_name': 'Rand', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jackson', 'locality_code': '57', 'latitude': 40.4667, 'longitude': -106.1857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80480', 'place_name': 'Walden', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jackson', 'locality_code': '57', 'latitude': 40.71, 'longitude': -106.2767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80001', 'place_name': 'Arvada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8028, 'longitude': -105.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80002', 'place_name': 'Arvada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.7945, 'longitude': -105.0984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80003', 'place_name': 'Arvada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8286, 'longitude': -105.0655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80004', 'place_name': 'Arvada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8141, 'longitude': -105.1177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80005', 'place_name': 'Arvada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8422, 'longitude': -105.1097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80006', 'place_name': 'Arvada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8028, 'longitude': -105.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80007', 'place_name': 'Arvada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8634, 'longitude': -105.1724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80021', 'place_name': 'Broomfield', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8854, 'longitude': -105.1139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80033', 'place_name': 'Wheat Ridge', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.774, 'longitude': -105.0962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80034', 'place_name': 'Wheat Ridge', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.7661, 'longitude': -105.0772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80123', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6206, 'longitude': -105.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80127', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.592, 'longitude': -105.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80128', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.5918, 'longitude': -105.0832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80162', 'place_name': 'Littleton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.522, 'longitude': -105.2239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80214', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.7436, 'longitude': -105.0643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80215', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.7435, 'longitude': -105.1009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80225', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6971, 'longitude': -105.1204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80226', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.7123, 'longitude': -105.0918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80228', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6888, 'longitude': -105.156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80232', 'place_name': 'Denver', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6895, 'longitude': -105.0908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80401', 'place_name': 'Golden', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.7305, 'longitude': -105.1915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80402', 'place_name': 'Golden', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.7555, 'longitude': -105.2211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80403', 'place_name': 'Golden', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.8232, 'longitude': -105.2825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80419', 'place_name': 'Golden', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.522, 'longitude': -105.2239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80425', 'place_name': 'Buffalo Creek', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.3867, 'longitude': -105.2703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80433', 'place_name': 'Conifer', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.5197, 'longitude': -105.3169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80437', 'place_name': 'Evergreen', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.522, 'longitude': -105.2239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80439', 'place_name': 'Evergreen', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6374, 'longitude': -105.3402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80453', 'place_name': 'Idledale', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6684, 'longitude': -105.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80454', 'place_name': 'Indian Hills', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6296, 'longitude': -105.2514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80457', 'place_name': 'Kittredge', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6481, 'longitude': -105.2782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80465', 'place_name': 'Morrison', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.6125, 'longitude': -105.1746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80470', 'place_name': 'Pine', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Jefferson', 'locality_code': '59', 'latitude': 39.4667, 'longitude': -105.3741, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '81021', 'place_name': 'Arlington', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kiowa', 'locality_code': '61', 'latitude': 38.4068, 'longitude': -103.3697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81036', 'place_name': 'Eads', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kiowa', 'locality_code': '61', 'latitude': 38.4408, 'longitude': -102.5549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81045', 'place_name': 'Haswell', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kiowa', 'locality_code': '61', 'latitude': 38.4474, 'longitude': -103.1505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81071', 'place_name': 'Sheridan Lake', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kiowa', 'locality_code': '61', 'latitude': 38.4667, 'longitude': -102.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80805', 'place_name': 'Bethune', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kit Carson', 'locality_code': '63', 'latitude': 39.3448, 'longitude': -102.4281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80807', 'place_name': 'Burlington', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kit Carson', 'locality_code': '63', 'latitude': 39.3106, 'longitude': -102.2583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80815', 'place_name': 'Flagler', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kit Carson', 'locality_code': '63', 'latitude': 39.3127, 'longitude': -103.0624, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80834', 'place_name': 'Seibert', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kit Carson', 'locality_code': '63', 'latitude': 39.3183, 'longitude': -102.8822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80836', 'place_name': 'Stratton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kit Carson', 'locality_code': '63', 'latitude': 39.3087, 'longitude': -102.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80861', 'place_name': 'Vona', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Kit Carson', 'locality_code': '63', 'latitude': 39.3236, 'longitude': -102.7393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80429', 'place_name': 'Climax', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lake', 'locality_code': '65', 'latitude': 39.2258, 'longitude': -106.3117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80461', 'place_name': 'Leadville', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lake', 'locality_code': '65', 'latitude': 39.2497, 'longitude': -106.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81251', 'place_name': 'Twin Lakes', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lake', 'locality_code': '65', 'latitude': 39.1011, 'longitude': -106.4416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81122', 'place_name': 'Bayfield', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'La Plata', 'locality_code': '67', 'latitude': 37.2603, 'longitude': -107.6137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81137', 'place_name': 'Ignacio', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'La Plata', 'locality_code': '67', 'latitude': 37.1264, 'longitude': -107.6395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81301', 'place_name': 'Durango', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'La Plata', 'locality_code': '67', 'latitude': 37.2874, 'longitude': -107.8617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81302', 'place_name': 'Durango', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'La Plata', 'locality_code': '67', 'latitude': 37.2753, 'longitude': -107.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81303', 'place_name': 'Durango', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'La Plata', 'locality_code': '67', 'latitude': 37.1156, 'longitude': -107.8909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81326', 'place_name': 'Hesperus', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'La Plata', 'locality_code': '67', 'latitude': 37.1654, 'longitude': -108.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81329', 'place_name': 'Marvel', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'La Plata', 'locality_code': '67', 'latitude': 37.0926, 'longitude': -108.1252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80511', 'place_name': 'Estes Park', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.6281, 'longitude': -105.5692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80512', 'place_name': 'Bellvue', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.6265, 'longitude': -105.261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80513', 'place_name': 'Berthoud', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.2993, 'longitude': -105.1055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80515', 'place_name': 'Drake', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.4275, 'longitude': -105.3831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80517', 'place_name': 'Estes Park', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.3658, 'longitude': -105.5142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80521', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5813, 'longitude': -105.1039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80522', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.6429, 'longitude': -105.057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80523', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5853, 'longitude': -105.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80524', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5986, 'longitude': -105.0581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80525', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5384, 'longitude': -105.0547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80526', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5473, 'longitude': -105.1076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80527', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5853, 'longitude': -105.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80528', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.4961, 'longitude': -105.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80532', 'place_name': 'Glen Haven', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.4578, 'longitude': -105.447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80535', 'place_name': 'Laporte', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.6347, 'longitude': -105.1488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80536', 'place_name': 'Livermore', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.8701, 'longitude': -105.3766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80537', 'place_name': 'Loveland', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.3849, 'longitude': -105.0916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80538', 'place_name': 'Loveland', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.4262, 'longitude': -105.09, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80539', 'place_name': 'Loveland', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.3978, 'longitude': -105.075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80541', 'place_name': 'Masonville', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.4875, 'longitude': -105.2108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80545', 'place_name': 'Red Feather Lakes', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.8659, 'longitude': -105.6893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80547', 'place_name': 'Timnath', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5291, 'longitude': -104.9853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80549', 'place_name': 'Wellington', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.7255, 'longitude': -105.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80553', 'place_name': 'Fort Collins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Larimer', 'locality_code': '69', 'latitude': 40.5853, 'longitude': -105.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81020', 'place_name': 'Aguilar', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.3933, 'longitude': -104.6769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81024', 'place_name': 'Boncarbo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.2081, 'longitude': -104.7198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81027', 'place_name': 'Branson', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.0518, 'longitude': -103.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81046', 'place_name': 'Hoehne', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.2796, 'longitude': -104.3584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81049', 'place_name': 'Kim', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.3328, 'longitude': -103.3736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81059', 'place_name': 'Model', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.5192, 'longitude': -104.223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81081', 'place_name': 'Trinchera', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.0757, 'longitude': -104.1184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81082', 'place_name': 'Trinidad', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.2691, 'longitude': -104.5038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81091', 'place_name': 'Weston', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Las Animas', 'locality_code': '71', 'latitude': 37.1702, 'longitude': -104.8247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80804', 'place_name': 'Arriba', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lincoln', 'locality_code': '73', 'latitude': 39.3025, 'longitude': -103.271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80818', 'place_name': 'Genoa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lincoln', 'locality_code': '73', 'latitude': 39.3383, 'longitude': -103.4607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80821', 'place_name': 'Hugo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lincoln', 'locality_code': '73', 'latitude': 39.0843, 'longitude': -103.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80823', 'place_name': 'Karval', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lincoln', 'locality_code': '73', 'latitude': 38.7119, 'longitude': -103.5006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80826', 'place_name': 'Limon', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lincoln', 'locality_code': '73', 'latitude': 39.2639, 'longitude': -103.6922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80828', 'place_name': 'Limon', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Lincoln', 'locality_code': '73', 'latitude': 39.2713, 'longitude': -103.6856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80722', 'place_name': 'Atwood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.5082, 'longitude': -103.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80726', 'place_name': 'Crook', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.8747, 'longitude': -102.8472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80728', 'place_name': 'Fleming', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.637, 'longitude': -102.8688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80736', 'place_name': 'Iliff', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.7692, 'longitude': -103.0968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80741', 'place_name': 'Merino', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.5708, 'longitude': -103.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80745', 'place_name': 'Padroni', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.8842, 'longitude': -103.3728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80747', 'place_name': 'Peetz', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.9519, 'longitude': -103.1166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80751', 'place_name': 'Sterling', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Logan', 'locality_code': '75', 'latitude': 40.6306, 'longitude': -103.2212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81501', 'place_name': 'Grand Junction', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.0783, 'longitude': -108.5457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81502', 'place_name': 'Grand Junction', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.0179, 'longitude': -108.4814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81503', 'place_name': 'Grand Junction', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.0307, 'longitude': -108.4361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81504', 'place_name': 'Grand Junction', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.0791, 'longitude': -108.4916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81505', 'place_name': 'Grand Junction', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.1071, 'longitude': -108.5968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81506', 'place_name': 'Grand Junction', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.1032, 'longitude': -108.5491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81507', 'place_name': 'Grand Junction', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.0157, 'longitude': -108.6129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81520', 'place_name': 'Clifton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.0805, 'longitude': -108.4496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81521', 'place_name': 'Fruita', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.1637, 'longitude': -108.7218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81522', 'place_name': 'Gateway', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 38.6784, 'longitude': -108.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81523', 'place_name': 'Glade Park', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 38.9894, 'longitude': -108.781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81524', 'place_name': 'Loma', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.2279, 'longitude': -108.8149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81525', 'place_name': 'Mack', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.2554, 'longitude': -108.9296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81526', 'place_name': 'Palisade', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.1032, 'longitude': -108.368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81527', 'place_name': 'Whitewater', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 38.9744, 'longitude': -108.399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81624', 'place_name': 'Collbran', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.2453, 'longitude': -107.9249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81630', 'place_name': 'De Beque', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.3118, 'longitude': -108.2304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81643', 'place_name': 'Mesa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.1612, 'longitude': -108.1044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81646', 'place_name': 'Molina', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mesa', 'locality_code': '77', 'latitude': 39.1891, 'longitude': -108.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81130', 'place_name': 'Creede', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Mineral', 'locality_code': '79', 'latitude': 37.8164, 'longitude': -106.9277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81610', 'place_name': 'Dinosaur', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Moffat', 'locality_code': '81', 'latitude': 40.2566, 'longitude': -108.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81625', 'place_name': 'Craig', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Moffat', 'locality_code': '81', 'latitude': 40.5224, 'longitude': -107.5615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81626', 'place_name': 'Craig', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Moffat', 'locality_code': '81', 'latitude': 40.5152, 'longitude': -107.5465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81633', 'place_name': 'Dinosaur', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Moffat', 'locality_code': '81', 'latitude': 40.377, 'longitude': -108.399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81638', 'place_name': 'Hamilton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Moffat', 'locality_code': '81', 'latitude': 40.325, 'longitude': -107.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81640', 'place_name': 'Maybell', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Moffat', 'locality_code': '81', 'latitude': 40.6738, 'longitude': -108.3699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81653', 'place_name': 'Slater', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Moffat', 'locality_code': '81', 'latitude': 40.9979, 'longitude': -107.3388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81321', 'place_name': 'Cortez', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.3549, 'longitude': -108.5837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81323', 'place_name': 'Dolores', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.4666, 'longitude': -108.4717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81327', 'place_name': 'Lewis', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.5177, 'longitude': -108.6546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81328', 'place_name': 'Mancos', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.3471, 'longitude': -108.2982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81330', 'place_name': 'Mesa Verde National Park', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.2313, 'longitude': -108.4825, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '81331', 'place_name': 'Pleasant View', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.5888, 'longitude': -108.8095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81334', 'place_name': 'Towaoc', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.2084, 'longitude': -108.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81335', 'place_name': 'Yellow Jacket', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montezuma', 'locality_code': '83', 'latitude': 37.5344, 'longitude': -108.7173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81220', 'place_name': 'Cimarron', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.3876, 'longitude': -107.4824, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '81401', 'place_name': 'Montrose', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.4678, 'longitude': -107.8752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81402', 'place_name': 'Montrose', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.4851, 'longitude': -107.886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81403', 'place_name': 'Montrose', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.3602, 'longitude': -107.9381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81411', 'place_name': 'Bedrock', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.2509, 'longitude': -108.9799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81422', 'place_name': 'Naturita', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.2183, 'longitude': -108.5687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81424', 'place_name': 'Nucla', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.2682, 'longitude': -108.5476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81425', 'place_name': 'Olathe', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.5976, 'longitude': -107.9921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81429', 'place_name': 'Paradox', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.3711, 'longitude': -108.9698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81431', 'place_name': 'Redvale', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Montrose', 'locality_code': '85', 'latitude': 38.1865, 'longitude': -108.3895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80649', 'place_name': 'Orchard', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.3639, 'longitude': -104.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80653', 'place_name': 'Weldona', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.3681, 'longitude': -103.9678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80654', 'place_name': 'Wiggins', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.1598, 'longitude': -104.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80701', 'place_name': 'Fort Morgan', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.2541, 'longitude': -103.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80705', 'place_name': 'Log Lane Village', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.2707, 'longitude': -103.8338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80723', 'place_name': 'Brush', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.2603, 'longitude': -103.6279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80733', 'place_name': 'Hillrose', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.3459, 'longitude': -103.5057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80750', 'place_name': 'Snyder', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Morgan', 'locality_code': '87', 'latitude': 40.3307, 'longitude': -103.5971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81030', 'place_name': 'Cheraw', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Otero', 'locality_code': '89', 'latitude': 38.107, 'longitude': -103.5102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81039', 'place_name': 'Fowler', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Otero', 'locality_code': '89', 'latitude': 38.1231, 'longitude': -104.0299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81050', 'place_name': 'La Junta', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Otero', 'locality_code': '89', 'latitude': 37.9546, 'longitude': -103.6644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81058', 'place_name': 'Manzanola', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Otero', 'locality_code': '89', 'latitude': 38.1109, 'longitude': -103.8766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81067', 'place_name': 'Rocky Ford', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Otero', 'locality_code': '89', 'latitude': 38.049, 'longitude': -103.7251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81077', 'place_name': 'Swink', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Otero', 'locality_code': '89', 'latitude': 38.0145, 'longitude': -103.6283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81427', 'place_name': 'Ouray', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Ouray', 'locality_code': '91', 'latitude': 38.0258, 'longitude': -107.6726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81432', 'place_name': 'Ridgway', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Ouray', 'locality_code': '91', 'latitude': 38.1381, 'longitude': -107.7533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80420', 'place_name': 'Alma', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.2839, 'longitude': -106.0628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80421', 'place_name': 'Bailey', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.4482, 'longitude': -105.4693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80432', 'place_name': 'Como', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.1587, 'longitude': -105.817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80440', 'place_name': 'Fairplay', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.2256, 'longitude': -105.9994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80448', 'place_name': 'Grant', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.4612, 'longitude': -105.6583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80449', 'place_name': 'Hartsel', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 38.9673, 'longitude': -105.8788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80456', 'place_name': 'Jefferson', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.2759, 'longitude': -105.6865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80475', 'place_name': 'Shawnee', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.4211, 'longitude': -105.5542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80820', 'place_name': 'Guffey', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 38.8146, 'longitude': -105.5784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80827', 'place_name': 'Lake George', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Park', 'locality_code': '93', 'latitude': 39.0342, 'longitude': -105.4347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80721', 'place_name': 'Amherst', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Phillips', 'locality_code': '95', 'latitude': 40.6824, 'longitude': -102.1706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80731', 'place_name': 'Haxtun', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Phillips', 'locality_code': '95', 'latitude': 40.6406, 'longitude': -102.6052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80734', 'place_name': 'Holyoke', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Phillips', 'locality_code': '95', 'latitude': 40.5825, 'longitude': -102.2825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80746', 'place_name': 'Paoli', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Phillips', 'locality_code': '95', 'latitude': 40.6106, 'longitude': -102.4722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81611', 'place_name': 'Aspen', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pitkin', 'locality_code': '97', 'latitude': 39.1951, 'longitude': -106.8236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81612', 'place_name': 'Aspen', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pitkin', 'locality_code': '97', 'latitude': 39.2234, 'longitude': -106.8828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81615', 'place_name': 'Snowmass Village', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pitkin', 'locality_code': '97', 'latitude': 39.2212, 'longitude': -106.932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81642', 'place_name': 'Meredith', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pitkin', 'locality_code': '97', 'latitude': 39.3199, 'longitude': -106.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81654', 'place_name': 'Snowmass', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pitkin', 'locality_code': '97', 'latitude': 39.2258, 'longitude': -107.0303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81656', 'place_name': 'Woody Creek', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pitkin', 'locality_code': '97', 'latitude': 39.2831, 'longitude': -106.8985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81041', 'place_name': 'Granada', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Prowers', 'locality_code': '99', 'latitude': 38.0545, 'longitude': -102.3271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81043', 'place_name': 'Hartman', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Prowers', 'locality_code': '99', 'latitude': 38.1195, 'longitude': -102.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81047', 'place_name': 'Holly', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Prowers', 'locality_code': '99', 'latitude': 38.0205, 'longitude': -102.1415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81052', 'place_name': 'Lamar', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Prowers', 'locality_code': '99', 'latitude': 38.0841, 'longitude': -102.6192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81092', 'place_name': 'Wiley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Prowers', 'locality_code': '99', 'latitude': 38.159, 'longitude': -102.7147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81001', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.2879, 'longitude': -104.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81002', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.2544, 'longitude': -104.6091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81003', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.2843, 'longitude': -104.6234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81004', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.2441, 'longitude': -104.6278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81005', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.2352, 'longitude': -104.66, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81006', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.2447, 'longitude': -104.5318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81007', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.387, 'longitude': -104.7792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81008', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.3133, 'longitude': -104.6284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81009', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.1286, 'longitude': -104.5523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81010', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.1286, 'longitude': -104.5523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81011', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.1286, 'longitude': -104.5523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81012', 'place_name': 'Pueblo', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.1286, 'longitude': -104.5523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81019', 'place_name': 'Colorado City', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 37.9441, 'longitude': -104.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81022', 'place_name': 'Avondale', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.1025, 'longitude': -104.5298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81023', 'place_name': 'Beulah', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.0837, 'longitude': -104.9724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81025', 'place_name': 'Boone', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 38.2646, 'longitude': -104.2585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81069', 'place_name': 'Rye', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Pueblo', 'locality_code': '101', 'latitude': 37.9236, 'longitude': -104.9303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81641', 'place_name': 'Meeker', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Rio Blanco', 'locality_code': '103', 'latitude': 40.0387, 'longitude': -107.8925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81648', 'place_name': 'Rangely', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Rio Blanco', 'locality_code': '103', 'latitude': 40.0828, 'longitude': -108.7991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81132', 'place_name': 'Del Norte', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Rio Grande', 'locality_code': '105', 'latitude': 37.6447, 'longitude': -106.4073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81135', 'place_name': 'Homelake', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Rio Grande', 'locality_code': '105', 'latitude': 37.5756, 'longitude': -106.097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81144', 'place_name': 'Monte Vista', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Rio Grande', 'locality_code': '105', 'latitude': 37.5731, 'longitude': -106.1408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81154', 'place_name': 'South Fork', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Rio Grande', 'locality_code': '105', 'latitude': 37.6725, 'longitude': -106.6125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80428', 'place_name': 'Clark', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.7268, 'longitude': -106.9215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80467', 'place_name': 'Oak Creek', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.2567, 'longitude': -106.9296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80469', 'place_name': 'Phippsburg', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.1907, 'longitude': -106.9735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80477', 'place_name': 'Steamboat Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.485, 'longitude': -106.8317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80479', 'place_name': 'Toponas', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.0603, 'longitude': -106.8081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80483', 'place_name': 'Yampa', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.1304, 'longitude': -106.9116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80487', 'place_name': 'Steamboat Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.6327, 'longitude': -106.9318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80488', 'place_name': 'Steamboat Springs', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.6197, 'longitude': -106.8607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81639', 'place_name': 'Hayden', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Routt', 'locality_code': '107', 'latitude': 40.4945, 'longitude': -107.2571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81125', 'place_name': 'Center', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Saguache', 'locality_code': '109', 'latitude': 37.7343, 'longitude': -106.0906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81131', 'place_name': 'Crestone', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Saguache', 'locality_code': '109', 'latitude': 37.953, 'longitude': -105.6879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81143', 'place_name': 'Moffat', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Saguache', 'locality_code': '109', 'latitude': 38.0452, 'longitude': -105.8411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81149', 'place_name': 'Saguache', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Saguache', 'locality_code': '109', 'latitude': 38.0977, 'longitude': -106.1876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81155', 'place_name': 'Villa Grove', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Saguache', 'locality_code': '109', 'latitude': 38.2952, 'longitude': -106.1102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81248', 'place_name': 'Sargents', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Saguache', 'locality_code': '109', 'latitude': 38.4033, 'longitude': -106.4161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81433', 'place_name': 'Silverton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'San Juan', 'locality_code': '111', 'latitude': 37.809, 'longitude': -107.6667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81325', 'place_name': 'Egnar', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'San Miguel', 'locality_code': '113', 'latitude': 37.9344, 'longitude': -108.9299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81423', 'place_name': 'Norwood', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'San Miguel', 'locality_code': '113', 'latitude': 38.1104, 'longitude': -108.2845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81426', 'place_name': 'Ophir', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'San Miguel', 'locality_code': '113', 'latitude': 37.8569, 'longitude': -107.8326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81430', 'place_name': 'Placerville', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'San Miguel', 'locality_code': '113', 'latitude': 38.0167, 'longitude': -108.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '81435', 'place_name': 'Telluride', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'San Miguel', 'locality_code': '113', 'latitude': 37.94, 'longitude': -107.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80737', 'place_name': 'Julesburg', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Sedgwick', 'locality_code': '115', 'latitude': 40.9708, 'longitude': -102.2575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80744', 'place_name': 'Ovid', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Sedgwick', 'locality_code': '115', 'latitude': 40.9459, 'longitude': -102.3874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80749', 'place_name': 'Sedgwick', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Sedgwick', 'locality_code': '115', 'latitude': 40.9103, 'longitude': -102.5291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80424', 'place_name': 'Breckenridge', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Summit', 'locality_code': '117', 'latitude': 39.4753, 'longitude': -106.0225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80435', 'place_name': 'Dillon', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Summit', 'locality_code': '117', 'latitude': 39.5952, 'longitude': -105.9741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80443', 'place_name': 'Frisco', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Summit', 'locality_code': '117', 'latitude': 39.5589, 'longitude': -106.1332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80497', 'place_name': 'Silverthorne', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Summit', 'locality_code': '117', 'latitude': 39.6411, 'longitude': -106.108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80498', 'place_name': 'Silverthorne', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Summit', 'locality_code': '117', 'latitude': 39.7647, 'longitude': -106.2211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80813', 'place_name': 'Cripple Creek', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Teller', 'locality_code': '119', 'latitude': 38.8261, 'longitude': -105.1499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80814', 'place_name': 'Divide', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Teller', 'locality_code': '119', 'latitude': 38.9576, 'longitude': -105.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80816', 'place_name': 'Florissant', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Teller', 'locality_code': '119', 'latitude': 38.8546, 'longitude': -105.3121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80860', 'place_name': 'Victor', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Teller', 'locality_code': '119', 'latitude': 38.71, 'longitude': -105.14, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '80863', 'place_name': 'Woodland Park', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Teller', 'locality_code': '119', 'latitude': 38.9969, 'longitude': -105.0623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80866', 'place_name': 'Woodland Park', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Teller', 'locality_code': '119', 'latitude': 38.9939, 'longitude': -105.0569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80720', 'place_name': 'Akron', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Washington', 'locality_code': '121', 'latitude': 40.1803, 'longitude': -103.2259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80740', 'place_name': 'Lindon', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Washington', 'locality_code': '121', 'latitude': 39.7909, 'longitude': -103.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80743', 'place_name': 'Otis', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Washington', 'locality_code': '121', 'latitude': 40.203, 'longitude': -102.9392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80757', 'place_name': 'Woodrow', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Washington', 'locality_code': '121', 'latitude': 39.805, 'longitude': -103.5752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80801', 'place_name': 'Anton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Washington', 'locality_code': '121', 'latitude': 39.6909, 'longitude': -103.1373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80812', 'place_name': 'Cope', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Washington', 'locality_code': '121', 'latitude': 39.6848, 'longitude': -102.9904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80504', 'place_name': 'Longmont', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.1306, 'longitude': -104.9504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80514', 'place_name': 'Dacono', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.0836, 'longitude': -104.9297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80516', 'place_name': 'Erie', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.0597, 'longitude': -105.0686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80520', 'place_name': 'Firestone', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.1125, 'longitude': -104.9366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80530', 'place_name': 'Frederick', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.0978, 'longitude': -104.9293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80534', 'place_name': 'Johnstown', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.3355, 'longitude': -104.9236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80542', 'place_name': 'Mead', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.2347, 'longitude': -104.9994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80543', 'place_name': 'Milliken', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.3294, 'longitude': -104.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80546', 'place_name': 'Severance', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.525, 'longitude': -104.8505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80550', 'place_name': 'Windsor', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.4837, 'longitude': -104.8994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80551', 'place_name': 'Windsor', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.4775, 'longitude': -104.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80610', 'place_name': 'Ault', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.5938, 'longitude': -104.7356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80611', 'place_name': 'Briggsdale', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.6392, 'longitude': -104.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80612', 'place_name': 'Carr', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.8666, 'longitude': -104.8859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80615', 'place_name': 'Eaton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.5273, 'longitude': -104.7146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80620', 'place_name': 'Evans', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.3803, 'longitude': -104.6971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80621', 'place_name': 'Fort Lupton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.108, 'longitude': -104.8013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80622', 'place_name': 'Galeton', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.5378, 'longitude': -104.4585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80623', 'place_name': 'Gilcrest', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.2854, 'longitude': -104.7825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80624', 'place_name': 'Gill', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.4696, 'longitude': -104.5, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80631', 'place_name': 'Greeley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.385, 'longitude': -104.6806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80632', 'place_name': 'Greeley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.3766, 'longitude': -104.7629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80633', 'place_name': 'Greeley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.4233, 'longitude': -104.7091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80634', 'place_name': 'Greeley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.4109, 'longitude': -104.7541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80638', 'place_name': 'Greeley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.4233, 'longitude': -104.7091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80639', 'place_name': 'Greeley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.3993, 'longitude': -104.7017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80642', 'place_name': 'Hudson', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.0606, 'longitude': -104.6532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80643', 'place_name': 'Keenesburg', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.0958, 'longitude': -104.4464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80644', 'place_name': 'Kersey', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.3963, 'longitude': -104.5288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80645', 'place_name': 'La Salle', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.3211, 'longitude': -104.7268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80646', 'place_name': 'Lucerne', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.4824, 'longitude': -104.7054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80648', 'place_name': 'Nunn', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.7265, 'longitude': -104.785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80650', 'place_name': 'Pierce', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.6359, 'longitude': -104.7638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80651', 'place_name': 'Platteville', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.2131, 'longitude': -104.8028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80652', 'place_name': 'Roggen', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.0878, 'longitude': -104.282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80729', 'place_name': 'Grover', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.8716, 'longitude': -104.2346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80732', 'place_name': 'Hereford', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.9751, 'longitude': -104.3053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80742', 'place_name': 'New Raymer', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.6851, 'longitude': -103.839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80754', 'place_name': 'Stoneham', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Weld', 'locality_code': '123', 'latitude': 40.687, 'longitude': -103.6387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80727', 'place_name': 'Eckley', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Yuma', 'locality_code': '125', 'latitude': 40.1138, 'longitude': -102.4828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80735', 'place_name': 'Idalia', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Yuma', 'locality_code': '125', 'latitude': 39.8167, 'longitude': -102.4262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80755', 'place_name': 'Vernon', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Yuma', 'locality_code': '125', 'latitude': 39.9331, 'longitude': -102.3193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80758', 'place_name': 'Wray', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Yuma', 'locality_code': '125', 'latitude': 40.0685, 'longitude': -102.393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80759', 'place_name': 'Yuma', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Yuma', 'locality_code': '125', 'latitude': 40.1301, 'longitude': -102.7072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80822', 'place_name': 'Joes', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Yuma', 'locality_code': '125', 'latitude': 39.6564, 'longitude': -102.6788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '80824', 'place_name': 'Kirk', 'state': 'Colorado', 'state_ab': 'CO', 'county': 'Yuma', 'locality_code': '125', 'latitude': 39.6171, 'longitude': -102.4776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6404', 'place_name': 'Botsford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3665, 'longitude': -73.2571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6440', 'place_name': 'Hawleyville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.4276, 'longitude': -73.3551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6468', 'place_name': 'Monroe', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3312, 'longitude': -73.2243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6470', 'place_name': 'Newtown', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3931, 'longitude': -73.3167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6482', 'place_name': 'Sandy Hook', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.4087, 'longitude': -73.2485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6484', 'place_name': 'Shelton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3047, 'longitude': -73.1294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6491', 'place_name': 'Stevenson', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3866, 'longitude': -73.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6601', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.167, 'longitude': -73.2048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6602', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1798, 'longitude': -73.189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6604', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1796, 'longitude': -73.2019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6605', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1668, 'longitude': -73.2163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6606', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2091, 'longitude': -73.2086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6607', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1784, 'longitude': -73.165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6608', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1895, 'longitude': -73.1811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6610', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2005, 'longitude': -73.1688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6611', 'place_name': 'Trumbull', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2564, 'longitude': -73.2111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6612', 'place_name': 'Easton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2523, 'longitude': -73.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6614', 'place_name': 'Stratford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.216, 'longitude': -73.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6615', 'place_name': 'Stratford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.177, 'longitude': -73.1336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6673', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.167, 'longitude': -73.2048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6699', 'place_name': 'Bridgeport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.167, 'longitude': -73.2048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6784', 'place_name': 'Sherman', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.5714, 'longitude': -73.4947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6801', 'place_name': 'Bethel', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3813, 'longitude': -73.4008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6804', 'place_name': 'Brookfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.465, 'longitude': -73.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6807', 'place_name': 'Cos Cob', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.053, 'longitude': -73.5935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6810', 'place_name': 'Danbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3917, 'longitude': -73.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6811', 'place_name': 'Danbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.424, 'longitude': -73.4716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6812', 'place_name': 'New Fairfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.473, 'longitude': -73.4978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6813', 'place_name': 'Danbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3948, 'longitude': -73.454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6814', 'place_name': 'Danbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3089, 'longitude': -73.3637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6816', 'place_name': 'Danbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3089, 'longitude': -73.3637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6817', 'place_name': 'Danbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3948, 'longitude': -73.454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6820', 'place_name': 'Darien', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0768, 'longitude': -73.4853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6824', 'place_name': 'Fairfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1692, 'longitude': -73.2681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6825', 'place_name': 'Fairfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1928, 'longitude': -73.2402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6828', 'place_name': 'Fairfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.169, 'longitude': -73.2334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6829', 'place_name': 'Georgetown', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2555, 'longitude': -73.4279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6830', 'place_name': 'Greenwich', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0427, 'longitude': -73.6262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6831', 'place_name': 'Greenwich', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0549, 'longitude': -73.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6836', 'place_name': 'Greenwich', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0265, 'longitude': -73.6285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6838', 'place_name': 'Greens Farms', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1238, 'longitude': -73.3195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6840', 'place_name': 'New Canaan', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.151, 'longitude': -73.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6850', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1222, 'longitude': -73.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6851', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1323, 'longitude': -73.4058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6852', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3089, 'longitude': -73.3637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6853', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0702, 'longitude': -73.4397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6854', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0957, 'longitude': -73.4285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6855', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1014, 'longitude': -73.4011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6856', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1112, 'longitude': -73.4204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6857', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3089, 'longitude': -73.3637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6858', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1105, 'longitude': -73.4162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6860', 'place_name': 'Norwalk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3089, 'longitude': -73.3637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6870', 'place_name': 'Old Greenwich', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0354, 'longitude': -73.5673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6875', 'place_name': 'Redding Center', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3089, 'longitude': -73.3637, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6876', 'place_name': 'Redding Ridge', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.314, 'longitude': -73.3504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6877', 'place_name': 'Ridgefield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2977, 'longitude': -73.4973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6878', 'place_name': 'Riverside', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.038, 'longitude': -73.5811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6879', 'place_name': 'Ridgefield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2815, 'longitude': -73.4982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6880', 'place_name': 'Westport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1434, 'longitude': -73.3496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6881', 'place_name': 'Westport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1415, 'longitude': -73.3579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6883', 'place_name': 'Weston', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2195, 'longitude': -73.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6888', 'place_name': 'Westport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.3089, 'longitude': -73.3637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6889', 'place_name': 'Westport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.141, 'longitude': -73.3469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6890', 'place_name': 'Southport', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1428, 'longitude': -73.2884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6896', 'place_name': 'Redding', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2711, 'longitude': -73.3863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6897', 'place_name': 'Wilton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.2018, 'longitude': -73.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6901', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0531, 'longitude': -73.539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6902', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0602, 'longitude': -73.5445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6903', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.1352, 'longitude': -73.5684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6904', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0534, 'longitude': -73.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6905', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0888, 'longitude': -73.5435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6906', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0692, 'longitude': -73.5236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6907', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0942, 'longitude': -73.5203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6910', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0391, 'longitude': -73.5591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6911', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0534, 'longitude': -73.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6912', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0534, 'longitude': -73.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6913', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0534, 'longitude': -73.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6914', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0534, 'longitude': -73.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6920', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0534, 'longitude': -73.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6921', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0499, 'longitude': -73.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6922', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0516, 'longitude': -73.5143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6926', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0412, 'longitude': -73.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6927', 'place_name': 'Stamford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Fairfield', 'locality_code': '1', 'latitude': 41.0534, 'longitude': -73.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6001', 'place_name': 'Avon', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7905, 'longitude': -72.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6002', 'place_name': 'Bloomfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8316, 'longitude': -72.7249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6006', 'place_name': 'Windsor', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8526, 'longitude': -72.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6010', 'place_name': 'Bristol', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6823, 'longitude': -72.9302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6011', 'place_name': 'Bristol', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6718, 'longitude': -72.9493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6013', 'place_name': 'Burlington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7573, 'longitude': -72.9444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6016', 'place_name': 'Broad Brook', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9042, 'longitude': -72.5444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6019', 'place_name': 'Canton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8384, 'longitude': -72.8987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6020', 'place_name': 'Canton Center', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8539, 'longitude': -72.9028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6022', 'place_name': 'Collinsville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8513, 'longitude': -72.9283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6023', 'place_name': 'East Berlin', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6128, 'longitude': -72.719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6025', 'place_name': 'East Glastonbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6889, 'longitude': -72.5345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6026', 'place_name': 'East Granby', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9322, 'longitude': -72.7459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6027', 'place_name': 'East Hartland', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 42.0016, 'longitude': -72.9242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6028', 'place_name': 'East Windsor Hill', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8592, 'longitude': -72.603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6030', 'place_name': 'Farmington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6032', 'place_name': 'Farmington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7284, 'longitude': -72.8415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6033', 'place_name': 'Glastonbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7073, 'longitude': -72.5727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6034', 'place_name': 'Farmington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6035', 'place_name': 'Granby', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9602, 'longitude': -72.7994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6037', 'place_name': 'Berlin', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6215, 'longitude': -72.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6040', 'place_name': 'Manchester', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7777, 'longitude': -72.5244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6041', 'place_name': 'Manchester', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7759, 'longitude': -72.5215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6042', 'place_name': 'Manchester', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7966, 'longitude': -72.5292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6045', 'place_name': 'Manchester', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7759, 'longitude': -72.5215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6050', 'place_name': 'New Britain', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.666, 'longitude': -72.7784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6051', 'place_name': 'New Britain', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6667, 'longitude': -72.7722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6052', 'place_name': 'New Britain', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6588, 'longitude': -72.7989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6053', 'place_name': 'New Britain', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6867, 'longitude': -72.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6059', 'place_name': 'North Canton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8997, 'longitude': -72.8907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6060', 'place_name': 'North Granby', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 42.0219, 'longitude': -72.8409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6062', 'place_name': 'Plainville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6727, 'longitude': -72.8644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6064', 'place_name': 'Poquonock', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9048, 'longitude': -72.6787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6067', 'place_name': 'Rocky Hill', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6583, 'longitude': -72.6632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6070', 'place_name': 'Simsbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8759, 'longitude': -72.8012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6073', 'place_name': 'South Glastonbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6571, 'longitude': -72.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6074', 'place_name': 'South Windsor', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8341, 'longitude': -72.5576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6078', 'place_name': 'Suffield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.99, 'longitude': -72.642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6080', 'place_name': 'Suffield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9818, 'longitude': -72.6506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6081', 'place_name': 'Tariffville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9077, 'longitude': -72.7678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6082', 'place_name': 'Enfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.989, 'longitude': -72.5652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6083', 'place_name': 'Enfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9762, 'longitude': -72.5918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6085', 'place_name': 'Unionville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7477, 'longitude': -72.8874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6087', 'place_name': 'Unionville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7576, 'longitude': -72.885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6088', 'place_name': 'East Windsor', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9099, 'longitude': -72.6029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6089', 'place_name': 'Weatogue', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8372, 'longitude': -72.8253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6090', 'place_name': 'West Granby', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9556, 'longitude': -72.862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6091', 'place_name': 'West Hartland', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 42.0076, 'longitude': -72.9707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6092', 'place_name': 'West Simsbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8718, 'longitude': -72.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6093', 'place_name': 'West Suffield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 42.0115, 'longitude': -72.7362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6095', 'place_name': 'Windsor', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.8561, 'longitude': -72.6639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6096', 'place_name': 'Windsor Locks', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9261, 'longitude': -72.6458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6101', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7801, 'longitude': -72.6771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6102', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6103', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7672, 'longitude': -72.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6104', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6105', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7691, 'longitude': -72.701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6106', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7498, 'longitude': -72.6947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6107', 'place_name': 'West Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7556, 'longitude': -72.7532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6108', 'place_name': 'East Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7803, 'longitude': -72.618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6109', 'place_name': 'Wethersfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7013, 'longitude': -72.6763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6110', 'place_name': 'West Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7326, 'longitude': -72.7337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6111', 'place_name': 'Newington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.686, 'longitude': -72.7296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6112', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7905, 'longitude': -72.6964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6114', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7403, 'longitude': -72.6807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6115', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7588, 'longitude': -72.6794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6117', 'place_name': 'West Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.79, 'longitude': -72.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6118', 'place_name': 'East Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7472, 'longitude': -72.6103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6119', 'place_name': 'West Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7628, 'longitude': -72.7268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6120', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.786, 'longitude': -72.6758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6123', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7637, 'longitude': -72.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6126', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7637, 'longitude': -72.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6127', 'place_name': 'West Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6128', 'place_name': 'East Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6129', 'place_name': 'Wethersfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6131', 'place_name': 'Newington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6132', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7637, 'longitude': -72.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6133', 'place_name': 'West Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6134', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7637, 'longitude': -72.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6137', 'place_name': 'West Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6138', 'place_name': 'East Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6140', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6141', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6142', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6143', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6144', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6145', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6146', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6147', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6150', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6151', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6152', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7637, 'longitude': -72.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6153', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6154', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7715, 'longitude': -72.6867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6155', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7693, 'longitude': -72.6865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6156', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7679, 'longitude': -72.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6160', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7665, 'longitude': -72.6933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6161', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.766, 'longitude': -72.6718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6167', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7637, 'longitude': -72.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6176', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6180', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7918, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6183', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.7638, 'longitude': -72.673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6199', 'place_name': 'Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.9274, 'longitude': -72.6804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6444', 'place_name': 'Marion', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.5637, 'longitude': -72.9257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6447', 'place_name': 'Marlborough', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6412, 'longitude': -72.4609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6467', 'place_name': 'Milldale', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.5659, 'longitude': -72.8918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6479', 'place_name': 'Plantsville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.5797, 'longitude': -72.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6489', 'place_name': 'Southington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Hartford', 'locality_code': '3', 'latitude': 41.6052, 'longitude': -72.8727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6018', 'place_name': 'Canaan', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 42.0248, 'longitude': -73.3232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6021', 'place_name': 'Colebrook', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.9895, 'longitude': -73.0957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6024', 'place_name': 'East Canaan', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 42.0158, 'longitude': -73.2913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6031', 'place_name': 'Falls Village', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.9559, 'longitude': -73.3632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6039', 'place_name': 'Lakeville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.9516, 'longitude': -73.4377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6057', 'place_name': 'New Hartford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8468, 'longitude': -73.0104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6058', 'place_name': 'Norfolk', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.9854, 'longitude': -73.1992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6061', 'place_name': 'Pine Meadow', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8765, 'longitude': -72.967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6063', 'place_name': 'Barkhamsted', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.9293, 'longitude': -72.914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6065', 'place_name': 'Riverton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.9686, 'longitude': -73.0145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6068', 'place_name': 'Salisbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 42.0015, 'longitude': -73.4215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6069', 'place_name': 'Sharon', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8714, 'longitude': -73.4578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6079', 'place_name': 'Taconic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 42.032, 'longitude': -73.4038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6094', 'place_name': 'Winchester Center', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8963, 'longitude': -73.1463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6098', 'place_name': 'Winsted', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.9252, 'longitude': -73.0663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6750', 'place_name': 'Bantam', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.7215, 'longitude': -73.252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6751', 'place_name': 'Bethlehem', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6387, 'longitude': -73.2091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6752', 'place_name': 'Bridgewater', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.5287, 'longitude': -73.3609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6753', 'place_name': 'Cornwall', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8281, 'longitude': -73.3323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6754', 'place_name': 'Cornwall Bridge', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8187, 'longitude': -73.371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6755', 'place_name': 'Gaylordsville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6486, 'longitude': -73.4835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6756', 'place_name': 'Goshen', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8335, 'longitude': -73.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6757', 'place_name': 'Kent', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.7316, 'longitude': -73.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6758', 'place_name': 'Lakeside', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6754, 'longitude': -73.242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6759', 'place_name': 'Litchfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.7541, 'longitude': -73.2, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6763', 'place_name': 'Morris', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6881, 'longitude': -73.1765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6776', 'place_name': 'New Milford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.5817, 'longitude': -73.4128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6777', 'place_name': 'New Preston Marble Dale', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6903, 'longitude': -73.3103, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6778', 'place_name': 'Northfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.7077, 'longitude': -73.109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6779', 'place_name': 'Oakville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.5909, 'longitude': -73.0873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6781', 'place_name': 'Pequabuck', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6699, 'longitude': -72.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6782', 'place_name': 'Plymouth', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6611, 'longitude': -73.0449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6783', 'place_name': 'Roxbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.5509, 'longitude': -73.2993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6785', 'place_name': 'South Kent', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6951, 'longitude': -73.469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6786', 'place_name': 'Terryville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6762, 'longitude': -73.0092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6787', 'place_name': 'Thomaston', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6786, 'longitude': -73.0886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6790', 'place_name': 'Torrington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8131, 'longitude': -73.1156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6791', 'place_name': 'Harwinton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.7701, 'longitude': -73.0728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6792', 'place_name': 'Torrington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.7549, 'longitude': -73.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6793', 'place_name': 'Washington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6296, 'longitude': -73.2884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6794', 'place_name': 'Washington Depot', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6559, 'longitude': -73.3274, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6795', 'place_name': 'Watertown', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.6057, 'longitude': -73.1221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6796', 'place_name': 'West Cornwall', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.8689, 'longitude': -73.3313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6798', 'place_name': 'Woodbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Litchfield', 'locality_code': '5', 'latitude': 41.5521, 'longitude': -73.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6409', 'place_name': 'Centerbrook', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.3474, 'longitude': -72.4173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6412', 'place_name': 'Chester', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.4049, 'longitude': -72.4643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6413', 'place_name': 'Clinton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.2912, 'longitude': -72.528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6414', 'place_name': 'Cobalt', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5667, 'longitude': -72.5581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6416', 'place_name': 'Cromwell', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.6105, 'longitude': -72.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6417', 'place_name': 'Deep River', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.3765, 'longitude': -72.4486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6419', 'place_name': 'Killingworth', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.3696, 'longitude': -72.5712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6422', 'place_name': 'Durham', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.465, 'longitude': -72.6875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6423', 'place_name': 'East Haddam', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.4696, 'longitude': -72.4059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6424', 'place_name': 'East Hampton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5761, 'longitude': -72.5093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6426', 'place_name': 'Essex', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.3549, 'longitude': -72.3965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6438', 'place_name': 'Haddam', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.4627, 'longitude': -72.505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6441', 'place_name': 'Higganum', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.4682, 'longitude': -72.5751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6442', 'place_name': 'Ivoryton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.3421, 'longitude': -72.4404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6455', 'place_name': 'Middlefield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5168, 'longitude': -72.7186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6456', 'place_name': 'Middle Haddam', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.554, 'longitude': -72.5501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6457', 'place_name': 'Middletown', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5569, 'longitude': -72.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6459', 'place_name': 'Middletown', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5565, 'longitude': -72.6582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6469', 'place_name': 'Moodus', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5078, 'longitude': -72.4419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6475', 'place_name': 'Old Saybrook', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.2913, 'longitude': -72.385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6480', 'place_name': 'Portland', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5852, 'longitude': -72.6128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6481', 'place_name': 'Rockfall', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.5341, 'longitude': -72.6997, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6498', 'place_name': 'Westbrook', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Middlesex', 'locality_code': '7', 'latitude': 41.2927, 'longitude': -72.4563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6401', 'place_name': 'Ansonia', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3427, 'longitude': -73.0742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6403', 'place_name': 'Beacon Falls', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.4369, 'longitude': -73.0597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6405', 'place_name': 'Branford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.28, 'longitude': -72.8106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6408', 'place_name': 'Cheshire', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3657, 'longitude': -72.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6410', 'place_name': 'Cheshire', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5055, 'longitude': -72.9081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6411', 'place_name': 'Cheshire', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.499, 'longitude': -72.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6418', 'place_name': 'Derby', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3229, 'longitude': -73.08, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6437', 'place_name': 'Guilford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3154, 'longitude': -72.6968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6443', 'place_name': 'Madison', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.309, 'longitude': -72.6153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6450', 'place_name': 'Meriden', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5334, 'longitude': -72.7997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6451', 'place_name': 'Meriden', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5401, 'longitude': -72.8189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6460', 'place_name': 'Milford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.2175, 'longitude': -73.0549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6461', 'place_name': 'Milford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.2338, 'longitude': -73.0747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6471', 'place_name': 'North Branford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3323, 'longitude': -72.7809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6472', 'place_name': 'Northford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3962, 'longitude': -72.7809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6473', 'place_name': 'North Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3822, 'longitude': -72.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6477', 'place_name': 'Orange', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.2815, 'longitude': -73.0287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6478', 'place_name': 'Oxford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.4202, 'longitude': -73.1296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6483', 'place_name': 'Seymour', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3862, 'longitude': -73.0817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6487', 'place_name': 'South Britain', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.4709, 'longitude': -73.2515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6488', 'place_name': 'Southbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.4767, 'longitude': -73.2241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6492', 'place_name': 'Wallingford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.46, 'longitude': -72.8222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6493', 'place_name': 'Wallingford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3657, 'longitude': -72.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6494', 'place_name': 'Wallingford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3657, 'longitude': -72.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6495', 'place_name': 'Wallingford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3885, 'longitude': -72.8795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6501', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6502', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6503', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6504', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3657, 'longitude': -72.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6505', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6506', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6507', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6508', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6509', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6510', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3087, 'longitude': -72.9271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6511', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3184, 'longitude': -72.9318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6512', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6513', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3072, 'longitude': -72.8654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6514', 'place_name': 'Hamden', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.362, 'longitude': -72.9361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6515', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3293, 'longitude': -72.9664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6516', 'place_name': 'West Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.2701, 'longitude': -72.9638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6517', 'place_name': 'Hamden', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3484, 'longitude': -72.9117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6518', 'place_name': 'Hamden', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.4097, 'longitude': -72.911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6519', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.2963, 'longitude': -72.9373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6520', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6521', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6524', 'place_name': 'Bethany', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.4262, 'longitude': -73.0007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6525', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6530', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6531', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6532', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6533', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6534', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6535', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6536', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3082, 'longitude': -72.9282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6537', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3657, 'longitude': -72.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6538', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.3657, 'longitude': -72.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6540', 'place_name': 'New Haven', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.2996, 'longitude': -72.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6701', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6702', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5566, 'longitude': -73.0385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6703', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6704', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5754, 'longitude': -73.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6705', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5503, 'longitude': -72.9963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6706', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5363, 'longitude': -73.0306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6708', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5511, 'longitude': -73.0645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6710', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5675, 'longitude': -73.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6712', 'place_name': 'Prospect', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5022, 'longitude': -72.9788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6716', 'place_name': 'Wolcott', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.597, 'longitude': -72.9828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6720', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6721', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6722', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6723', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6724', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6725', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6726', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6749', 'place_name': 'Waterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5582, 'longitude': -73.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6762', 'place_name': 'Middlebury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.5343, 'longitude': -73.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6770', 'place_name': 'Naugatuck', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New Haven', 'locality_code': '9', 'latitude': 41.492, 'longitude': -73.0493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6249', 'place_name': 'Lebanon', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.633, 'longitude': -72.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6254', 'place_name': 'North Franklin', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.6161, 'longitude': -72.1425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6320', 'place_name': 'New London', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3507, 'longitude': -72.1062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6330', 'place_name': 'Baltic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.6263, 'longitude': -72.0775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6333', 'place_name': 'East Lyme', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3668, 'longitude': -72.233, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6334', 'place_name': 'Bozrah', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5465, 'longitude': -72.1711, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6335', 'place_name': 'Gales Ferry', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4285, 'longitude': -72.0672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6336', 'place_name': 'Gilman', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5795, 'longitude': -72.1963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6338', 'place_name': 'Mashantucket', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4757, 'longitude': -71.9574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6339', 'place_name': 'Ledyard', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4401, 'longitude': -71.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6340', 'place_name': 'Groton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3572, 'longitude': -72.0579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6349', 'place_name': 'Groton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3997, 'longitude': -72.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6350', 'place_name': 'Hanover', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.6445, 'longitude': -72.0677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6351', 'place_name': 'Jewett City', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.6052, 'longitude': -71.9808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6353', 'place_name': 'Montville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.479, 'longitude': -72.1512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6355', 'place_name': 'Mystic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3616, 'longitude': -71.9774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6357', 'place_name': 'Niantic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3253, 'longitude': -72.2108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6359', 'place_name': 'North Stonington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4531, 'longitude': -71.8727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6360', 'place_name': 'Norwich', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5371, 'longitude': -72.0849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6365', 'place_name': 'Preston', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5224, 'longitude': -71.9934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6370', 'place_name': 'Oakdale', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4706, 'longitude': -72.1904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6371', 'place_name': 'Old Lyme', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3347, 'longitude': -72.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6372', 'place_name': 'Old Mystic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3882, 'longitude': -71.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6375', 'place_name': 'Quaker Hill', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4032, 'longitude': -72.1172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6376', 'place_name': 'South Lyme', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.2967, 'longitude': -72.2633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6378', 'place_name': 'Stonington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3664, 'longitude': -71.9155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6379', 'place_name': 'Pawcatuck', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3735, 'longitude': -71.8478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6380', 'place_name': 'Taftville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5653, 'longitude': -72.0529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6382', 'place_name': 'Uncasville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4622, 'longitude': -72.1126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6383', 'place_name': 'Versailles', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.6016, 'longitude': -72.0404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6384', 'place_name': 'Voluntown', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5831, 'longitude': -71.855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6385', 'place_name': 'Waterford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3469, 'longitude': -72.1458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6388', 'place_name': 'West Mystic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.3441, 'longitude': -71.9765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6389', 'place_name': 'Yantic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5598, 'longitude': -72.1237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6415', 'place_name': 'Colchester', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5662, 'longitude': -72.3441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6420', 'place_name': 'Salem', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4966, 'longitude': -72.2725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6439', 'place_name': 'Hadlyme', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.4212, 'longitude': -72.4141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6474', 'place_name': 'North Westchester', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'New London', 'locality_code': '11', 'latitude': 41.5809, 'longitude': -72.4012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6029', 'place_name': 'Ellington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.9114, 'longitude': -72.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6043', 'place_name': 'Bolton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.7689, 'longitude': -72.4396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6066', 'place_name': 'Vernon Rockville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.8501, 'longitude': -72.4649, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6071', 'place_name': 'Somers', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.9978, 'longitude': -72.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6072', 'place_name': 'Somersville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.9765, 'longitude': -72.4906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6075', 'place_name': 'Stafford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.9848, 'longitude': -72.289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6076', 'place_name': 'Stafford Springs', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.9661, 'longitude': -72.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6077', 'place_name': 'Staffordville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.9916, 'longitude': -72.2577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6084', 'place_name': 'Tolland', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.8696, 'longitude': -72.3718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6231', 'place_name': 'Amston', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.629, 'longitude': -72.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6232', 'place_name': 'Andover', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.7332, 'longitude': -72.3767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6237', 'place_name': 'Columbia', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.6973, 'longitude': -72.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6238', 'place_name': 'Coventry', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.7822, 'longitude': -72.3332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6248', 'place_name': 'Hebron', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.6842, 'longitude': -72.3986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6250', 'place_name': 'Mansfield Center', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.7698, 'longitude': -72.2011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6251', 'place_name': 'Mansfield Depot', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.7993, 'longitude': -72.3065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6265', 'place_name': 'South Willington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.8554, 'longitude': -72.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6268', 'place_name': 'Storrs Mansfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.7997, 'longitude': -72.2478, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6269', 'place_name': 'Storrs Mansfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.808, 'longitude': -72.251, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6279', 'place_name': 'Willington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Tolland', 'locality_code': '13', 'latitude': 41.8966, 'longitude': -72.2622, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6226', 'place_name': 'Willimantic', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7149, 'longitude': -72.2134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6230', 'place_name': 'Abington', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.8473, 'longitude': -72.0253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6233', 'place_name': 'Ballouville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.8768, 'longitude': -71.8612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6234', 'place_name': 'Brooklyn', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7807, 'longitude': -71.9541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6235', 'place_name': 'Chaplin', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.8026, 'longitude': -72.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6239', 'place_name': 'Danielson', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7982, 'longitude': -71.8807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6241', 'place_name': 'Dayville', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.854, 'longitude': -71.8683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6242', 'place_name': 'Eastford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.8771, 'longitude': -72.0895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6243', 'place_name': 'East Killingly', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.8452, 'longitude': -71.8026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6244', 'place_name': 'East Woodstock', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9843, 'longitude': -71.981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6245', 'place_name': 'Fabyan', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 42.0198, 'longitude': -71.9417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6246', 'place_name': 'Grosvenor Dale', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9711, 'longitude': -71.8917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6247', 'place_name': 'Hampton', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7671, 'longitude': -72.0662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6255', 'place_name': 'North Grosvenordale', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9784, 'longitude': -71.8997, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '6256', 'place_name': 'North Windham', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7451, 'longitude': -72.1601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6258', 'place_name': 'Pomfret', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.889, 'longitude': -71.9682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6259', 'place_name': 'Pomfret Center', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.8697, 'longitude': -71.982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6260', 'place_name': 'Putnam', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9185, 'longitude': -71.8968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6262', 'place_name': 'Quinebaug', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 42.0217, 'longitude': -71.9391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6263', 'place_name': 'Rogers', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.8391, 'longitude': -71.9063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6264', 'place_name': 'Scotland', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.6958, 'longitude': -72.087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6266', 'place_name': 'South Windham', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.6677, 'longitude': -72.1681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6267', 'place_name': 'South Woodstock', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9439, 'longitude': -71.9453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6277', 'place_name': 'Thompson', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9803, 'longitude': -71.8376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6278', 'place_name': 'Ashford', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.889, 'longitude': -72.1476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6280', 'place_name': 'Windham', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7027, 'longitude': -72.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6281', 'place_name': 'Woodstock', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9602, 'longitude': -72.004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6282', 'place_name': 'Woodstock Valley', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.9153, 'longitude': -72.0937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6331', 'place_name': 'Canterbury', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.6844, 'longitude': -72.001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6332', 'place_name': 'Central Village', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7229, 'longitude': -71.9067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6354', 'place_name': 'Moosup', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.721, 'longitude': -71.885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6373', 'place_name': 'Oneco', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.6937, 'longitude': -71.8084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6374', 'place_name': 'Plainfield', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.6775, 'longitude': -71.922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6377', 'place_name': 'Sterling', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7156, 'longitude': -71.8196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6387', 'place_name': 'Wauregan', 'state': 'Connecticut', 'state_ab': 'CT', 'county': 'Windham', 'locality_code': '15', 'latitude': 41.7445, 'longitude': -71.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20001', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9122, 'longitude': -77.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20002', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9024, 'longitude': -76.9901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20003', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8829, 'longitude': -76.9895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20004', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.893, 'longitude': -77.0263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20005', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9067, 'longitude': -77.0312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20006', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8964, 'longitude': -77.0447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20007', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9144, 'longitude': -77.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20008', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9363, 'longitude': -77.0599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20009', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9202, 'longitude': -77.0375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20010', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9327, 'longitude': -77.0322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20011', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9518, 'longitude': -77.0203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20012', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9757, 'longitude': -77.0282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20013', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20015', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9658, 'longitude': -77.068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20016', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9381, 'longitude': -77.086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20017', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9367, 'longitude': -76.994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20018', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9277, 'longitude': -76.9762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20019', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8902, 'longitude': -76.9376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20020', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.86, 'longitude': -76.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20022', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.945, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20024', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8759, 'longitude': -77.016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20026', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20027', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9007, 'longitude': -77.0501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20029', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20030', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20032', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8338, 'longitude': -76.9995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20033', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20035', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20036', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9087, 'longitude': -77.0414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20037', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9014, 'longitude': -77.0504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20038', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20039', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20040', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20041', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20042', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20043', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20044', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20045', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8966, 'longitude': -77.0319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20047', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20049', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8959, 'longitude': -77.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20050', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20052', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9001, 'longitude': -77.0479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20053', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20055', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9016, 'longitude': -77.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20056', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20057', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20058', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20059', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20060', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.918, 'longitude': -77.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20061', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20062', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9, 'longitude': -77.0369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20063', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9053, 'longitude': -77.0466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20064', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9332, 'longitude': -76.9963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20065', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8834, 'longitude': -77.0282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20066', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20067', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20068', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20069', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20070', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20071', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20073', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.897, 'longitude': -77.0251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20074', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20075', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20076', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20077', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20078', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20080', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20081', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20082', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20090', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20091', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20201', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20202', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20203', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9053, 'longitude': -77.0466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20204', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20206', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20207', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20208', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8966, 'longitude': -77.0117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20210', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20211', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20212', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20213', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20214', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20215', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20216', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8919, 'longitude': -77.0141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20217', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20218', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20219', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20220', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20221', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20222', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20223', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20224', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20226', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20227', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20228', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20229', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20230', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20232', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9006, 'longitude': -77.0391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20233', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20235', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9154, 'longitude': -77.0572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20237', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.895, 'longitude': -77.0367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20238', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20239', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20240', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8971, 'longitude': -77.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20241', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20242', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8678, 'longitude': -77.0289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20244', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20245', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20250', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8873, 'longitude': -77.0327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20251', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20252', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9584, 'longitude': -77.0519, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20254', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20260', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20261', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20262', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20265', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20266', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20268', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20270', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20277', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20289', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20299', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20301', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8894, 'longitude': -77.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20303', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20306', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20310', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20314', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20317', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9363, 'longitude': -77.0123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20318', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20319', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8667, 'longitude': -77.0166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20330', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20340', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20350', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20355', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20370', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20372', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20373', 'place_name': 'Naval Anacost Annex', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20374', 'place_name': 'Washington Navy Yard', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20375', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8262, 'longitude': -77.0174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20376', 'place_name': 'Washington Navy Yard', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9164, 'longitude': -76.9947, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20380', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20388', 'place_name': 'Washington Navy Yard', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20389', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20390', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20391', 'place_name': 'Washington Navy Yard', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20392', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20393', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20394', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20395', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20398', 'place_name': 'Washington Navy Yard', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20401', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20402', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20403', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20404', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8992, 'longitude': -77.0089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20405', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20406', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20407', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20408', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20409', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20410', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20411', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.884, 'longitude': -77.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20412', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8953, 'longitude': -77.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20413', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20414', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.884, 'longitude': -77.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20415', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20416', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20417', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.907, 'longitude': -77.0058, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20418', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9043, 'longitude': -77.0572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20419', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20420', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9035, 'longitude': -77.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20421', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20422', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20423', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20424', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20425', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20426', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20427', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9021, 'longitude': -77.0476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20428', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20429', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20431', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8986, 'longitude': -77.0428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20433', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9, 'longitude': -77.042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20434', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20435', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8994, 'longitude': -77.0403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20436', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8959, 'longitude': -77.0211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20437', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9028, 'longitude': -77.0485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20439', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20440', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9139, 'longitude': -77.0453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20441', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9239, 'longitude': -77.0363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20442', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.896, 'longitude': -77.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20444', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20447', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8847, 'longitude': -77.0252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20451', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8977, 'longitude': -77.0444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20453', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20456', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8981, 'longitude': -77.0401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20460', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8764, 'longitude': -77.0188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20463', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20468', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20469', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20470', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20472', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20500', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8946, 'longitude': -77.0355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20501', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8987, 'longitude': -77.0362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20502', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8987, 'longitude': -77.0362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20503', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9007, 'longitude': -77.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20504', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20505', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20506', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8994, 'longitude': -77.0377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20507', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20508', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20509', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8987, 'longitude': -77.0356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20510', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20511', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20515', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20520', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8932, 'longitude': -77.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20521', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20522', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8932, 'longitude': -77.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20523', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8945, 'longitude': -77.0478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20524', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9024, 'longitude': -77.0326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20525', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20526', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9022, 'longitude': -77.0437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20527', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9029, 'longitude': -77.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20528', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20529', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8973, 'longitude': -77.0142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20530', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8976, 'longitude': -77.027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20531', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8938, 'longitude': -77.0218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20533', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9011, 'longitude': -77.0326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20534', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8941, 'longitude': -77.0125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20535', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8941, 'longitude': -77.0251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20536', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9012, 'longitude': -77.0169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20537', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8941, 'longitude': -77.0251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20538', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20539', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20540', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8874, 'longitude': -77.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20541', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8874, 'longitude': -77.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20542', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9408, 'longitude': -77.0283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20543', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20544', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20546', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.891, 'longitude': -77.0211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20547', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20548', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8981, 'longitude': -77.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20549', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20551', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.892, 'longitude': -77.0452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20552', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20553', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8873, 'longitude': -77.0231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20554', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20555', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9, 'longitude': -77.0401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20557', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8874, 'longitude': -77.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20559', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8874, 'longitude': -77.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20560', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20565', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8919, 'longitude': -77.0189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20566', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8971, 'longitude': -77.0554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20570', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8991, 'longitude': -77.0401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20571', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9006, 'longitude': -77.0346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20572', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20573', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20575', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20576', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8937, 'longitude': -77.0236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20577', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9008, 'longitude': -77.0345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20578', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20579', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9043, 'longitude': -77.0446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20580', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20581', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20585', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20586', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.9022, 'longitude': -77.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20590', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.884, 'longitude': -77.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20591', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20593', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20594', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8849, 'longitude': -77.0184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20597', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20599', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8933, 'longitude': -77.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56901', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8952, 'longitude': -77.0365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56915', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8952, 'longitude': -77.0365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56920', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8952, 'longitude': -77.0365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56933', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8952, 'longitude': -77.0365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56944', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8952, 'longitude': -77.0365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56972', 'place_name': 'Washington', 'state': 'District of Columbia', 'state_ab': 'DC', 'county': 'District of Columbia', 'locality_code': '1', 'latitude': 38.8951, 'longitude': -77.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19901', 'place_name': 'Dover', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.1564, 'longitude': -75.4955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19902', 'place_name': 'Dover Afb', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.1253, 'longitude': -75.4818, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19903', 'place_name': 'Dover', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.1087, 'longitude': -75.448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19904', 'place_name': 'Dover', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.1605, 'longitude': -75.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19905', 'place_name': 'Dover', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.1582, 'longitude': -75.5244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19906', 'place_name': 'Dover', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.157, 'longitude': -75.5294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19934', 'place_name': 'Camden Wyoming', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.0991, 'longitude': -75.5966, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19936', 'place_name': 'Cheswold', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.2184, 'longitude': -75.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19938', 'place_name': 'Clayton', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.2564, 'longitude': -75.6904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19943', 'place_name': 'Felton', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.0225, 'longitude': -75.5829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19946', 'place_name': 'Frederica', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.0342, 'longitude': -75.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19952', 'place_name': 'Harrington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 38.924, 'longitude': -75.5843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19953', 'place_name': 'Hartly', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.1542, 'longitude': -75.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19954', 'place_name': 'Houston', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 38.9114, 'longitude': -75.5064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19955', 'place_name': 'Kenton', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.2256, 'longitude': -75.6642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19961', 'place_name': 'Little Creek', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.1663, 'longitude': -75.4483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19962', 'place_name': 'Magnolia', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.0735, 'longitude': -75.5083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19964', 'place_name': 'Marydel', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.0998, 'longitude': -75.7287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19977', 'place_name': 'Smyrna', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.2934, 'longitude': -75.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19979', 'place_name': 'Viola', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.0419, 'longitude': -75.5726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19980', 'place_name': 'Woodside', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Kent', 'locality_code': '1', 'latitude': 39.0724, 'longitude': -75.5711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19701', 'place_name': 'Bear', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.6102, 'longitude': -75.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19702', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.6349, 'longitude': -75.6993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19703', 'place_name': 'Claymont', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.8044, 'longitude': -75.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19706', 'place_name': 'Delaware City', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5725, 'longitude': -75.5957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19707', 'place_name': 'Hockessin', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.776, 'longitude': -75.6889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19708', 'place_name': 'Kirkwood', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5776, 'longitude': -75.6901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19709', 'place_name': 'Middletown', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.4815, 'longitude': -75.6832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19710', 'place_name': 'Montchanin', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7898, 'longitude': -75.5891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19711', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7011, 'longitude': -75.7375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19712', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19713', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.6699, 'longitude': -75.7151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19714', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19715', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19716', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.6896, 'longitude': -75.7584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19717', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.6837, 'longitude': -75.7497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19718', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19720', 'place_name': 'New Castle', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5929, 'longitude': -75.6515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19721', 'place_name': 'New Castle', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19725', 'place_name': 'Newark', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19726', 'place_name': 'New Castle', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.6621, 'longitude': -75.5663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19730', 'place_name': 'Odessa', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.4592, 'longitude': -75.6536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19731', 'place_name': 'Port Penn', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5129, 'longitude': -75.5852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19732', 'place_name': 'Rockland', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7939, 'longitude': -75.5738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19733', 'place_name': 'Saint Georges', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5555, 'longitude': -75.6505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19734', 'place_name': 'Townsend', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.3819, 'longitude': -75.6834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19735', 'place_name': 'Winterthur', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.8029, 'longitude': -75.5916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19736', 'place_name': 'Yorklyn', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.8082, 'longitude': -75.6755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19801', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7378, 'longitude': -75.5497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19802', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7564, 'longitude': -75.534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19803', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7994, 'longitude': -75.5317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19804', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7168, 'longitude': -75.6184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19805', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7434, 'longitude': -75.5827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19806', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7571, 'longitude': -75.5635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19807', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7949, 'longitude': -75.6161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19808', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7359, 'longitude': -75.6647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19809', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7647, 'longitude': -75.5069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19810', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.8188, 'longitude': -75.5064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19850', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19880', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19884', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19885', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19886', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19890', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19891', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19892', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19893', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19894', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19895', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19896', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19897', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.5645, 'longitude': -75.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19898', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19899', 'place_name': 'Wilmington', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'New Castle', 'locality_code': '3', 'latitude': 39.7459, 'longitude': -75.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19930', 'place_name': 'Bethany Beach', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.531, 'longitude': -75.0674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19931', 'place_name': 'Bethel', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.5685, 'longitude': -75.6243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19933', 'place_name': 'Bridgeville', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.7366, 'longitude': -75.6088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19939', 'place_name': 'Dagsboro', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.5596, 'longitude': -75.2113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19940', 'place_name': 'Delmar', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.477, 'longitude': -75.5759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19941', 'place_name': 'Ellendale', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.8057, 'longitude': -75.4056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19944', 'place_name': 'Fenwick Island', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.4865, 'longitude': -75.0589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19945', 'place_name': 'Frankford', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.5177, 'longitude': -75.2006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19947', 'place_name': 'Georgetown', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.679, 'longitude': -75.3932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19950', 'place_name': 'Greenwood', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.8175, 'longitude': -75.5935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19951', 'place_name': 'Harbeson', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.6723, 'longitude': -75.2236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19956', 'place_name': 'Laurel', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.5537, 'longitude': -75.5631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19958', 'place_name': 'Lewes', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.7381, 'longitude': -75.1747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19960', 'place_name': 'Lincoln', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.8613, 'longitude': -75.4, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19963', 'place_name': 'Milford', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.9218, 'longitude': -75.4299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19966', 'place_name': 'Millsboro', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.6595, 'longitude': -75.2464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19967', 'place_name': 'Millville', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.5496, 'longitude': -75.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19968', 'place_name': 'Milton', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.7687, 'longitude': -75.2953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19969', 'place_name': 'Nassau', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.7521, 'longitude': -75.1877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19970', 'place_name': 'Ocean View', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.5617, 'longitude': -75.0966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19971', 'place_name': 'Rehoboth Beach', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.7209, 'longitude': -75.076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19973', 'place_name': 'Seaford', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.6404, 'longitude': -75.6041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19975', 'place_name': 'Selbyville', 'state': 'Delaware', 'state_ab': 'DE', 'county': 'Sussex', 'locality_code': '5', 'latitude': 38.4654, 'longitude': -75.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32601', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6489, 'longitude': -82.325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32602', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6299, 'longitude': -82.3966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32603', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6515, 'longitude': -82.3493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32604', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.5733, 'longitude': -82.3979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32605', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6785, 'longitude': -82.3679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32606', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6954, 'longitude': -82.4023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32607', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6456, 'longitude': -82.4033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32608', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6132, 'longitude': -82.3873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32609', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.7005, 'longitude': -82.308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32610', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6813, 'longitude': -82.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32611', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6813, 'longitude': -82.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32612', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6813, 'longitude': -82.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32614', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6813, 'longitude': -82.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32615', 'place_name': 'Alachua', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.8135, 'longitude': -82.472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32616', 'place_name': 'Alachua', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.792, 'longitude': -82.496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32618', 'place_name': 'Archer', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.5597, 'longitude': -82.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32627', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6516, 'longitude': -82.3248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32631', 'place_name': 'Earleton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.7439, 'longitude': -82.1034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32633', 'place_name': 'Evinston', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.4869, 'longitude': -82.2312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32635', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6813, 'longitude': -82.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32640', 'place_name': 'Hawthorne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.574, 'longitude': -82.1056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32641', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6824, 'longitude': -82.2014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32643', 'place_name': 'High Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.841, 'longitude': -82.6156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32653', 'place_name': 'Gainesville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.7728, 'longitude': -82.3782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32654', 'place_name': 'Island Grove', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.4536, 'longitude': -82.1065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32655', 'place_name': 'High Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.8175, 'longitude': -82.6006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32658', 'place_name': 'La Crosse', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.8433, 'longitude': -82.4048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32662', 'place_name': 'Lochloosa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.5116, 'longitude': -82.1004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32667', 'place_name': 'Micanopy', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.5122, 'longitude': -82.3053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32669', 'place_name': 'Newberry', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.6609, 'longitude': -82.5852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32694', 'place_name': 'Waldo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Alachua', 'locality_code': '1', 'latitude': 29.7871, 'longitude': -82.1608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32040', 'place_name': 'Glen Saint Mary', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Baker', 'locality_code': '3', 'latitude': 30.2861, 'longitude': -82.2041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32063', 'place_name': 'Macclenny', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Baker', 'locality_code': '3', 'latitude': 30.2737, 'longitude': -82.1325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32072', 'place_name': 'Olustee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Baker', 'locality_code': '3', 'latitude': 30.2041, 'longitude': -82.4287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32087', 'place_name': 'Sanderson', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Baker', 'locality_code': '3', 'latitude': 30.2522, 'longitude': -82.2729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32401', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.1606, 'longitude': -85.6494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32402', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.2345, 'longitude': -85.692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32403', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.0583, 'longitude': -85.5762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32404', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.1653, 'longitude': -85.5763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32405', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.1949, 'longitude': -85.6727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32406', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.2345, 'longitude': -85.692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32407', 'place_name': 'Panama City Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.2007, 'longitude': -85.8136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32408', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.1655, 'longitude': -85.7116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32409', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.3117, 'longitude': -85.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32410', 'place_name': 'Mexico Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 29.9395, 'longitude': -85.4096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32411', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.2345, 'longitude': -85.692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32412', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.2345, 'longitude': -85.692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32413', 'place_name': 'Panama City Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.3105, 'longitude': -85.9106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32417', 'place_name': 'Panama City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.1595, 'longitude': -85.6598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32438', 'place_name': 'Fountain', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.4753, 'longitude': -85.4293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32444', 'place_name': 'Lynn Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.2362, 'longitude': -85.6467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32466', 'place_name': 'Youngstown', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bay', 'locality_code': '5', 'latitude': 30.3269, 'longitude': -85.5169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32042', 'place_name': 'Graham', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bradford', 'locality_code': '7', 'latitude': 29.9689, 'longitude': -82.1226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32044', 'place_name': 'Hampton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bradford', 'locality_code': '7', 'latitude': 29.8575, 'longitude': -82.1483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32058', 'place_name': 'Lawtey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bradford', 'locality_code': '7', 'latitude': 30.0472, 'longitude': -82.1055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32091', 'place_name': 'Starke', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bradford', 'locality_code': '7', 'latitude': 29.9583, 'longitude': -82.1185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32622', 'place_name': 'Brooker', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Bradford', 'locality_code': '7', 'latitude': 29.919, 'longitude': -82.2956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32754', 'place_name': 'Mims', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.6974, 'longitude': -80.8663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32775', 'place_name': 'Scottsmoor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.7702, 'longitude': -80.872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32780', 'place_name': 'Titusville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.5697, 'longitude': -80.8191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32781', 'place_name': 'Titusville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.6122, 'longitude': -80.8076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32783', 'place_name': 'Titusville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.6122, 'longitude': -80.8076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32796', 'place_name': 'Titusville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.6271, 'longitude': -80.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32815', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3067, 'longitude': -80.6862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32899', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3067, 'longitude': -80.6862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32901', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0691, 'longitude': -80.62, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32902', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0836, 'longitude': -80.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32903', 'place_name': 'Indialantic', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.1091, 'longitude': -80.5787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32904', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0673, 'longitude': -80.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32905', 'place_name': 'Palm Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0313, 'longitude': -80.5995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32906', 'place_name': 'Palm Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0671, 'longitude': -80.6503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32907', 'place_name': 'Palm Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0168, 'longitude': -80.6739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32908', 'place_name': 'Palm Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 27.9816, 'longitude': -80.6894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32909', 'place_name': 'Palm Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 27.9694, 'longitude': -80.6473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32910', 'place_name': 'Palm Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0345, 'longitude': -80.5887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32911', 'place_name': 'Palm Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0345, 'longitude': -80.5887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32912', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0836, 'longitude': -80.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32919', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0836, 'longitude': -80.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32920', 'place_name': 'Cape Canaveral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3903, 'longitude': -80.6043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32922', 'place_name': 'Cocoa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3672, 'longitude': -80.7465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32923', 'place_name': 'Cocoa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.4275, 'longitude': -80.829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32924', 'place_name': 'Cocoa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3067, 'longitude': -80.6862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32925', 'place_name': 'Patrick Afb', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.1743, 'longitude': -80.584, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32926', 'place_name': 'Cocoa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.391, 'longitude': -80.787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32927', 'place_name': 'Cocoa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.4566, 'longitude': -80.7978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32931', 'place_name': 'Cocoa Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3325, 'longitude': -80.6121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32932', 'place_name': 'Cocoa Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3206, 'longitude': -80.6092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32934', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.1331, 'longitude': -80.7112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32935', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.1384, 'longitude': -80.6524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32936', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0836, 'longitude': -80.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32937', 'place_name': 'Satellite Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.178, 'longitude': -80.602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32940', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.2061, 'longitude': -80.685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32941', 'place_name': 'Melbourne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 27.9246, 'longitude': -80.5235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32949', 'place_name': 'Grant', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 27.9289, 'longitude': -80.5264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32950', 'place_name': 'Malabar', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 27.9761, 'longitude': -80.5788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32951', 'place_name': 'Melbourne Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.0219, 'longitude': -80.5389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32952', 'place_name': 'Merritt Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.2764, 'longitude': -80.6568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32953', 'place_name': 'Merritt Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3888, 'longitude': -80.7301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32954', 'place_name': 'Merritt Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.5392, 'longitude': -80.672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32955', 'place_name': 'Rockledge', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3134, 'longitude': -80.7319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32956', 'place_name': 'Rockledge', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3298, 'longitude': -80.7323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32959', 'place_name': 'Sharpes', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 28.3067, 'longitude': -80.6862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32976', 'place_name': 'Sebastian', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Brevard', 'locality_code': '9', 'latitude': 27.8679, 'longitude': -80.5416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33004', 'place_name': 'Dania', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0476, 'longitude': -80.1447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33008', 'place_name': 'Hallandale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 25.9812, 'longitude': -80.1484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33009', 'place_name': 'Hallandale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 25.985, 'longitude': -80.1407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33019', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.007, 'longitude': -80.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33020', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0161, 'longitude': -80.1517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33021', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0218, 'longitude': -80.1891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33022', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0134, 'longitude': -80.1442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33023', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 25.9894, 'longitude': -80.2153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33024', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0296, 'longitude': -80.2489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33025', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 25.9921, 'longitude': -80.2712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33026', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0229, 'longitude': -80.2974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33027', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 25.9974, 'longitude': -80.3248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33028', 'place_name': 'Pembroke Pines', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0185, 'longitude': -80.3449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33029', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 25.9924, 'longitude': -80.4089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33060', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2315, 'longitude': -80.1235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33061', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2539, 'longitude': -80.1342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33062', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2343, 'longitude': -80.0941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33063', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2674, 'longitude': -80.2092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33064', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2785, 'longitude': -80.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33065', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2729, 'longitude': -80.2603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33066', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2535, 'longitude': -80.1775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33067', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.3033, 'longitude': -80.2415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33068', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.216, 'longitude': -80.2205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33069', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2288, 'longitude': -80.1635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33071', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2435, 'longitude': -80.2601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33072', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2335, 'longitude': -80.0924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33073', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2997, 'longitude': -80.181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33074', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2379, 'longitude': -80.1248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33075', 'place_name': 'Coral Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2712, 'longitude': -80.2706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33076', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.3168, 'longitude': -80.2753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33077', 'place_name': 'Pompano Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2379, 'longitude': -80.1248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33081', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0112, 'longitude': -80.1495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33082', 'place_name': 'Pembroke Pines', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0031, 'longitude': -80.2239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33083', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0112, 'longitude': -80.1495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33084', 'place_name': 'Hollywood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0112, 'longitude': -80.1495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33093', 'place_name': 'Margate', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2445, 'longitude': -80.2064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33097', 'place_name': 'Coconut Creek', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.2517, 'longitude': -80.1789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33301', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1216, 'longitude': -80.1288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33302', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33303', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1969, 'longitude': -80.0952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33304', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1387, 'longitude': -80.1218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33305', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1497, 'longitude': -80.1229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33306', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1656, 'longitude': -80.1118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33307', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33308', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0984, 'longitude': -80.1822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33309', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1817, 'longitude': -80.1746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33310', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1443, 'longitude': -80.2069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33311', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1421, 'longitude': -80.1728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33312', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0968, 'longitude': -80.181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33313', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1487, 'longitude': -80.2075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33314', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0697, 'longitude': -80.2246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33315', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0989, 'longitude': -80.1541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33316', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1042, 'longitude': -80.126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33317', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1122, 'longitude': -80.2264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33318', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1184, 'longitude': -80.252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33319', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1848, 'longitude': -80.2406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33320', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1625, 'longitude': -80.2582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33321', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.212, 'longitude': -80.2696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33322', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1502, 'longitude': -80.2745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33323', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.152, 'longitude': -80.3165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33324', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1255, 'longitude': -80.2644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33325', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1097, 'longitude': -80.3215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33326', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1158, 'longitude': -80.3681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33327', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1168, 'longitude': -80.4156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33328', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0671, 'longitude': -80.2723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33329', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33330', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0663, 'longitude': -80.3339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33331', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.048, 'longitude': -80.3749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33332', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0596, 'longitude': -80.4146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33334', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1845, 'longitude': -80.1344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33335', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.0892, 'longitude': -80.336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33336', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1219, 'longitude': -80.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33337', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.129, 'longitude': -80.2601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33338', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33339', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33340', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33345', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1654, 'longitude': -80.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33346', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33348', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33349', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33351', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1793, 'longitude': -80.2746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33355', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33359', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1223, 'longitude': -80.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33388', 'place_name': 'Plantation', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1342, 'longitude': -80.2318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33394', 'place_name': 'Fort Lauderdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.1221, 'longitude': -80.139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33441', 'place_name': 'Deerfield Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.3096, 'longitude': -80.0992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33442', 'place_name': 'Deerfield Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.3124, 'longitude': -80.1412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33443', 'place_name': 'Deerfield Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.3184, 'longitude': -80.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33973', 'place_name': 'Lehigh Acres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Broward', 'locality_code': '11', 'latitude': 26.602, 'longitude': -81.7311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32421', 'place_name': 'Altha', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 30.5319, 'longitude': -85.1704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32424', 'place_name': 'Blountstown', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 30.4394, 'longitude': -85.062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32430', 'place_name': 'Clarksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 30.3568, 'longitude': -85.1898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32449', 'place_name': 'Wewahitchka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 30.4059, 'longitude': -85.1974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33927', 'place_name': 'El Jobean', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9324, 'longitude': -82.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33938', 'place_name': 'Murdock', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.902, 'longitude': -82, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33946', 'place_name': 'Placida', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.8323, 'longitude': -82.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33947', 'place_name': 'Rotonda West', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.8842, 'longitude': -82.2691, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '33948', 'place_name': 'Port Charlotte', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9827, 'longitude': -82.1412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33949', 'place_name': 'Port Charlotte', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9939, 'longitude': -82.0984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33950', 'place_name': 'Punta Gorda', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9152, 'longitude': -82.0532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33951', 'place_name': 'Punta Gorda', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9708, 'longitude': -81.9845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33952', 'place_name': 'Port Charlotte', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9905, 'longitude': -82.0964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33953', 'place_name': 'Port Charlotte', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 27.004, 'longitude': -82.2117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33954', 'place_name': 'Port Charlotte', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 27.0228, 'longitude': -82.1108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33955', 'place_name': 'Punta Gorda', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.824, 'longitude': -81.9547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33980', 'place_name': 'Punta Gorda', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9298, 'longitude': -82.0454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33981', 'place_name': 'Port Charlotte', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9379, 'longitude': -82.2388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33982', 'place_name': 'Punta Gorda', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 26.9668, 'longitude': -81.9545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33983', 'place_name': 'Punta Gorda', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Charlotte', 'locality_code': '15', 'latitude': 27.0074, 'longitude': -82.0163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34423', 'place_name': 'Crystal River', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.867, 'longitude': -82.5727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34428', 'place_name': 'Crystal River', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9584, 'longitude': -82.5993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34429', 'place_name': 'Crystal River', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.8547, 'longitude': -82.6669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34433', 'place_name': 'Dunnellon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9949, 'longitude': -82.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34434', 'place_name': 'Dunnellon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9938, 'longitude': -82.4241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34436', 'place_name': 'Floral City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.7304, 'longitude': -82.3077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34441', 'place_name': 'Hernando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9311, 'longitude': -82.372, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34442', 'place_name': 'Hernando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9223, 'longitude': -82.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34445', 'place_name': 'Holder', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9669, 'longitude': -82.4207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34446', 'place_name': 'Homosassa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.7508, 'longitude': -82.5139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34447', 'place_name': 'Homosassa Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.8049, 'longitude': -82.5743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34448', 'place_name': 'Homosassa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.788, 'longitude': -82.568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34450', 'place_name': 'Inverness', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.834, 'longitude': -82.2822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34451', 'place_name': 'Inverness', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.8358, 'longitude': -82.3304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34452', 'place_name': 'Inverness', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.8358, 'longitude': -82.3304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34453', 'place_name': 'Inverness', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.8723, 'longitude': -82.3454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34460', 'place_name': 'Lecanto', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.8593, 'longitude': -82.5087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34461', 'place_name': 'Lecanto', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.8516, 'longitude': -82.4876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34464', 'place_name': 'Beverly Hills', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9169, 'longitude': -82.4582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34465', 'place_name': 'Beverly Hills', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.9295, 'longitude': -82.4892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34487', 'place_name': 'Homosassa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Citrus', 'locality_code': '17', 'latitude': 28.7814, 'longitude': -82.6151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32003', 'place_name': 'Fleming Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.0933, 'longitude': -81.719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32006', 'place_name': 'Fleming Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.107, 'longitude': -81.7167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32030', 'place_name': 'Doctors Inlet', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.1056, 'longitude': -81.769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32043', 'place_name': 'Green Cove Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 29.9983, 'longitude': -81.7647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32050', 'place_name': 'Middleburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.0689, 'longitude': -81.8604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32065', 'place_name': 'Orange Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.1382, 'longitude': -81.7742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32067', 'place_name': 'Orange Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.1661, 'longitude': -81.7065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32068', 'place_name': 'Middleburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.084, 'longitude': -81.8645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32073', 'place_name': 'Orange Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 30.1637, 'longitude': -81.7291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32079', 'place_name': 'Penney Farms', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 29.9849, 'longitude': -81.8022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32160', 'place_name': 'Lake Geneva', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 29.7683, 'longitude': -81.9907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32656', 'place_name': 'Keystone Heights', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Clay', 'locality_code': '19', 'latitude': 29.7976, 'longitude': -81.9899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34101', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1423, 'longitude': -81.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34102', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.134, 'longitude': -81.7953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34103', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1917, 'longitude': -81.8039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34104', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1529, 'longitude': -81.7417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34105', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1938, 'longitude': -81.7636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34106', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1423, 'longitude': -81.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34107', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1423, 'longitude': -81.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34108', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.2416, 'longitude': -81.8071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34109', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.2534, 'longitude': -81.7644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34110', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.2823, 'longitude': -81.7573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34112', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1184, 'longitude': -81.7361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34113', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.0426, 'longitude': -81.7182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34114', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.0143, 'longitude': -81.5856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34116', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1873, 'longitude': -81.711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34117', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1156, 'longitude': -81.5239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34119', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.2665, 'longitude': -81.7146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34120', 'place_name': 'Naples', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.3304, 'longitude': -81.5871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34137', 'place_name': 'Copeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 25.9542, 'longitude': -81.3575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34138', 'place_name': 'Chokoloskee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 25.8129, 'longitude': -81.362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34139', 'place_name': 'Everglades City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 25.857, 'longitude': -81.3778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34140', 'place_name': 'Goodland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 25.9248, 'longitude': -81.6456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34141', 'place_name': 'Ochopee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 25.8734, 'longitude': -81.1599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34142', 'place_name': 'Immokalee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.1844, 'longitude': -81.4152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34143', 'place_name': 'Immokalee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 26.4642, 'longitude': -81.5047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34145', 'place_name': 'Marco Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 25.9388, 'longitude': -81.6968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34146', 'place_name': 'Marco Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Collier', 'locality_code': '21', 'latitude': 25.9412, 'longitude': -81.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32024', 'place_name': 'Lake City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Columbia', 'locality_code': '23', 'latitude': 30.1055, 'longitude': -82.6878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32025', 'place_name': 'Lake City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Columbia', 'locality_code': '23', 'latitude': 30.1601, 'longitude': -82.6396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32038', 'place_name': 'Fort White', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Columbia', 'locality_code': '23', 'latitude': 29.9207, 'longitude': -82.6879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32055', 'place_name': 'Lake City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Columbia', 'locality_code': '23', 'latitude': 30.2702, 'longitude': -82.6254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32056', 'place_name': 'Lake City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Columbia', 'locality_code': '23', 'latitude': 30.1897, 'longitude': -82.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32061', 'place_name': 'Lulu', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Columbia', 'locality_code': '23', 'latitude': 30.0754, 'longitude': -82.5385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34265', 'place_name': 'Arcadia', 'state': 'Florida', 'state_ab': 'FL', 'county': 'DeSoto', 'locality_code': '27', 'latitude': 27.1861, 'longitude': -81.8099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34266', 'place_name': 'Arcadia', 'state': 'Florida', 'state_ab': 'FL', 'county': 'DeSoto', 'locality_code': '27', 'latitude': 27.1861, 'longitude': -81.8667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34267', 'place_name': 'Fort Ogden', 'state': 'Florida', 'state_ab': 'FL', 'county': 'DeSoto', 'locality_code': '27', 'latitude': 27.1861, 'longitude': -81.8099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34268', 'place_name': 'Nocatee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'DeSoto', 'locality_code': '27', 'latitude': 27.1603, 'longitude': -81.8823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34269', 'place_name': 'Arcadia', 'state': 'Florida', 'state_ab': 'FL', 'county': 'DeSoto', 'locality_code': '27', 'latitude': 27.0675, 'longitude': -81.9855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32628', 'place_name': 'Cross City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Dixie', 'locality_code': '29', 'latitude': 29.6372, 'longitude': -83.2032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32648', 'place_name': 'Horseshoe Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Dixie', 'locality_code': '29', 'latitude': 29.4869, 'longitude': -83.2616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32680', 'place_name': 'Old Town', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Dixie', 'locality_code': '29', 'latitude': 29.6699, 'longitude': -83.005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32692', 'place_name': 'Suwannee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Dixie', 'locality_code': '29', 'latitude': 29.3295, 'longitude': -83.14, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32099', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3375, 'longitude': -81.7686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32201', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3894, 'longitude': -81.6808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32202', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3299, 'longitude': -81.6517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32203', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3228, 'longitude': -81.547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32204', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3189, 'longitude': -81.6854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32205', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3172, 'longitude': -81.722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32206', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3511, 'longitude': -81.6488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32207', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2908, 'longitude': -81.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32208', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3937, 'longitude': -81.6889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32209', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3584, 'longitude': -81.692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32210', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2687, 'longitude': -81.7473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32211', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.348, 'longitude': -81.5882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32212', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2132, 'longitude': -81.69, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32214', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32216', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2787, 'longitude': -81.5831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32217', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2407, 'longitude': -81.617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32218', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.4507, 'longitude': -81.6626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32219', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.4034, 'longitude': -81.7635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32220', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.329, 'longitude': -81.8176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32221', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2837, 'longitude': -81.8202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32222', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2292, 'longitude': -81.8131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32223', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.1548, 'longitude': -81.63, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32224', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3031, 'longitude': -81.4404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32225', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.351, 'longitude': -81.5061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32226', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.4735, 'longitude': -81.5448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32227', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3802, 'longitude': -81.416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32228', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3824, 'longitude': -81.4369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32229', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32231', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32232', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32233', 'place_name': 'Atlantic Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3483, 'longitude': -81.4159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32234', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2757, 'longitude': -81.9686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32235', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32236', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32237', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32238', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32239', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32240', 'place_name': 'Jacksonville Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2947, 'longitude': -81.3931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32241', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32244', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2231, 'longitude': -81.7556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32245', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32246', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2933, 'longitude': -81.5092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32247', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3449, 'longitude': -81.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32250', 'place_name': 'Jacksonville Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2801, 'longitude': -81.4165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32254', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3415, 'longitude': -81.7358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32255', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3322, 'longitude': -81.6557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32256', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.2214, 'longitude': -81.5571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32257', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.1927, 'longitude': -81.605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32258', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.1459, 'longitude': -81.5739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32266', 'place_name': 'Neptune Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3155, 'longitude': -81.4051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32277', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Duval', 'locality_code': '31', 'latitude': 30.3704, 'longitude': -81.5864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32501', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4223, 'longitude': -87.2248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32502', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4095, 'longitude': -87.2229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32503', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4564, 'longitude': -87.2104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32504', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4873, 'longitude': -87.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32505', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4481, 'longitude': -87.2589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32506', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4129, 'longitude': -87.3092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32507', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.3737, 'longitude': -87.3126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32508', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.3511, 'longitude': -87.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32509', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4643, 'longitude': -87.3403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32511', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4061, 'longitude': -87.2917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32512', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.3943, 'longitude': -87.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32513', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.5571, 'longitude': -87.2596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32514', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.5241, 'longitude': -87.2167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32516', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4213, 'longitude': -87.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32520', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4124, 'longitude': -87.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32521', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4213, 'longitude': -87.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32522', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4213, 'longitude': -87.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32523', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4213, 'longitude': -87.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32524', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4213, 'longitude': -87.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32526', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4756, 'longitude': -87.3179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32533', 'place_name': 'Cantonment', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.6143, 'longitude': -87.3251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32534', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.5301, 'longitude': -87.2793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32535', 'place_name': 'Century', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.9687, 'longitude': -87.3216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32559', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.3563, 'longitude': -87.2773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32560', 'place_name': 'Gonzalez', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.5818, 'longitude': -87.2929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32568', 'place_name': 'Mc David', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.8686, 'longitude': -87.4539, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32577', 'place_name': 'Molino', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.6902, 'longitude': -87.3852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32591', 'place_name': 'Pensacola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Escambia', 'locality_code': '33', 'latitude': 30.4213, 'longitude': -87.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32110', 'place_name': 'Bunnell', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Flagler', 'locality_code': '35', 'latitude': 29.4562, 'longitude': -81.3244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32135', 'place_name': 'Palm Coast', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Flagler', 'locality_code': '35', 'latitude': 29.4661, 'longitude': -81.2828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32136', 'place_name': 'Flagler Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Flagler', 'locality_code': '35', 'latitude': 29.475, 'longitude': -81.1303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32137', 'place_name': 'Palm Coast', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Flagler', 'locality_code': '35', 'latitude': 29.5565, 'longitude': -81.219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32142', 'place_name': 'Palm Coast', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Flagler', 'locality_code': '35', 'latitude': 29.4661, 'longitude': -81.2828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32143', 'place_name': 'Palm Coast', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Flagler', 'locality_code': '35', 'latitude': 29.585, 'longitude': -81.2078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32164', 'place_name': 'Palm Coast', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Flagler', 'locality_code': '35', 'latitude': 29.4861, 'longitude': -81.2045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32318', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Franklin', 'locality_code': '37', 'latitude': 30.4383, 'longitude': -84.2807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32320', 'place_name': 'Apalachicola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Franklin', 'locality_code': '37', 'latitude': 29.7255, 'longitude': -85.0063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32322', 'place_name': 'Carrabelle', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Franklin', 'locality_code': '37', 'latitude': 29.8692, 'longitude': -84.6358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32323', 'place_name': 'Lanark Village', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Franklin', 'locality_code': '37', 'latitude': 29.8826, 'longitude': -84.5964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32328', 'place_name': 'Eastpoint', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Franklin', 'locality_code': '37', 'latitude': 29.7495, 'longitude': -84.8162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32329', 'place_name': 'Apalachicola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Franklin', 'locality_code': '37', 'latitude': 29.726, 'longitude': -84.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32324', 'place_name': 'Chattahoochee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.6834, 'longitude': -84.828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32330', 'place_name': 'Greensboro', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.5696, 'longitude': -84.7453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32332', 'place_name': 'Gretna', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.6171, 'longitude': -84.6599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32333', 'place_name': 'Havana', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.6092, 'longitude': -84.4143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32343', 'place_name': 'Midway', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.485, 'longitude': -84.4768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32351', 'place_name': 'Quincy', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.5867, 'longitude': -84.6094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32352', 'place_name': 'Quincy', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.6512, 'longitude': -84.5866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32353', 'place_name': 'Quincy', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gadsden', 'locality_code': '39', 'latitude': 30.5497, 'longitude': -84.6069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32619', 'place_name': 'Bell', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gilchrist', 'locality_code': '41', 'latitude': 29.7837, 'longitude': -82.8711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32693', 'place_name': 'Trenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gilchrist', 'locality_code': '41', 'latitude': 29.6133, 'longitude': -82.8176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33471', 'place_name': 'Moore Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Glades', 'locality_code': '43', 'latitude': 26.8327, 'longitude': -81.2188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33944', 'place_name': 'Palmdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Glades', 'locality_code': '43', 'latitude': 26.9464, 'longitude': -81.3091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32456', 'place_name': 'Port Saint Joe', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gulf', 'locality_code': '45', 'latitude': 29.8119, 'longitude': -85.303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32457', 'place_name': 'Port Saint Joe', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gulf', 'locality_code': '45', 'latitude': 29.8119, 'longitude': -85.303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32465', 'place_name': 'Wewahitchka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Gulf', 'locality_code': '45', 'latitude': 30.0933, 'longitude': -85.2048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32052', 'place_name': 'Jasper', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hamilton', 'locality_code': '47', 'latitude': 30.5029, 'longitude': -82.9322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32053', 'place_name': 'Jennings', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hamilton', 'locality_code': '47', 'latitude': 30.5482, 'longitude': -83.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32096', 'place_name': 'White Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hamilton', 'locality_code': '47', 'latitude': 30.3387, 'longitude': -82.7765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33834', 'place_name': 'Bowling Green', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hardee', 'locality_code': '49', 'latitude': 27.6019, 'longitude': -81.8507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33865', 'place_name': 'Ona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hardee', 'locality_code': '49', 'latitude': 27.4127, 'longitude': -81.928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33873', 'place_name': 'Wauchula', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hardee', 'locality_code': '49', 'latitude': 27.5517, 'longitude': -81.8074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33890', 'place_name': 'Zolfo Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hardee', 'locality_code': '49', 'latitude': 27.48, 'longitude': -81.7423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33440', 'place_name': 'Clewiston', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hendry', 'locality_code': '51', 'latitude': 26.7172, 'longitude': -80.9492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33930', 'place_name': 'Felda', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hendry', 'locality_code': '51', 'latitude': 26.5398, 'longitude': -81.4356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33935', 'place_name': 'Labelle', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hendry', 'locality_code': '51', 'latitude': 26.7321, 'longitude': -81.434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33975', 'place_name': 'Labelle', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hendry', 'locality_code': '51', 'latitude': 26.7633, 'longitude': -81.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34601', 'place_name': 'Brooksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.5658, 'longitude': -82.3737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34602', 'place_name': 'Brooksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.5093, 'longitude': -82.2957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34603', 'place_name': 'Brooksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.5642, 'longitude': -82.4165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34604', 'place_name': 'Brooksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.4409, 'longitude': -82.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34605', 'place_name': 'Brooksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.5059, 'longitude': -82.4226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34606', 'place_name': 'Spring Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.4655, 'longitude': -82.5981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34607', 'place_name': 'Spring Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.5065, 'longitude': -82.6267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34608', 'place_name': 'Spring Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.4797, 'longitude': -82.5562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34609', 'place_name': 'Spring Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.4794, 'longitude': -82.5083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34611', 'place_name': 'Spring Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.5642, 'longitude': -82.4165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34613', 'place_name': 'Brooksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.5466, 'longitude': -82.5213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34614', 'place_name': 'Brooksville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.6622, 'longitude': -82.5236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34636', 'place_name': 'Istachatta', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.655, 'longitude': -82.2677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34661', 'place_name': 'Nobleton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hernando', 'locality_code': '53', 'latitude': 28.6436, 'longitude': -82.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33825', 'place_name': 'Avon Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.6001, 'longitude': -81.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33826', 'place_name': 'Avon Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.5959, 'longitude': -81.5062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33852', 'place_name': 'Lake Placid', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.2945, 'longitude': -81.3649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33857', 'place_name': 'Lorida', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.415, 'longitude': -81.1965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33862', 'place_name': 'Lake Placid', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.2931, 'longitude': -81.3629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33870', 'place_name': 'Sebring', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.4924, 'longitude': -81.4357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33871', 'place_name': 'Sebring', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.4858, 'longitude': -81.4079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33872', 'place_name': 'Sebring', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.4703, 'longitude': -81.4872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33875', 'place_name': 'Sebring', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.4676, 'longitude': -81.4581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33876', 'place_name': 'Sebring', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.4287, 'longitude': -81.3519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33960', 'place_name': 'Venus', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Highlands', 'locality_code': '55', 'latitude': 27.1203, 'longitude': -81.3909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33503', 'place_name': 'Balm', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.7648, 'longitude': -82.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33508', 'place_name': 'Brandon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9318, 'longitude': -82.295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33509', 'place_name': 'Brandon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9378, 'longitude': -82.2859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33510', 'place_name': 'Brandon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9551, 'longitude': -82.2966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33511', 'place_name': 'Brandon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9056, 'longitude': -82.2881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33527', 'place_name': 'Dover', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.992, 'longitude': -82.2138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33530', 'place_name': 'Durant', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9068, 'longitude': -82.1767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33534', 'place_name': 'Gibsonton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8411, 'longitude': -82.3698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33547', 'place_name': 'Lithia', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8293, 'longitude': -82.1357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33548', 'place_name': 'Lutz', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.1385, 'longitude': -82.4821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33549', 'place_name': 'Lutz', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.1367, 'longitude': -82.461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33550', 'place_name': 'Mango', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9797, 'longitude': -82.3065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33556', 'place_name': 'Odessa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.1421, 'longitude': -82.5905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33558', 'place_name': 'Lutz', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.1474, 'longitude': -82.5152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33563', 'place_name': 'Plant City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.013, 'longitude': -82.1339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33564', 'place_name': 'Plant City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0296, 'longitude': -82.1347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33565', 'place_name': 'Plant City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0699, 'longitude': -82.1576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33566', 'place_name': 'Plant City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0094, 'longitude': -82.1138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33567', 'place_name': 'Plant City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.922, 'longitude': -82.1216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33568', 'place_name': 'Riverview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33569', 'place_name': 'Riverview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.845, 'longitude': -82.3125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33570', 'place_name': 'Ruskin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.7015, 'longitude': -82.4355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33571', 'place_name': 'Sun City Center', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.7201, 'longitude': -82.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33572', 'place_name': 'Apollo Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.7716, 'longitude': -82.4102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33573', 'place_name': 'Sun City Center', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.7147, 'longitude': -82.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33575', 'place_name': 'Ruskin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.7144, 'longitude': -82.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33579', 'place_name': 'Riverview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8024, 'longitude': -82.2755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33583', 'place_name': 'Seffner', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33584', 'place_name': 'Seffner', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9922, 'longitude': -82.2863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33586', 'place_name': 'Sun City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.6784, 'longitude': -82.4787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33587', 'place_name': 'Sydney', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9634, 'longitude': -82.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33592', 'place_name': 'Thonotosassa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0617, 'longitude': -82.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33594', 'place_name': 'Valrico', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9408, 'longitude': -82.242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33595', 'place_name': 'Valrico', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9379, 'longitude': -82.2364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33596', 'place_name': 'Valrico', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8925, 'longitude': -82.243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33598', 'place_name': 'Wimauma', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.7015, 'longitude': -82.3151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33601', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9961, 'longitude': -82.582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33602', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9614, 'longitude': -82.4597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33603', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9845, 'longitude': -82.463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33604', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0173, 'longitude': -82.4578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33605', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9671, 'longitude': -82.4334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33606', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9475, 'longitude': -82.4584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33607', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9625, 'longitude': -82.4895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33608', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8434, 'longitude': -82.4884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33609', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9425, 'longitude': -82.5057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33610', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9951, 'longitude': -82.4046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33611', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8914, 'longitude': -82.5067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33612', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0502, 'longitude': -82.45, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33613', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0772, 'longitude': -82.4455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33614', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0091, 'longitude': -82.5034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33615', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0081, 'longitude': -82.5805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33616', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8742, 'longitude': -82.5203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33617', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0384, 'longitude': -82.3949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33618', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0763, 'longitude': -82.4852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33619', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9382, 'longitude': -82.3756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33620', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.06, 'longitude': -82.4079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33621', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.8491, 'longitude': -82.4946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33622', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9475, 'longitude': -82.4584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33623', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9475, 'longitude': -82.4584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33624', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.079, 'longitude': -82.5268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33625', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0726, 'longitude': -82.559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33626', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0509, 'longitude': -82.6164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33629', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.921, 'longitude': -82.5079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33630', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33631', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33633', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33634', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0068, 'longitude': -82.556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33635', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0301, 'longitude': -82.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33637', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.0338, 'longitude': -82.3659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33646', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.094, 'longitude': -82.4021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33647', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 28.1147, 'longitude': -82.3678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33650', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33655', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9475, 'longitude': -82.4584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33660', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33661', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33662', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33663', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33664', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33672', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9475, 'longitude': -82.4584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33673', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33674', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33675', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33677', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33679', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33680', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33681', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33682', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33684', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33685', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33686', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33687', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33688', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33689', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.9475, 'longitude': -82.4584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33694', 'place_name': 'Tampa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Hillsborough', 'locality_code': '57', 'latitude': 27.872, 'longitude': -82.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32425', 'place_name': 'Bonifay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Holmes', 'locality_code': '59', 'latitude': 30.8464, 'longitude': -85.69, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32452', 'place_name': 'Noma', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Holmes', 'locality_code': '59', 'latitude': 30.9821, 'longitude': -85.6185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32455', 'place_name': 'Ponce De Leon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Holmes', 'locality_code': '59', 'latitude': 30.7041, 'longitude': -85.9546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32464', 'place_name': 'Westville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Holmes', 'locality_code': '59', 'latitude': 30.8747, 'longitude': -85.913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32948', 'place_name': 'Fellsmere', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.7643, 'longitude': -80.6019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32957', 'place_name': 'Roseland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.8359, 'longitude': -80.4931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32958', 'place_name': 'Sebastian', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.7901, 'longitude': -80.4784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32960', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.633, 'longitude': -80.4031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32961', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.6175, 'longitude': -80.4231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32962', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.5885, 'longitude': -80.3923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32963', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.6898, 'longitude': -80.3757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32964', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.6386, 'longitude': -80.3973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32965', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.6386, 'longitude': -80.3973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32966', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.6372, 'longitude': -80.4794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32967', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.6972, 'longitude': -80.4416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32968', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.5999, 'longitude': -80.4382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32969', 'place_name': 'Vero Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.709, 'longitude': -80.5726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32970', 'place_name': 'Wabasso', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.7484, 'longitude': -80.4362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32971', 'place_name': 'Winter Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.7192, 'longitude': -80.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32978', 'place_name': 'Sebastian', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Indian River', 'locality_code': '61', 'latitude': 27.709, 'longitude': -80.5726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32420', 'place_name': 'Alford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.6412, 'longitude': -85.3756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32423', 'place_name': 'Bascom', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.9514, 'longitude': -85.0972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32426', 'place_name': 'Campbellton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.9563, 'longitude': -85.3766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32431', 'place_name': 'Cottondale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.8004, 'longitude': -85.3847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32432', 'place_name': 'Cypress', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.7158, 'longitude': -85.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32440', 'place_name': 'Graceville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.9426, 'longitude': -85.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32442', 'place_name': 'Grand Ridge', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.7148, 'longitude': -85.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32443', 'place_name': 'Greenwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.8667, 'longitude': -85.1153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32445', 'place_name': 'Malone', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.9602, 'longitude': -85.1639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32446', 'place_name': 'Marianna', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.7996, 'longitude': -85.2293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32447', 'place_name': 'Marianna', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.7603, 'longitude': -85.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32448', 'place_name': 'Marianna', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.6749, 'longitude': -85.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32460', 'place_name': 'Sneads', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jackson', 'locality_code': '63', 'latitude': 30.7276, 'longitude': -84.9337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32336', 'place_name': 'Lamont', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 30.3772, 'longitude': -83.8129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32337', 'place_name': 'Lloyd', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 30.4778, 'longitude': -84.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32344', 'place_name': 'Monticello', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 30.5197, 'longitude': -83.8925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32345', 'place_name': 'Monticello', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 30.5451, 'longitude': -83.8713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32361', 'place_name': 'Wacissa', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 30.3585, 'longitude': -83.9871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32753', 'place_name': 'Debary', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 28.883, 'longitude': -81.3087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32013', 'place_name': 'Day', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lafayette', 'locality_code': '67', 'latitude': 30.1941, 'longitude': -83.2913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32066', 'place_name': 'Mayo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lafayette', 'locality_code': '67', 'latitude': 30.04, 'longitude': -83.1462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32102', 'place_name': 'Astor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 29.165, 'longitude': -81.5399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32158', 'place_name': 'Lady Lake', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.9175, 'longitude': -81.9229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32159', 'place_name': 'Lady Lake', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.9299, 'longitude': -81.9256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32702', 'place_name': 'Altoona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 29.0219, 'longitude': -81.6323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32726', 'place_name': 'Eustis', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.855, 'longitude': -81.6789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32727', 'place_name': 'Eustis', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8555, 'longitude': -81.6741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32735', 'place_name': 'Grand Island', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8866, 'longitude': -81.7391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32736', 'place_name': 'Eustis', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.9102, 'longitude': -81.5235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32756', 'place_name': 'Mount Dora', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8111, 'longitude': -81.6536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32757', 'place_name': 'Mount Dora', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.774, 'longitude': -81.6439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32767', 'place_name': 'Paisley', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.9993, 'longitude': -81.503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32776', 'place_name': 'Sorrento', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8035, 'longitude': -81.5323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32778', 'place_name': 'Tavares', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.801, 'longitude': -81.734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32784', 'place_name': 'Umatilla', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.9254, 'longitude': -81.6801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34705', 'place_name': 'Astatula', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.7088, 'longitude': -81.7195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34711', 'place_name': 'Clermont', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.5525, 'longitude': -81.7574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34712', 'place_name': 'Clermont', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.5494, 'longitude': -81.7729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34713', 'place_name': 'Clermont', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.5494, 'longitude': -81.7729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34715', 'place_name': 'Clermont', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.6259, 'longitude': -81.7306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34729', 'place_name': 'Ferndale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.6219, 'longitude': -81.7034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34731', 'place_name': 'Fruitland Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8639, 'longitude': -81.8998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34736', 'place_name': 'Groveland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.5644, 'longitude': -81.8745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34737', 'place_name': 'Howey In The Hills', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.6971, 'longitude': -81.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34748', 'place_name': 'Leesburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.808, 'longitude': -81.8858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34749', 'place_name': 'Leesburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8108, 'longitude': -81.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34753', 'place_name': 'Mascotte', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.583, 'longitude': -81.8941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34755', 'place_name': 'Minneola', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.5744, 'longitude': -81.7462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34756', 'place_name': 'Montverde', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.5972, 'longitude': -81.6794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34762', 'place_name': 'Okahumpka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.7545, 'longitude': -81.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34788', 'place_name': 'Leesburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8887, 'longitude': -81.7827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34789', 'place_name': 'Leesburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.8108, 'longitude': -81.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34797', 'place_name': 'Yalaha', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lake', 'locality_code': '69', 'latitude': 28.7444, 'longitude': -81.8263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33901', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6204, 'longitude': -81.8725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33902', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6239, 'longitude': -81.8836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33903', 'place_name': 'North Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.693, 'longitude': -81.9125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33904', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6065, 'longitude': -81.9502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33905', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6693, 'longitude': -81.7605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33906', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5529, 'longitude': -81.9486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33907', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5681, 'longitude': -81.8736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33908', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5025, 'longitude': -81.9276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33909', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6939, 'longitude': -81.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33910', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5529, 'longitude': -81.9486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33911', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5963, 'longitude': -81.8824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33912', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.4972, 'longitude': -81.8246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33913', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5228, 'longitude': -81.7065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33914', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5557, 'longitude': -82.0206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33915', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6599, 'longitude': -81.8934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33916', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6466, 'longitude': -81.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33917', 'place_name': 'North Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.7357, 'longitude': -81.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33918', 'place_name': 'North Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6673, 'longitude': -81.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33919', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5567, 'longitude': -81.9034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33920', 'place_name': 'Alva', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.7147, 'longitude': -81.6351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33921', 'place_name': 'Boca Grande', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.7545, 'longitude': -82.2611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33922', 'place_name': 'Bokeelia', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6627, 'longitude': -82.1401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33924', 'place_name': 'Captiva', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5215, 'longitude': -82.1802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33928', 'place_name': 'Estero', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.4351, 'longitude': -81.8102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33929', 'place_name': 'Estero', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.4381, 'longitude': -81.8068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33931', 'place_name': 'Fort Myers Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.4527, 'longitude': -81.9501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33932', 'place_name': 'Fort Myers Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5529, 'longitude': -81.9486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33936', 'place_name': 'Lehigh Acres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5936, 'longitude': -81.6619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33945', 'place_name': 'Pineland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6583, 'longitude': -82.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33956', 'place_name': 'Saint James City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.529, 'longitude': -82.0916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33957', 'place_name': 'Sanibel', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.4514, 'longitude': -82.0868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33965', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.4637, 'longitude': -81.7722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33966', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5824, 'longitude': -81.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33970', 'place_name': 'Lehigh Acres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5647, 'longitude': -81.6208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33971', 'place_name': 'Lehigh Acres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6388, 'longitude': -81.6992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33972', 'place_name': 'Lehigh Acres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6492, 'longitude': -81.6167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33974', 'place_name': 'Lehigh Acres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5677, 'longitude': -81.5954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33976', 'place_name': 'Lehigh Acres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5952, 'longitude': -81.6849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33990', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6265, 'longitude': -81.9677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33991', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6281, 'longitude': -82.0182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33993', 'place_name': 'Cape Coral', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.6786, 'longitude': -82.0254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33994', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.5529, 'longitude': -81.9486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34133', 'place_name': 'Bonita Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.3398, 'longitude': -81.7787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34134', 'place_name': 'Bonita Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.3626, 'longitude': -81.8183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34135', 'place_name': 'Bonita Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.3771, 'longitude': -81.7334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34136', 'place_name': 'Bonita Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Lee', 'locality_code': '71', 'latitude': 26.3398, 'longitude': -81.7787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32301', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4286, 'longitude': -84.2593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32302', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4383, 'longitude': -84.2807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32303', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4874, 'longitude': -84.3189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32304', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4478, 'longitude': -84.3211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32305', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.334, 'longitude': -84.287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32306', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4425, 'longitude': -84.2986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32307', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4257, 'longitude': -84.2877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32308', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4771, 'longitude': -84.2246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32309', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.5422, 'longitude': -84.1413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32310', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.3991, 'longitude': -84.3298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32311', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4156, 'longitude': -84.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32312', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.5185, 'longitude': -84.2627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32313', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4793, 'longitude': -84.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32314', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4793, 'longitude': -84.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32315', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4793, 'longitude': -84.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32316', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4793, 'longitude': -84.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32317', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4651, 'longitude': -84.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32362', 'place_name': 'Woodville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.3193, 'longitude': -84.2674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32395', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4793, 'longitude': -84.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32399', 'place_name': 'Tallahassee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Leon', 'locality_code': '73', 'latitude': 30.4383, 'longitude': -84.2807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32621', 'place_name': 'Bronson', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.461, 'longitude': -82.6356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32625', 'place_name': 'Cedar Key', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.171, 'longitude': -83.0168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32626', 'place_name': 'Chiefland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.4832, 'longitude': -82.8809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32639', 'place_name': 'Gulf Hammock', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.2447, 'longitude': -82.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32644', 'place_name': 'Chiefland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.4602, 'longitude': -82.8553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32668', 'place_name': 'Morriston', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.2813, 'longitude': -82.4917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32683', 'place_name': 'Otter Creek', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.3109, 'longitude': -82.7945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32696', 'place_name': 'Williston', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.3977, 'longitude': -82.4856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34449', 'place_name': 'Inglis', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.0955, 'longitude': -82.6561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34498', 'place_name': 'Yankeetown', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Levy', 'locality_code': '75', 'latitude': 29.0305, 'longitude': -82.719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32321', 'place_name': 'Bristol', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Liberty', 'locality_code': '77', 'latitude': 30.4223, 'longitude': -84.9466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32334', 'place_name': 'Hosford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Liberty', 'locality_code': '77', 'latitude': 30.3639, 'longitude': -84.8054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32335', 'place_name': 'Sumatra', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Liberty', 'locality_code': '77', 'latitude': 30.0206, 'longitude': -84.9806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32360', 'place_name': 'Telogia', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Liberty', 'locality_code': '77', 'latitude': 30.3511, 'longitude': -84.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32059', 'place_name': 'Lee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Madison', 'locality_code': '79', 'latitude': 30.3979, 'longitude': -83.2844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32331', 'place_name': 'Greenville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Madison', 'locality_code': '79', 'latitude': 30.4512, 'longitude': -83.6474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32340', 'place_name': 'Madison', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Madison', 'locality_code': '79', 'latitude': 30.4802, 'longitude': -83.4067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32341', 'place_name': 'Madison', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Madison', 'locality_code': '79', 'latitude': 30.4776, 'longitude': -83.3914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32350', 'place_name': 'Pinetta', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Madison', 'locality_code': '79', 'latitude': 30.5997, 'longitude': -83.3405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34201', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4047, 'longitude': -82.4705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34202', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4067, 'longitude': -82.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34203', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4547, 'longitude': -82.5359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34204', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4272, 'longitude': -82.4387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34205', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4841, 'longitude': -82.5834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34206', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4989, 'longitude': -82.5748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34207', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4394, 'longitude': -82.5778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34208', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4678, 'longitude': -82.512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34209', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4759, 'longitude': -82.6167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34210', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4544, 'longitude': -82.6358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34211', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.45, 'longitude': -82.3773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34212', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4978, 'longitude': -82.4101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34215', 'place_name': 'Cortez', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4713, 'longitude': -82.6823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34216', 'place_name': 'Anna Maria', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.5291, 'longitude': -82.7317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34217', 'place_name': 'Bradenton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4859, 'longitude': -82.7102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34218', 'place_name': 'Holmes Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4995, 'longitude': -82.7099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34219', 'place_name': 'Parrish', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.5572, 'longitude': -82.396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34220', 'place_name': 'Palmetto', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.5214, 'longitude': -82.5723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34221', 'place_name': 'Palmetto', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.5429, 'longitude': -82.563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34222', 'place_name': 'Ellenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.5382, 'longitude': -82.5006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34228', 'place_name': 'Longboat Key', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4125, 'longitude': -82.659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34243', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4072, 'longitude': -82.5303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34250', 'place_name': 'Terra Ceia', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.5722, 'longitude': -82.5832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34251', 'place_name': 'Myakka City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.3648, 'longitude': -82.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34260', 'place_name': 'Manasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4272, 'longitude': -82.4387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34264', 'place_name': 'Oneco', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4475, 'longitude': -82.5462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34270', 'place_name': 'Tallevast', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4054, 'longitude': -82.5435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34280', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4272, 'longitude': -82.4387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34281', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4272, 'longitude': -82.4387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34282', 'place_name': 'Bradenton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Manatee', 'locality_code': '81', 'latitude': 27.4272, 'longitude': -82.4387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32111', 'place_name': 'Candler', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0607, 'longitude': -81.969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32113', 'place_name': 'Citra', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.3918, 'longitude': -82.1062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32133', 'place_name': 'Eastlake Weir', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0088, 'longitude': -81.9094, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32134', 'place_name': 'Fort Mc Coy', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.391, 'longitude': -81.8551, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32179', 'place_name': 'Ocklawaha', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0643, 'longitude': -81.8857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32182', 'place_name': 'Orange Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.4856, 'longitude': -81.9589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32183', 'place_name': 'Ocklawaha', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0597, 'longitude': -81.9051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32192', 'place_name': 'Sparr', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.3268, 'longitude': -82.1046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32195', 'place_name': 'Weirsdale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 28.9782, 'longitude': -81.8932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32617', 'place_name': 'Anthony', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.3048, 'longitude': -82.1262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32634', 'place_name': 'Fairfield', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.3509, 'longitude': -82.2765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32663', 'place_name': 'Lowell', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.3424, 'longitude': -82.2126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32664', 'place_name': 'Mc Intosh', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.438, 'longitude': -82.2295, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32681', 'place_name': 'Orange Lake', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.4236, 'longitude': -82.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32686', 'place_name': 'Reddick', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.3754, 'longitude': -82.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34420', 'place_name': 'Belleview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0531, 'longitude': -82.0375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34421', 'place_name': 'Belleview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.2407, 'longitude': -82.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34430', 'place_name': 'Dunnellon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0491, 'longitude': -82.4609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34431', 'place_name': 'Dunnellon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1392, 'longitude': -82.5328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34432', 'place_name': 'Dunnellon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1015, 'longitude': -82.3413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34470', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1989, 'longitude': -82.0874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34471', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1605, 'longitude': -82.1288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34472', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1253, 'longitude': -82.0086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34473', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0058, 'longitude': -82.1828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34474', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1565, 'longitude': -82.2095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34475', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.2573, 'longitude': -82.161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34476', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1159, 'longitude': -82.2422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34477', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1872, 'longitude': -82.1401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34478', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1872, 'longitude': -82.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34479', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.2541, 'longitude': -82.1095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34480', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1056, 'longitude': -82.098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34481', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.1281, 'longitude': -82.2975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34482', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.2611, 'longitude': -82.2195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34483', 'place_name': 'Ocala', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.2407, 'longitude': -82.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34488', 'place_name': 'Silver Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.2635, 'longitude': -81.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34489', 'place_name': 'Silver Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.2152, 'longitude': -82.0972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34491', 'place_name': 'Summerfield', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 29.0112, 'longitude': -82.0325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34492', 'place_name': 'Summerfield', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Marion', 'locality_code': '83', 'latitude': 28.998, 'longitude': -82.0161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33455', 'place_name': 'Hobe Sound', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.0813, 'longitude': -80.1509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33475', 'place_name': 'Hobe Sound', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.0595, 'longitude': -80.1364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34956', 'place_name': 'Indiantown', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.0615, 'longitude': -80.4803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34957', 'place_name': 'Jensen Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.2356, 'longitude': -80.2277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34958', 'place_name': 'Jensen Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.2424, 'longitude': -80.2246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34990', 'place_name': 'Palm City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.1656, 'longitude': -80.2916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34991', 'place_name': 'Palm City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.1678, 'longitude': -80.2662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34992', 'place_name': 'Port Salerno', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.1442, 'longitude': -80.2006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34994', 'place_name': 'Stuart', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.1968, 'longitude': -80.2538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34995', 'place_name': 'Stuart', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.1754, 'longitude': -80.2415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34996', 'place_name': 'Stuart', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.1929, 'longitude': -80.2164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34997', 'place_name': 'Stuart', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Martin', 'locality_code': '85', 'latitude': 27.1398, 'longitude': -80.2129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33002', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8576, 'longitude': -80.2781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33010', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8325, 'longitude': -80.2808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33011', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8576, 'longitude': -80.2781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33012', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8654, 'longitude': -80.3059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33013', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8594, 'longitude': -80.2725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33014', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8963, 'longitude': -80.3063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33015', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9388, 'longitude': -80.3165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33016', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8803, 'longitude': -80.3368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33017', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8576, 'longitude': -80.2781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33018', 'place_name': 'Hialeah', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9098, 'longitude': -80.3889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33030', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.4766, 'longitude': -80.4839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33031', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5323, 'longitude': -80.5075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33032', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5303, 'longitude': -80.3918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33033', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.4906, 'longitude': -80.438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33034', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.2846, 'longitude': -80.6246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33035', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.4573, 'longitude': -80.4572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33039', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5021, 'longitude': -80.3997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33054', 'place_name': 'Opa Locka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9097, 'longitude': -80.247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '33055', 'place_name': 'Opa Locka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9476, 'longitude': -80.2778, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '33056', 'place_name': 'Miami Gardens', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.942, 'longitude': -80.2456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33090', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5584, 'longitude': -80.4582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33092', 'place_name': 'Homestead', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5584, 'longitude': -80.4582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33101', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7791, 'longitude': -80.1978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33102', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33106', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8527, 'longitude': -80.3012, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '33109', 'place_name': 'Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7588, 'longitude': -80.1376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33111', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33114', 'place_name': 'Coral Gables', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7215, 'longitude': -80.2684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33116', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33119', 'place_name': 'Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7845, 'longitude': -80.132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33122', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8001, 'longitude': -80.281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33124', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33125', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7825, 'longitude': -80.2341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33126', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7763, 'longitude': -80.2919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33127', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8143, 'longitude': -80.2051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33128', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7756, 'longitude': -80.2089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33129', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7559, 'longitude': -80.2013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33130', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7672, 'longitude': -80.2059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33131', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7629, 'longitude': -80.1895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33132', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7867, 'longitude': -80.18, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33133', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7378, 'longitude': -80.2248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33134', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.768, 'longitude': -80.2714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33135', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7664, 'longitude': -80.2317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33136', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7864, 'longitude': -80.2042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33137', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8156, 'longitude': -80.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33138', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8521, 'longitude': -80.1821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33139', 'place_name': 'Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7873, 'longitude': -80.1564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33140', 'place_name': 'Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8198, 'longitude': -80.1337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33141', 'place_name': 'Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8486, 'longitude': -80.1446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33142', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.813, 'longitude': -80.232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33143', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7022, 'longitude': -80.2978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33144', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7626, 'longitude': -80.3096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33145', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7539, 'longitude': -80.2253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33146', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7205, 'longitude': -80.2728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33147', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8507, 'longitude': -80.2366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33149', 'place_name': 'Key Biscayne', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6921, 'longitude': -80.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33150', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8512, 'longitude': -80.207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33151', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8321, 'longitude': -80.2094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33152', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7955, 'longitude': -80.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33153', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8655, 'longitude': -80.1936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33154', 'place_name': 'Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7907, 'longitude': -80.13, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33155', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7392, 'longitude': -80.3103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33156', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6682, 'longitude': -80.2973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33157', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6062, 'longitude': -80.3426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33158', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6364, 'longitude': -80.3187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33160', 'place_name': 'North Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9449, 'longitude': -80.1391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33161', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8934, 'longitude': -80.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33162', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9286, 'longitude': -80.183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33163', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.945, 'longitude': -80.2145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33164', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33165', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7343, 'longitude': -80.3588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33166', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8301, 'longitude': -80.2926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33167', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8856, 'longitude': -80.2292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33168', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8902, 'longitude': -80.2101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33169', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9441, 'longitude': -80.2144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33170', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5584, 'longitude': -80.4582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33172', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7735, 'longitude': -80.3572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33173', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6992, 'longitude': -80.3618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33174', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7628, 'longitude': -80.3611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33175', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7341, 'longitude': -80.4068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33176', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6574, 'longitude': -80.3627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33177', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5968, 'longitude': -80.4046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33178', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8141, 'longitude': -80.3549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33179', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9571, 'longitude': -80.1814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33180', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.9597, 'longitude': -80.1403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33181', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.8965, 'longitude': -80.157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33182', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7877, 'longitude': -80.4166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33183', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7, 'longitude': -80.413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33184', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7574, 'longitude': -80.403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33185', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7274, 'longitude': -80.4497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33186', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6694, 'longitude': -80.4085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33187', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.596, 'longitude': -80.507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33188', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33189', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.573, 'longitude': -80.3374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33190', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5593, 'longitude': -80.3483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33191', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33192', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33193', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6964, 'longitude': -80.4401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33194', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.5584, 'longitude': -80.4582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33195', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7729, 'longitude': -80.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33196', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.6615, 'longitude': -80.441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33197', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33198', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33199', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33206', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33222', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7577, 'longitude': -80.3748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33231', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33233', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33234', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33238', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33239', 'place_name': 'Miami Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7907, 'longitude': -80.13, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33242', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33243', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33245', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33247', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33255', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33256', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33257', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33261', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33265', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33266', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33269', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33280', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33283', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33296', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33299', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Miami-Dade', 'locality_code': '86', 'latitude': 25.7743, 'longitude': -80.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33001', 'place_name': 'Long Key', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.8306, 'longitude': -80.8049, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '33036', 'place_name': 'Islamorada', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.9233, 'longitude': -80.63, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33037', 'place_name': 'Key Largo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 25.0865, 'longitude': -80.4473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33040', 'place_name': 'Key West', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.5552, 'longitude': -81.7816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33041', 'place_name': 'Key West', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.5552, 'longitude': -81.7816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33042', 'place_name': 'Summerland Key', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.667, 'longitude': -81.5099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33043', 'place_name': 'Big Pine Key', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.68, 'longitude': -81.362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33045', 'place_name': 'Key West', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.5552, 'longitude': -81.7816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33050', 'place_name': 'Marathon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.7279, 'longitude': -81.0386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33051', 'place_name': 'Key Colony Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.7234, 'longitude': -81.0203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33052', 'place_name': 'Marathon Shores', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 24.7233, 'longitude': -81.0632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33070', 'place_name': 'Tavernier', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Monroe', 'locality_code': '87', 'latitude': 25.0108, 'longitude': -80.5218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32009', 'place_name': 'Bryceville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Nassau', 'locality_code': '89', 'latitude': 30.4193, 'longitude': -81.9724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32011', 'place_name': 'Callahan', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Nassau', 'locality_code': '89', 'latitude': 30.552, 'longitude': -81.8145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32034', 'place_name': 'Fernandina Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Nassau', 'locality_code': '89', 'latitude': 30.6697, 'longitude': -81.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32035', 'place_name': 'Fernandina Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Nassau', 'locality_code': '89', 'latitude': 30.6697, 'longitude': -81.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32041', 'place_name': 'Yulee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Nassau', 'locality_code': '89', 'latitude': 30.6233, 'longitude': -81.5902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32046', 'place_name': 'Hilliard', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Nassau', 'locality_code': '89', 'latitude': 30.6884, 'longitude': -81.9345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32097', 'place_name': 'Yulee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Nassau', 'locality_code': '89', 'latitude': 30.6222, 'longitude': -81.5906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32531', 'place_name': 'Baker', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.8316, 'longitude': -86.677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32536', 'place_name': 'Crestview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.7644, 'longitude': -86.5917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32537', 'place_name': 'Milligan', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.742, 'longitude': -86.6552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32539', 'place_name': 'Crestview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.7773, 'longitude': -86.4832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32540', 'place_name': 'Destin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.3935, 'longitude': -86.4958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32541', 'place_name': 'Destin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.3949, 'longitude': -86.4692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32542', 'place_name': 'Eglin Afb', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.5393, 'longitude': -86.6087, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32544', 'place_name': 'Hurlburt Field', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.4229, 'longitude': -86.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32547', 'place_name': 'Fort Walton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.4487, 'longitude': -86.6255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32548', 'place_name': 'Fort Walton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.4206, 'longitude': -86.6286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32549', 'place_name': 'Fort Walton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.4208, 'longitude': -86.6194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32564', 'place_name': 'Holt', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.7416, 'longitude': -86.7198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32567', 'place_name': 'Laurel Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.9524, 'longitude': -86.4003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32569', 'place_name': 'Mary Esther', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.4085, 'longitude': -86.7352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32578', 'place_name': 'Niceville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.5169, 'longitude': -86.4822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32579', 'place_name': 'Shalimar', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.4456, 'longitude': -86.5717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32580', 'place_name': 'Valparaiso', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.5092, 'longitude': -86.5009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32588', 'place_name': 'Niceville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okaloosa', 'locality_code': '91', 'latitude': 30.6612, 'longitude': -86.5945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34972', 'place_name': 'Okeechobee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okeechobee', 'locality_code': '93', 'latitude': 27.4203, 'longitude': -80.9454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34973', 'place_name': 'Okeechobee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okeechobee', 'locality_code': '93', 'latitude': 27.2439, 'longitude': -80.8298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34974', 'place_name': 'Okeechobee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Okeechobee', 'locality_code': '93', 'latitude': 27.2002, 'longitude': -80.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32703', 'place_name': 'Apopka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.6354, 'longitude': -81.4888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32704', 'place_name': 'Apopka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.6762, 'longitude': -81.5119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32709', 'place_name': 'Christmas', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5462, 'longitude': -81.0116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32710', 'place_name': 'Clarcona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.6128, 'longitude': -81.4987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32712', 'place_name': 'Apopka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.712, 'longitude': -81.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32751', 'place_name': 'Maitland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.6255, 'longitude': -81.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32768', 'place_name': 'Plymouth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.6985, 'longitude': -81.5698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32777', 'place_name': 'Tangerine', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.765, 'longitude': -81.6306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32789', 'place_name': 'Winter Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5978, 'longitude': -81.3534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32790', 'place_name': 'Winter Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32792', 'place_name': 'Winter Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5974, 'longitude': -81.3036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32793', 'place_name': 'Winter Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32794', 'place_name': 'Maitland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.6278, 'longitude': -81.3631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32798', 'place_name': 'Zellwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.7194, 'longitude': -81.5762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32801', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5399, 'longitude': -81.3727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32802', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5383, 'longitude': -81.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32803', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5559, 'longitude': -81.3535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32804', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5754, 'longitude': -81.3955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32805', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5302, 'longitude': -81.4045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32806', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.514, 'longitude': -81.357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32807', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5515, 'longitude': -81.3051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32808', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5803, 'longitude': -81.4396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32809', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4637, 'longitude': -81.3948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32810', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.6214, 'longitude': -81.4294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32811', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5163, 'longitude': -81.4516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32812', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4998, 'longitude': -81.3288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32814', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5702, 'longitude': -81.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32816', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32817', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5891, 'longitude': -81.2277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32818', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5801, 'longitude': -81.4846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32819', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4522, 'longitude': -81.4678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32820', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5725, 'longitude': -81.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32821', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.3957, 'longitude': -81.4666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32822', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4944, 'longitude': -81.2902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32824', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.3932, 'longitude': -81.3622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32825', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5469, 'longitude': -81.2571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32826', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5826, 'longitude': -81.1907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32827', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4317, 'longitude': -81.343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32828', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5523, 'longitude': -81.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32829', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4671, 'longitude': -81.2417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32830', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.3822, 'longitude': -81.569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32831', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4656, 'longitude': -81.151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32832', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.3774, 'longitude': -81.1888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32833', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5088, 'longitude': -81.0703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32834', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32835', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5289, 'longitude': -81.4787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32836', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4115, 'longitude': -81.525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32837', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.3949, 'longitude': -81.4179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32839', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4871, 'longitude': -81.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32853', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32854', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32855', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5383, 'longitude': -81.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32856', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5484, 'longitude': -81.4201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32857', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32858', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32859', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.4429, 'longitude': -81.4026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32860', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32861', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32862', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5383, 'longitude': -81.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32867', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32868', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32869', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32872', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5383, 'longitude': -81.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32877', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32878', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32885', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5456, 'longitude': -81.3782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32886', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5383, 'longitude': -81.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32887', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32891', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5663, 'longitude': -81.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32896', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5419, 'longitude': -81.3791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32897', 'place_name': 'Orlando', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5383, 'longitude': -81.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34734', 'place_name': 'Gotha', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5384, 'longitude': -81.5208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34740', 'place_name': 'Killarney', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5454, 'longitude': -81.6507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34760', 'place_name': 'Oakland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5547, 'longitude': -81.6322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34761', 'place_name': 'Ocoee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5837, 'longitude': -81.5326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34777', 'place_name': 'Winter Garden', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5416, 'longitude': -81.6058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34778', 'place_name': 'Winter Garden', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5653, 'longitude': -81.5862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34786', 'place_name': 'Windermere', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5006, 'longitude': -81.5354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34787', 'place_name': 'Winter Garden', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Orange', 'locality_code': '95', 'latitude': 28.5423, 'longitude': -81.5911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33848', 'place_name': 'Intercession City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.2774, 'longitude': -81.5069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34739', 'place_name': 'Kenansville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 27.8767, 'longitude': -81.05, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34741', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.3051, 'longitude': -81.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34742', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.3047, 'longitude': -81.4167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34743', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.3306, 'longitude': -81.3544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34744', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.3078, 'longitude': -81.3681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34745', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.3047, 'longitude': -81.4167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34746', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.268, 'longitude': -81.4675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34747', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.3037, 'longitude': -81.5898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34758', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.1984, 'longitude': -81.487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34769', 'place_name': 'Saint Cloud', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.248, 'longitude': -81.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34770', 'place_name': 'Saint Cloud', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.2489, 'longitude': -81.2812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34771', 'place_name': 'Saint Cloud', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.273, 'longitude': -81.2003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34772', 'place_name': 'Saint Cloud', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.1905, 'longitude': -81.2645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34773', 'place_name': 'Saint Cloud', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Osceola', 'locality_code': '97', 'latitude': 28.1293, 'longitude': -81.0176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33401', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7165, 'longitude': -80.0679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33402', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7153, 'longitude': -80.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33403', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.8035, 'longitude': -80.0756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33404', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7832, 'longitude': -80.0638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33405', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.67, 'longitude': -80.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33406', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6396, 'longitude': -80.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33407', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7492, 'longitude': -80.0725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33408', 'place_name': 'North Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.8289, 'longitude': -80.0603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33409', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7162, 'longitude': -80.0965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33410', 'place_name': 'Palm Beach Gardens', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.8234, 'longitude': -80.1387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33411', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6644, 'longitude': -80.1741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33412', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.8055, 'longitude': -80.2482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33413', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6555, 'longitude': -80.1596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33414', 'place_name': 'Wellington', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6587, 'longitude': -80.2414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33415', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.656, 'longitude': -80.126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33416', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6654, 'longitude': -80.0929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33417', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7197, 'longitude': -80.1248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33418', 'place_name': 'Palm Beach Gardens', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.8234, 'longitude': -80.1387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33419', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7153, 'longitude': -80.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33420', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7153, 'longitude': -80.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33421', 'place_name': 'Royal Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7084, 'longitude': -80.2306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33422', 'place_name': 'West Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7153, 'longitude': -80.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33424', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5253, 'longitude': -80.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33425', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5253, 'longitude': -80.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33426', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5175, 'longitude': -80.0834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33427', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.376, 'longitude': -80.1072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33428', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3446, 'longitude': -80.2109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33429', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3587, 'longitude': -80.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33430', 'place_name': 'Belle Glade', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6843, 'longitude': -80.6724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33431', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3799, 'longitude': -80.0975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33432', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3462, 'longitude': -80.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33433', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3464, 'longitude': -80.1564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33434', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3839, 'longitude': -80.1749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33435', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5254, 'longitude': -80.061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33436', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5354, 'longitude': -80.1124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33437', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5312, 'longitude': -80.1418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33438', 'place_name': 'Canal Point', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.8592, 'longitude': -80.6337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33444', 'place_name': 'Delray Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4564, 'longitude': -80.0793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33445', 'place_name': 'Delray Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4564, 'longitude': -80.1054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33446', 'place_name': 'Delray Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4517, 'longitude': -80.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33448', 'place_name': 'Delray Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4615, 'longitude': -80.0728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33449', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6048, 'longitude': -80.2149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33454', 'place_name': 'Greenacres', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6237, 'longitude': -80.1253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33458', 'place_name': 'Jupiter', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.9339, 'longitude': -80.1201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33459', 'place_name': 'Lake Harbor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6931, 'longitude': -80.8145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33460', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6182, 'longitude': -80.056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33461', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6232, 'longitude': -80.0946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33462', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5747, 'longitude': -80.0794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33463', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5955, 'longitude': -80.1291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33464', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3587, 'longitude': -80.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33465', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6283, 'longitude': -80.1326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33466', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6171, 'longitude': -80.0723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33467', 'place_name': 'Lake Worth', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6104, 'longitude': -80.1683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33468', 'place_name': 'Jupiter', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.9342, 'longitude': -80.0942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33469', 'place_name': 'Jupiter', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.9831, 'longitude': -80.108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33470', 'place_name': 'Loxahatchee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7383, 'longitude': -80.276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33472', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5384, 'longitude': -80.1856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33473', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5088, 'longitude': -80.1896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33474', 'place_name': 'Boynton Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.5253, 'longitude': -80.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33476', 'place_name': 'Pahokee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.8142, 'longitude': -80.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33477', 'place_name': 'Jupiter', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.9217, 'longitude': -80.077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33478', 'place_name': 'Jupiter', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.9212, 'longitude': -80.2144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33480', 'place_name': 'Palm Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.7206, 'longitude': -80.0388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33481', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3587, 'longitude': -80.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33482', 'place_name': 'Delray Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4615, 'longitude': -80.0728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33483', 'place_name': 'Delray Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4546, 'longitude': -80.0656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33484', 'place_name': 'Delray Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4543, 'longitude': -80.1346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33486', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3481, 'longitude': -80.1104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33487', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.4116, 'longitude': -80.0928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33488', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3587, 'longitude': -80.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33493', 'place_name': 'South Bay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.6701, 'longitude': -80.7312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33496', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.403, 'longitude': -80.1813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33497', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3587, 'longitude': -80.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33498', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3907, 'longitude': -80.2161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33499', 'place_name': 'Boca Raton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Palm Beach', 'locality_code': '99', 'latitude': 26.3587, 'longitude': -80.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33523', 'place_name': 'Dade City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.4247, 'longitude': -82.2185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33524', 'place_name': 'Crystal Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.1822, 'longitude': -82.1523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33525', 'place_name': 'Dade City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3318, 'longitude': -82.2446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33526', 'place_name': 'Dade City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3101, 'longitude': -82.2478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33537', 'place_name': 'Lacoochee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.4658, 'longitude': -82.172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33539', 'place_name': 'Zephyrhills', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.213, 'longitude': -82.1657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33540', 'place_name': 'Zephyrhills', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2151, 'longitude': -82.1506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33541', 'place_name': 'Zephyrhills', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2311, 'longitude': -82.2057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33542', 'place_name': 'Zephyrhills', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2303, 'longitude': -82.1779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33543', 'place_name': 'Wesley Chapel', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2397, 'longitude': -82.3279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33544', 'place_name': 'Wesley Chapel', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2397, 'longitude': -82.3279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33545', 'place_name': 'Wesley Chapel', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2697, 'longitude': -82.2903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33559', 'place_name': 'Lutz', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.1801, 'longitude': -82.4169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33574', 'place_name': 'Saint Leo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3348, 'longitude': -82.2693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33576', 'place_name': 'San Antonio', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3371, 'longitude': -82.2882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33578', 'place_name': 'Riverview', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 27.8633, 'longitude': -82.3499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33593', 'place_name': 'Trilby', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.4625, 'longitude': -82.1948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34610', 'place_name': 'Spring Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.4079, 'longitude': -82.5398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34637', 'place_name': 'Land O Lakes', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2782, 'longitude': -82.4625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34638', 'place_name': 'Land O Lakes', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2478, 'longitude': -82.4962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34639', 'place_name': 'Land O Lakes', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2258, 'longitude': -82.4547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34652', 'place_name': 'New Port Richey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2326, 'longitude': -82.7327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34653', 'place_name': 'New Port Richey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2444, 'longitude': -82.6986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34654', 'place_name': 'New Port Richey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3022, 'longitude': -82.6264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34655', 'place_name': 'New Port Richey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2129, 'longitude': -82.6807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34656', 'place_name': 'New Port Richey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2442, 'longitude': -82.7193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34667', 'place_name': 'Hudson', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3648, 'longitude': -82.6757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34668', 'place_name': 'Port Richey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3011, 'longitude': -82.6927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34669', 'place_name': 'Hudson', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3506, 'longitude': -82.6288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34673', 'place_name': 'Port Richey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2717, 'longitude': -82.7195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34674', 'place_name': 'Hudson', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.3644, 'longitude': -82.6934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34679', 'place_name': 'Aripeka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.4302, 'longitude': -82.6616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34680', 'place_name': 'Elfers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.2167, 'longitude': -82.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34690', 'place_name': 'Holiday', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.1913, 'longitude': -82.7279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34691', 'place_name': 'Holiday', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.1913, 'longitude': -82.756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34692', 'place_name': 'Holiday', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pasco', 'locality_code': '101', 'latitude': 28.188, 'longitude': -82.7346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33701', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7723, 'longitude': -82.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33702', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8427, 'longitude': -82.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33703', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.817, 'longitude': -82.6264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33704', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7954, 'longitude': -82.6373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33705', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7391, 'longitude': -82.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33706', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7456, 'longitude': -82.7516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33707', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7549, 'longitude': -82.7208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33708', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8116, 'longitude': -82.8014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33709', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8201, 'longitude': -82.7308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33710', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7898, 'longitude': -82.7243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33711', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7465, 'longitude': -82.6897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33712', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7353, 'longitude': -82.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33713', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.789, 'longitude': -82.6779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33714', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8176, 'longitude': -82.6776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33715', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.6705, 'longitude': -82.7119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33716', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8738, 'longitude': -82.64, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33729', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8819, 'longitude': -82.6644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33730', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7709, 'longitude': -82.6793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33731', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33732', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33733', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.7709, 'longitude': -82.6793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33734', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33736', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33737', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33738', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33740', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33741', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33742', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33743', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33744', 'place_name': 'Bay Pines', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8142, 'longitude': -82.7782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33747', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33755', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.9781, 'longitude': -82.7815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33756', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.947, 'longitude': -82.7943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33757', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33758', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33759', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.975, 'longitude': -82.7019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33760', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.9004, 'longitude': -82.7152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33761', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.031, 'longitude': -82.7239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33762', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8942, 'longitude': -82.6746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33763', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0173, 'longitude': -82.7461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33764', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.916, 'longitude': -82.7343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33765', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.9902, 'longitude': -82.7433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33766', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33767', 'place_name': 'Clearwater Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.9598, 'longitude': -82.8286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33769', 'place_name': 'Clearwater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33770', 'place_name': 'Largo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.917, 'longitude': -82.8027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33771', 'place_name': 'Largo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.9085, 'longitude': -82.7568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33772', 'place_name': 'Seminole', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8466, 'longitude': -82.7954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33773', 'place_name': 'Largo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8802, 'longitude': -82.7534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33774', 'place_name': 'Largo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8839, 'longitude': -82.8265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33775', 'place_name': 'Seminole', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8397, 'longitude': -82.7912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33776', 'place_name': 'Seminole', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8505, 'longitude': -82.8263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33777', 'place_name': 'Seminole', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8688, 'longitude': -82.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33778', 'place_name': 'Largo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.884, 'longitude': -82.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33779', 'place_name': 'Largo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8397, 'longitude': -82.7725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33780', 'place_name': 'Pinellas Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33781', 'place_name': 'Pinellas Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8387, 'longitude': -82.7151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33782', 'place_name': 'Pinellas Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8681, 'longitude': -82.7086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33784', 'place_name': 'Saint Petersburg', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33785', 'place_name': 'Indian Rocks Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8868, 'longitude': -82.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33786', 'place_name': 'Belleair Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.9229, 'longitude': -82.8393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34660', 'place_name': 'Ozona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.067, 'longitude': -82.7784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34677', 'place_name': 'Oldsmar', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.046, 'longitude': -82.6848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34681', 'place_name': 'Crystal Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0914, 'longitude': -82.7798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34682', 'place_name': 'Palm Harbor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0781, 'longitude': -82.7637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34683', 'place_name': 'Palm Harbor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0662, 'longitude': -82.7585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34684', 'place_name': 'Palm Harbor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0848, 'longitude': -82.7253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34685', 'place_name': 'Palm Harbor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0967, 'longitude': -82.6964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34688', 'place_name': 'Tarpon Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.1458, 'longitude': -82.6825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34689', 'place_name': 'Tarpon Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.1385, 'longitude': -82.743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34695', 'place_name': 'Safety Harbor', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0096, 'longitude': -82.6967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34697', 'place_name': 'Dunedin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 27.8918, 'longitude': -82.7248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34698', 'place_name': 'Dunedin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Pinellas', 'locality_code': '103', 'latitude': 28.0284, 'longitude': -82.7794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33801', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0381, 'longitude': -81.9392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33802', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.021, 'longitude': -81.9852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33803', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.014, 'longitude': -81.9523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33804', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0395, 'longitude': -81.9498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33805', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.072, 'longitude': -81.9609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33806', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0395, 'longitude': -81.9498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33807', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0395, 'longitude': -81.9498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33809', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.1762, 'longitude': -81.9591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33810', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.1479, 'longitude': -82.0372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33811', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9865, 'longitude': -82.0139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33812', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9729, 'longitude': -81.8931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33813', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9611, 'longitude': -81.9398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33815', 'place_name': 'Lakeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0496, 'longitude': -82.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33820', 'place_name': 'Alturas', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0026, 'longitude': -81.6186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33823', 'place_name': 'Auburndale', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0724, 'longitude': -81.8122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33827', 'place_name': 'Babson Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8163, 'longitude': -81.5139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33830', 'place_name': 'Bartow', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8957, 'longitude': -81.8127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33831', 'place_name': 'Bartow', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8964, 'longitude': -81.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33835', 'place_name': 'Bradley', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.6993, 'longitude': -81.9494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33836', 'place_name': 'Davenport', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.1672, 'longitude': -81.6316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33837', 'place_name': 'Davenport', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.1963, 'longitude': -81.6079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33838', 'place_name': 'Dundee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0194, 'longitude': -81.6212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33839', 'place_name': 'Eagle Lake', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9787, 'longitude': -81.7564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33840', 'place_name': 'Eaton Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0086, 'longitude': -81.9076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33841', 'place_name': 'Fort Meade', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.7464, 'longitude': -81.7823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33843', 'place_name': 'Frostproof', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.7211, 'longitude': -81.5148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33844', 'place_name': 'Haines City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.1145, 'longitude': -81.6201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33845', 'place_name': 'Haines City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0026, 'longitude': -81.6186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33846', 'place_name': 'Highland City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9647, 'longitude': -81.8672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33847', 'place_name': 'Homeland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8178, 'longitude': -81.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33849', 'place_name': 'Kathleen', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.1975, 'longitude': -82.0396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33850', 'place_name': 'Lake Alfred', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0895, 'longitude': -81.7271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33851', 'place_name': 'Lake Hamilton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0369, 'longitude': -81.628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33853', 'place_name': 'Lake Wales', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9002, 'longitude': -81.5847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33854', 'place_name': 'Lakeshore', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.966, 'longitude': -81.6965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33855', 'place_name': 'Indian Lake Estates', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.798, 'longitude': -81.3572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33856', 'place_name': 'Nalcrest', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8557, 'longitude': -81.4309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33858', 'place_name': 'Loughman', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.242, 'longitude': -81.5667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33859', 'place_name': 'Lake Wales', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8774, 'longitude': -81.6221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33860', 'place_name': 'Mulberry', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.902, 'longitude': -82.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33863', 'place_name': 'Nichols', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8903, 'longitude': -82.0315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33867', 'place_name': 'River Ranch', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.7686, 'longitude': -81.1966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33868', 'place_name': 'Polk City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.1987, 'longitude': -81.8083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33877', 'place_name': 'Waverly', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9769, 'longitude': -81.6144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33880', 'place_name': 'Winter Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.9873, 'longitude': -81.7625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33881', 'place_name': 'Winter Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0452, 'longitude': -81.7325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33882', 'place_name': 'Winter Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0294, 'longitude': -81.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33883', 'place_name': 'Winter Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0222, 'longitude': -81.7329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33884', 'place_name': 'Winter Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.981, 'longitude': -81.6736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33885', 'place_name': 'Winter Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0026, 'longitude': -81.6186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33888', 'place_name': 'Winter Haven', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0231, 'longitude': -81.7234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33896', 'place_name': 'Davenport', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.2531, 'longitude': -81.6509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33897', 'place_name': 'Davenport', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.3112, 'longitude': -81.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33898', 'place_name': 'Lake Wales', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 27.8643, 'longitude': -81.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33967', 'place_name': 'Fort Myers', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 26.4722, 'longitude': -81.8122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34714', 'place_name': 'Clermont', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.4113, 'longitude': -81.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34759', 'place_name': 'Kissimmee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Polk', 'locality_code': '105', 'latitude': 28.0946, 'longitude': -81.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32007', 'place_name': 'Bostwick', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.7996, 'longitude': -81.6273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32112', 'place_name': 'Crescent City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.4272, 'longitude': -81.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32131', 'place_name': 'East Palatka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.6609, 'longitude': -81.5879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32138', 'place_name': 'Grandin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.7277, 'longitude': -81.9184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32139', 'place_name': 'Georgetown', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.3842, 'longitude': -81.6183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32140', 'place_name': 'Florahome', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.7581, 'longitude': -81.8622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32147', 'place_name': 'Hollister', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.6227, 'longitude': -81.8137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32148', 'place_name': 'Interlachen', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.627, 'longitude': -81.8894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32149', 'place_name': 'Interlachen', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.6242, 'longitude': -81.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32157', 'place_name': 'Lake Como', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.4839, 'longitude': -81.5729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32177', 'place_name': 'Palatka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.6577, 'longitude': -81.6595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32178', 'place_name': 'Palatka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.6486, 'longitude': -81.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32181', 'place_name': 'Pomona Park', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.5002, 'longitude': -81.5915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32185', 'place_name': 'Putnam Hall', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.7368, 'longitude': -81.958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32187', 'place_name': 'San Mateo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.5888, 'longitude': -81.5921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32189', 'place_name': 'Satsuma', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.5594, 'longitude': -81.6406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32193', 'place_name': 'Welaka', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.4905, 'longitude': -81.653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32666', 'place_name': 'Melrose', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 29.7325, 'longitude': -82.0279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33112', 'place_name': 'Miami', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Putnam', 'locality_code': '107', 'latitude': 25.7964, 'longitude': -80.3849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32004', 'place_name': 'Ponte Vedra Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 30.2397, 'longitude': -81.3856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32033', 'place_name': 'Elkton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.7882, 'longitude': -81.462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32080', 'place_name': 'Saint Augustine', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.7964, 'longitude': -81.2649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32081', 'place_name': 'Ponte Vedra', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 30.1204, 'longitude': -81.4128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32082', 'place_name': 'Ponte Vedra Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 30.1223, 'longitude': -81.3627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32084', 'place_name': 'Saint Augustine', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.9175, 'longitude': -81.3668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32085', 'place_name': 'Saint Augustine', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.9377, 'longitude': -81.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32086', 'place_name': 'Saint Augustine', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.8285, 'longitude': -81.3237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32092', 'place_name': 'Saint Augustine', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.9475, 'longitude': -81.5264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32095', 'place_name': 'Saint Augustine', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 30.011, 'longitude': -81.4108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32145', 'place_name': 'Hastings', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.7051, 'longitude': -81.4909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32259', 'place_name': 'Saint Johns', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 30.0815, 'longitude': -81.5477, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32260', 'place_name': 'Jacksonville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Saint Johns', 'locality_code': '109', 'latitude': 29.9377, 'longitude': -81.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34945', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.4382, 'longitude': -80.444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34946', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.5008, 'longitude': -80.36, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34947', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.4493, 'longitude': -80.3592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34948', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3822, 'longitude': -80.409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34949', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3896, 'longitude': -80.2615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34950', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.4486, 'longitude': -80.3385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34951', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.5391, 'longitude': -80.4052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34952', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.2889, 'longitude': -80.298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34953', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.2625, 'longitude': -80.3793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34954', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3822, 'longitude': -80.409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34979', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3822, 'longitude': -80.409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34981', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.4049, 'longitude': -80.3623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34982', 'place_name': 'Fort Pierce', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3908, 'longitude': -80.3246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34983', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3094, 'longitude': -80.345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34984', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.2655, 'longitude': -80.3389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34985', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.2939, 'longitude': -80.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34986', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3215, 'longitude': -80.403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34987', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.2606, 'longitude': -80.4771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34988', 'place_name': 'Port Saint Lucie', 'state': 'Florida', 'state_ab': 'FL', 'county': 'St. Lucie', 'locality_code': '111', 'latitude': 27.3868, 'longitude': -80.5037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32530', 'place_name': 'Bagdad', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.5986, 'longitude': -87.0315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32561', 'place_name': 'Gulf Breeze', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.3571, 'longitude': -87.1639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32562', 'place_name': 'Gulf Breeze', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.3571, 'longitude': -87.1639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32563', 'place_name': 'Gulf Breeze', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.3962, 'longitude': -87.0274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32565', 'place_name': 'Jay', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.8985, 'longitude': -87.1332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32566', 'place_name': 'Navarre', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.4212, 'longitude': -86.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32570', 'place_name': 'Milton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.6604, 'longitude': -87.0473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32571', 'place_name': 'Milton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.6698, 'longitude': -87.1794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32572', 'place_name': 'Milton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.6592, 'longitude': -87.0497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32583', 'place_name': 'Milton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Santa Rosa', 'locality_code': '113', 'latitude': 30.5761, 'longitude': -87.0663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34223', 'place_name': 'Englewood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 26.9667, 'longitude': -82.3599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34224', 'place_name': 'Englewood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 26.92, 'longitude': -82.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34229', 'place_name': 'Osprey', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.1838, 'longitude': -82.4853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34230', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.335, 'longitude': -82.5372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34231', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.2666, 'longitude': -82.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34232', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3262, 'longitude': -82.4724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34233', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.2866, 'longitude': -82.477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34234', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3688, 'longitude': -82.5268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34235', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3672, 'longitude': -82.4848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34236', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3269, 'longitude': -82.5433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34237', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3369, 'longitude': -82.5128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34238', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.2427, 'longitude': -82.4751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34239', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3111, 'longitude': -82.5195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34240', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.339, 'longitude': -82.3473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34241', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.2822, 'longitude': -82.4181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34242', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.2566, 'longitude': -82.5398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34249', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.2664, 'longitude': -82.4841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34272', 'place_name': 'Laurel', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.147, 'longitude': -82.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34274', 'place_name': 'Nokomis', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.144, 'longitude': -82.4645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34275', 'place_name': 'Nokomis', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.1384, 'longitude': -82.4518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34276', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3364, 'longitude': -82.5307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34277', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3364, 'longitude': -82.5307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34278', 'place_name': 'Sarasota', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.3316, 'longitude': -82.5285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34284', 'place_name': 'Venice', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.1675, 'longitude': -82.381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34285', 'place_name': 'Venice', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0933, 'longitude': -82.4498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34286', 'place_name': 'North Port', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0748, 'longitude': -82.1756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34287', 'place_name': 'North Port', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0478, 'longitude': -82.2416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34288', 'place_name': 'North Port', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0498, 'longitude': -82.1288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34289', 'place_name': 'North Port', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0808, 'longitude': -82.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34290', 'place_name': 'North Port', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0459, 'longitude': -82.2491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34291', 'place_name': 'North Port', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0997, 'longitude': -82.2095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34292', 'place_name': 'Venice', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.09, 'longitude': -82.37, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34293', 'place_name': 'Venice', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.0606, 'longitude': -82.352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34295', 'place_name': 'Englewood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sarasota', 'locality_code': '115', 'latitude': 27.086, 'longitude': -82.4389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32701', 'place_name': 'Altamonte Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6666, 'longitude': -81.365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32707', 'place_name': 'Casselberry', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6617, 'longitude': -81.3122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32708', 'place_name': 'Winter Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6831, 'longitude': -81.2814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32714', 'place_name': 'Altamonte Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6625, 'longitude': -81.4117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32715', 'place_name': 'Altamonte Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6611, 'longitude': -81.3656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32716', 'place_name': 'Altamonte Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32718', 'place_name': 'Casselberry', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32719', 'place_name': 'Winter Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32730', 'place_name': 'Casselberry', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6513, 'longitude': -81.3418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32732', 'place_name': 'Geneva', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7503, 'longitude': -81.1114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32733', 'place_name': 'Goldenrod', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6133, 'longitude': -81.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32746', 'place_name': 'Lake Mary', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7577, 'longitude': -81.3508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32747', 'place_name': 'Lake Monroe', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.8272, 'longitude': -81.3329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32750', 'place_name': 'Longwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.712, 'longitude': -81.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32752', 'place_name': 'Longwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32762', 'place_name': 'Oviedo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32765', 'place_name': 'Oviedo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6513, 'longitude': -81.2066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32766', 'place_name': 'Oviedo', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.6607, 'longitude': -81.1134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32771', 'place_name': 'Sanford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.8013, 'longitude': -81.285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32772', 'place_name': 'Sanford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.8072, 'longitude': -81.2502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32773', 'place_name': 'Sanford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7644, 'longitude': -81.282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32779', 'place_name': 'Longwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7168, 'longitude': -81.4126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32791', 'place_name': 'Longwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32795', 'place_name': 'Lake Mary', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32799', 'place_name': 'Mid Florida', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Seminole', 'locality_code': '117', 'latitude': 28.7448, 'longitude': -81.2233, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32162', 'place_name': 'The Villages', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.9341, 'longitude': -81.9599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32163', 'place_name': 'The Villages', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.9338, 'longitude': -81.9914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33513', 'place_name': 'Bushnell', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.6611, 'longitude': -82.1553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33514', 'place_name': 'Center Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.6635, 'longitude': -81.9963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33521', 'place_name': 'Coleman', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.7997, 'longitude': -82.0701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33538', 'place_name': 'Lake Panasoffkee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.7953, 'longitude': -82.1363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33585', 'place_name': 'Sumterville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.7356, 'longitude': -82.0616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '33597', 'place_name': 'Webster', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.549, 'longitude': -82.0805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34484', 'place_name': 'Oxford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.9059, 'longitude': -82.0612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '34785', 'place_name': 'Wildwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Sumter', 'locality_code': '119', 'latitude': 28.8454, 'longitude': -82.0347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32008', 'place_name': 'Branford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Suwannee', 'locality_code': '121', 'latitude': 29.9395, 'longitude': -82.8993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32060', 'place_name': 'Live Oak', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Suwannee', 'locality_code': '121', 'latitude': 30.1759, 'longitude': -83.0304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32062', 'place_name': 'Mc Alpin', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Suwannee', 'locality_code': '121', 'latitude': 30.1509, 'longitude': -82.9662, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32064', 'place_name': 'Live Oak', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Suwannee', 'locality_code': '121', 'latitude': 30.2956, 'longitude': -82.9844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32071', 'place_name': 'O Brien', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Suwannee', 'locality_code': '121', 'latitude': 30.0381, 'longitude': -82.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32094', 'place_name': 'Wellborn', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Suwannee', 'locality_code': '121', 'latitude': 30.1796, 'longitude': -82.8505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32347', 'place_name': 'Perry', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Taylor', 'locality_code': '123', 'latitude': 30.1668, 'longitude': -83.616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32348', 'place_name': 'Perry', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Taylor', 'locality_code': '123', 'latitude': 29.9665, 'longitude': -83.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32356', 'place_name': 'Salem', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Taylor', 'locality_code': '123', 'latitude': 29.8539, 'longitude': -83.4421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32357', 'place_name': 'Shady Grove', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Taylor', 'locality_code': '123', 'latitude': 30.288, 'longitude': -83.6318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32359', 'place_name': 'Steinhatchee', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Taylor', 'locality_code': '123', 'latitude': 29.6739, 'longitude': -83.3723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32026', 'place_name': 'Raiford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Union', 'locality_code': '125', 'latitude': 30.0699, 'longitude': -82.1927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32054', 'place_name': 'Lake Butler', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Union', 'locality_code': '125', 'latitude': 30.0035, 'longitude': -82.3828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32083', 'place_name': 'Raiford', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Union', 'locality_code': '125', 'latitude': 30.0704, 'longitude': -82.2001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32697', 'place_name': 'Worthington Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Union', 'locality_code': '125', 'latitude': 29.9315, 'longitude': -82.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32105', 'place_name': 'Barberville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2005, 'longitude': -81.4065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32114', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2012, 'longitude': -81.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32115', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2108, 'longitude': -81.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32116', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.1091, 'longitude': -80.9843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32117', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2353, 'longitude': -81.0658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32118', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2219, 'longitude': -81.0095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32119', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.16, 'longitude': -81.0269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32120', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2108, 'longitude': -81.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32121', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2108, 'longitude': -81.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32122', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2108, 'longitude': -81.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32123', 'place_name': 'Port Orange', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.1383, 'longitude': -80.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32124', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.1419, 'longitude': -81.1402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32125', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2108, 'longitude': -81.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32126', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2108, 'longitude': -81.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32127', 'place_name': 'Port Orange', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.1383, 'longitude': -80.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32128', 'place_name': 'Port Orange', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.1383, 'longitude': -80.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32129', 'place_name': 'Port Orange', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.1372, 'longitude': -81.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32130', 'place_name': 'De Leon Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.1166, 'longitude': -81.3488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32132', 'place_name': 'Edgewater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9818, 'longitude': -80.9103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32141', 'place_name': 'Edgewater', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9455, 'longitude': -80.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32168', 'place_name': 'New Smyrna Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0247, 'longitude': -80.9584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32169', 'place_name': 'New Smyrna Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0172, 'longitude': -80.8885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32170', 'place_name': 'New Smyrna Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0258, 'longitude': -80.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32173', 'place_name': 'Ormond Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2858, 'longitude': -81.0559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32174', 'place_name': 'Ormond Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2833, 'longitude': -81.0882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32175', 'place_name': 'Ormond Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2858, 'longitude': -81.0559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32176', 'place_name': 'Ormond Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.3222, 'longitude': -81.0584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32180', 'place_name': 'Pierson', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2226, 'longitude': -81.4353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32190', 'place_name': 'Seville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.3201, 'longitude': -81.5279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32198', 'place_name': 'Daytona Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.2108, 'longitude': -81.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32706', 'place_name': 'Cassadaga', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9664, 'longitude': -81.2371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32713', 'place_name': 'Debary', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.8846, 'longitude': -81.3065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32720', 'place_name': 'Deland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0266, 'longitude': -81.3349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32721', 'place_name': 'Deland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9973, 'longitude': -81.2995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32722', 'place_name': 'Glenwood', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0861, 'longitude': -81.3542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32723', 'place_name': 'Deland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0275, 'longitude': -81.3068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32724', 'place_name': 'Deland', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0422, 'longitude': -81.2863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32725', 'place_name': 'Deltona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.8989, 'longitude': -81.2473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32728', 'place_name': 'Deltona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0227, 'longitude': -81.1722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32738', 'place_name': 'Deltona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9093, 'longitude': -81.1922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32739', 'place_name': 'Deltona', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 29.0227, 'longitude': -81.1722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32744', 'place_name': 'Lake Helen', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9806, 'longitude': -81.2334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32745', 'place_name': 'Mid Florida', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.7676, 'longitude': -81.3522, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '32759', 'place_name': 'Oak Hill', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.87, 'longitude': -80.8551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32763', 'place_name': 'Orange City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9453, 'longitude': -81.2995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32764', 'place_name': 'Osteen', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.8426, 'longitude': -81.1562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32774', 'place_name': 'Orange City', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Volusia', 'locality_code': '127', 'latitude': 28.9489, 'longitude': -81.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32326', 'place_name': 'Crawfordville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Wakulla', 'locality_code': '129', 'latitude': 30.176, 'longitude': -84.3752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32327', 'place_name': 'Crawfordville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Wakulla', 'locality_code': '129', 'latitude': 30.2108, 'longitude': -84.3205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32346', 'place_name': 'Panacea', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Wakulla', 'locality_code': '129', 'latitude': 30.0153, 'longitude': -84.3912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32355', 'place_name': 'Saint Marks', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Wakulla', 'locality_code': '129', 'latitude': 30.1631, 'longitude': -84.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32358', 'place_name': 'Sopchoppy', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Wakulla', 'locality_code': '129', 'latitude': 30.0714, 'longitude': -84.4549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32422', 'place_name': 'Argyle', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.7056, 'longitude': -86.0314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32433', 'place_name': 'Defuniak Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.8494, 'longitude': -86.2023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32434', 'place_name': 'Mossy Head', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.7432, 'longitude': -86.3149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32435', 'place_name': 'Defuniak Springs', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.721, 'longitude': -86.1152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32439', 'place_name': 'Freeport', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.4896, 'longitude': -86.1684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32459', 'place_name': 'Santa Rosa Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.3659, 'longitude': -86.2458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32461', 'place_name': 'Rosemary Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.2835, 'longitude': -86.0305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32538', 'place_name': 'Paxton', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.9709, 'longitude': -86.3111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32550', 'place_name': 'Miramar Beach', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Walton', 'locality_code': '131', 'latitude': 30.385, 'longitude': -86.3473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32427', 'place_name': 'Caryville', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Washington', 'locality_code': '133', 'latitude': 30.7123, 'longitude': -85.8014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32428', 'place_name': 'Chipley', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Washington', 'locality_code': '133', 'latitude': 30.7107, 'longitude': -85.5486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32437', 'place_name': 'Ebro', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Washington', 'locality_code': '133', 'latitude': 30.4352, 'longitude': -85.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32462', 'place_name': 'Vernon', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Washington', 'locality_code': '133', 'latitude': 30.6267, 'longitude': -85.7553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '32463', 'place_name': 'Wausau', 'state': 'Florida', 'state_ab': 'FL', 'county': 'Washington', 'locality_code': '133', 'latitude': 30.6321, 'longitude': -85.5888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31513', 'place_name': 'Baxley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Appling', 'locality_code': '1', 'latitude': 31.7837, 'longitude': -82.3486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31515', 'place_name': 'Baxley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Appling', 'locality_code': '1', 'latitude': 31.7783, 'longitude': -82.3485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31562', 'place_name': 'Saint George', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Appling', 'locality_code': '1', 'latitude': 30.5224, 'longitude': -82.0376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31563', 'place_name': 'Surrency', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Appling', 'locality_code': '1', 'latitude': 31.6489, 'longitude': -82.1982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31624', 'place_name': 'Axson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Atkinson', 'locality_code': '3', 'latitude': 31.3035, 'longitude': -82.7319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31642', 'place_name': 'Pearson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Atkinson', 'locality_code': '3', 'latitude': 31.3106, 'longitude': -82.8591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31650', 'place_name': 'Willacoochee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Atkinson', 'locality_code': '3', 'latitude': 31.3455, 'longitude': -83.0449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31510', 'place_name': 'Alma', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bacon', 'locality_code': '5', 'latitude': 31.5465, 'longitude': -82.4633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31721', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baker', 'locality_code': '7', 'latitude': 31.5105, 'longitude': -84.3087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39837', 'place_name': 'Colquitt', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baker', 'locality_code': '7', 'latitude': 31.173, 'longitude': -84.731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39841', 'place_name': 'Damascus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baker', 'locality_code': '7', 'latitude': 31.2984, 'longitude': -84.7175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39845', 'place_name': 'Donalsonville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baker', 'locality_code': '7', 'latitude': 31.0505, 'longitude': -84.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39862', 'place_name': 'Leary', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baker', 'locality_code': '7', 'latitude': 31.4849, 'longitude': -84.5128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39870', 'place_name': 'Newton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baker', 'locality_code': '7', 'latitude': 31.3164, 'longitude': -84.3367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31034', 'place_name': 'Hardwick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baldwin', 'locality_code': '9', 'latitude': 33.0227, 'longitude': -83.247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31059', 'place_name': 'Milledgeville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baldwin', 'locality_code': '9', 'latitude': 33.0846, 'longitude': -83.238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31061', 'place_name': 'Milledgeville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baldwin', 'locality_code': '9', 'latitude': 33.08, 'longitude': -83.2379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31062', 'place_name': 'Milledgeville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Baldwin', 'locality_code': '9', 'latitude': 33.0491, 'longitude': -83.2174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30511', 'place_name': 'Baldwin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Banks', 'locality_code': '11', 'latitude': 34.4574, 'longitude': -83.476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30547', 'place_name': 'Homer', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Banks', 'locality_code': '11', 'latitude': 34.3563, 'longitude': -83.4974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30558', 'place_name': 'Maysville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Banks', 'locality_code': '11', 'latitude': 34.2529, 'longitude': -83.5616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30011', 'place_name': 'Auburn', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Barrow', 'locality_code': '13', 'latitude': 34.0191, 'longitude': -83.8261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30620', 'place_name': 'Bethlehem', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Barrow', 'locality_code': '13', 'latitude': 33.9261, 'longitude': -83.7282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30666', 'place_name': 'Statham', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Barrow', 'locality_code': '13', 'latitude': 33.9602, 'longitude': -83.5893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30680', 'place_name': 'Winder', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Barrow', 'locality_code': '13', 'latitude': 33.9985, 'longitude': -83.7115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30103', 'place_name': 'Adairsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.3595, 'longitude': -84.9176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30120', 'place_name': 'Cartersville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.187, 'longitude': -84.8204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30121', 'place_name': 'Cartersville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.2079, 'longitude': -84.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30123', 'place_name': 'Cassville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.2442, 'longitude': -84.8457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30137', 'place_name': 'Emerson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.12, 'longitude': -84.757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30145', 'place_name': 'Kingston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.2501, 'longitude': -84.9973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30171', 'place_name': 'Rydal', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.3379, 'longitude': -84.7376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30178', 'place_name': 'Taylorsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.1229, 'longitude': -84.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30184', 'place_name': 'White', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bartow', 'locality_code': '15', 'latitude': 34.2717, 'longitude': -84.7383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31750', 'place_name': 'Fitzgerald', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ben Hill', 'locality_code': '17', 'latitude': 31.7248, 'longitude': -83.2495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39840', 'place_name': 'Cuthbert', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ben Hill', 'locality_code': '17', 'latitude': 31.7706, 'longitude': -84.7936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31622', 'place_name': 'Alapaha', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Berrien', 'locality_code': '19', 'latitude': 31.394, 'longitude': -83.2132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31639', 'place_name': 'Nashville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Berrien', 'locality_code': '19', 'latitude': 31.2074, 'longitude': -83.2319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31645', 'place_name': 'Ray City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Berrien', 'locality_code': '19', 'latitude': 31.0825, 'longitude': -83.2143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31749', 'place_name': 'Enigma', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Berrien', 'locality_code': '19', 'latitude': 31.3736, 'longitude': -83.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31052', 'place_name': 'Lizella', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.7773, 'longitude': -83.825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31201', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8095, 'longitude': -83.6168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31202', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8407, 'longitude': -83.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31203', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8067, 'longitude': -83.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31204', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8424, 'longitude': -83.6766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31205', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8067, 'longitude': -83.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31206', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.7914, 'longitude': -83.679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31207', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8304, 'longitude': -83.6486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31208', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8067, 'longitude': -83.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31209', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8067, 'longitude': -83.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31210', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8926, 'longitude': -83.7455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31211', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8869, 'longitude': -83.6021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31213', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8393, 'longitude': -83.6388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31216', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.7486, 'longitude': -83.7477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31217', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8118, 'longitude': -83.565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31220', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8595, 'longitude': -83.802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31221', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8407, 'longitude': -83.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31294', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8407, 'longitude': -83.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31295', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8102, 'longitude': -83.569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31296', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.8067, 'longitude': -83.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31297', 'place_name': 'Macon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bibb', 'locality_code': '21', 'latitude': 32.7004, 'longitude': -83.6572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31014', 'place_name': 'Cochran', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bleckley', 'locality_code': '23', 'latitude': 32.3981, 'longitude': -83.3229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31542', 'place_name': 'Hoboken', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brantley', 'locality_code': '25', 'latitude': 31.1431, 'longitude': -82.1207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31543', 'place_name': 'Hortense', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brantley', 'locality_code': '25', 'latitude': 31.3199, 'longitude': -81.9596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31553', 'place_name': 'Nahunta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brantley', 'locality_code': '25', 'latitude': 31.1827, 'longitude': -81.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31566', 'place_name': 'Waynesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brantley', 'locality_code': '25', 'latitude': 31.2448, 'longitude': -81.8039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31625', 'place_name': 'Barney', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brooks', 'locality_code': '27', 'latitude': 31.0074, 'longitude': -83.5219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31629', 'place_name': 'Dixie', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brooks', 'locality_code': '27', 'latitude': 30.7722, 'longitude': -83.6792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31638', 'place_name': 'Morven', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brooks', 'locality_code': '27', 'latitude': 30.9416, 'longitude': -83.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31643', 'place_name': 'Quitman', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brooks', 'locality_code': '27', 'latitude': 30.7797, 'longitude': -83.5567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31720', 'place_name': 'Barwick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Brooks', 'locality_code': '27', 'latitude': 30.8902, 'longitude': -83.7407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31308', 'place_name': 'Ellabell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bryan', 'locality_code': '29', 'latitude': 32.1273, 'longitude': -81.4983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31321', 'place_name': 'Pembroke', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bryan', 'locality_code': '29', 'latitude': 32.1812, 'longitude': -81.6656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31324', 'place_name': 'Richmond Hill', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bryan', 'locality_code': '29', 'latitude': 31.8962, 'longitude': -81.294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30415', 'place_name': 'Brooklet', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bulloch', 'locality_code': '31', 'latitude': 32.294, 'longitude': -81.628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30450', 'place_name': 'Portal', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bulloch', 'locality_code': '31', 'latitude': 32.555, 'longitude': -81.9123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30452', 'place_name': 'Register', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bulloch', 'locality_code': '31', 'latitude': 32.3382, 'longitude': -81.8728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30458', 'place_name': 'Statesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bulloch', 'locality_code': '31', 'latitude': 32.4408, 'longitude': -81.774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30459', 'place_name': 'Statesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bulloch', 'locality_code': '31', 'latitude': 32.447, 'longitude': -81.7777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30460', 'place_name': 'Statesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bulloch', 'locality_code': '31', 'latitude': 32.4179, 'longitude': -81.7823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30461', 'place_name': 'Statesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Bulloch', 'locality_code': '31', 'latitude': 32.45, 'longitude': -81.7158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30426', 'place_name': 'Girard', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Burke', 'locality_code': '33', 'latitude': 33.0437, 'longitude': -81.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30441', 'place_name': 'Midville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Burke', 'locality_code': '33', 'latitude': 32.8638, 'longitude': -82.2042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30456', 'place_name': 'Sardis', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Burke', 'locality_code': '33', 'latitude': 32.9809, 'longitude': -81.773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30811', 'place_name': 'Gough', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Burke', 'locality_code': '33', 'latitude': 33.0918, 'longitude': -82.2265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30816', 'place_name': 'Keysville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Burke', 'locality_code': '33', 'latitude': 33.1719, 'longitude': -82.1834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30830', 'place_name': 'Waynesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Burke', 'locality_code': '33', 'latitude': 33.1013, 'longitude': -81.9908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30216', 'place_name': 'Flovilla', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Butts', 'locality_code': '35', 'latitude': 33.25, 'longitude': -83.9079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30233', 'place_name': 'Jackson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Butts', 'locality_code': '35', 'latitude': 33.282, 'longitude': -83.9784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30234', 'place_name': 'Jenkinsburg', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Butts', 'locality_code': '35', 'latitude': 33.3224, 'longitude': -84.0287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39842', 'place_name': 'Dawson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Calhoun', 'locality_code': '37', 'latitude': 31.7703, 'longitude': -84.5238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39866', 'place_name': 'Morgan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Calhoun', 'locality_code': '37', 'latitude': 31.5374, 'longitude': -84.5994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39886', 'place_name': 'Shellman', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Calhoun', 'locality_code': '37', 'latitude': 31.7608, 'longitude': -84.6092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31547', 'place_name': 'Kings Bay', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Camden', 'locality_code': '39', 'latitude': 30.7906, 'longitude': -81.5607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31548', 'place_name': 'Kingsland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Camden', 'locality_code': '39', 'latitude': 30.7977, 'longitude': -81.7075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31558', 'place_name': 'Saint Marys', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Camden', 'locality_code': '39', 'latitude': 30.7305, 'longitude': -81.5465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31565', 'place_name': 'Waverly', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Camden', 'locality_code': '39', 'latitude': 31.0427, 'longitude': -81.5697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31568', 'place_name': 'White Oak', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Camden', 'locality_code': '39', 'latitude': 30.9952, 'longitude': -81.7782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31569', 'place_name': 'Woodbine', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Camden', 'locality_code': '39', 'latitude': 30.9437, 'longitude': -81.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30439', 'place_name': 'Metter', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Candler', 'locality_code': '43', 'latitude': 32.401, 'longitude': -82.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30451', 'place_name': 'Pulaski', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Candler', 'locality_code': '43', 'latitude': 32.3902, 'longitude': -81.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30108', 'place_name': 'Bowdon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.5373, 'longitude': -85.2533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30109', 'place_name': 'Bowdon Junction', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.6534, 'longitude': -85.1362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30112', 'place_name': 'Carrollton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.5809, 'longitude': -85.0792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30116', 'place_name': 'Carrollton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.6045, 'longitude': -85.0499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30117', 'place_name': 'Carrollton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.5798, 'longitude': -85.0812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30118', 'place_name': 'Carrollton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.5712, 'longitude': -85.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30119', 'place_name': 'Carrollton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.6189, 'longitude': -85.0736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30150', 'place_name': 'Mount Zion', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.643, 'longitude': -85.1818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30170', 'place_name': 'Roopville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.4322, 'longitude': -85.1671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30179', 'place_name': 'Temple', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.7677, 'longitude': -85.0133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30180', 'place_name': 'Villa Rica', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.7173, 'longitude': -84.9297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30185', 'place_name': 'Whitesburg', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Carroll', 'locality_code': '45', 'latitude': 33.5111, 'longitude': -84.9254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30726', 'place_name': 'Graysville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Catoosa', 'locality_code': '47', 'latitude': 34.9765, 'longitude': -85.1413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30736', 'place_name': 'Ringgold', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Catoosa', 'locality_code': '47', 'latitude': 34.9205, 'longitude': -85.1549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30742', 'place_name': 'Fort Oglethorpe', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Catoosa', 'locality_code': '47', 'latitude': 34.9506, 'longitude': -85.2432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31537', 'place_name': 'Folkston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Charlton', 'locality_code': '49', 'latitude': 30.8508, 'longitude': -82.0116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31302', 'place_name': 'Bloomingdale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.1177, 'longitude': -81.3085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31322', 'place_name': 'Pooler', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.1149, 'longitude': -81.252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31328', 'place_name': 'Tybee Island', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0068, 'longitude': -80.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31401', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0749, 'longitude': -81.0883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31402', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0835, 'longitude': -81.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31403', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.9714, 'longitude': -81.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31404', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0543, 'longitude': -81.0492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31405', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0391, 'longitude': -81.1242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31406', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.989, 'longitude': -81.0979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31407', 'place_name': 'Port Wentworth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.1491, 'longitude': -81.1632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31408', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.1082, 'longitude': -81.1746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31409', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0093, 'longitude': -81.157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31410', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0175, 'longitude': -80.997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31411', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.9268, 'longitude': -81.0381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31412', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0835, 'longitude': -81.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31414', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.9714, 'longitude': -81.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31415', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0753, 'longitude': -81.1289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31416', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 32.0053, 'longitude': -81.0477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31418', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.9714, 'longitude': -81.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31419', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.9959, 'longitude': -81.2358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31420', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.9714, 'longitude': -81.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31421', 'place_name': 'Savannah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chatham', 'locality_code': '51', 'latitude': 31.9714, 'longitude': -81.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31805', 'place_name': 'Cusseta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chattahoochee', 'locality_code': '53', 'latitude': 32.299, 'longitude': -84.7645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30730', 'place_name': 'Lyerly', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chattooga', 'locality_code': '55', 'latitude': 34.403, 'longitude': -85.4038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30731', 'place_name': 'Menlo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chattooga', 'locality_code': '55', 'latitude': 34.5864, 'longitude': -85.4774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30747', 'place_name': 'Summerville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chattooga', 'locality_code': '55', 'latitude': 34.4859, 'longitude': -85.3362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30753', 'place_name': 'Trion', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Chattooga', 'locality_code': '55', 'latitude': 34.5468, 'longitude': -85.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30107', 'place_name': 'Ball Ground', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.3393, 'longitude': -84.3758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30114', 'place_name': 'Canton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.2505, 'longitude': -84.4909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30115', 'place_name': 'Canton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.1993, 'longitude': -84.4199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30142', 'place_name': 'Holly Springs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.174, 'longitude': -84.5013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30146', 'place_name': 'Lebanon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.2429, 'longitude': -84.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30151', 'place_name': 'Nelson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.382, 'longitude': -84.371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30169', 'place_name': 'Canton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.234, 'longitude': -84.4904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30183', 'place_name': 'Waleska', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.3217, 'longitude': -84.562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30188', 'place_name': 'Woodstock', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.106, 'longitude': -84.5117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30189', 'place_name': 'Woodstock', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cherokee', 'locality_code': '57', 'latitude': 34.1281, 'longitude': -84.5717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30601', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9761, 'longitude': -83.3632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30602', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9433, 'longitude': -83.3724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30603', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9609, 'longitude': -83.3779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30604', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9443, 'longitude': -83.3891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30605', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9321, 'longitude': -83.3525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30606', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9461, 'longitude': -83.418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30607', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 34.007, 'longitude': -83.4278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30608', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9443, 'longitude': -83.3891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30609', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9464, 'longitude': -83.3774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30612', 'place_name': 'Athens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9443, 'longitude': -83.3891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30683', 'place_name': 'Winterville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clarke', 'locality_code': '59', 'latitude': 33.9543, 'longitude': -83.2906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39823', 'place_name': 'Blakely', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clay', 'locality_code': '61', 'latitude': 31.3791, 'longitude': -84.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39824', 'place_name': 'Bluffton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clay', 'locality_code': '61', 'latitude': 31.52, 'longitude': -84.867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39836', 'place_name': 'Coleman', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clay', 'locality_code': '61', 'latitude': 31.6726, 'longitude': -84.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39846', 'place_name': 'Edison', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clay', 'locality_code': '61', 'latitude': 31.5607, 'longitude': -84.7381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39851', 'place_name': 'Fort Gaines', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clay', 'locality_code': '61', 'latitude': 31.6264, 'longitude': -85.0548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39854', 'place_name': 'Georgetown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clay', 'locality_code': '61', 'latitude': 31.8854, 'longitude': -85.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39867', 'place_name': 'Morris', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clay', 'locality_code': '61', 'latitude': 31.8343, 'longitude': -84.9255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30236', 'place_name': 'Jonesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5242, 'longitude': -84.359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30237', 'place_name': 'Jonesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5007, 'longitude': -84.3513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30238', 'place_name': 'Jonesboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.4944, 'longitude': -84.3797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30250', 'place_name': 'Lovejoy', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.4429, 'longitude': -84.3136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30260', 'place_name': 'Morrow', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5849, 'longitude': -84.3247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30273', 'place_name': 'Rex', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5808, 'longitude': -84.2782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30274', 'place_name': 'Riverdale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5531, 'longitude': -84.4003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30287', 'place_name': 'Morrow', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5007, 'longitude': -84.3513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30288', 'place_name': 'Conley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.6369, 'longitude': -84.3371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30294', 'place_name': 'Ellenwood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.6166, 'longitude': -84.2939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30296', 'place_name': 'Riverdale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5667, 'longitude': -84.4364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30297', 'place_name': 'Forest Park', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.6115, 'longitude': -84.3745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30298', 'place_name': 'Forest Park', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clayton', 'locality_code': '63', 'latitude': 33.5007, 'longitude': -84.3513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31623', 'place_name': 'Argyle', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clinch', 'locality_code': '65', 'latitude': 31.0744, 'longitude': -82.644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31630', 'place_name': 'Du Pont', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clinch', 'locality_code': '65', 'latitude': 30.9885, 'longitude': -82.8715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31631', 'place_name': 'Fargo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clinch', 'locality_code': '65', 'latitude': 30.6819, 'longitude': -82.5665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31634', 'place_name': 'Homerville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Clinch', 'locality_code': '65', 'latitude': 31.0509, 'longitude': -82.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30006', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9526, 'longitude': -84.5499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30007', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9125, 'longitude': -84.5572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30008', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.8972, 'longitude': -84.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30060', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9382, 'longitude': -84.5403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30061', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9328, 'longitude': -84.556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30062', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0025, 'longitude': -84.4633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30063', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9653, 'longitude': -84.5112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30064', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9343, 'longitude': -84.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30065', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9125, 'longitude': -84.5572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30066', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0378, 'longitude': -84.5038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30067', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9282, 'longitude': -84.4733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30068', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9679, 'longitude': -84.4385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30069', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9125, 'longitude': -84.5572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30080', 'place_name': 'Smyrna', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.8796, 'longitude': -84.5023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30081', 'place_name': 'Smyrna', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.8588, 'longitude': -84.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30082', 'place_name': 'Smyrna', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.8631, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30090', 'place_name': 'Marietta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9525, 'longitude': -84.5471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30101', 'place_name': 'Acworth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0756, 'longitude': -84.6477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30102', 'place_name': 'Acworth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0707, 'longitude': -84.5894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30106', 'place_name': 'Austell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.8369, 'longitude': -84.6307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30111', 'place_name': 'Clarkdale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9125, 'longitude': -84.5572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30126', 'place_name': 'Mableton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.8332, 'longitude': -84.6031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30127', 'place_name': 'Powder Springs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9135, 'longitude': -84.6859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30144', 'place_name': 'Kennesaw', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0287, 'longitude': -84.6047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30152', 'place_name': 'Kennesaw', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.9951, 'longitude': -84.6544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30156', 'place_name': 'Kennesaw', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0177, 'longitude': -84.625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30160', 'place_name': 'Kennesaw', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0177, 'longitude': -84.625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30168', 'place_name': 'Austell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 33.7838, 'longitude': -84.5952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31144', 'place_name': 'Kennesaw', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cobb', 'locality_code': '67', 'latitude': 34.0233, 'longitude': -84.6156, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31512', 'place_name': 'Ambrose', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coffee', 'locality_code': '69', 'latitude': 31.5367, 'longitude': -82.9976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31519', 'place_name': 'Broxton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coffee', 'locality_code': '69', 'latitude': 31.6484, 'longitude': -82.905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31533', 'place_name': 'Douglas', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coffee', 'locality_code': '69', 'latitude': 31.4973, 'longitude': -82.8465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31534', 'place_name': 'Douglas', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coffee', 'locality_code': '69', 'latitude': 31.5088, 'longitude': -82.8499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31535', 'place_name': 'Douglas', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coffee', 'locality_code': '69', 'latitude': 31.4551, 'longitude': -82.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31554', 'place_name': 'Nicholls', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coffee', 'locality_code': '69', 'latitude': 31.4498, 'longitude': -82.6032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31567', 'place_name': 'West Green', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coffee', 'locality_code': '69', 'latitude': 31.6143, 'longitude': -82.7243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31722', 'place_name': 'Berlin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.0682, 'longitude': -83.6238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31744', 'place_name': 'Doerun', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.3136, 'longitude': -83.9253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31747', 'place_name': 'Ellenton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.1789, 'longitude': -83.5889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31753', 'place_name': 'Funston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.2054, 'longitude': -83.8776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31756', 'place_name': 'Hartsfield', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.2173, 'longitude': -83.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31768', 'place_name': 'Moultrie', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.1792, 'longitude': -83.7641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31771', 'place_name': 'Norman Park', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.2462, 'longitude': -83.6549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31776', 'place_name': 'Moultrie', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.1727, 'longitude': -83.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31788', 'place_name': 'Moultrie', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Colquitt', 'locality_code': '71', 'latitude': 31.0855, 'longitude': -83.6821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30802', 'place_name': 'Appling', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Columbia', 'locality_code': '73', 'latitude': 33.6271, 'longitude': -82.2856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30809', 'place_name': 'Evans', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Columbia', 'locality_code': '73', 'latitude': 33.5412, 'longitude': -82.1398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30813', 'place_name': 'Grovetown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Columbia', 'locality_code': '73', 'latitude': 33.4504, 'longitude': -82.1982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30814', 'place_name': 'Harlem', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Columbia', 'locality_code': '73', 'latitude': 33.417, 'longitude': -82.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30917', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Columbia', 'locality_code': '73', 'latitude': 33.5277, 'longitude': -82.2355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39813', 'place_name': 'Arlington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Columbia', 'locality_code': '73', 'latitude': 31.442, 'longitude': -84.7241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31620', 'place_name': 'Adel', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cook', 'locality_code': '75', 'latitude': 31.1251, 'longitude': -83.4213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31627', 'place_name': 'Cecil', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cook', 'locality_code': '75', 'latitude': 31.0403, 'longitude': -83.3915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31637', 'place_name': 'Lenox', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cook', 'locality_code': '75', 'latitude': 31.2664, 'longitude': -83.4481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31647', 'place_name': 'Sparks', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Cook', 'locality_code': '75', 'latitude': 31.179, 'longitude': -83.4476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30220', 'place_name': 'Grantville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.2473, 'longitude': -84.835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30229', 'place_name': 'Haralson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.2322, 'longitude': -84.5685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30259', 'place_name': 'Moreland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.2734, 'longitude': -84.7566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30263', 'place_name': 'Newnan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.3696, 'longitude': -84.8194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30264', 'place_name': 'Newnan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.361, 'longitude': -84.8142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30265', 'place_name': 'Newnan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.3958, 'longitude': -84.7121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30271', 'place_name': 'Newnan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.3514, 'longitude': -84.7561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30275', 'place_name': 'Sargent', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.4299, 'longitude': -84.8744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30276', 'place_name': 'Senoia', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.2845, 'longitude': -84.5918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30277', 'place_name': 'Sharpsburg', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.4013, 'longitude': -84.654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30289', 'place_name': 'Turin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Coweta', 'locality_code': '77', 'latitude': 33.326, 'longitude': -84.6371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31050', 'place_name': 'Knoxville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Crawford', 'locality_code': '79', 'latitude': 32.7243, 'longitude': -83.9977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31066', 'place_name': 'Musella', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Crawford', 'locality_code': '79', 'latitude': 32.8202, 'longitude': -84.0456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31078', 'place_name': 'Roberta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Crawford', 'locality_code': '79', 'latitude': 32.7222, 'longitude': -84.0451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31010', 'place_name': 'Cordele', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Crisp', 'locality_code': '81', 'latitude': 31.9172, 'longitude': -83.7854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31015', 'place_name': 'Cordele', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Crisp', 'locality_code': '81', 'latitude': 31.9566, 'longitude': -83.7835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31712', 'place_name': 'Arabi', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Crisp', 'locality_code': '81', 'latitude': 31.8496, 'longitude': -83.7277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30738', 'place_name': 'Rising Fawn', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dade', 'locality_code': '83', 'latitude': 34.8139, 'longitude': -85.5019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30752', 'place_name': 'Trenton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dade', 'locality_code': '83', 'latitude': 34.9017, 'longitude': -85.5171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30757', 'place_name': 'Wildwood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dade', 'locality_code': '83', 'latitude': 34.9779, 'longitude': -85.4305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30534', 'place_name': 'Dawsonville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dawson', 'locality_code': '85', 'latitude': 34.4537, 'longitude': -84.155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39815', 'place_name': 'Attapulgus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Decatur', 'locality_code': '87', 'latitude': 30.7493, 'longitude': -84.4846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39818', 'place_name': 'Bainbridge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Decatur', 'locality_code': '87', 'latitude': 30.8845, 'longitude': -84.5655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39819', 'place_name': 'Bainbridge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Decatur', 'locality_code': '87', 'latitude': 30.9039, 'longitude': -84.569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39852', 'place_name': 'Fowlstown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Decatur', 'locality_code': '87', 'latitude': 30.8024, 'longitude': -84.5471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30002', 'place_name': 'Avondale Estates', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7717, 'longitude': -84.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30021', 'place_name': 'Clarkston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8101, 'longitude': -84.2388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30030', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7699, 'longitude': -84.295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30031', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7748, 'longitude': -84.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30032', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7408, 'longitude': -84.2632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30033', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8123, 'longitude': -84.2819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30034', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.6954, 'longitude': -84.2489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30035', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7278, 'longitude': -84.2143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30036', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7748, 'longitude': -84.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30037', 'place_name': 'Decatur', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7748, 'longitude': -84.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30038', 'place_name': 'Lithonia', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.6823, 'longitude': -84.161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30058', 'place_name': 'Lithonia', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7356, 'longitude': -84.1009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30072', 'place_name': 'Pine Lake', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7906, 'longitude': -84.2053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30074', 'place_name': 'Redan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7454, 'longitude': -84.1316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30079', 'place_name': 'Scottdale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7934, 'longitude': -84.2585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30083', 'place_name': 'Stone Mountain', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7942, 'longitude': -84.2018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30084', 'place_name': 'Tucker', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.857, 'longitude': -84.216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30085', 'place_name': 'Tucker', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8545, 'longitude': -84.2171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30086', 'place_name': 'Stone Mountain', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30087', 'place_name': 'Stone Mountain', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8082, 'longitude': -84.1702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30088', 'place_name': 'Stone Mountain', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.758, 'longitude': -84.1802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30319', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8687, 'longitude': -84.3351, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30322', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.7952, 'longitude': -84.3248, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30329', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8236, 'longitude': -84.3214, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30333', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30340', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8932, 'longitude': -84.2539, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30341', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8879, 'longitude': -84.2905, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30345', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8513, 'longitude': -84.287, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30346', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.9267, 'longitude': -84.3334, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30350', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.9795, 'longitude': -84.3411, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30356', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30359', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30360', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.9378, 'longitude': -84.2716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30362', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30366', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31119', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31141', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31145', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31146', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39901', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'DeKalb', 'locality_code': '89', 'latitude': 33.8913, 'longitude': -84.0746, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31011', 'place_name': 'Chauncey', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dodge', 'locality_code': '91', 'latitude': 32.1046, 'longitude': -83.0646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31012', 'place_name': 'Chester', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dodge', 'locality_code': '91', 'latitude': 32.3982, 'longitude': -83.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31023', 'place_name': 'Eastman', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dodge', 'locality_code': '91', 'latitude': 32.2084, 'longitude': -83.186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31077', 'place_name': 'Rhine', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dodge', 'locality_code': '91', 'latitude': 31.938, 'longitude': -83.1837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31007', 'place_name': 'Byromville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dooly', 'locality_code': '93', 'latitude': 32.189, 'longitude': -83.9332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31051', 'place_name': 'Lilly', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dooly', 'locality_code': '93', 'latitude': 32.1471, 'longitude': -83.8774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31063', 'place_name': 'Montezuma', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dooly', 'locality_code': '93', 'latitude': 32.3026, 'longitude': -84.0041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31070', 'place_name': 'Pinehurst', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dooly', 'locality_code': '93', 'latitude': 32.1967, 'longitude': -83.7209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31091', 'place_name': 'Unadilla', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dooly', 'locality_code': '93', 'latitude': 32.2558, 'longitude': -83.7447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31092', 'place_name': 'Vienna', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dooly', 'locality_code': '93', 'latitude': 32.0913, 'longitude': -83.7922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31701', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5678, 'longitude': -84.1619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31702', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5948, 'longitude': -84.1948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31703', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5785, 'longitude': -84.1557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31704', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.55, 'longitude': -84.0612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31705', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5464, 'longitude': -84.0783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31706', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5593, 'longitude': -84.1765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31707', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5789, 'longitude': -84.2118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31708', 'place_name': 'Albany', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5911, 'longitude': -84.1324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31782', 'place_name': 'Putney', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Dougherty', 'locality_code': '95', 'latitude': 31.5431, 'longitude': -84.2196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30122', 'place_name': 'Lithia Springs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Douglas', 'locality_code': '97', 'latitude': 33.7655, 'longitude': -84.6469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30133', 'place_name': 'Douglasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Douglas', 'locality_code': '97', 'latitude': 33.6897, 'longitude': -84.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30134', 'place_name': 'Douglasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Douglas', 'locality_code': '97', 'latitude': 33.7606, 'longitude': -84.7477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30135', 'place_name': 'Douglasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Douglas', 'locality_code': '97', 'latitude': 33.6989, 'longitude': -84.7454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30154', 'place_name': 'Douglasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Douglas', 'locality_code': '97', 'latitude': 33.7515, 'longitude': -84.7477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30187', 'place_name': 'Winston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Douglas', 'locality_code': '97', 'latitude': 33.6634, 'longitude': -84.8639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39832', 'place_name': 'Cedar Springs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Early', 'locality_code': '99', 'latitude': 31.1745, 'longitude': -85.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39834', 'place_name': 'Climax', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Early', 'locality_code': '99', 'latitude': 30.8757, 'longitude': -84.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31648', 'place_name': 'Statenville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Echols', 'locality_code': '101', 'latitude': 30.7065, 'longitude': -83.019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31303', 'place_name': 'Clyo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Effingham', 'locality_code': '103', 'latitude': 32.5126, 'longitude': -81.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31307', 'place_name': 'Eden', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Effingham', 'locality_code': '103', 'latitude': 32.1736, 'longitude': -81.3992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31312', 'place_name': 'Guyton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Effingham', 'locality_code': '103', 'latitude': 32.314, 'longitude': -81.3896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31318', 'place_name': 'Meldrim', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Effingham', 'locality_code': '103', 'latitude': 32.1499, 'longitude': -81.3722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31326', 'place_name': 'Rincon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Effingham', 'locality_code': '103', 'latitude': 32.296, 'longitude': -81.2354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31329', 'place_name': 'Springfield', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Effingham', 'locality_code': '103', 'latitude': 32.3697, 'longitude': -81.3618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30624', 'place_name': 'Bowman', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Elbert', 'locality_code': '105', 'latitude': 34.1919, 'longitude': -83.0284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30634', 'place_name': 'Dewy Rose', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Elbert', 'locality_code': '105', 'latitude': 34.1853, 'longitude': -82.9434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30635', 'place_name': 'Elberton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Elbert', 'locality_code': '105', 'latitude': 34.1082, 'longitude': -82.8448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30401', 'place_name': 'Swainsboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Emanuel', 'locality_code': '107', 'latitude': 32.5699, 'longitude': -82.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30425', 'place_name': 'Garfield', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Emanuel', 'locality_code': '107', 'latitude': 32.6549, 'longitude': -82.1002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30447', 'place_name': 'Norristown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Emanuel', 'locality_code': '107', 'latitude': 32.5041, 'longitude': -82.4848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30448', 'place_name': 'Nunez', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Emanuel', 'locality_code': '107', 'latitude': 32.4759, 'longitude': -82.3726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30464', 'place_name': 'Stillmore', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Emanuel', 'locality_code': '107', 'latitude': 32.4421, 'longitude': -82.2151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30471', 'place_name': 'Twin City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Emanuel', 'locality_code': '107', 'latitude': 32.6129, 'longitude': -82.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31002', 'place_name': 'Adrian', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Emanuel', 'locality_code': '107', 'latitude': 32.5635, 'longitude': -82.5695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30414', 'place_name': 'Bellville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Evans', 'locality_code': '109', 'latitude': 32.1524, 'longitude': -81.9743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30417', 'place_name': 'Claxton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Evans', 'locality_code': '109', 'latitude': 32.165, 'longitude': -81.908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30423', 'place_name': 'Daisy', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Evans', 'locality_code': '109', 'latitude': 32.1519, 'longitude': -81.8346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30429', 'place_name': 'Hagan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Evans', 'locality_code': '109', 'latitude': 32.156, 'longitude': -81.9337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30513', 'place_name': 'Blue Ridge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fannin', 'locality_code': '111', 'latitude': 34.8555, 'longitude': -84.3281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30541', 'place_name': 'Epworth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fannin', 'locality_code': '111', 'latitude': 34.9129, 'longitude': -84.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30555', 'place_name': 'Mc Caysville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fannin', 'locality_code': '111', 'latitude': 34.9739, 'longitude': -84.4291, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30559', 'place_name': 'Mineral Bluff', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fannin', 'locality_code': '111', 'latitude': 34.9341, 'longitude': -84.2541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30560', 'place_name': 'Morganton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fannin', 'locality_code': '111', 'latitude': 34.8714, 'longitude': -84.2115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30205', 'place_name': 'Brooks', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fayette', 'locality_code': '113', 'latitude': 33.2984, 'longitude': -84.4769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30214', 'place_name': 'Fayetteville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fayette', 'locality_code': '113', 'latitude': 33.4679, 'longitude': -84.4806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30215', 'place_name': 'Fayetteville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fayette', 'locality_code': '113', 'latitude': 33.3943, 'longitude': -84.4738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30269', 'place_name': 'Peachtree City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fayette', 'locality_code': '113', 'latitude': 33.3915, 'longitude': -84.5635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30290', 'place_name': 'Tyrone', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fayette', 'locality_code': '113', 'latitude': 33.4719, 'longitude': -84.5914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31169', 'place_name': 'Peachtree City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fayette', 'locality_code': '113', 'latitude': 33.3967, 'longitude': -84.5958, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30105', 'place_name': 'Armuchee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.4411, 'longitude': -85.1843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30124', 'place_name': 'Cave Spring', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.1167, 'longitude': -85.3379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30129', 'place_name': 'Coosa', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.3333, 'longitude': -85.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30147', 'place_name': 'Lindale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.1707, 'longitude': -85.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30149', 'place_name': 'Mount Berry', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.2804, 'longitude': -85.1821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30161', 'place_name': 'Rome', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.2507, 'longitude': -85.1465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30162', 'place_name': 'Rome', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.2905, 'longitude': -85.2138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30163', 'place_name': 'Rome', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.3333, 'longitude': -85.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30164', 'place_name': 'Rome', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.3333, 'longitude': -85.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30165', 'place_name': 'Rome', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.2837, 'longitude': -85.2231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30172', 'place_name': 'Shannon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.3333, 'longitude': -85.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30173', 'place_name': 'Silver Creek', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Floyd', 'locality_code': '115', 'latitude': 34.1593, 'longitude': -85.1429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30028', 'place_name': 'Cumming', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Forsyth', 'locality_code': '117', 'latitude': 34.2897, 'longitude': -84.1796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30040', 'place_name': 'Cumming', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Forsyth', 'locality_code': '117', 'latitude': 34.2321, 'longitude': -84.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30041', 'place_name': 'Cumming', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Forsyth', 'locality_code': '117', 'latitude': 34.2037, 'longitude': -84.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30520', 'place_name': 'Canon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Franklin', 'locality_code': '119', 'latitude': 34.3478, 'longitude': -83.1267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30521', 'place_name': 'Carnesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Franklin', 'locality_code': '119', 'latitude': 34.3631, 'longitude': -83.2547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30553', 'place_name': 'Lavonia', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Franklin', 'locality_code': '119', 'latitude': 34.4528, 'longitude': -83.113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30639', 'place_name': 'Franklin Springs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Franklin', 'locality_code': '119', 'latitude': 34.2743, 'longitude': -83.147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30662', 'place_name': 'Royston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Franklin', 'locality_code': '119', 'latitude': 34.2778, 'longitude': -83.1406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30004', 'place_name': 'Alpharetta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.1124, 'longitude': -84.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30005', 'place_name': 'Alpharetta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.0782, 'longitude': -84.2281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30009', 'place_name': 'Alpharetta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.077, 'longitude': -84.3033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30022', 'place_name': 'Alpharetta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.0268, 'longitude': -84.2422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30023', 'place_name': 'Alpharetta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.0754, 'longitude': -84.2941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30075', 'place_name': 'Roswell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.0408, 'longitude': -84.3859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30076', 'place_name': 'Roswell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.0213, 'longitude': -84.3104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30077', 'place_name': 'Roswell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 34.0232, 'longitude': -84.3616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30213', 'place_name': 'Fairburn', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.5648, 'longitude': -84.5809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30268', 'place_name': 'Palmetto', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.5242, 'longitude': -84.679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30272', 'place_name': 'Red Oak', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.6259, 'longitude': -84.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30291', 'place_name': 'Union City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.5832, 'longitude': -84.5499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30301', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30302', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30303', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7525, 'longitude': -84.3888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30304', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8482, 'longitude': -84.4293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30305', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.832, 'longitude': -84.3851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30306', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.786, 'longitude': -84.3514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30307', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7691, 'longitude': -84.336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30308', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7718, 'longitude': -84.3757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30309', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7984, 'longitude': -84.3883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30310', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7278, 'longitude': -84.4232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30311', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.723, 'longitude': -84.4702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30312', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7467, 'longitude': -84.3781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30313', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7683, 'longitude': -84.3935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30314', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7561, 'longitude': -84.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30315', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7051, 'longitude': -84.3808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30316', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7217, 'longitude': -84.3339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30317', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7498, 'longitude': -84.3169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30318', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7865, 'longitude': -84.4454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30320', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.6568, 'longitude': -84.4236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30321', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30324', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8206, 'longitude': -84.3549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30325', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30326', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8482, 'longitude': -84.3582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30327', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8627, 'longitude': -84.42, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30328', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.9335, 'longitude': -84.3958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30331', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7224, 'longitude': -84.5205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30332', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7763, 'longitude': -84.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30334', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7489, 'longitude': -84.3872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30336', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7406, 'longitude': -84.5545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30337', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.6428, 'longitude': -84.4618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30338', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.9669, 'longitude': -84.3249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30339', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8713, 'longitude': -84.4629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30342', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8842, 'longitude': -84.3761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30343', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30344', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.6919, 'longitude': -84.448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30348', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30349', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.6053, 'longitude': -84.4813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30353', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30354', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.6675, 'longitude': -84.3896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30355', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30357', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30358', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30361', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30363', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.791, 'longitude': -84.3992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30364', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30368', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30369', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30370', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30371', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30374', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30375', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30377', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30378', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30380', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30384', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30385', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30388', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30392', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30394', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.749, 'longitude': -84.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30396', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30398', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31106', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31107', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31126', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31131', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31136', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.7473, 'longitude': -84.3824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31139', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31150', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31156', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31192', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31193', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31195', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31196', 'place_name': 'Atlanta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Fulton', 'locality_code': '121', 'latitude': 33.8444, 'longitude': -84.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30522', 'place_name': 'Cherry Log', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gilmer', 'locality_code': '123', 'latitude': 34.7804, 'longitude': -84.3908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30536', 'place_name': 'Ellijay', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gilmer', 'locality_code': '123', 'latitude': 34.655, 'longitude': -84.3554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30539', 'place_name': 'East Ellijay', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gilmer', 'locality_code': '123', 'latitude': 34.684, 'longitude': -84.4727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30540', 'place_name': 'Ellijay', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gilmer', 'locality_code': '123', 'latitude': 34.6775, 'longitude': -84.4812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30810', 'place_name': 'Gibson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glascock', 'locality_code': '125', 'latitude': 33.2471, 'longitude': -82.5766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30820', 'place_name': 'Mitchell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glascock', 'locality_code': '125', 'latitude': 33.2052, 'longitude': -82.6817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31520', 'place_name': 'Brunswick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.1807, 'longitude': -81.4949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31521', 'place_name': 'Brunswick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.15, 'longitude': -81.4915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31522', 'place_name': 'Saint Simons Island', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.23, 'longitude': -81.3502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31523', 'place_name': 'Brunswick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.2189, 'longitude': -81.546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31524', 'place_name': 'Brunswick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.222, 'longitude': -81.4826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31525', 'place_name': 'Brunswick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.2804, 'longitude': -81.5305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31527', 'place_name': 'Jekyll Island', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.074, 'longitude': -81.4128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31561', 'place_name': 'Sea Island', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Glynn', 'locality_code': '127', 'latitude': 31.1989, 'longitude': -81.3322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30139', 'place_name': 'Fairmount', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.4362, 'longitude': -84.6999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30701', 'place_name': 'Calhoun', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.4965, 'longitude': -84.9345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30703', 'place_name': 'Calhoun', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.5026, 'longitude': -84.9511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30732', 'place_name': 'Oakman', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.569, 'longitude': -84.7119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30733', 'place_name': 'Plainville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.4145, 'longitude': -85.0312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30734', 'place_name': 'Ranger', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.5404, 'longitude': -84.727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30735', 'place_name': 'Resaca', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.5833, 'longitude': -84.9068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30746', 'place_name': 'Sugar Valley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gordon', 'locality_code': '129', 'latitude': 34.5519, 'longitude': -85.026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39827', 'place_name': 'Cairo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Grady', 'locality_code': '131', 'latitude': 30.9528, 'longitude': -84.2069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39829', 'place_name': 'Calvary', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Grady', 'locality_code': '131', 'latitude': 30.7462, 'longitude': -84.3125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39897', 'place_name': 'Whigham', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Grady', 'locality_code': '131', 'latitude': 30.8836, 'longitude': -84.3246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30642', 'place_name': 'Greensboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Greene', 'locality_code': '133', 'latitude': 33.5637, 'longitude': -83.1702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30665', 'place_name': 'Siloam', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Greene', 'locality_code': '133', 'latitude': 33.5368, 'longitude': -83.081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30669', 'place_name': 'Union Point', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Greene', 'locality_code': '133', 'latitude': 33.6345, 'longitude': -83.0879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30678', 'place_name': 'White Plains', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Greene', 'locality_code': '133', 'latitude': 33.4581, 'longitude': -83.0802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30003', 'place_name': 'Norcross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9604, 'longitude': -84.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30010', 'place_name': 'Norcross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9604, 'longitude': -84.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30017', 'place_name': 'Grayson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.8901, 'longitude': -83.9632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30019', 'place_name': 'Dacula', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9883, 'longitude': -83.8795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30024', 'place_name': 'Suwanee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 34.0425, 'longitude': -84.0262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30026', 'place_name': 'North Metro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9792, 'longitude': -84.1263, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30029', 'place_name': 'North Metro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9792, 'longitude': -84.1263, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30039', 'place_name': 'Snellville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.8178, 'longitude': -84.0229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30042', 'place_name': 'Lawrenceville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9295, 'longitude': -84.1032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30043', 'place_name': 'Lawrenceville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 34.0031, 'longitude': -84.0126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30044', 'place_name': 'Lawrenceville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9418, 'longitude': -84.0706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30045', 'place_name': 'Lawrenceville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9367, 'longitude': -83.9573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30046', 'place_name': 'Lawrenceville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9496, 'longitude': -83.9942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30047', 'place_name': 'Lilburn', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.8656, 'longitude': -84.0725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30048', 'place_name': 'Lilburn', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9604, 'longitude': -84.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30049', 'place_name': 'Lawrenceville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9495, 'longitude': -83.9922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30052', 'place_name': 'Loganville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.8769, 'longitude': -83.8968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30071', 'place_name': 'Norcross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9381, 'longitude': -84.1972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30078', 'place_name': 'Snellville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.8635, 'longitude': -84.0081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30091', 'place_name': 'Norcross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9604, 'longitude': -84.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30092', 'place_name': 'Peachtree Corners', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9701, 'longitude': -84.2216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30093', 'place_name': 'Norcross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.906, 'longitude': -84.184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30095', 'place_name': 'Duluth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 34.0256, 'longitude': -84.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30096', 'place_name': 'Duluth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9845, 'longitude': -84.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30097', 'place_name': 'Duluth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 34.026, 'longitude': -84.147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30098', 'place_name': 'Duluth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9604, 'longitude': -84.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30099', 'place_name': 'Duluth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9595, 'longitude': -84.105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30515', 'place_name': 'Buford', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 33.9604, 'longitude': -84.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30518', 'place_name': 'Buford', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 34.1124, 'longitude': -83.9965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30519', 'place_name': 'Buford', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Gwinnett', 'locality_code': '135', 'latitude': 34.0797, 'longitude': -83.9308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30510', 'place_name': 'Alto', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Habersham', 'locality_code': '137', 'latitude': 34.4591, 'longitude': -83.602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30523', 'place_name': 'Clarkesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Habersham', 'locality_code': '137', 'latitude': 34.645, 'longitude': -83.5243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30531', 'place_name': 'Cornelia', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Habersham', 'locality_code': '137', 'latitude': 34.5209, 'longitude': -83.5453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30535', 'place_name': 'Demorest', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Habersham', 'locality_code': '137', 'latitude': 34.5756, 'longitude': -83.5696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30563', 'place_name': 'Mount Airy', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Habersham', 'locality_code': '137', 'latitude': 34.5678, 'longitude': -83.4713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30580', 'place_name': 'Turnerville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Habersham', 'locality_code': '137', 'latitude': 34.6766, 'longitude': -83.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30501', 'place_name': 'Gainesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.3073, 'longitude': -83.8256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30502', 'place_name': 'Chestnut Mountain', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.213, 'longitude': -83.7949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30503', 'place_name': 'Gainesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.3454, 'longitude': -83.9505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30504', 'place_name': 'Gainesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.2723, 'longitude': -83.8793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30506', 'place_name': 'Gainesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.3562, 'longitude': -83.8882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30507', 'place_name': 'Gainesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.2591, 'longitude': -83.7716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30527', 'place_name': 'Clermont', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.4761, 'longitude': -83.7853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30542', 'place_name': 'Flowery Branch', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.1819, 'longitude': -83.9024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30543', 'place_name': 'Gillsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.3001, 'longitude': -83.6757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30554', 'place_name': 'Lula', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.3876, 'longitude': -83.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30564', 'place_name': 'Murrayville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.4342, 'longitude': -83.8949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30566', 'place_name': 'Oakwood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hall', 'locality_code': '139', 'latitude': 34.2372, 'longitude': -83.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31087', 'place_name': 'Sparta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hancock', 'locality_code': '141', 'latitude': 33.2571, 'longitude': -83.0892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30110', 'place_name': 'Bremen', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Haralson', 'locality_code': '143', 'latitude': 33.7309, 'longitude': -85.1286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30113', 'place_name': 'Buchanan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Haralson', 'locality_code': '143', 'latitude': 33.8283, 'longitude': -85.1506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30140', 'place_name': 'Felton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Haralson', 'locality_code': '143', 'latitude': 33.8823, 'longitude': -85.2349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30176', 'place_name': 'Tallapoosa', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Haralson', 'locality_code': '143', 'latitude': 33.7602, 'longitude': -85.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30182', 'place_name': 'Waco', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Haralson', 'locality_code': '143', 'latitude': 33.684, 'longitude': -85.2197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31804', 'place_name': 'Cataula', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Harris', 'locality_code': '145', 'latitude': 32.6242, 'longitude': -84.9207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31807', 'place_name': 'Ellerslie', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Harris', 'locality_code': '145', 'latitude': 32.6312, 'longitude': -84.7895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31811', 'place_name': 'Hamilton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Harris', 'locality_code': '145', 'latitude': 32.7418, 'longitude': -84.8848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31822', 'place_name': 'Pine Mountain', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Harris', 'locality_code': '145', 'latitude': 32.8735, 'longitude': -84.896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31823', 'place_name': 'Pine Mountain Valley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Harris', 'locality_code': '145', 'latitude': 32.8226, 'longitude': -84.8204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31826', 'place_name': 'Shiloh', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Harris', 'locality_code': '145', 'latitude': 32.8101, 'longitude': -84.696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31831', 'place_name': 'Waverly Hall', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Harris', 'locality_code': '145', 'latitude': 32.6793, 'longitude': -84.7425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30516', 'place_name': 'Bowersville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hart', 'locality_code': '147', 'latitude': 34.3996, 'longitude': -83.0484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30643', 'place_name': 'Hartwell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Hart', 'locality_code': '147', 'latitude': 34.3571, 'longitude': -82.9296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30217', 'place_name': 'Franklin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Heard', 'locality_code': '149', 'latitude': 33.278, 'longitude': -85.134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30228', 'place_name': 'Hampton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Henry', 'locality_code': '151', 'latitude': 33.4124, 'longitude': -84.2947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30248', 'place_name': 'Locust Grove', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Henry', 'locality_code': '151', 'latitude': 33.3449, 'longitude': -84.0982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30252', 'place_name': 'Mcdonough', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Henry', 'locality_code': '151', 'latitude': 33.4768, 'longitude': -84.055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30253', 'place_name': 'Mcdonough', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Henry', 'locality_code': '151', 'latitude': 33.451, 'longitude': -84.1544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30281', 'place_name': 'Stockbridge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Henry', 'locality_code': '151', 'latitude': 33.5633, 'longitude': -84.2165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31005', 'place_name': 'Bonaire', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.546, 'longitude': -83.6047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31013', 'place_name': 'Clinchfield', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.3386, 'longitude': -83.6926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31025', 'place_name': 'Elko', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.3336, 'longitude': -83.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31028', 'place_name': 'Centerville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.6344, 'longitude': -83.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31047', 'place_name': 'Kathleen', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.4672, 'longitude': -83.6128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31069', 'place_name': 'Perry', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.4605, 'longitude': -83.7283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31088', 'place_name': 'Warner Robins', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.5934, 'longitude': -83.6416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31093', 'place_name': 'Warner Robins', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.6368, 'longitude': -83.6395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31095', 'place_name': 'Warner Robins', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.4874, 'longitude': -83.6697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31098', 'place_name': 'Warner Robins', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.6181, 'longitude': -83.5739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31099', 'place_name': 'Warner Robins', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Houston', 'locality_code': '153', 'latitude': 32.6462, 'longitude': -83.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31760', 'place_name': 'Irwinville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Irwin', 'locality_code': '155', 'latitude': 31.7063, 'longitude': -83.4086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31769', 'place_name': 'Mystic', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Irwin', 'locality_code': '155', 'latitude': 31.6209, 'longitude': -83.2498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31774', 'place_name': 'Ocilla', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Irwin', 'locality_code': '155', 'latitude': 31.5929, 'longitude': -83.2565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31798', 'place_name': 'Wray', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Irwin', 'locality_code': '155', 'latitude': 31.5952, 'longitude': -83.1075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30517', 'place_name': 'Braselton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.1389, 'longitude': -83.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30529', 'place_name': 'Commerce', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.2134, 'longitude': -83.448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30530', 'place_name': 'Commerce', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.1683, 'longitude': -83.4022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30548', 'place_name': 'Hoschton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.0866, 'longitude': -83.7803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30549', 'place_name': 'Jefferson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.1062, 'longitude': -83.5708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30565', 'place_name': 'Nicholson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.097, 'longitude': -83.421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30567', 'place_name': 'Pendergrass', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.1796, 'longitude': -83.6634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30575', 'place_name': 'Talmo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.1951, 'longitude': -83.7187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30599', 'place_name': 'Commerce', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jackson', 'locality_code': '157', 'latitude': 34.204, 'longitude': -83.4571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30055', 'place_name': 'Mansfield', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jasper', 'locality_code': '159', 'latitude': 33.4314, 'longitude': -83.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31038', 'place_name': 'Hillsboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jasper', 'locality_code': '159', 'latitude': 33.1421, 'longitude': -83.6404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31064', 'place_name': 'Monticello', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jasper', 'locality_code': '159', 'latitude': 33.3118, 'longitude': -83.714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31085', 'place_name': 'Shady Dale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jasper', 'locality_code': '159', 'latitude': 33.435, 'longitude': -83.6269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31532', 'place_name': 'Denton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jeff Davis', 'locality_code': '161', 'latitude': 31.7226, 'longitude': -82.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31539', 'place_name': 'Hazlehurst', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jeff Davis', 'locality_code': '161', 'latitude': 31.8606, 'longitude': -82.5909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30413', 'place_name': 'Bartow', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jefferson', 'locality_code': '163', 'latitude': 32.8632, 'longitude': -82.4708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30434', 'place_name': 'Louisville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jefferson', 'locality_code': '163', 'latitude': 33.0163, 'longitude': -82.3836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30477', 'place_name': 'Wadley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jefferson', 'locality_code': '163', 'latitude': 32.8747, 'longitude': -82.4025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30803', 'place_name': 'Avera', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jefferson', 'locality_code': '163', 'latitude': 33.141, 'longitude': -82.515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30818', 'place_name': 'Matthews', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jefferson', 'locality_code': '163', 'latitude': 33.2652, 'longitude': -82.3294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30823', 'place_name': 'Stapleton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jefferson', 'locality_code': '163', 'latitude': 33.1894, 'longitude': -82.4597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30833', 'place_name': 'Wrens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jefferson', 'locality_code': '163', 'latitude': 33.2104, 'longitude': -82.381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30442', 'place_name': 'Millen', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jenkins', 'locality_code': '165', 'latitude': 32.7877, 'longitude': -81.9618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30822', 'place_name': 'Perkins', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jenkins', 'locality_code': '165', 'latitude': 32.9129, 'longitude': -81.8538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31049', 'place_name': 'Kite', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Johnson', 'locality_code': '167', 'latitude': 32.7078, 'longitude': -82.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31096', 'place_name': 'Wrightsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Johnson', 'locality_code': '167', 'latitude': 32.7219, 'longitude': -82.7262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31032', 'place_name': 'Gray', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jones', 'locality_code': '169', 'latitude': 33.0172, 'longitude': -83.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31033', 'place_name': 'Haddock', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Jones', 'locality_code': '169', 'latitude': 33.0519, 'longitude': -83.4312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30204', 'place_name': 'Barnesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lamar', 'locality_code': '171', 'latitude': 33.0457, 'longitude': -84.1515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30257', 'place_name': 'Milner', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lamar', 'locality_code': '171', 'latitude': 33.141, 'longitude': -84.1759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31635', 'place_name': 'Lakeland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lanier', 'locality_code': '173', 'latitude': 31.0381, 'longitude': -83.0889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31649', 'place_name': 'Stockton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lanier', 'locality_code': '173', 'latitude': 31.0229, 'longitude': -83.0139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30454', 'place_name': 'Rockledge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.3915, 'longitude': -82.7479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31009', 'place_name': 'Cadwell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.3174, 'longitude': -83.0268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31019', 'place_name': 'Dexter', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.4356, 'longitude': -83.0528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31021', 'place_name': 'Dublin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.4593, 'longitude': -82.9381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31022', 'place_name': 'Dudley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.5259, 'longitude': -83.0899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31027', 'place_name': 'East Dublin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.5482, 'longitude': -82.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31040', 'place_name': 'Dublin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.5401, 'longitude': -82.915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31065', 'place_name': 'Montrose', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.5619, 'longitude': -83.1601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31075', 'place_name': 'Rentz', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Laurens', 'locality_code': '175', 'latitude': 32.3799, 'longitude': -82.967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31763', 'place_name': 'Leesburg', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lee', 'locality_code': '177', 'latitude': 31.6812, 'longitude': -84.1593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31787', 'place_name': 'Smithville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lee', 'locality_code': '177', 'latitude': 31.8847, 'longitude': -84.2271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31301', 'place_name': 'Allenhurst', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.7741, 'longitude': -81.6186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31309', 'place_name': 'Fleming', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.8645, 'longitude': -81.4232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31310', 'place_name': 'Hinesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.8068, 'longitude': -81.4371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31313', 'place_name': 'Hinesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.8513, 'longitude': -81.6072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31314', 'place_name': 'Fort Stewart', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.8701, 'longitude': -81.6318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31315', 'place_name': 'Fort Stewart', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.8938, 'longitude': -81.5902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31320', 'place_name': 'Midway', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.8018, 'longitude': -81.3909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31323', 'place_name': 'Riceboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.7357, 'longitude': -81.4671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31333', 'place_name': 'Walthourville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Liberty', 'locality_code': '179', 'latitude': 31.7705, 'longitude': -81.6208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30817', 'place_name': 'Lincolnton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lincoln', 'locality_code': '181', 'latitude': 33.7773, 'longitude': -82.4435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31316', 'place_name': 'Ludowici', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Long', 'locality_code': '183', 'latitude': 31.7705, 'longitude': -81.7453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31601', 'place_name': 'Valdosta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.7539, 'longitude': -83.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31602', 'place_name': 'Valdosta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.8931, 'longitude': -83.3278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31603', 'place_name': 'Valdosta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.828, 'longitude': -83.2522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31604', 'place_name': 'Valdosta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.828, 'longitude': -83.2522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31605', 'place_name': 'Valdosta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.946, 'longitude': -83.2474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31606', 'place_name': 'Valdosta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.7989, 'longitude': -83.1891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31632', 'place_name': 'Hahira', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.9913, 'longitude': -83.3727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31636', 'place_name': 'Lake Park', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.6906, 'longitude': -83.1753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31641', 'place_name': 'Naylor', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.8985, 'longitude': -83.1224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31698', 'place_name': 'Valdosta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.8485, 'longitude': -83.2878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31699', 'place_name': 'Moody Afb', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lowndes', 'locality_code': '185', 'latitude': 30.9785, 'longitude': -83.2165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30533', 'place_name': 'Dahlonega', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lumpkin', 'locality_code': '187', 'latitude': 34.5299, 'longitude': -83.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30597', 'place_name': 'Dahlonega', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Lumpkin', 'locality_code': '187', 'latitude': 34.5277, 'longitude': -83.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30806', 'place_name': 'Boneville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McDuffie', 'locality_code': '189', 'latitude': 33.528, 'longitude': -82.5104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30808', 'place_name': 'Dearing', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McDuffie', 'locality_code': '189', 'latitude': 33.407, 'longitude': -82.3955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30824', 'place_name': 'Thomson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McDuffie', 'locality_code': '189', 'latitude': 33.4774, 'longitude': -82.4942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31304', 'place_name': 'Crescent', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McIntosh', 'locality_code': '191', 'latitude': 31.5094, 'longitude': -81.3695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31305', 'place_name': 'Darien', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McIntosh', 'locality_code': '191', 'latitude': 31.3826, 'longitude': -81.4312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31319', 'place_name': 'Meridian', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McIntosh', 'locality_code': '191', 'latitude': 31.459, 'longitude': -81.3689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31327', 'place_name': 'Sapelo Island', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McIntosh', 'locality_code': '191', 'latitude': 31.3974, 'longitude': -81.2787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31331', 'place_name': 'Townsend', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'McIntosh', 'locality_code': '191', 'latitude': 31.5673, 'longitude': -81.4182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31041', 'place_name': 'Ideal', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Macon', 'locality_code': '193', 'latitude': 32.3696, 'longitude': -84.188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31057', 'place_name': 'Marshallville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Macon', 'locality_code': '193', 'latitude': 32.452, 'longitude': -83.9435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31068', 'place_name': 'Oglethorpe', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Macon', 'locality_code': '193', 'latitude': 32.2842, 'longitude': -84.083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30627', 'place_name': 'Carlton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Madison', 'locality_code': '195', 'latitude': 33.9852, 'longitude': -83.0038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30628', 'place_name': 'Colbert', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Madison', 'locality_code': '195', 'latitude': 34.0382, 'longitude': -83.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30629', 'place_name': 'Comer', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Madison', 'locality_code': '195', 'latitude': 34.0888, 'longitude': -83.122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30633', 'place_name': 'Danielsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Madison', 'locality_code': '195', 'latitude': 34.1708, 'longitude': -83.2758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30646', 'place_name': 'Hull', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Madison', 'locality_code': '195', 'latitude': 34.0478, 'longitude': -83.311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30647', 'place_name': 'Ila', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Madison', 'locality_code': '195', 'latitude': 34.1726, 'longitude': -83.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31803', 'place_name': 'Buena Vista', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Marion', 'locality_code': '197', 'latitude': 32.2542, 'longitude': -84.4898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30218', 'place_name': 'Gay', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Meriwether', 'locality_code': '199', 'latitude': 33.1274, 'longitude': -84.5836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30222', 'place_name': 'Greenville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Meriwether', 'locality_code': '199', 'latitude': 33.0468, 'longitude': -84.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30251', 'place_name': 'Luthersville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Meriwether', 'locality_code': '199', 'latitude': 33.2101, 'longitude': -84.7444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30293', 'place_name': 'Woodbury', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Meriwether', 'locality_code': '199', 'latitude': 32.9813, 'longitude': -84.5986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31816', 'place_name': 'Manchester', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Meriwether', 'locality_code': '199', 'latitude': 32.8721, 'longitude': -84.6312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31830', 'place_name': 'Warm Springs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Meriwether', 'locality_code': '199', 'latitude': 32.9063, 'longitude': -84.7167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39817', 'place_name': 'Bainbridge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Miller', 'locality_code': '201', 'latitude': 30.9381, 'longitude': -84.5934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31716', 'place_name': 'Baconton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Mitchell', 'locality_code': '205', 'latitude': 31.3878, 'longitude': -84.1135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31730', 'place_name': 'Camilla', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Mitchell', 'locality_code': '205', 'latitude': 31.2199, 'longitude': -84.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31739', 'place_name': 'Cotton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Mitchell', 'locality_code': '205', 'latitude': 31.1616, 'longitude': -84.0668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31779', 'place_name': 'Pelham', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Mitchell', 'locality_code': '205', 'latitude': 31.1272, 'longitude': -84.1564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31784', 'place_name': 'Sale City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Mitchell', 'locality_code': '205', 'latitude': 31.26, 'longitude': -84.0422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31004', 'place_name': 'Bolingbroke', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Monroe', 'locality_code': '207', 'latitude': 32.947, 'longitude': -83.8006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31016', 'place_name': 'Culloden', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Monroe', 'locality_code': '207', 'latitude': 32.9003, 'longitude': -84.0626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31029', 'place_name': 'Forsyth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Monroe', 'locality_code': '207', 'latitude': 33.0508, 'longitude': -83.9362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31046', 'place_name': 'Juliette', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Monroe', 'locality_code': '207', 'latitude': 33.1194, 'longitude': -83.8235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31086', 'place_name': 'Smarr', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Monroe', 'locality_code': '207', 'latitude': 32.9895, 'longitude': -83.8761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30410', 'place_name': 'Ailey', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Montgomery', 'locality_code': '209', 'latitude': 32.2143, 'longitude': -82.4762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30412', 'place_name': 'Alston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Montgomery', 'locality_code': '209', 'latitude': 32.0775, 'longitude': -82.4825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30445', 'place_name': 'Mount Vernon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Montgomery', 'locality_code': '209', 'latitude': 32.184, 'longitude': -82.5867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30470', 'place_name': 'Tarrytown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Montgomery', 'locality_code': '209', 'latitude': 32.3188, 'longitude': -82.5593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30473', 'place_name': 'Uvalda', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Montgomery', 'locality_code': '209', 'latitude': 32.0483, 'longitude': -82.5089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30623', 'place_name': 'Bostwick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Morgan', 'locality_code': '211', 'latitude': 33.7373, 'longitude': -83.5143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30625', 'place_name': 'Buckhead', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Morgan', 'locality_code': '211', 'latitude': 33.5368, 'longitude': -83.3435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30645', 'place_name': 'High Shoals', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Morgan', 'locality_code': '211', 'latitude': 33.8013, 'longitude': -83.5164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30650', 'place_name': 'Madison', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Morgan', 'locality_code': '211', 'latitude': 33.5947, 'longitude': -83.4618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30663', 'place_name': 'Rutledge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Morgan', 'locality_code': '211', 'latitude': 33.6163, 'longitude': -83.6023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30705', 'place_name': 'Chatsworth', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Murray', 'locality_code': '213', 'latitude': 34.7589, 'longitude': -84.7943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30708', 'place_name': 'Cisco', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Murray', 'locality_code': '213', 'latitude': 34.9618, 'longitude': -84.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30711', 'place_name': 'Crandall', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Murray', 'locality_code': '213', 'latitude': 34.9412, 'longitude': -84.7645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30724', 'place_name': 'Eton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Murray', 'locality_code': '213', 'latitude': 34.8251, 'longitude': -84.7633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30751', 'place_name': 'Tennga', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Murray', 'locality_code': '213', 'latitude': 34.9814, 'longitude': -84.7352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31808', 'place_name': 'Fortson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.6288, 'longitude': -85.0017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31820', 'place_name': 'Midland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.5616, 'longitude': -84.8559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31829', 'place_name': 'Upatoi', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.5601, 'longitude': -84.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31901', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.473, 'longitude': -84.9795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31902', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.5243, 'longitude': -84.9558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31903', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.4245, 'longitude': -84.9481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31904', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.5161, 'longitude': -84.9785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31905', 'place_name': 'Fort Benning', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.3923, 'longitude': -84.9315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31906', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.4638, 'longitude': -84.9484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31907', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.4779, 'longitude': -84.898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31908', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.5349, 'longitude': -84.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31909', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.5369, 'longitude': -84.9274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31914', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.491, 'longitude': -84.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31917', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.491, 'longitude': -84.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31993', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.4821, 'longitude': -84.9771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31995', 'place_name': 'Fort Benning', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.4958, 'longitude': -84.964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31997', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.491, 'longitude': -84.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31998', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.491, 'longitude': -84.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31999', 'place_name': 'Columbus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Muscogee', 'locality_code': '215', 'latitude': 32.461, 'longitude': -84.9877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30014', 'place_name': 'Covington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Newton', 'locality_code': '217', 'latitude': 33.5293, 'longitude': -83.8496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30015', 'place_name': 'Covington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Newton', 'locality_code': '217', 'latitude': 33.5968, 'longitude': -83.8602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30016', 'place_name': 'Covington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Newton', 'locality_code': '217', 'latitude': 33.5146, 'longitude': -83.8626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30054', 'place_name': 'Oxford', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Newton', 'locality_code': '217', 'latitude': 33.6706, 'longitude': -83.874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30056', 'place_name': 'Newborn', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Newton', 'locality_code': '217', 'latitude': 33.5149, 'longitude': -83.7072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30070', 'place_name': 'Porterdale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Newton', 'locality_code': '217', 'latitude': 33.5712, 'longitude': -83.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30621', 'place_name': 'Bishop', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oconee', 'locality_code': '219', 'latitude': 33.8081, 'longitude': -83.4777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30622', 'place_name': 'Bogart', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oconee', 'locality_code': '219', 'latitude': 33.934, 'longitude': -83.5055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30638', 'place_name': 'Farmington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oconee', 'locality_code': '219', 'latitude': 33.7558, 'longitude': -83.4201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30677', 'place_name': 'Watkinsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oconee', 'locality_code': '219', 'latitude': 33.8542, 'longitude': -83.408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30619', 'place_name': 'Arnoldsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oglethorpe', 'locality_code': '221', 'latitude': 33.8803, 'longitude': -83.2341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30630', 'place_name': 'Crawford', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oglethorpe', 'locality_code': '221', 'latitude': 33.9076, 'longitude': -83.1646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30648', 'place_name': 'Lexington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oglethorpe', 'locality_code': '221', 'latitude': 33.8799, 'longitude': -83.0858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30667', 'place_name': 'Stephens', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oglethorpe', 'locality_code': '221', 'latitude': 33.7715, 'longitude': -83.1159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30671', 'place_name': 'Maxeys', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Oglethorpe', 'locality_code': '221', 'latitude': 33.7405, 'longitude': -83.1706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30132', 'place_name': 'Dallas', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Paulding', 'locality_code': '223', 'latitude': 33.9163, 'longitude': -84.8278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30141', 'place_name': 'Hiram', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Paulding', 'locality_code': '223', 'latitude': 33.8673, 'longitude': -84.7699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30157', 'place_name': 'Dallas', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Paulding', 'locality_code': '223', 'latitude': 33.9045, 'longitude': -84.8621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31008', 'place_name': 'Byron', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Peach', 'locality_code': '225', 'latitude': 32.6181, 'longitude': -83.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31030', 'place_name': 'Fort Valley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Peach', 'locality_code': '225', 'latitude': 32.5496, 'longitude': -83.8887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30143', 'place_name': 'Jasper', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pickens', 'locality_code': '227', 'latitude': 34.462, 'longitude': -84.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30148', 'place_name': 'Marble Hill', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pickens', 'locality_code': '227', 'latitude': 34.4398, 'longitude': -84.303, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30175', 'place_name': 'Talking Rock', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pickens', 'locality_code': '227', 'latitude': 34.5394, 'longitude': -84.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30177', 'place_name': 'Tate', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pickens', 'locality_code': '227', 'latitude': 34.4027, 'longitude': -84.3785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31516', 'place_name': 'Blackshear', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pierce', 'locality_code': '229', 'latitude': 31.2931, 'longitude': -82.2617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31518', 'place_name': 'Bristol', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pierce', 'locality_code': '229', 'latitude': 31.4833, 'longitude': -82.215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31551', 'place_name': 'Mershon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pierce', 'locality_code': '229', 'latitude': 31.4783, 'longitude': -82.217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31556', 'place_name': 'Offerman', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pierce', 'locality_code': '229', 'latitude': 31.4126, 'longitude': -82.1155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31557', 'place_name': 'Patterson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pierce', 'locality_code': '229', 'latitude': 31.3903, 'longitude': -82.1274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30206', 'place_name': 'Concord', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pike', 'locality_code': '231', 'latitude': 33.0998, 'longitude': -84.447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30256', 'place_name': 'Meansville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pike', 'locality_code': '231', 'latitude': 33.0134, 'longitude': -84.3169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30258', 'place_name': 'Molena', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pike', 'locality_code': '231', 'latitude': 32.9978, 'longitude': -84.4558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30292', 'place_name': 'Williamson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pike', 'locality_code': '231', 'latitude': 33.1598, 'longitude': -84.3795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30295', 'place_name': 'Zebulon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pike', 'locality_code': '231', 'latitude': 33.1002, 'longitude': -84.3108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30104', 'place_name': 'Aragon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Polk', 'locality_code': '233', 'latitude': 34.0666, 'longitude': -85.0696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30125', 'place_name': 'Cedartown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Polk', 'locality_code': '233', 'latitude': 34.0112, 'longitude': -85.2459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30138', 'place_name': 'Esom Hill', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Polk', 'locality_code': '233', 'latitude': 33.949, 'longitude': -85.3877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30153', 'place_name': 'Rockmart', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Polk', 'locality_code': '233', 'latitude': 33.9979, 'longitude': -85.0594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31036', 'place_name': 'Hawkinsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Pulaski', 'locality_code': '235', 'latitude': 32.2778, 'longitude': -83.4948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31024', 'place_name': 'Eatonton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Putnam', 'locality_code': '237', 'latitude': 33.3127, 'longitude': -83.3628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31026', 'place_name': 'Eatonton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Putnam', 'locality_code': '237', 'latitude': 33.3304, 'longitude': -83.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30525', 'place_name': 'Clayton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.8826, 'longitude': -83.4065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30537', 'place_name': 'Dillard', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.9777, 'longitude': -83.3199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30552', 'place_name': 'Lakemont', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.7617, 'longitude': -83.4038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30562', 'place_name': 'Mountain City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.9181, 'longitude': -83.3854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30568', 'place_name': 'Rabun Gap', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.9576, 'longitude': -83.3901, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30573', 'place_name': 'Tallulah Falls', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.742, 'longitude': -83.3977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30576', 'place_name': 'Tiger', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.8174, 'longitude': -83.4333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30581', 'place_name': 'Wiley', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rabun', 'locality_code': '241', 'latitude': 34.8045, 'longitude': -83.4191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30805', 'place_name': 'Blythe', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.2941, 'longitude': -82.203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30812', 'place_name': 'Gracewood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.3726, 'longitude': -82.0321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30815', 'place_name': 'Hephzibah', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.3433, 'longitude': -82.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30901', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.4601, 'longitude': -81.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30903', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.386, 'longitude': -82.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30904', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.4737, 'longitude': -82.0131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30905', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.413, 'longitude': -82.1337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30906', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.3589, 'longitude': -82.0099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30907', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.5229, 'longitude': -82.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30909', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.4717, 'longitude': -82.0834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30912', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.4705, 'longitude': -81.9881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30914', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.386, 'longitude': -82.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30916', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.386, 'longitude': -82.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30919', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.386, 'longitude': -82.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30999', 'place_name': 'Augusta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Richmond', 'locality_code': '245', 'latitude': 33.386, 'longitude': -82.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30012', 'place_name': 'Conyers', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rockdale', 'locality_code': '247', 'latitude': 33.7192, 'longitude': -84.0021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30013', 'place_name': 'Conyers', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rockdale', 'locality_code': '247', 'latitude': 33.6436, 'longitude': -83.9684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30094', 'place_name': 'Conyers', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Rockdale', 'locality_code': '247', 'latitude': 33.6111, 'longitude': -84.0683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31806', 'place_name': 'Ellaville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Schley', 'locality_code': '249', 'latitude': 32.239, 'longitude': -84.3039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30424', 'place_name': 'Dover', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Screven', 'locality_code': '251', 'latitude': 32.5771, 'longitude': -81.7151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30446', 'place_name': 'Newington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Screven', 'locality_code': '251', 'latitude': 32.581, 'longitude': -81.4826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30449', 'place_name': 'Oliver', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Screven', 'locality_code': '251', 'latitude': 32.5281, 'longitude': -81.5332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30455', 'place_name': 'Rocky Ford', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Screven', 'locality_code': '251', 'latitude': 32.723, 'longitude': -81.7933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30467', 'place_name': 'Sylvania', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Screven', 'locality_code': '251', 'latitude': 32.7439, 'longitude': -81.6287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39825', 'place_name': 'Brinson', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Seminole', 'locality_code': '253', 'latitude': 30.9788, 'longitude': -84.7373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39859', 'place_name': 'Iron City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Seminole', 'locality_code': '253', 'latitude': 31.013, 'longitude': -84.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39861', 'place_name': 'Jakin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Seminole', 'locality_code': '253', 'latitude': 31.1824, 'longitude': -85.0121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30212', 'place_name': 'Experiment', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Spalding', 'locality_code': '255', 'latitude': 33.2782, 'longitude': -84.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30223', 'place_name': 'Griffin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Spalding', 'locality_code': '255', 'latitude': 33.2549, 'longitude': -84.2728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30224', 'place_name': 'Griffin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Spalding', 'locality_code': '255', 'latitude': 33.2404, 'longitude': -84.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30266', 'place_name': 'Orchard Hill', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Spalding', 'locality_code': '255', 'latitude': 33.2657, 'longitude': -84.299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30284', 'place_name': 'Sunny Side', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Spalding', 'locality_code': '255', 'latitude': 33.3453, 'longitude': -84.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30538', 'place_name': 'Eastanollee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stephens', 'locality_code': '257', 'latitude': 34.5037, 'longitude': -83.2587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30557', 'place_name': 'Martin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stephens', 'locality_code': '257', 'latitude': 34.487, 'longitude': -83.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30577', 'place_name': 'Toccoa', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stephens', 'locality_code': '257', 'latitude': 34.5665, 'longitude': -83.3114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30598', 'place_name': 'Toccoa Falls', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stephens', 'locality_code': '257', 'latitude': 34.5942, 'longitude': -83.3557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31814', 'place_name': 'Louvale', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stewart', 'locality_code': '259', 'latitude': 32.1752, 'longitude': -84.8252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31815', 'place_name': 'Lumpkin', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stewart', 'locality_code': '259', 'latitude': 32.0435, 'longitude': -84.8022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31821', 'place_name': 'Omaha', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stewart', 'locality_code': '259', 'latitude': 32.1176, 'longitude': -84.9711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31825', 'place_name': 'Richland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Stewart', 'locality_code': '259', 'latitude': 32.0846, 'longitude': -84.6667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31709', 'place_name': 'Americus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Sumter', 'locality_code': '261', 'latitude': 32.0404, 'longitude': -84.2153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31711', 'place_name': 'Andersonville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Sumter', 'locality_code': '261', 'latitude': 32.1559, 'longitude': -84.164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31719', 'place_name': 'Americus', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Sumter', 'locality_code': '261', 'latitude': 32.0833, 'longitude': -84.2975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31735', 'place_name': 'Cobb', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Sumter', 'locality_code': '261', 'latitude': 31.9617, 'longitude': -83.9581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31743', 'place_name': 'De Soto', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Sumter', 'locality_code': '261', 'latitude': 31.9502, 'longitude': -84.0271, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31764', 'place_name': 'Leslie', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Sumter', 'locality_code': '261', 'latitude': 31.954, 'longitude': -84.0783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31780', 'place_name': 'Plains', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Sumter', 'locality_code': '261', 'latitude': 32.0339, 'longitude': -84.3586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31801', 'place_name': 'Box Springs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Talbot', 'locality_code': '263', 'latitude': 32.5195, 'longitude': -84.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31810', 'place_name': 'Geneva', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Talbot', 'locality_code': '263', 'latitude': 32.5799, 'longitude': -84.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31812', 'place_name': 'Junction City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Talbot', 'locality_code': '263', 'latitude': 32.608, 'longitude': -84.4574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31827', 'place_name': 'Talbotton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Talbot', 'locality_code': '263', 'latitude': 32.6797, 'longitude': -84.5462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31836', 'place_name': 'Woodland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Talbot', 'locality_code': '263', 'latitude': 32.79, 'longitude': -84.5654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30631', 'place_name': 'Crawfordville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Taliaferro', 'locality_code': '265', 'latitude': 33.5708, 'longitude': -82.8872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30664', 'place_name': 'Sharon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Taliaferro', 'locality_code': '265', 'latitude': 33.56, 'longitude': -82.7948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30420', 'place_name': 'Cobbtown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tattnall', 'locality_code': '267', 'latitude': 32.2642, 'longitude': -82.1333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30421', 'place_name': 'Collins', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tattnall', 'locality_code': '267', 'latitude': 32.1852, 'longitude': -82.1095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30427', 'place_name': 'Glennville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tattnall', 'locality_code': '267', 'latitude': 31.9467, 'longitude': -81.9483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30438', 'place_name': 'Manassas', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tattnall', 'locality_code': '267', 'latitude': 32.1605, 'longitude': -82.0196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30453', 'place_name': 'Reidsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tattnall', 'locality_code': '267', 'latitude': 32.0548, 'longitude': -82.1478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30499', 'place_name': 'Reidsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tattnall', 'locality_code': '267', 'latitude': 32.0869, 'longitude': -82.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31006', 'place_name': 'Butler', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Taylor', 'locality_code': '269', 'latitude': 32.5726, 'longitude': -84.2343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31039', 'place_name': 'Howard', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Taylor', 'locality_code': '269', 'latitude': 32.596, 'longitude': -84.3844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31058', 'place_name': 'Mauk', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Taylor', 'locality_code': '269', 'latitude': 32.509, 'longitude': -84.3999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31076', 'place_name': 'Reynolds', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Taylor', 'locality_code': '269', 'latitude': 32.5541, 'longitude': -84.1011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31081', 'place_name': 'Rupert', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Taylor', 'locality_code': '269', 'latitude': 32.4325, 'longitude': -84.2738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31037', 'place_name': 'Mc Rae Helena', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Telfair', 'locality_code': '271', 'latitude': 32.0738, 'longitude': -82.9146, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31055', 'place_name': 'Mc Rae Helena', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Telfair', 'locality_code': '271', 'latitude': 32.068, 'longitude': -82.9007, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31060', 'place_name': 'Milan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Telfair', 'locality_code': '271', 'latitude': 31.9618, 'longitude': -83.0588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31083', 'place_name': 'Scotland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Telfair', 'locality_code': '271', 'latitude': 32.0488, 'longitude': -82.8171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31544', 'place_name': 'Jacksonville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Telfair', 'locality_code': '271', 'latitude': 31.8481, 'longitude': -82.975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31549', 'place_name': 'Lumber City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Telfair', 'locality_code': '271', 'latitude': 31.9251, 'longitude': -82.7073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39826', 'place_name': 'Bronwood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Terrell', 'locality_code': '273', 'latitude': 31.8308, 'longitude': -84.364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39828', 'place_name': 'Cairo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Terrell', 'locality_code': '273', 'latitude': 30.8768, 'longitude': -84.2091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39885', 'place_name': 'Sasser', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Terrell', 'locality_code': '273', 'latitude': 31.7191, 'longitude': -84.3479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31626', 'place_name': 'Boston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.7855, 'longitude': -83.7971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31738', 'place_name': 'Coolidge', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.9859, 'longitude': -83.8752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31757', 'place_name': 'Thomasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.8536, 'longitude': -83.8883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31758', 'place_name': 'Thomasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.8366, 'longitude': -83.9788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31765', 'place_name': 'Meigs', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 31.0625, 'longitude': -84.0824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31773', 'place_name': 'Ochlocknee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.9742, 'longitude': -84.055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31778', 'place_name': 'Pavo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.9401, 'longitude': -83.7409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31792', 'place_name': 'Thomasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.8385, 'longitude': -83.9696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31799', 'place_name': 'Thomasville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Thomas', 'locality_code': '275', 'latitude': 30.8366, 'longitude': -83.9788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31727', 'place_name': 'Brookfield', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tift', 'locality_code': '277', 'latitude': 31.4417, 'longitude': -83.5037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31733', 'place_name': 'Chula', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tift', 'locality_code': '277', 'latitude': 31.5439, 'longitude': -83.5509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31775', 'place_name': 'Omega', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tift', 'locality_code': '277', 'latitude': 31.33, 'longitude': -83.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31793', 'place_name': 'Tifton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tift', 'locality_code': '277', 'latitude': 31.4619, 'longitude': -83.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31794', 'place_name': 'Tifton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tift', 'locality_code': '277', 'latitude': 31.4639, 'longitude': -83.4999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31795', 'place_name': 'Ty Ty', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Tift', 'locality_code': '277', 'latitude': 31.4718, 'longitude': -83.6468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30436', 'place_name': 'Lyons', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Toombs', 'locality_code': '279', 'latitude': 32.1711, 'longitude': -82.3078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30474', 'place_name': 'Vidalia', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Toombs', 'locality_code': '279', 'latitude': 32.1934, 'longitude': -82.4067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30475', 'place_name': 'Vidalia', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Toombs', 'locality_code': '279', 'latitude': 32.1775, 'longitude': -82.3739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30546', 'place_name': 'Hiawassee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Towns', 'locality_code': '281', 'latitude': 34.9063, 'longitude': -83.7274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30582', 'place_name': 'Young Harris', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Towns', 'locality_code': '281', 'latitude': 34.9588, 'longitude': -83.8688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30457', 'place_name': 'Soperton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Treutlen', 'locality_code': '283', 'latitude': 32.3869, 'longitude': -82.5871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30230', 'place_name': 'Hogansville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Troup', 'locality_code': '285', 'latitude': 33.1644, 'longitude': -84.9309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30240', 'place_name': 'Lagrange', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Troup', 'locality_code': '285', 'latitude': 33.0243, 'longitude': -85.0739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30241', 'place_name': 'Lagrange', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Troup', 'locality_code': '285', 'latitude': 33.0249, 'longitude': -84.9577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30261', 'place_name': 'Lagrange', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Troup', 'locality_code': '285', 'latitude': 33.0457, 'longitude': -85.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31833', 'place_name': 'West Point', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Troup', 'locality_code': '285', 'latitude': 32.8337, 'longitude': -85.1197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31714', 'place_name': 'Ashburn', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Turner', 'locality_code': '287', 'latitude': 31.7059, 'longitude': -83.6608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31783', 'place_name': 'Rebecca', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Turner', 'locality_code': '287', 'latitude': 31.7979, 'longitude': -83.5235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31790', 'place_name': 'Sycamore', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Turner', 'locality_code': '287', 'latitude': 31.6553, 'longitude': -83.6064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31017', 'place_name': 'Danville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Twiggs', 'locality_code': '289', 'latitude': 32.6057, 'longitude': -83.2454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31020', 'place_name': 'Dry Branch', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Twiggs', 'locality_code': '289', 'latitude': 32.7151, 'longitude': -83.4558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31044', 'place_name': 'Jeffersonville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Twiggs', 'locality_code': '289', 'latitude': 32.7411, 'longitude': -83.3859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30512', 'place_name': 'Blairsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Union', 'locality_code': '291', 'latitude': 34.8763, 'longitude': -83.992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30514', 'place_name': 'Blairsville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Union', 'locality_code': '291', 'latitude': 34.8762, 'longitude': -83.9582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30572', 'place_name': 'Suches', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Union', 'locality_code': '291', 'latitude': 34.7253, 'longitude': -84.0496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30285', 'place_name': 'The Rock', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Upson', 'locality_code': '293', 'latitude': 32.9717, 'longitude': -84.2424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30286', 'place_name': 'Thomaston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Upson', 'locality_code': '293', 'latitude': 32.9015, 'longitude': -84.3324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31097', 'place_name': 'Yatesville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Upson', 'locality_code': '293', 'latitude': 32.9156, 'longitude': -84.1593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30707', 'place_name': 'Chickamauga', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walker', 'locality_code': '295', 'latitude': 34.858, 'longitude': -85.3221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30725', 'place_name': 'Flintstone', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walker', 'locality_code': '295', 'latitude': 34.9252, 'longitude': -85.3524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30728', 'place_name': 'La Fayette', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walker', 'locality_code': '295', 'latitude': 34.692, 'longitude': -85.2602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30739', 'place_name': 'Rock Spring', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walker', 'locality_code': '295', 'latitude': 34.8065, 'longitude': -85.2415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30741', 'place_name': 'Rossville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walker', 'locality_code': '295', 'latitude': 34.9535, 'longitude': -85.2968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30750', 'place_name': 'Lookout Mountain', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walker', 'locality_code': '295', 'latitude': 34.9335, 'longitude': -85.3794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30018', 'place_name': 'Jersey', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walton', 'locality_code': '297', 'latitude': 33.718, 'longitude': -83.8015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30025', 'place_name': 'Social Circle', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walton', 'locality_code': '297', 'latitude': 33.6791, 'longitude': -83.6835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30641', 'place_name': 'Good Hope', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walton', 'locality_code': '297', 'latitude': 33.7613, 'longitude': -83.595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30655', 'place_name': 'Monroe', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walton', 'locality_code': '297', 'latitude': 33.7883, 'longitude': -83.7013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30656', 'place_name': 'Monroe', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Walton', 'locality_code': '297', 'latitude': 33.8386, 'longitude': -83.7104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31501', 'place_name': 'Waycross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ware', 'locality_code': '299', 'latitude': 31.2243, 'longitude': -82.3596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31502', 'place_name': 'Waycross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ware', 'locality_code': '299', 'latitude': 31.2137, 'longitude': -82.3557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31503', 'place_name': 'Waycross', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ware', 'locality_code': '299', 'latitude': 31.2137, 'longitude': -82.3557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31550', 'place_name': 'Manor', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ware', 'locality_code': '299', 'latitude': 31.1088, 'longitude': -82.5742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31552', 'place_name': 'Millwood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ware', 'locality_code': '299', 'latitude': 31.2506, 'longitude': -82.6441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31564', 'place_name': 'Waresboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Ware', 'locality_code': '299', 'latitude': 31.248, 'longitude': -82.4737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30807', 'place_name': 'Camak', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Warren', 'locality_code': '301', 'latitude': 33.4535, 'longitude': -82.646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30819', 'place_name': 'Mesena', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Warren', 'locality_code': '301', 'latitude': 33.4599, 'longitude': -82.5901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30821', 'place_name': 'Norwood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Warren', 'locality_code': '301', 'latitude': 33.4789, 'longitude': -82.7356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30828', 'place_name': 'Warrenton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Warren', 'locality_code': '301', 'latitude': 33.4091, 'longitude': -82.6357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31045', 'place_name': 'Jewell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Warren', 'locality_code': '301', 'latitude': 33.2963, 'longitude': -82.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31018', 'place_name': 'Davisboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Washington', 'locality_code': '303', 'latitude': 32.9443, 'longitude': -82.6227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31035', 'place_name': 'Harrison', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Washington', 'locality_code': '303', 'latitude': 32.842, 'longitude': -82.7159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31067', 'place_name': 'Oconee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Washington', 'locality_code': '303', 'latitude': 32.8554, 'longitude': -82.9499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31082', 'place_name': 'Sandersville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Washington', 'locality_code': '303', 'latitude': 32.975, 'longitude': -82.8406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31089', 'place_name': 'Tennille', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Washington', 'locality_code': '303', 'latitude': 32.9063, 'longitude': -82.84, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31094', 'place_name': 'Warthen', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Washington', 'locality_code': '303', 'latitude': 33.1255, 'longitude': -82.8039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31545', 'place_name': 'Jesup', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wayne', 'locality_code': '305', 'latitude': 31.6043, 'longitude': -81.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31546', 'place_name': 'Jesup', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wayne', 'locality_code': '305', 'latitude': 31.5319, 'longitude': -81.8049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31555', 'place_name': 'Odum', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wayne', 'locality_code': '305', 'latitude': 31.6999, 'longitude': -81.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31560', 'place_name': 'Screven', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wayne', 'locality_code': '305', 'latitude': 31.5168, 'longitude': -82.0397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31598', 'place_name': 'Jesup', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wayne', 'locality_code': '305', 'latitude': 31.5782, 'longitude': -81.8802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31599', 'place_name': 'Jesup', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wayne', 'locality_code': '305', 'latitude': 31.5782, 'longitude': -81.8802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31824', 'place_name': 'Preston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Webster', 'locality_code': '307', 'latitude': 32.074, 'longitude': -84.5489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31832', 'place_name': 'Weston', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Webster', 'locality_code': '307', 'latitude': 31.9637, 'longitude': -84.5756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39877', 'place_name': 'Parrott', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Webster', 'locality_code': '307', 'latitude': 31.8939, 'longitude': -84.5112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30411', 'place_name': 'Alamo', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wheeler', 'locality_code': '309', 'latitude': 32.133, 'longitude': -82.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30428', 'place_name': 'Glenwood', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wheeler', 'locality_code': '309', 'latitude': 32.1572, 'longitude': -82.6759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30528', 'place_name': 'Cleveland', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'White', 'locality_code': '311', 'latitude': 34.5839, 'longitude': -83.75, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30545', 'place_name': 'Helen', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'White', 'locality_code': '311', 'latitude': 34.6866, 'longitude': -83.7399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30571', 'place_name': 'Sautee Nacoochee', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'White', 'locality_code': '311', 'latitude': 34.7162, 'longitude': -83.6931, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '30270', 'place_name': 'Peachtree City', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 33.3968, 'longitude': -84.59, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30710', 'place_name': 'Cohutta', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.9326, 'longitude': -84.9458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30719', 'place_name': 'Dalton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.7698, 'longitude': -84.9702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30720', 'place_name': 'Dalton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.7635, 'longitude': -84.9875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30721', 'place_name': 'Dalton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.7792, 'longitude': -84.9339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30722', 'place_name': 'Dalton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.7595, 'longitude': -84.9513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30740', 'place_name': 'Rocky Face', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.7745, 'longitude': -85.0561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30755', 'place_name': 'Tunnel Hill', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.8541, 'longitude': -85.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30756', 'place_name': 'Varnell', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Whitfield', 'locality_code': '313', 'latitude': 34.9012, 'longitude': -84.9738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31001', 'place_name': 'Abbeville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilcox', 'locality_code': '315', 'latitude': 31.9648, 'longitude': -83.3068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31071', 'place_name': 'Pineview', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilcox', 'locality_code': '315', 'latitude': 32.0907, 'longitude': -83.5158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31072', 'place_name': 'Pitts', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilcox', 'locality_code': '315', 'latitude': 31.9425, 'longitude': -83.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31079', 'place_name': 'Rochelle', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilcox', 'locality_code': '315', 'latitude': 31.9491, 'longitude': -83.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31084', 'place_name': 'Seville', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilcox', 'locality_code': '315', 'latitude': 31.9605, 'longitude': -83.601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30660', 'place_name': 'Rayle', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkes', 'locality_code': '317', 'latitude': 33.7856, 'longitude': -82.9504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30668', 'place_name': 'Tignall', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkes', 'locality_code': '317', 'latitude': 33.8778, 'longitude': -82.747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '30673', 'place_name': 'Washington', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkes', 'locality_code': '317', 'latitude': 33.7265, 'longitude': -82.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31003', 'place_name': 'Allentown', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkinson', 'locality_code': '319', 'latitude': 32.6064, 'longitude': -83.2095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31031', 'place_name': 'Gordon', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkinson', 'locality_code': '319', 'latitude': 32.8813, 'longitude': -83.3029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31042', 'place_name': 'Irwinton', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkinson', 'locality_code': '319', 'latitude': 32.8088, 'longitude': -83.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31054', 'place_name': 'Mc Intyre', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkinson', 'locality_code': '319', 'latitude': 32.8468, 'longitude': -83.204, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '31090', 'place_name': 'Toomsboro', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Wilkinson', 'locality_code': '319', 'latitude': 32.8219, 'longitude': -83.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31772', 'place_name': 'Oakfield', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Worth', 'locality_code': '321', 'latitude': 31.7798, 'longitude': -83.9706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31781', 'place_name': 'Poulan', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Worth', 'locality_code': '321', 'latitude': 31.5384, 'longitude': -83.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31789', 'place_name': 'Sumner', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Worth', 'locality_code': '321', 'latitude': 31.513, 'longitude': -83.7385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31791', 'place_name': 'Sylvester', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Worth', 'locality_code': '321', 'latitude': 31.5393, 'longitude': -83.8607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '31796', 'place_name': 'Warwick', 'state': 'Georgia', 'state_ab': 'GA', 'county': 'Worth', 'locality_code': '321', 'latitude': 31.831, 'longitude': -83.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96704', 'place_name': 'Captain Cook', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.4386, 'longitude': -155.8875, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96710', 'place_name': 'Hakalau', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.8882, 'longitude': -155.1333, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96718', 'place_name': 'Hawaii National Park', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5935, 'longitude': -155.438, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96719', 'place_name': 'Hawi', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 20.238, 'longitude': -155.838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96720', 'place_name': 'Hilo', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.7025, 'longitude': -155.0939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96721', 'place_name': 'Hilo', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.7299, 'longitude': -155.0907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96725', 'place_name': 'Holualoa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.6103, 'longitude': -155.9176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96726', 'place_name': 'Honaunau', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.4273, 'longitude': -155.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96727', 'place_name': 'Honokaa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 20.0827, 'longitude': -155.488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96728', 'place_name': 'Honomu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.8728, 'longitude': -155.1177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96737', 'place_name': 'Ocean View', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.1002, 'longitude': -155.7258, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96738', 'place_name': 'Waikoloa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.9724, 'longitude': -155.818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96739', 'place_name': 'Keauhou', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5606, 'longitude': -155.9623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96740', 'place_name': 'Kailua Kona', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.6531, 'longitude': -155.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96743', 'place_name': 'Kamuela', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 20.0081, 'longitude': -155.7052, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96745', 'place_name': 'Kailua Kona', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5935, 'longitude': -155.438, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96749', 'place_name': 'Keaau', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5893, 'longitude': -154.9926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96750', 'place_name': 'Kealakekua', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5261, 'longitude': -155.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96755', 'place_name': 'Kapaau', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 20.2183, 'longitude': -155.799, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96760', 'place_name': 'Kurtistown', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5693, 'longitude': -155.0349, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96764', 'place_name': 'Laupahoehoe', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.9802, 'longitude': -155.2323, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96771', 'place_name': 'Mountain View', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5506, 'longitude': -155.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96772', 'place_name': 'Naalehu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.0668, 'longitude': -155.6575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96773', 'place_name': 'Ninole', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.935, 'longitude': -155.1668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96774', 'place_name': 'Ookala', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 20.0119, 'longitude': -155.2747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96776', 'place_name': 'Paauilo', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 20.0271, 'longitude': -155.3697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96777', 'place_name': 'Pahala', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.2079, 'longitude': -155.4815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96778', 'place_name': 'Pahoa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.5089, 'longitude': -154.9231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96780', 'place_name': 'Papaaloa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.9751, 'longitude': -155.2203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96781', 'place_name': 'Papaikou', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.7916, 'longitude': -155.0984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96783', 'place_name': 'Pepeekeo', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.8353, 'longitude': -155.113, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96785', 'place_name': 'Volcano', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Hawaii', 'locality_code': '1', 'latitude': 19.4801, 'longitude': -155.1974, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96701', 'place_name': 'Aiea', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3908, 'longitude': -157.9332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96706', 'place_name': 'Ewa Beach', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3274, 'longitude': -158.0103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96707', 'place_name': 'Kapolei', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3453, 'longitude': -158.087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96709', 'place_name': 'Kapolei', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3233, 'longitude': -158.0058, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96712', 'place_name': 'Haleiwa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.6312, 'longitude': -158.0693, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96717', 'place_name': 'Hauula', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.6139, 'longitude': -157.9157, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96730', 'place_name': 'Kaaawa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.5481, 'longitude': -157.8495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96731', 'place_name': 'Kahuku', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.675, 'longitude': -157.9725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96734', 'place_name': 'Kailua', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4063, 'longitude': -157.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96744', 'place_name': 'Kaneohe', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4228, 'longitude': -157.8115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96759', 'place_name': 'Kunia', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.463, 'longitude': -158.0639, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96762', 'place_name': 'Laie', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.6253, 'longitude': -157.941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96782', 'place_name': 'Pearl City', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4084, 'longitude': -157.9652, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96786', 'place_name': 'Wahiawa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.5006, 'longitude': -158.0435, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96789', 'place_name': 'Mililani', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4531, 'longitude': -158.0174, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96791', 'place_name': 'Waialua', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.5766, 'longitude': -158.1267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96792', 'place_name': 'Waianae', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4352, 'longitude': -158.1781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96795', 'place_name': 'Waimanalo', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3418, 'longitude': -157.7131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96797', 'place_name': 'Waipahu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3982, 'longitude': -158.0124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96801', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3278, 'longitude': -157.8294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96802', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.306, 'longitude': -157.8587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96803', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.306, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96804', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.306, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96805', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3062, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96806', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3062, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96807', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3062, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96808', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3062, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96809', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3062, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96810', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3062, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96811', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3278, 'longitude': -157.8294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96812', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3061, 'longitude': -157.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96813', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3179, 'longitude': -157.8521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96814', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2998, 'longitude': -157.8439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96815', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2811, 'longitude': -157.8266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96816', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2887, 'longitude': -157.8006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96817', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3295, 'longitude': -157.8615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96818', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3532, 'longitude': -157.9269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96819', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3488, 'longitude': -157.8759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96820', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.351, 'longitude': -157.8795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96821', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2928, 'longitude': -157.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96822', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3117, 'longitude': -157.8298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96823', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3072, 'longitude': -157.8465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96824', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2808, 'longitude': -157.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96825', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2987, 'longitude': -157.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96826', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2941, 'longitude': -157.8284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96828', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.294, 'longitude': -157.8226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96830', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2841, 'longitude': -157.834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96836', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2899, 'longitude': -157.8384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96837', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.315, 'longitude': -157.8633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96838', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.349, 'longitude': -157.875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96839', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3206, 'longitude': -157.8126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96840', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3068, 'longitude': -157.8607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96841', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3103, 'longitude': -157.8594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96843', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3055, 'longitude': -157.853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96844', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.2951, 'longitude': -157.8162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96846', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3206, 'longitude': -157.8699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96847', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3022, 'longitude': -157.8443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96848', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3206, 'longitude': -157.8126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96849', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3341, 'longitude': -157.9172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96850', 'place_name': 'Honolulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3095, 'longitude': -157.863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96853', 'place_name': 'Jbphh', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4061, 'longitude': -157.9609, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96854', 'place_name': 'Wheeler Army Airfield', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4877, 'longitude': -158.0351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96857', 'place_name': 'Schofield Barracks', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4963, 'longitude': -158.0646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96858', 'place_name': 'Fort Shafter', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3416, 'longitude': -157.8918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96859', 'place_name': 'Tripler Army Medical Center', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.4061, 'longitude': -157.9609, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96861', 'place_name': 'Camp H M Smith', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 21.3967, 'longitude': -157.8994, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96898', 'place_name': 'Wake Island', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Honolulu', 'locality_code': '3', 'latitude': 19.2836, 'longitude': 166.6419, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96703', 'place_name': 'Anahola', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 22.1423, 'longitude': -159.3139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96705', 'place_name': 'Eleele', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9074, 'longitude': -159.5832, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96714', 'place_name': 'Hanalei', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 22.1603, 'longitude': -159.5471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96715', 'place_name': 'Hanamaulu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9977, 'longitude': -159.3592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96716', 'place_name': 'Hanapepe', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9156, 'longitude': -159.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96722', 'place_name': 'Princeville', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 22.2192, 'longitude': -159.4866, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96741', 'place_name': 'Kalaheo', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9259, 'longitude': -159.5303, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96746', 'place_name': 'Kapaa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 22.0868, 'longitude': -159.3448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96747', 'place_name': 'Kaumakani', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9213, 'longitude': -159.6241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96751', 'place_name': 'Kealia', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 22.106, 'longitude': -159.3085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96752', 'place_name': 'Kekaha', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9735, 'longitude': -159.7199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96754', 'place_name': 'Kilauea', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 22.2073, 'longitude': -159.3954, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96756', 'place_name': 'Koloa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9083, 'longitude': -159.4749, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96765', 'place_name': 'Lawai', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9309, 'longitude': -159.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96766', 'place_name': 'Lihue', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9816, 'longitude': -159.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96769', 'place_name': 'Makaweli', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9454, 'longitude': -159.9214, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96796', 'place_name': 'Waimea', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Kauai', 'locality_code': '7', 'latitude': 21.9571, 'longitude': -159.6689, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96708', 'place_name': 'Haiku', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.9071, 'longitude': -156.3, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96713', 'place_name': 'Hana', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.7616, 'longitude': -156.0397, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96729', 'place_name': 'Hoolehua', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 21.173, 'longitude': -157.0791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96732', 'place_name': 'Kahului', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8814, 'longitude': -156.4783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96733', 'place_name': 'Kahului', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8895, 'longitude': -156.4743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96742', 'place_name': 'Kalaupapa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 21.1929, 'longitude': -156.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96748', 'place_name': 'Kaunakakai', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 21.0905, 'longitude': -156.969, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96753', 'place_name': 'Kihei', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.7441, 'longitude': -156.4475, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96757', 'place_name': 'Kualapuu', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 21.1601, 'longitude': -157.0277, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96761', 'place_name': 'Lahaina', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.9174, 'longitude': -156.6772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96763', 'place_name': 'Lanai City', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8293, 'longitude': -156.921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96767', 'place_name': 'Lahaina', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8666, 'longitude': -156.6467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96768', 'place_name': 'Makawao', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8469, 'longitude': -156.3327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96770', 'place_name': 'Maunaloa', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 21.1422, 'longitude': -157.2193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96779', 'place_name': 'Paia', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.9154, 'longitude': -156.3802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96784', 'place_name': 'Puunene', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8666, 'longitude': -156.6467, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96788', 'place_name': 'Pukalani', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8559, 'longitude': -156.3259, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96790', 'place_name': 'Kula', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.7534, 'longitude': -156.326, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96793', 'place_name': 'Wailuku', 'state': 'Hawaii', 'state_ab': 'HI', 'county': 'Maui', 'locality_code': '9', 'latitude': 20.8966, 'longitude': -156.5036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50002', 'place_name': 'Adair', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adair', 'locality_code': '1', 'latitude': 41.5137, 'longitude': -94.6444, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '50837', 'place_name': 'Bridgewater', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adair', 'locality_code': '1', 'latitude': 41.2589, 'longitude': -94.6669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50846', 'place_name': 'Fontanelle', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adair', 'locality_code': '1', 'latitude': 41.2896, 'longitude': -94.5419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50849', 'place_name': 'Greenfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adair', 'locality_code': '1', 'latitude': 41.3133, 'longitude': -94.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50858', 'place_name': 'Orient', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adair', 'locality_code': '1', 'latitude': 41.2192, 'longitude': -94.3705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50839', 'place_name': 'Carbon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adams', 'locality_code': '3', 'latitude': 41.0487, 'longitude': -94.8231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50841', 'place_name': 'Corning', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adams', 'locality_code': '3', 'latitude': 40.9871, 'longitude': -94.7358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50857', 'place_name': 'Nodaway', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adams', 'locality_code': '3', 'latitude': 40.954, 'longitude': -94.8731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50859', 'place_name': 'Prescott', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Adams', 'locality_code': '3', 'latitude': 41.0577, 'longitude': -94.5942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52140', 'place_name': 'Dorchester', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Allamakee', 'locality_code': '5', 'latitude': 43.4421, 'longitude': -91.5076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52146', 'place_name': 'Harpers Ferry', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Allamakee', 'locality_code': '5', 'latitude': 43.1698, 'longitude': -91.2188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52151', 'place_name': 'Lansing', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Allamakee', 'locality_code': '5', 'latitude': 43.3661, 'longitude': -91.266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52160', 'place_name': 'New Albin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Allamakee', 'locality_code': '5', 'latitude': 43.4899, 'longitude': -91.2942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52162', 'place_name': 'Postville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Allamakee', 'locality_code': '5', 'latitude': 43.0036, 'longitude': -91.5478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52170', 'place_name': 'Waterville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Allamakee', 'locality_code': '5', 'latitude': 43.2078, 'longitude': -91.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52172', 'place_name': 'Waukon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Allamakee', 'locality_code': '5', 'latitude': 43.264, 'longitude': -91.48, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52544', 'place_name': 'Centerville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.7326, 'longitude': -92.8728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52549', 'place_name': 'Cincinnati', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.6344, 'longitude': -92.9219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52555', 'place_name': 'Exline', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.6414, 'longitude': -92.827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52571', 'place_name': 'Moravia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.8825, 'longitude': -92.8534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52572', 'place_name': 'Moulton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.6866, 'longitude': -92.6833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52574', 'place_name': 'Mystic', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.7883, 'longitude': -92.9284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52581', 'place_name': 'Plano', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.7751, 'longitude': -93.0386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52593', 'place_name': 'Udell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.7808, 'longitude': -92.7421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52594', 'place_name': 'Unionville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Appanoose', 'locality_code': '7', 'latitude': 40.8416, 'longitude': -92.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50025', 'place_name': 'Audubon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Audubon', 'locality_code': '9', 'latitude': 41.73, 'longitude': -94.9164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50042', 'place_name': 'Brayton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Audubon', 'locality_code': '9', 'latitude': 41.5524, 'longitude': -94.974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50076', 'place_name': 'Exira', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Audubon', 'locality_code': '9', 'latitude': 41.5768, 'longitude': -94.8571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50110', 'place_name': 'Gray', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Audubon', 'locality_code': '9', 'latitude': 41.8401, 'longitude': -94.9812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50117', 'place_name': 'Hamlin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Audubon', 'locality_code': '9', 'latitude': 41.6506, 'longitude': -94.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51543', 'place_name': 'Kimballton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Audubon', 'locality_code': '9', 'latitude': 41.6352, 'longitude': -95.0553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52206', 'place_name': 'Atkins', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.9881, 'longitude': -91.876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52208', 'place_name': 'Belle Plaine', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.8992, 'longitude': -92.2574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52209', 'place_name': 'Blairstown', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.9063, 'longitude': -92.0829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52229', 'place_name': 'Garrison', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 42.1588, 'longitude': -92.1644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52249', 'place_name': 'Keystone', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 42.0156, 'longitude': -92.2179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52257', 'place_name': 'Luzerne', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.9061, 'longitude': -92.1793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52313', 'place_name': 'Mount Auburn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 42.255, 'longitude': -92.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52315', 'place_name': 'Newhall', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.9927, 'longitude': -91.9779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52318', 'place_name': 'Norway', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.8992, 'longitude': -91.892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52332', 'place_name': 'Shellsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 42.0848, 'longitude': -91.8746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52345', 'place_name': 'Urbana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 42.2365, 'longitude': -91.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52346', 'place_name': 'Van Horne', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 42.0194, 'longitude': -92.1046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52349', 'place_name': 'Vinton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 42.1743, 'longitude': -91.9892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52351', 'place_name': 'Walford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.877, 'longitude': -91.8369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52354', 'place_name': 'Watkins', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Benton', 'locality_code': '11', 'latitude': 41.904, 'longitude': -91.9965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50613', 'place_name': 'Cedar Falls', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.5241, 'longitude': -92.4497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50614', 'place_name': 'Cedar Falls', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.4698, 'longitude': -92.3095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50623', 'place_name': 'Dewar', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.5253, 'longitude': -92.2207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50626', 'place_name': 'Dunkerton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.578, 'longitude': -92.1588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50634', 'place_name': 'Gilbertville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.4161, 'longitude': -92.2149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50643', 'place_name': 'Hudson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.3905, 'longitude': -92.4549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50651', 'place_name': 'La Porte City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.3416, 'longitude': -92.1862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50667', 'place_name': 'Raymond', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.4672, 'longitude': -92.2162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50701', 'place_name': 'Waterloo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.4778, 'longitude': -92.3661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50702', 'place_name': 'Waterloo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.4731, 'longitude': -92.3365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50703', 'place_name': 'Waterloo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.5149, 'longitude': -92.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50704', 'place_name': 'Waterloo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.4698, 'longitude': -92.3095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50707', 'place_name': 'Evansdale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Black Hawk', 'locality_code': '13', 'latitude': 42.4755, 'longitude': -92.2812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50031', 'place_name': 'Beaver', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 42.0387, 'longitude': -94.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50036', 'place_name': 'Boone', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 42.0694, 'longitude': -93.8781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50037', 'place_name': 'Boone', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 42.0597, 'longitude': -93.8802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50040', 'place_name': 'Boxholm', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 42.1706, 'longitude': -94.1052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50099', 'place_name': 'Boone', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 42.0597, 'longitude': -93.8802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50152', 'place_name': 'Luther', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 41.9387, 'longitude': -93.8371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50156', 'place_name': 'Madrid', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 41.8841, 'longitude': -93.8448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50212', 'place_name': 'Ogden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 42.0351, 'longitude': -94.0063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50223', 'place_name': 'Pilot Mound', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Boone', 'locality_code': '15', 'latitude': 42.1604, 'longitude': -94.0102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50622', 'place_name': 'Denver', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.6731, 'longitude': -92.3417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50631', 'place_name': 'Frederika', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.8827, 'longitude': -92.3063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50647', 'place_name': 'Janesville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.6465, 'longitude': -92.4791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50666', 'place_name': 'Plainfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.8503, 'longitude': -92.5116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50668', 'place_name': 'Readlyn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.6929, 'longitude': -92.2154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50674', 'place_name': 'Sumner', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.8419, 'longitude': -92.1186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50676', 'place_name': 'Tripoli', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.8105, 'longitude': -92.2659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50677', 'place_name': 'Waverly', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Bremer', 'locality_code': '17', 'latitude': 42.7748, 'longitude': -92.404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50607', 'place_name': 'Aurora', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.6203, 'longitude': -91.7335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50629', 'place_name': 'Fairbank', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.6162, 'longitude': -92.0326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50641', 'place_name': 'Hazleton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.6076, 'longitude': -91.9105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50644', 'place_name': 'Independence', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.4674, 'longitude': -91.8803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50648', 'place_name': 'Jesup', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.4823, 'longitude': -92.0456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50650', 'place_name': 'Lamont', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.5946, 'longitude': -91.6701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50671', 'place_name': 'Stanley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.6356, 'longitude': -91.8127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50682', 'place_name': 'Winthrop', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.4912, 'longitude': -91.7315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52210', 'place_name': 'Brandon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.3309, 'longitude': -92.0059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52326', 'place_name': 'Quasqueton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.3956, 'longitude': -91.7679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52329', 'place_name': 'Rowley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buchanan', 'locality_code': '19', 'latitude': 42.37, 'longitude': -91.8441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50510', 'place_name': 'Albert City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.7784, 'longitude': -94.9824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50565', 'place_name': 'Marathon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.8612, 'longitude': -94.9836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50568', 'place_name': 'Newell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.6157, 'longitude': -94.9946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50576', 'place_name': 'Rembrandt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.826, 'longitude': -95.1652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50585', 'place_name': 'Sioux Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.9065, 'longitude': -95.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50588', 'place_name': 'Storm Lake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.6474, 'longitude': -95.1961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50592', 'place_name': 'Truesdale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.7262, 'longitude': -95.1853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51002', 'place_name': 'Alta', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.6771, 'longitude': -95.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51033', 'place_name': 'Linn Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Buena Vista', 'locality_code': '21', 'latitude': 42.8742, 'longitude': -95.2512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50602', 'place_name': 'Allison', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.7615, 'longitude': -92.783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50604', 'place_name': 'Aplington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.587, 'longitude': -92.8751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50605', 'place_name': 'Aredale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.8318, 'longitude': -93.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50608', 'place_name': 'Austinville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.5824, 'longitude': -92.9599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50611', 'place_name': 'Bristow', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.7741, 'longitude': -92.8864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50619', 'place_name': 'Clarksville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.8041, 'longitude': -92.6588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50625', 'place_name': 'Dumont', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.7368, 'longitude': -92.9673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50636', 'place_name': 'Greene', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.8958, 'longitude': -92.8024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50649', 'place_name': 'Kesley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.6626, 'longitude': -92.9112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50660', 'place_name': 'New Hartford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.5831, 'longitude': -92.6164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50665', 'place_name': 'Parkersburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.5714, 'longitude': -92.7688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50670', 'place_name': 'Shell Rock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Butler', 'locality_code': '23', 'latitude': 42.7061, 'longitude': -92.5888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50538', 'place_name': 'Farnhamville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.2692, 'longitude': -94.4226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50551', 'place_name': 'Jolley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.4871, 'longitude': -94.757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50552', 'place_name': 'Knierim', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.4555, 'longitude': -94.4569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50561', 'place_name': 'Lytton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.423, 'longitude': -94.8597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50563', 'place_name': 'Manson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.5285, 'longitude': -94.5304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50575', 'place_name': 'Pomeroy', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.5511, 'longitude': -94.6839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50579', 'place_name': 'Rockwell City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.3961, 'longitude': -94.6292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50586', 'place_name': 'Somers', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.3561, 'longitude': -94.4464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51449', 'place_name': 'Lake City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.2705, 'longitude': -94.7458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51453', 'place_name': 'Lohrville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.2619, 'longitude': -94.5566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50058', 'place_name': 'Coon Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 41.894, 'longitude': -94.68, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51401', 'place_name': 'Carroll', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.072, 'longitude': -94.8667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51430', 'place_name': 'Arcadia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.0573, 'longitude': -95.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51436', 'place_name': 'Breda', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.1758, 'longitude': -95.0007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51440', 'place_name': 'Dedham', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 41.9055, 'longitude': -94.8149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51443', 'place_name': 'Glidden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.0618, 'longitude': -94.7148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51444', 'place_name': 'Halbur', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.0048, 'longitude': -94.9731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51451', 'place_name': 'Lanesboro', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.1845, 'longitude': -94.6917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51452', 'place_name': 'Lidderdale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.1254, 'longitude': -94.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51455', 'place_name': 'Manning', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 41.9072, 'longitude': -95.0556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51459', 'place_name': 'Ralston', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 42.0414, 'longitude': -94.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51463', 'place_name': 'Templeton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Carroll', 'locality_code': '27', 'latitude': 41.9121, 'longitude': -94.932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50020', 'place_name': 'Anita', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.45, 'longitude': -94.7794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50022', 'place_name': 'Atlantic', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.4003, 'longitude': -95.0101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50274', 'place_name': 'Wiota', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.3846, 'longitude': -94.8405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50843', 'place_name': 'Cumberland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.2632, 'longitude': -94.871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50853', 'place_name': 'Massena', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.2499, 'longitude': -94.7649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51535', 'place_name': 'Griswold', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.235, 'longitude': -95.1375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51544', 'place_name': 'Lewis', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.2963, 'longitude': -95.062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51552', 'place_name': 'Marne', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cass', 'locality_code': '29', 'latitude': 41.4547, 'longitude': -95.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52216', 'place_name': 'Clarence', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.8896, 'longitude': -91.0605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52255', 'place_name': 'Lowden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.8594, 'longitude': -90.9382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52306', 'place_name': 'Mechanicsville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.9039, 'longitude': -91.2764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52337', 'place_name': 'Stanwood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.8963, 'longitude': -91.1662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52358', 'place_name': 'West Branch', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.6726, 'longitude': -91.3141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52721', 'place_name': 'Bennett', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.7353, 'longitude': -90.9656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52747', 'place_name': 'Durant', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.6145, 'longitude': -90.91, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52772', 'place_name': 'Tipton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cedar', 'locality_code': '31', 'latitude': 41.7563, 'longitude': -91.1362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50401', 'place_name': 'Mason City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 43.1499, 'longitude': -93.1954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50402', 'place_name': 'Mason City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 43.1536, 'longitude': -93.201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50428', 'place_name': 'Clear Lake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 43.1406, 'longitude': -93.385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50433', 'place_name': 'Dougherty', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 42.9222, 'longitude': -93.0421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50457', 'place_name': 'Meservey', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 42.9137, 'longitude': -93.4773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50464', 'place_name': 'Plymouth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 43.246, 'longitude': -93.1226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50467', 'place_name': 'Rock Falls', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 43.2066, 'longitude': -93.0857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50469', 'place_name': 'Rockwell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 43.0032, 'longitude': -93.2167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50477', 'place_name': 'Swaledale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 42.9622, 'longitude': -93.3115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50479', 'place_name': 'Thornton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 42.9684, 'longitude': -93.4088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50482', 'place_name': 'Ventura', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cerro Gordo', 'locality_code': '33', 'latitude': 43.1262, 'longitude': -93.4706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51005', 'place_name': 'Aurelia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.6912, 'longitude': -95.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51012', 'place_name': 'Cherokee', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.7482, 'longitude': -95.5568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51014', 'place_name': 'Cleghorn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.8086, 'longitude': -95.7124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51029', 'place_name': 'Larrabee', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.8608, 'longitude': -95.5453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51035', 'place_name': 'Marcus', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.82, 'longitude': -95.8034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51037', 'place_name': 'Meriden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.7874, 'longitude': -95.6408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51049', 'place_name': 'Quimby', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.6303, 'longitude': -95.642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51061', 'place_name': 'Washta', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Cherokee', 'locality_code': '35', 'latitude': 42.5781, 'longitude': -95.7295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50603', 'place_name': 'Alta Vista', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Chickasaw', 'locality_code': '37', 'latitude': 43.1482, 'longitude': -92.4237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50630', 'place_name': 'Fredericksburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Chickasaw', 'locality_code': '37', 'latitude': 42.9593, 'longitude': -92.1983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50645', 'place_name': 'Ionia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Chickasaw', 'locality_code': '37', 'latitude': 43.0403, 'longitude': -92.4865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50658', 'place_name': 'Nashua', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Chickasaw', 'locality_code': '37', 'latitude': 42.9528, 'longitude': -92.5298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50659', 'place_name': 'New Hampton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Chickasaw', 'locality_code': '37', 'latitude': 43.056, 'longitude': -92.3131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50661', 'place_name': 'North Washington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Chickasaw', 'locality_code': '37', 'latitude': 43.1174, 'longitude': -92.4144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52154', 'place_name': 'Lawler', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Chickasaw', 'locality_code': '37', 'latitude': 43.0932, 'longitude': -92.144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50174', 'place_name': 'Murray', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clarke', 'locality_code': '39', 'latitude': 41.0376, 'longitude': -93.953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50213', 'place_name': 'Osceola', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clarke', 'locality_code': '39', 'latitude': 41.0295, 'longitude': -93.7712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50275', 'place_name': 'Woodburn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clarke', 'locality_code': '39', 'latitude': 41, 'longitude': -93.6083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51047', 'place_name': 'Peterson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 42.9328, 'longitude': -95.3377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51301', 'place_name': 'Spencer', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 43.1451, 'longitude': -95.1457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51333', 'place_name': 'Dickens', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 43.1548, 'longitude': -94.9854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51338', 'place_name': 'Everly', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 43.1609, 'longitude': -95.3228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51340', 'place_name': 'Fostoria', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 43.0824, 'longitude': -95.1511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51341', 'place_name': 'Gillett Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 43.0157, 'longitude': -95.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51343', 'place_name': 'Greenville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 43.0333, 'longitude': -95.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51357', 'place_name': 'Royal', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 43.0488, 'longitude': -95.2679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51366', 'place_name': 'Webb', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clay', 'locality_code': '41', 'latitude': 42.9502, 'longitude': -94.9951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52042', 'place_name': 'Edgewood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.6541, 'longitude': -91.395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52043', 'place_name': 'Elkader', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.8496, 'longitude': -91.4143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52044', 'place_name': 'Elkport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.7624, 'longitude': -91.3203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52047', 'place_name': 'Farmersburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.9522, 'longitude': -91.339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52048', 'place_name': 'Garber', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.7453, 'longitude': -91.2593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52049', 'place_name': 'Garnavillo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.8762, 'longitude': -91.2156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52052', 'place_name': 'Guttenberg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.7594, 'longitude': -91.119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52066', 'place_name': 'North Buena Vista', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.6783, 'longitude': -90.9518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52072', 'place_name': 'Saint Olaf', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.922, 'longitude': -91.3778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52076', 'place_name': 'Strawberry Point', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.6832, 'longitude': -91.5409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52077', 'place_name': 'Volga', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 42.7904, 'longitude': -91.5429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52156', 'place_name': 'Luana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 43.0493, 'longitude': -91.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52157', 'place_name': 'Mc Gregor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 43.0237, 'longitude': -91.1887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52158', 'place_name': 'Marquette', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 43.036, 'longitude': -91.1931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52159', 'place_name': 'Monona', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clayton', 'locality_code': '43', 'latitude': 43.034, 'longitude': -91.3934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52037', 'place_name': 'Delmar', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9961, 'longitude': -90.6087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52254', 'place_name': 'Lost Nation', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9745, 'longitude': -90.8265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52701', 'place_name': 'Andover', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9792, 'longitude': -90.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52727', 'place_name': 'Bryant', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9629, 'longitude': -90.3388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52729', 'place_name': 'Calamus', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8111, 'longitude': -90.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52730', 'place_name': 'Camanche', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.7886, 'longitude': -90.2709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52731', 'place_name': 'Charlotte', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9779, 'longitude': -90.4782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52732', 'place_name': 'Clinton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8517, 'longitude': -90.2078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52733', 'place_name': 'Clinton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8445, 'longitude': -90.1887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52734', 'place_name': 'Clinton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8444, 'longitude': -90.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52736', 'place_name': 'Clinton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8445, 'longitude': -90.1887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52742', 'place_name': 'De Witt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8267, 'longitude': -90.5237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52750', 'place_name': 'Goose Lake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9799, 'longitude': -90.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52751', 'place_name': 'Grand Mound', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8501, 'longitude': -90.6695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52757', 'place_name': 'Low Moor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8017, 'longitude': -90.3549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52771', 'place_name': 'Teeds Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9991, 'longitude': -90.2187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52774', 'place_name': 'Welton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.9081, 'longitude': -90.5954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52777', 'place_name': 'Wheatland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Clinton', 'locality_code': '45', 'latitude': 41.8259, 'longitude': -90.8402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51432', 'place_name': 'Aspinwall', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 41.9119, 'longitude': -95.1356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51439', 'place_name': 'Charter Oak', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.0707, 'longitude': -95.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51441', 'place_name': 'Deloit', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.1238, 'longitude': -95.3045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51442', 'place_name': 'Denison', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.0196, 'longitude': -95.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51448', 'place_name': 'Kiron', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.1794, 'longitude': -95.3115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51454', 'place_name': 'Manilla', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 41.8922, 'longitude': -95.2391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51460', 'place_name': 'Ricketts', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.1304, 'longitude': -95.5746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51461', 'place_name': 'Schleswig', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.1646, 'longitude': -95.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51465', 'place_name': 'Vail', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.0338, 'longitude': -95.1778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51467', 'place_name': 'Westside', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 42.1084, 'longitude': -95.1273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51520', 'place_name': 'Arion', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 41.9504, 'longitude': -95.4623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51528', 'place_name': 'Dow City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Crawford', 'locality_code': '47', 'latitude': 41.9134, 'longitude': -95.4862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50003', 'place_name': 'Adel', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.6221, 'longitude': -94.038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50038', 'place_name': 'Booneville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.5242, 'longitude': -93.8838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50039', 'place_name': 'Bouton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.8284, 'longitude': -93.9963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50063', 'place_name': 'Dallas Center', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.6862, 'longitude': -93.9707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50066', 'place_name': 'Dawson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.8324, 'longitude': -94.2171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50069', 'place_name': 'De Soto', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.5208, 'longitude': -94.0303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50070', 'place_name': 'Dexter', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.5198, 'longitude': -94.2145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50109', 'place_name': 'Granger', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.7611, 'longitude': -93.8244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50146', 'place_name': 'Linden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.6422, 'longitude': -94.2406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50167', 'place_name': 'Minburn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.7562, 'longitude': -94.015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50220', 'place_name': 'Perry', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.8397, 'longitude': -94.1022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50233', 'place_name': 'Redfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.5873, 'longitude': -94.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50261', 'place_name': 'Van Meter', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.4699, 'longitude': -93.9207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50263', 'place_name': 'Waukee', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.593, 'longitude': -93.8592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50276', 'place_name': 'Woodward', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dallas', 'locality_code': '49', 'latitude': 41.8452, 'longitude': -93.9056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52537', 'place_name': 'Bloomfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Davis', 'locality_code': '51', 'latitude': 40.7324, 'longitude': -92.3987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52552', 'place_name': 'Drakesville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Davis', 'locality_code': '51', 'latitude': 40.8253, 'longitude': -92.5051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52560', 'place_name': 'Floris', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Davis', 'locality_code': '51', 'latitude': 40.8591, 'longitude': -92.3247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52584', 'place_name': 'Pulaski', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Davis', 'locality_code': '51', 'latitude': 40.6941, 'longitude': -92.258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50065', 'place_name': 'Davis City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.6346, 'longitude': -93.8105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50067', 'place_name': 'Decatur', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.743, 'longitude': -93.8317, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '50103', 'place_name': 'Garden Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.7711, 'longitude': -93.6117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50108', 'place_name': 'Grand River', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.8137, 'longitude': -93.9544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50140', 'place_name': 'Lamoni', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.6229, 'longitude': -93.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50144', 'place_name': 'Leon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.7373, 'longitude': -93.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50262', 'place_name': 'Van Wert', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.8645, 'longitude': -93.8073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50264', 'place_name': 'Weldon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Decatur', 'locality_code': '53', 'latitude': 40.8739, 'longitude': -93.7387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50654', 'place_name': 'Masonville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.4794, 'longitude': -91.5913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52035', 'place_name': 'Colesburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.6383, 'longitude': -91.1963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52036', 'place_name': 'Delaware', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.4766, 'longitude': -91.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52038', 'place_name': 'Dundee', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.594, 'longitude': -91.5477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52041', 'place_name': 'Earlville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.5001, 'longitude': -91.2597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52050', 'place_name': 'Greeley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.5939, 'longitude': -91.3233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52057', 'place_name': 'Manchester', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.4834, 'longitude': -91.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52223', 'place_name': 'Delhi', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.4297, 'longitude': -91.331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52237', 'place_name': 'Hopkinton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.3422, 'longitude': -91.2461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52330', 'place_name': 'Ryan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Delaware', 'locality_code': '55', 'latitude': 42.3436, 'longitude': -91.4848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52601', 'place_name': 'Burlington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Des Moines', 'locality_code': '57', 'latitude': 40.8087, 'longitude': -91.117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52623', 'place_name': 'Danville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Des Moines', 'locality_code': '57', 'latitude': 40.854, 'longitude': -91.314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52637', 'place_name': 'Mediapolis', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Des Moines', 'locality_code': '57', 'latitude': 41.0059, 'longitude': -91.1321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52638', 'place_name': 'Middletown', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Des Moines', 'locality_code': '57', 'latitude': 40.8296, 'longitude': -91.2631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52650', 'place_name': 'Sperry', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Des Moines', 'locality_code': '57', 'latitude': 40.9419, 'longitude': -91.185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52655', 'place_name': 'West Burlington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Des Moines', 'locality_code': '57', 'latitude': 40.8321, 'longitude': -91.1799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52660', 'place_name': 'Yarmouth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Des Moines', 'locality_code': '57', 'latitude': 40.9835, 'longitude': -91.3026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51331', 'place_name': 'Arnolds Park', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dickinson', 'locality_code': '59', 'latitude': 43.3637, 'longitude': -95.1282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51347', 'place_name': 'Lake Park', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dickinson', 'locality_code': '59', 'latitude': 43.4452, 'longitude': -95.3216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51351', 'place_name': 'Milford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dickinson', 'locality_code': '59', 'latitude': 43.3196, 'longitude': -95.1615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51355', 'place_name': 'Okoboji', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dickinson', 'locality_code': '59', 'latitude': 43.3889, 'longitude': -95.1369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51360', 'place_name': 'Spirit Lake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dickinson', 'locality_code': '59', 'latitude': 43.4262, 'longitude': -95.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51363', 'place_name': 'Superior', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dickinson', 'locality_code': '59', 'latitude': 43.4318, 'longitude': -94.9469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51364', 'place_name': 'Terril', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dickinson', 'locality_code': '59', 'latitude': 43.3241, 'longitude': -94.9737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52001', 'place_name': 'Dubuque', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.515, 'longitude': -90.6819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52002', 'place_name': 'Dubuque', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.5122, 'longitude': -90.7384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52003', 'place_name': 'Dubuque', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.4649, 'longitude': -90.6829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52004', 'place_name': 'Dubuque', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.5006, 'longitude': -90.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52032', 'place_name': 'Bernard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.3321, 'longitude': -90.863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52033', 'place_name': 'Cascade', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.287, 'longitude': -91.0144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52039', 'place_name': 'Durango', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.5526, 'longitude': -90.8608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52040', 'place_name': 'Dyersville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.4833, 'longitude': -91.1183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52045', 'place_name': 'Epworth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.4439, 'longitude': -90.9313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52046', 'place_name': 'Farley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.4451, 'longitude': -91.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52053', 'place_name': 'Holy Cross', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.5808, 'longitude': -90.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52056', 'place_name': 'Luxemburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.5783, 'longitude': -91.0621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52065', 'place_name': 'New Vienna', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.5678, 'longitude': -91.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52068', 'place_name': 'Peosta', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.4435, 'longitude': -90.8094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52073', 'place_name': 'Sherrill', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.6171, 'longitude': -90.8115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52078', 'place_name': 'Worthington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.393, 'longitude': -91.1069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52079', 'place_name': 'Zwingle', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.2775, 'longitude': -90.7507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52099', 'place_name': 'Dubuque', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Dubuque', 'locality_code': '61', 'latitude': 42.5006, 'longitude': -90.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50514', 'place_name': 'Armstrong', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Emmet', 'locality_code': '63', 'latitude': 43.4024, 'longitude': -94.4853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50531', 'place_name': 'Dolliver', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Emmet', 'locality_code': '63', 'latitude': 43.4664, 'longitude': -94.6242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50578', 'place_name': 'Ringsted', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Emmet', 'locality_code': '63', 'latitude': 43.2977, 'longitude': -94.5291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51334', 'place_name': 'Estherville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Emmet', 'locality_code': '63', 'latitude': 43.4017, 'longitude': -94.818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51365', 'place_name': 'Wallingford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Emmet', 'locality_code': '63', 'latitude': 43.3189, 'longitude': -94.7964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50606', 'place_name': 'Arlington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.7338, 'longitude': -91.6668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50655', 'place_name': 'Maynard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.7752, 'longitude': -91.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50662', 'place_name': 'Oelwein', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.6811, 'longitude': -91.9131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50664', 'place_name': 'Oran', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.7012, 'longitude': -92.0762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50681', 'place_name': 'Westgate', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.7812, 'longitude': -92.0122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52135', 'place_name': 'Clermont', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 43.013, 'longitude': -91.6552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52141', 'place_name': 'Elgin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.9548, 'longitude': -91.6454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52142', 'place_name': 'Fayette', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.8494, 'longitude': -91.8139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52147', 'place_name': 'Hawkeye', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.9487, 'longitude': -91.9578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52164', 'place_name': 'Randalia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.8626, 'longitude': -91.8846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52166', 'place_name': 'Saint Lucas', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 43.0664, 'longitude': -91.9335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52169', 'place_name': 'Wadena', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.855, 'longitude': -91.6639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52171', 'place_name': 'Waucoma', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 43.0433, 'longitude': -92.0302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52175', 'place_name': 'West Union', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fayette', 'locality_code': '65', 'latitude': 42.9438, 'longitude': -91.8334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50435', 'place_name': 'Floyd', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Floyd', 'locality_code': '67', 'latitude': 43.143, 'longitude': -92.724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50458', 'place_name': 'Nora Springs', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Floyd', 'locality_code': '67', 'latitude': 43.1479, 'longitude': -93.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50468', 'place_name': 'Rockford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Floyd', 'locality_code': '67', 'latitude': 43.0573, 'longitude': -92.952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50471', 'place_name': 'Rudd', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Floyd', 'locality_code': '67', 'latitude': 43.142, 'longitude': -92.8885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50616', 'place_name': 'Charles City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Floyd', 'locality_code': '67', 'latitude': 43.0683, 'longitude': -92.6761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50620', 'place_name': 'Colwell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Floyd', 'locality_code': '67', 'latitude': 43.1584, 'longitude': -92.5905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50653', 'place_name': 'Marble Rock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Floyd', 'locality_code': '67', 'latitude': 42.9645, 'longitude': -92.8917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50041', 'place_name': 'Bradford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.633, 'longitude': -93.2449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50227', 'place_name': 'Popejoy', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.5974, 'longitude': -93.4279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50420', 'place_name': 'Alexander', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.8114, 'longitude': -93.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50427', 'place_name': 'Chapin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.8349, 'longitude': -93.2226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50431', 'place_name': 'Coulter', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.7382, 'longitude': -93.37, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50441', 'place_name': 'Hampton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.7405, 'longitude': -93.211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50452', 'place_name': 'Latimer', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.7598, 'longitude': -93.3518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50475', 'place_name': 'Sheffield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.8779, 'longitude': -93.2156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50633', 'place_name': 'Geneva', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Franklin', 'locality_code': '69', 'latitude': 42.6755, 'longitude': -93.1294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51639', 'place_name': 'Farragut', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.7215, 'longitude': -95.4776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51640', 'place_name': 'Hamburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.6149, 'longitude': -95.6258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51645', 'place_name': 'Imogene', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.8631, 'longitude': -95.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51648', 'place_name': 'Percival', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.7401, 'longitude': -95.8093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51649', 'place_name': 'Randolph', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.8704, 'longitude': -95.5624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51650', 'place_name': 'Riverton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.6629, 'longitude': -95.5773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51652', 'place_name': 'Sidney', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.7507, 'longitude': -95.6403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51653', 'place_name': 'Tabor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.9004, 'longitude': -95.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51654', 'place_name': 'Thurman', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Fremont', 'locality_code': '71', 'latitude': 40.8424, 'longitude': -95.7605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50050', 'place_name': 'Churdan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 42.1614, 'longitude': -94.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50059', 'place_name': 'Cooper', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 42.0363, 'longitude': -94.397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50064', 'place_name': 'Dana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 42.1075, 'longitude': -94.2408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50107', 'place_name': 'Grand Junction', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 42.0296, 'longitude': -94.2336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50129', 'place_name': 'Jefferson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 42.0093, 'longitude': -94.3888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50217', 'place_name': 'Paton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 42.1658, 'longitude': -94.273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50235', 'place_name': 'Rippey', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 41.9257, 'longitude': -94.2132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51462', 'place_name': 'Scranton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Greene', 'locality_code': '73', 'latitude': 42.0124, 'longitude': -94.5518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50609', 'place_name': 'Beaman', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.2367, 'longitude': -92.8162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50621', 'place_name': 'Conrad', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.2342, 'longitude': -92.8865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50624', 'place_name': 'Dike', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.473, 'longitude': -92.6122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50638', 'place_name': 'Grundy Center', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.3672, 'longitude': -92.7773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50642', 'place_name': 'Holland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.4011, 'longitude': -92.7999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50657', 'place_name': 'Morrison', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.3433, 'longitude': -92.6738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50669', 'place_name': 'Reinbeck', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.3131, 'longitude': -92.5948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50673', 'place_name': 'Stout', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.5264, 'longitude': -92.7119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50680', 'place_name': 'Wellsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Grundy', 'locality_code': '75', 'latitude': 42.4494, 'longitude': -92.9398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50026', 'place_name': 'Bagley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.8341, 'longitude': -94.4415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50029', 'place_name': 'Bayard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.8519, 'longitude': -94.5583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50048', 'place_name': 'Casey', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.505, 'longitude': -94.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50115', 'place_name': 'Guthrie Center', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.6837, 'longitude': -94.4864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50128', 'place_name': 'Jamaica', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.8419, 'longitude': -94.3204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50164', 'place_name': 'Menlo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.5348, 'longitude': -94.409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50216', 'place_name': 'Panora', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.6967, 'longitude': -94.3606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50250', 'place_name': 'Stuart', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.5033, 'longitude': -94.3186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50277', 'place_name': 'Yale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Guthrie', 'locality_code': '77', 'latitude': 41.7753, 'longitude': -94.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50034', 'place_name': 'Blairsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.4937, 'longitude': -93.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50075', 'place_name': 'Ellsworth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.3009, 'longitude': -93.549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50130', 'place_name': 'Jewell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.3139, 'longitude': -93.6428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50132', 'place_name': 'Kamrar', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.3945, 'longitude': -93.7279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50231', 'place_name': 'Randall', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.2383, 'longitude': -93.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50246', 'place_name': 'Stanhope', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.2904, 'longitude': -93.7751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50249', 'place_name': 'Stratford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.2847, 'longitude': -93.9029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50271', 'place_name': 'Williams', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.4883, 'longitude': -93.5449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50595', 'place_name': 'Webster City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hamilton', 'locality_code': '79', 'latitude': 42.4657, 'longitude': -93.8262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50423', 'place_name': 'Britt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 43.1006, 'longitude': -93.7752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50430', 'place_name': 'Corwith', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 42.9927, 'longitude': -93.9575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50432', 'place_name': 'Crystal Lake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 43.2233, 'longitude': -93.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50438', 'place_name': 'Garner', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 43.1144, 'longitude': -93.5944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50439', 'place_name': 'Goodell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 42.9383, 'longitude': -93.5824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50447', 'place_name': 'Kanawha', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 42.9434, 'longitude': -93.7728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50449', 'place_name': 'Klemme', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 43.0136, 'longitude': -93.5879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50484', 'place_name': 'Woden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hancock', 'locality_code': '81', 'latitude': 43.2226, 'longitude': -93.9109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50006', 'place_name': 'Alden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.5179, 'longitude': -93.3841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50043', 'place_name': 'Buckeye', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.4179, 'longitude': -93.3755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50102', 'place_name': 'Garden City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.2455, 'longitude': -93.3955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50122', 'place_name': 'Hubbard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.3022, 'longitude': -93.2939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50126', 'place_name': 'Iowa Falls', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.5138, 'longitude': -93.2709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50206', 'place_name': 'New Providence', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.2693, 'longitude': -93.1753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50230', 'place_name': 'Radcliffe', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.3241, 'longitude': -93.4234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50258', 'place_name': 'Union', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.2521, 'longitude': -93.0562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50259', 'place_name': 'Gifford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.3831, 'longitude': -93.2506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50269', 'place_name': 'Whitten', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.2718, 'longitude': -93.0214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50601', 'place_name': 'Ackley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.5527, 'longitude': -93.0608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50627', 'place_name': 'Eldora', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.3572, 'longitude': -93.1037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50672', 'place_name': 'Steamboat Rock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Hardin', 'locality_code': '83', 'latitude': 42.4178, 'longitude': -93.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51529', 'place_name': 'Dunlap', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.8603, 'longitude': -95.6257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51545', 'place_name': 'Little Sioux', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.8083, 'longitude': -96.0314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51546', 'place_name': 'Logan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.643, 'longitude': -95.7889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51550', 'place_name': 'Magnolia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.6921, 'longitude': -95.8742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51555', 'place_name': 'Missouri Valley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.5644, 'longitude': -95.8913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51556', 'place_name': 'Modale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.6371, 'longitude': -95.9852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51557', 'place_name': 'Mondamin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.7089, 'longitude': -96.0072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51563', 'place_name': 'Persia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.5647, 'longitude': -95.5658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51564', 'place_name': 'Pisgah', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.8214, 'longitude': -95.9192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51579', 'place_name': 'Woodbine', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Harrison', 'locality_code': '85', 'latitude': 41.7373, 'longitude': -95.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52630', 'place_name': 'Hillsboro', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 40.8372, 'longitude': -91.7119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52641', 'place_name': 'Mount Pleasant', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 40.9646, 'longitude': -91.5614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52642', 'place_name': 'Rome', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 40.9774, 'longitude': -91.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52644', 'place_name': 'Mount Union', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 41.0374, 'longitude': -91.4138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52645', 'place_name': 'New London', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 40.9161, 'longitude': -91.3986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52647', 'place_name': 'Olds', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 41.1342, 'longitude': -91.5449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52649', 'place_name': 'Salem', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 40.8568, 'longitude': -91.6336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52652', 'place_name': 'Swedesburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 41.1043, 'longitude': -91.547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52654', 'place_name': 'Wayland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 41.1449, 'longitude': -91.6589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52659', 'place_name': 'Winfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Henry', 'locality_code': '87', 'latitude': 41.1257, 'longitude': -91.4379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50466', 'place_name': 'Riceville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Howard', 'locality_code': '89', 'latitude': 43.3719, 'longitude': -92.5554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50628', 'place_name': 'Elma', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Howard', 'locality_code': '89', 'latitude': 43.2786, 'longitude': -92.3981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52134', 'place_name': 'Chester', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Howard', 'locality_code': '89', 'latitude': 43.473, 'longitude': -92.4155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52136', 'place_name': 'Cresco', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Howard', 'locality_code': '89', 'latitude': 43.363, 'longitude': -92.126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52155', 'place_name': 'Lime Springs', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Howard', 'locality_code': '89', 'latitude': 43.4556, 'longitude': -92.2733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52163', 'place_name': 'Protivin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Howard', 'locality_code': '89', 'latitude': 43.217, 'longitude': -92.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50519', 'place_name': 'Bode', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.8661, 'longitude': -94.2781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50520', 'place_name': 'Bradgate', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.7794, 'longitude': -94.4002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50529', 'place_name': 'Dakota City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.7214, 'longitude': -94.1993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50541', 'place_name': 'Gilmore City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.7067, 'longitude': -94.4108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50545', 'place_name': 'Hardy', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.7975, 'longitude': -94.0799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50548', 'place_name': 'Humboldt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.7196, 'longitude': -94.2132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50558', 'place_name': 'Livermore', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.8666, 'longitude': -94.1747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50570', 'place_name': 'Ottosen', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.8764, 'longitude': -94.3786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50577', 'place_name': 'Renwick', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.8491, 'longitude': -94.0074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50582', 'place_name': 'Rutland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.7635, 'longitude': -94.2719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50591', 'place_name': 'Thor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Humboldt', 'locality_code': '91', 'latitude': 42.6889, 'longitude': -94.039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51006', 'place_name': 'Battle Creek', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ida', 'locality_code': '93', 'latitude': 42.3327, 'longitude': -95.6045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51020', 'place_name': 'Galva', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ida', 'locality_code': '93', 'latitude': 42.5105, 'longitude': -95.4298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51025', 'place_name': 'Holstein', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ida', 'locality_code': '93', 'latitude': 42.4948, 'longitude': -95.565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51431', 'place_name': 'Arthur', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ida', 'locality_code': '93', 'latitude': 42.3363, 'longitude': -95.3675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51445', 'place_name': 'Ida Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ida', 'locality_code': '93', 'latitude': 42.34, 'longitude': -95.4645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52203', 'place_name': 'Amana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.8313, 'longitude': -91.8855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52204', 'place_name': 'Amana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.8, 'longitude': -91.8707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52220', 'place_name': 'Conroy', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.7292, 'longitude': -91.9977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52236', 'place_name': 'Homestead', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.7339, 'longitude': -91.8795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52251', 'place_name': 'Ladora', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.7564, 'longitude': -92.1873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52301', 'place_name': 'Marengo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.7863, 'longitude': -92.072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52307', 'place_name': 'Middle Amana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.7954, 'longitude': -91.9018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52308', 'place_name': 'Millersburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.5733, 'longitude': -92.1599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52316', 'place_name': 'North English', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.5241, 'longitude': -92.0893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52325', 'place_name': 'Parnell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.5702, 'longitude': -92.0052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52334', 'place_name': 'South Amana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.7576, 'longitude': -91.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52347', 'place_name': 'Victor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.729, 'longitude': -92.2842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52361', 'place_name': 'Williamsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Iowa', 'locality_code': '95', 'latitude': 41.6393, 'longitude': -92.024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52030', 'place_name': 'Andrew', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.1536, 'longitude': -90.5924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52031', 'place_name': 'Bellevue', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.2582, 'longitude': -90.4356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52054', 'place_name': 'La Motte', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.3044, 'longitude': -90.6177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52060', 'place_name': 'Maquoketa', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.0778, 'longitude': -90.6771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52064', 'place_name': 'Miles', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.1006, 'longitude': -90.3367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52069', 'place_name': 'Preston', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.0539, 'longitude': -90.3954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52070', 'place_name': 'Sabula', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.0737, 'longitude': -90.1955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52071', 'place_name': 'Saint Donatus', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.3196, 'longitude': -90.4903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52074', 'place_name': 'Spragueville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.0727, 'longitude': -90.473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52075', 'place_name': 'Springbrook', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.1674, 'longitude': -90.4846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52207', 'place_name': 'Baldwin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.0732, 'longitude': -90.82, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52309', 'place_name': 'Monmouth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jackson', 'locality_code': '97', 'latitude': 42.0772, 'longitude': -90.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50028', 'place_name': 'Baxter', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.8204, 'longitude': -93.1583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50054', 'place_name': 'Colfax', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.6788, 'longitude': -93.2588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50127', 'place_name': 'Ira', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.7771, 'longitude': -93.2058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50135', 'place_name': 'Kellogg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.7184, 'longitude': -92.9114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50137', 'place_name': 'Killduff', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.608, 'longitude': -92.9046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50153', 'place_name': 'Lynnville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.5698, 'longitude': -92.7877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50168', 'place_name': 'Mingo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.7898, 'longitude': -93.288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50170', 'place_name': 'Monroe', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.5222, 'longitude': -93.1019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50208', 'place_name': 'Newton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.6992, 'longitude': -93.0455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50228', 'place_name': 'Prairie City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.5854, 'longitude': -93.241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50232', 'place_name': 'Reasnor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.5798, 'longitude': -93.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50251', 'place_name': 'Sully', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jasper', 'locality_code': '99', 'latitude': 41.574, 'longitude': -92.8451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52533', 'place_name': 'Batavia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jefferson', 'locality_code': '101', 'latitude': 40.9905, 'longitude': -92.1431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52556', 'place_name': 'Fairfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jefferson', 'locality_code': '101', 'latitude': 41.0039, 'longitude': -91.9576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52557', 'place_name': 'Fairfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jefferson', 'locality_code': '101', 'latitude': 41.0166, 'longitude': -91.9682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52567', 'place_name': 'Libertyville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jefferson', 'locality_code': '101', 'latitude': 40.9499, 'longitude': -92.025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52580', 'place_name': 'Packwood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jefferson', 'locality_code': '101', 'latitude': 41.1228, 'longitude': -92.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52635', 'place_name': 'Lockridge', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jefferson', 'locality_code': '101', 'latitude': 41.0119, 'longitude': -91.7645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52235', 'place_name': 'Hills', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.5557, 'longitude': -91.5308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52240', 'place_name': 'Iowa City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.6355, 'longitude': -91.5016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52241', 'place_name': 'Coralville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.6937, 'longitude': -91.5906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52242', 'place_name': 'Iowa City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.6627, 'longitude': -91.5477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52243', 'place_name': 'Iowa City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.6611, 'longitude': -91.5302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52244', 'place_name': 'Iowa City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.5727, 'longitude': -91.6619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52245', 'place_name': 'Iowa City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.6649, 'longitude': -91.5151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52246', 'place_name': 'Iowa City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.6438, 'longitude': -91.5669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52317', 'place_name': 'North Liberty', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.7443, 'longitude': -91.6061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52322', 'place_name': 'Oxford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.6507, 'longitude': -91.7724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52333', 'place_name': 'Solon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.8099, 'longitude': -91.5086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52338', 'place_name': 'Swisher', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.8268, 'longitude': -91.6739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52340', 'place_name': 'Tiffin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.7018, 'longitude': -91.6773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52755', 'place_name': 'Lone Tree', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Johnson', 'locality_code': '103', 'latitude': 41.4988, 'longitude': -91.4363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52205', 'place_name': 'Anamosa', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.1078, 'longitude': -91.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52212', 'place_name': 'Center Junction', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.1161, 'longitude': -91.0871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52252', 'place_name': 'Langworthy', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.192, 'longitude': -91.2258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52305', 'place_name': 'Martelle', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.0035, 'longitude': -91.3217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52310', 'place_name': 'Monticello', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.2326, 'longitude': -91.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52312', 'place_name': 'Morley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.006, 'longitude': -91.2459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52320', 'place_name': 'Olin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 41.9954, 'longitude': -91.1409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52321', 'place_name': 'Onslow', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.107, 'longitude': -91.0151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52323', 'place_name': 'Oxford Junction', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 41.9854, 'longitude': -90.9543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52362', 'place_name': 'Wyoming', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Jones', 'locality_code': '105', 'latitude': 42.0604, 'longitude': -90.994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50104', 'place_name': 'Gibson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.4868, 'longitude': -92.3867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50136', 'place_name': 'Keswick', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.4613, 'longitude': -92.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50255', 'place_name': 'Thornburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.4547, 'longitude': -92.3357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50268', 'place_name': 'What Cheer', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.3953, 'longitude': -92.3548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52231', 'place_name': 'Harper', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.3728, 'longitude': -92.0388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52248', 'place_name': 'Keota', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.3504, 'longitude': -91.9641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52335', 'place_name': 'South English', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.4529, 'longitude': -92.068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52355', 'place_name': 'Webster', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.4364, 'longitude': -92.1765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52550', 'place_name': 'Delta', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.3167, 'longitude': -92.3359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52562', 'place_name': 'Hayesville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.3363, 'longitude': -92.1784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52563', 'place_name': 'Hedrick', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.1826, 'longitude': -92.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52568', 'place_name': 'Martinsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.1948, 'longitude': -92.2715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52576', 'place_name': 'Ollie', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.2001, 'longitude': -92.1354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52585', 'place_name': 'Richland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.1939, 'longitude': -91.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52591', 'place_name': 'Sigourney', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Keokuk', 'locality_code': '107', 'latitude': 41.3301, 'longitude': -92.2019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50451', 'place_name': 'Lakota', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.3772, 'longitude': -94.0938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50480', 'place_name': 'Titonka', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.2456, 'longitude': -94.0367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50483', 'place_name': 'Wesley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.0977, 'longitude': -94.0038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50511', 'place_name': 'Algona', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.066, 'longitude': -94.2306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50517', 'place_name': 'Bancroft', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.2935, 'longitude': -94.2108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50522', 'place_name': 'Burt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.2062, 'longitude': -94.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50539', 'place_name': 'Fenton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.242, 'longitude': -94.4044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50556', 'place_name': 'Ledyard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.4346, 'longitude': -94.1503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50559', 'place_name': 'Lone Rock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.1666, 'longitude': -94.3586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50560', 'place_name': 'Lu Verne', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 42.9868, 'longitude': -94.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50590', 'place_name': 'Swea City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.4022, 'longitude': -94.3193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50598', 'place_name': 'Whittemore', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Kossuth', 'locality_code': '109', 'latitude': 43.0619, 'longitude': -94.4269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52619', 'place_name': 'Argyle', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.5317, 'longitude': -91.5663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52624', 'place_name': 'Denmark', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.7417, 'longitude': -91.3374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52625', 'place_name': 'Donnellson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.6612, 'longitude': -91.5745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52627', 'place_name': 'Fort Madison', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.633, 'longitude': -91.3398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52631', 'place_name': 'Houghton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.77, 'longitude': -91.6138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52632', 'place_name': 'Keokuk', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.4094, 'longitude': -91.3982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52639', 'place_name': 'Montrose', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.5139, 'longitude': -91.424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52648', 'place_name': 'Pilot Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.7628, 'longitude': -91.5368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52656', 'place_name': 'West Point', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.715, 'longitude': -91.4397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52657', 'place_name': 'Saint Paul', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.7695, 'longitude': -91.5171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52658', 'place_name': 'Wever', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lee', 'locality_code': '111', 'latitude': 40.7067, 'longitude': -91.2268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52202', 'place_name': 'Alburnett', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.1583, 'longitude': -91.6392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52213', 'place_name': 'Center Point', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.1898, 'longitude': -91.7758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52214', 'place_name': 'Central City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.1982, 'longitude': -91.4914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52218', 'place_name': 'Coggon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.2792, 'longitude': -91.5413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52219', 'place_name': 'Prairieburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.2383, 'longitude': -91.4224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52227', 'place_name': 'Ely', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.8943, 'longitude': -91.5738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52228', 'place_name': 'Fairfax', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.9153, 'longitude': -91.7801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52233', 'place_name': 'Hiawatha', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0425, 'longitude': -91.677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52253', 'place_name': 'Lisbon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.9212, 'longitude': -91.3861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52302', 'place_name': 'Marion', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0411, 'longitude': -91.5941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52314', 'place_name': 'Mount Vernon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.9287, 'longitude': -91.4274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52324', 'place_name': 'Palo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0365, 'longitude': -91.7877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52328', 'place_name': 'Robins', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0731, 'longitude': -91.6648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52336', 'place_name': 'Springville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0607, 'longitude': -91.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52341', 'place_name': 'Toddville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.1039, 'longitude': -91.729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52344', 'place_name': 'Troy Mills', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.29, 'longitude': -91.6824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52352', 'place_name': 'Walker', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.2867, 'longitude': -91.7807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52401', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.9743, 'longitude': -91.6554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52402', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0188, 'longitude': -91.6612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52403', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.9843, 'longitude': -91.6259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52404', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.9521, 'longitude': -91.6853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52405', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 41.9804, 'longitude': -91.7098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52406', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0083, 'longitude': -91.6441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52407', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0794, 'longitude': -91.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52408', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0794, 'longitude': -91.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52409', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0794, 'longitude': -91.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52410', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0794, 'longitude': -91.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52411', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0493, 'longitude': -91.7263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52497', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0794, 'longitude': -91.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52498', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0794, 'longitude': -91.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52499', 'place_name': 'Cedar Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Linn', 'locality_code': '113', 'latitude': 42.0794, 'longitude': -91.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52640', 'place_name': 'Morning Sun', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Louisa', 'locality_code': '115', 'latitude': 41.0984, 'longitude': -91.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52646', 'place_name': 'Oakville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Louisa', 'locality_code': '115', 'latitude': 41.1003, 'longitude': -91.0439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52653', 'place_name': 'Wapello', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Louisa', 'locality_code': '115', 'latitude': 41.207, 'longitude': -91.1719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52737', 'place_name': 'Columbus City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Louisa', 'locality_code': '115', 'latitude': 41.2593, 'longitude': -91.3747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52738', 'place_name': 'Columbus Junction', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Louisa', 'locality_code': '115', 'latitude': 41.2926, 'longitude': -91.3006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52752', 'place_name': 'Grandview', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Louisa', 'locality_code': '115', 'latitude': 41.2759, 'longitude': -91.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52754', 'place_name': 'Letts', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Louisa', 'locality_code': '115', 'latitude': 41.293, 'longitude': -91.204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50049', 'place_name': 'Chariton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lucas', 'locality_code': '117', 'latitude': 41.0226, 'longitude': -93.3042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50068', 'place_name': 'Derby', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lucas', 'locality_code': '117', 'latitude': 40.9355, 'longitude': -93.4796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50151', 'place_name': 'Lucas', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lucas', 'locality_code': '117', 'latitude': 41.0585, 'longitude': -93.4836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50238', 'place_name': 'Russell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lucas', 'locality_code': '117', 'latitude': 40.9456, 'longitude': -93.1784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50272', 'place_name': 'Williamson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lucas', 'locality_code': '117', 'latitude': 41.0959, 'longitude': -93.2559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51230', 'place_name': 'Alvord', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.3201, 'longitude': -96.291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51235', 'place_name': 'Doon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.2872, 'longitude': -96.202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51237', 'place_name': 'George', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.3439, 'longitude': -95.9894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51240', 'place_name': 'Inwood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.3047, 'longitude': -96.4363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51241', 'place_name': 'Larchwood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.4387, 'longitude': -96.4252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51242', 'place_name': 'Lester', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.4443, 'longitude': -96.3361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51243', 'place_name': 'Little Rock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.4496, 'longitude': -95.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51246', 'place_name': 'Rock Rapids', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Lyon', 'locality_code': '119', 'latitude': 43.4272, 'longitude': -96.1781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50033', 'place_name': 'Bevington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.363, 'longitude': -93.7928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50072', 'place_name': 'Earlham', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.4709, 'longitude': -94.1294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50155', 'place_name': 'Macksburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.2104, 'longitude': -94.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50218', 'place_name': 'Patterson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.3499, 'longitude': -93.8803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50222', 'place_name': 'Peru', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.2145, 'longitude': -93.9437, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '50240', 'place_name': 'Saint Charles', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.2924, 'longitude': -93.8242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50257', 'place_name': 'Truro', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.2076, 'longitude': -93.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50273', 'place_name': 'Winterset', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Madison', 'locality_code': '121', 'latitude': 41.3391, 'longitude': -94.0088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50027', 'place_name': 'Barnes City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.4883, 'longitude': -92.4703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50143', 'place_name': 'Leighton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.3647, 'longitude': -92.8081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50207', 'place_name': 'New Sharon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.464, 'longitude': -92.6848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52534', 'place_name': 'Beacon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.272, 'longitude': -92.6819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52543', 'place_name': 'Cedar', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.2121, 'longitude': -92.509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52561', 'place_name': 'Fremont', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.2117, 'longitude': -92.4362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52577', 'place_name': 'Oskaloosa', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.2942, 'longitude': -92.6439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52586', 'place_name': 'Rose Hill', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.3309, 'longitude': -92.472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52595', 'place_name': 'University Park', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mahaska', 'locality_code': '123', 'latitude': 41.2864, 'longitude': -92.6184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50044', 'place_name': 'Bussey', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.2094, 'longitude': -92.8963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50057', 'place_name': 'Columbia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.1838, 'longitude': -93.1582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50062', 'place_name': 'Melcher Dallas', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.225, 'longitude': -93.2413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50116', 'place_name': 'Hamilton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.19, 'longitude': -92.959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50119', 'place_name': 'Harvey', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.303, 'longitude': -92.9318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50138', 'place_name': 'Knoxville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.3164, 'longitude': -93.0954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50163', 'place_name': 'Melcher Dallas', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.225, 'longitude': -93.2413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50214', 'place_name': 'Otley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.4518, 'longitude': -93.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50219', 'place_name': 'Pella', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.4082, 'longitude': -92.9172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50225', 'place_name': 'Pleasantville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.3738, 'longitude': -93.2712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50252', 'place_name': 'Swan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.4636, 'longitude': -93.301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50256', 'place_name': 'Tracy', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marion', 'locality_code': '125', 'latitude': 41.2756, 'longitude': -92.8753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50005', 'place_name': 'Albion', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 42.1143, 'longitude': -92.9882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50051', 'place_name': 'Clemons', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 42.09, 'longitude': -93.1688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50078', 'place_name': 'Ferguson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 41.9374, 'longitude': -92.865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50106', 'place_name': 'Gilman', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 41.9012, 'longitude': -92.8101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50120', 'place_name': 'Haverhill', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 41.9337, 'longitude': -92.9829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50141', 'place_name': 'Laurel', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 41.8829, 'longitude': -92.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50142', 'place_name': 'Le Grand', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 42.0066, 'longitude': -92.7756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50148', 'place_name': 'Liscomb', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 42.184, 'longitude': -92.9833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50158', 'place_name': 'Marshalltown', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 42.0405, 'longitude': -92.9127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50162', 'place_name': 'Melbourne', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 41.9323, 'longitude': -93.0856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50234', 'place_name': 'Rhodes', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 41.9177, 'longitude': -93.1796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50239', 'place_name': 'Saint Anthony', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 42.152, 'longitude': -93.1824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50247', 'place_name': 'State Center', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Marshall', 'locality_code': '127', 'latitude': 42.0109, 'longitude': -93.1673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51533', 'place_name': 'Emerson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.0284, 'longitude': -95.4106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51534', 'place_name': 'Glenwood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.047, 'longitude': -95.7389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51540', 'place_name': 'Hastings', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.0132, 'longitude': -95.5008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51541', 'place_name': 'Henderson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.1254, 'longitude': -95.4586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51551', 'place_name': 'Malvern', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.0074, 'longitude': -95.584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51554', 'place_name': 'Mineola', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.1414, 'longitude': -95.7005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51561', 'place_name': 'Pacific Junction', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.0271, 'longitude': -95.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51571', 'place_name': 'Silver City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mills', 'locality_code': '129', 'latitude': 41.113, 'longitude': -95.6269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50426', 'place_name': 'Carpenter', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.415, 'longitude': -93.0149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50454', 'place_name': 'Little Cedar', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.3919, 'longitude': -92.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50455', 'place_name': 'Mc Intire', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.45, 'longitude': -92.6048, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '50460', 'place_name': 'Orchard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.2355, 'longitude': -92.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50461', 'place_name': 'Osage', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.2872, 'longitude': -92.8144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50472', 'place_name': 'Saint Ansgar', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.4061, 'longitude': -92.9235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50476', 'place_name': 'Stacyville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.4457, 'longitude': -92.761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50481', 'place_name': 'Toeterville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Mitchell', 'locality_code': '131', 'latitude': 43.3564, 'longitude': -92.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51010', 'place_name': 'Castana', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 42.0744, 'longitude': -95.9086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51034', 'place_name': 'Mapleton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 42.1585, 'longitude': -95.7909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51040', 'place_name': 'Onawa', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 42.037, 'longitude': -96.1072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51051', 'place_name': 'Rodney', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 42.198, 'longitude': -95.9769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51060', 'place_name': 'Ute', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 42.0581, 'longitude': -95.7125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51063', 'place_name': 'Whiting', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 42.1522, 'longitude': -96.1822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51523', 'place_name': 'Blencoe', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 41.9237, 'longitude': -96.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51558', 'place_name': 'Moorhead', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 41.9186, 'longitude': -95.829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51572', 'place_name': 'Soldier', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monona', 'locality_code': '133', 'latitude': 41.9942, 'longitude': -95.7825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50150', 'place_name': 'Lovilia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monroe', 'locality_code': '135', 'latitude': 41.1272, 'longitude': -92.9293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52531', 'place_name': 'Albia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monroe', 'locality_code': '135', 'latitude': 41.0287, 'longitude': -92.7946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52569', 'place_name': 'Melrose', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Monroe', 'locality_code': '135', 'latitude': 40.9665, 'longitude': -93.0145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50847', 'place_name': 'Grant', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Montgomery', 'locality_code': '137', 'latitude': 41.1427, 'longitude': -94.9842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50864', 'place_name': 'Villisca', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Montgomery', 'locality_code': '137', 'latitude': 40.9437, 'longitude': -94.9796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51532', 'place_name': 'Elliott', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Montgomery', 'locality_code': '137', 'latitude': 41.1306, 'longitude': -95.1602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51566', 'place_name': 'Red Oak', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Montgomery', 'locality_code': '137', 'latitude': 41.0079, 'longitude': -95.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51573', 'place_name': 'Stanton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Montgomery', 'locality_code': '137', 'latitude': 40.9859, 'longitude': -95.0988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51591', 'place_name': 'Red Oak', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Montgomery', 'locality_code': '137', 'latitude': 41.0303, 'longitude': -95.1562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52720', 'place_name': 'Atalissa', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.5614, 'longitude': -91.1748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52739', 'place_name': 'Conesville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.3805, 'longitude': -91.3465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52749', 'place_name': 'Fruitland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.3486, 'longitude': -91.1237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52759', 'place_name': 'Montpelier', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.4625, 'longitude': -90.8088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52760', 'place_name': 'Moscow', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.5646, 'longitude': -91.0859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52761', 'place_name': 'Muscatine', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.4304, 'longitude': -91.0509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52766', 'place_name': 'Nichols', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.4766, 'longitude': -91.2931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52769', 'place_name': 'Stockton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.5914, 'longitude': -90.8588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52776', 'place_name': 'West Liberty', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.5701, 'longitude': -91.2668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52778', 'place_name': 'Wilton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Muscatine', 'locality_code': '139', 'latitude': 41.5858, 'longitude': -91.01, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51009', 'place_name': 'Calumet', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 42.9444, 'longitude': -95.5515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51046', 'place_name': 'Paullina', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 42.9703, 'longitude': -95.7083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51058', 'place_name': 'Sutherland', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 42.9826, 'longitude': -95.4807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51201', 'place_name': 'Sheldon', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 43.1808, 'longitude': -95.8401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51231', 'place_name': 'Archer', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 43.1179, 'longitude': -95.7417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51245', 'place_name': 'Primghar', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 43.0759, 'longitude': -95.6533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51248', 'place_name': 'Sanborn', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 43.189, 'longitude': -95.6622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51346', 'place_name': 'Hartley', 'state': 'Iowa', 'state_ab': 'IA', 'county': "O'Brien", 'locality_code': '141', 'latitude': 43.18, 'longitude': -95.4817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51232', 'place_name': 'Ashton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Osceola', 'locality_code': '143', 'latitude': 43.3053, 'longitude': -95.7655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51249', 'place_name': 'Sibley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Osceola', 'locality_code': '143', 'latitude': 43.4069, 'longitude': -95.7424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51345', 'place_name': 'Harris', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Osceola', 'locality_code': '143', 'latitude': 43.4568, 'longitude': -95.4426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51350', 'place_name': 'Melvin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Osceola', 'locality_code': '143', 'latitude': 43.2845, 'longitude': -95.593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51354', 'place_name': 'Ocheyedan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Osceola', 'locality_code': '143', 'latitude': 43.391, 'longitude': -95.5204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51601', 'place_name': 'Shenandoah', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.7581, 'longitude': -95.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51603', 'place_name': 'Shenandoah', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.7656, 'longitude': -95.3722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51630', 'place_name': 'Blanchard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.6122, 'longitude': -95.2054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51631', 'place_name': 'Braddyville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.5991, 'longitude': -94.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51632', 'place_name': 'Clarinda', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.7491, 'longitude': -95.038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51636', 'place_name': 'Coin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.6686, 'longitude': -95.2217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51637', 'place_name': 'College Springs', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.6249, 'longitude': -95.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51638', 'place_name': 'Essex', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.8404, 'longitude': -95.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51647', 'place_name': 'Northboro', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.6127, 'longitude': -95.3096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51651', 'place_name': 'Shambaugh', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.6575, 'longitude': -95.025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51656', 'place_name': 'Yorktown', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Page', 'locality_code': '145', 'latitude': 40.7374, 'longitude': -95.1562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50515', 'place_name': 'Ayrshire', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 43.037, 'longitude': -94.8478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50527', 'place_name': 'Curlew', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 42.9633, 'longitude': -94.7975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50528', 'place_name': 'Cylinder', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 43.1507, 'longitude': -94.5107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50536', 'place_name': 'Emmetsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 43.1082, 'longitude': -94.6825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50562', 'place_name': 'Mallard', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 42.9417, 'longitude': -94.6746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50597', 'place_name': 'West Bend', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 42.9574, 'longitude': -94.4564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51342', 'place_name': 'Graettinger', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 43.2277, 'longitude': -94.7334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51358', 'place_name': 'Ruthven', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Palo Alto', 'locality_code': '147', 'latitude': 43.1448, 'longitude': -94.8842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51001', 'place_name': 'Akron', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.8354, 'longitude': -96.5225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51008', 'place_name': 'Brunsville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.8093, 'longitude': -96.2626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51024', 'place_name': 'Hinton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.604, 'longitude': -96.305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51028', 'place_name': 'Kingsley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.6191, 'longitude': -95.9762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51031', 'place_name': 'Le Mars', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.7962, 'longitude': -96.1704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51038', 'place_name': 'Merrill', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.7047, 'longitude': -96.2283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51045', 'place_name': 'Oyens', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.8199, 'longitude': -96.0566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51050', 'place_name': 'Remsen', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.8149, 'longitude': -95.9544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51062', 'place_name': 'Westfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Plymouth', 'locality_code': '149', 'latitude': 42.6953, 'longitude': -96.492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50540', 'place_name': 'Fonda', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.6051, 'longitude': -94.8297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50546', 'place_name': 'Havelock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.8411, 'longitude': -94.7252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50554', 'place_name': 'Laurens', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.8409, 'longitude': -94.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50571', 'place_name': 'Palmer', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.6419, 'longitude': -94.5432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50573', 'place_name': 'Plover', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.8783, 'longitude': -94.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50574', 'place_name': 'Pocahontas', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.7296, 'longitude': -94.6737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50581', 'place_name': 'Rolfe', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.8082, 'longitude': -94.5166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50593', 'place_name': 'Varina', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pocahontas', 'locality_code': '151', 'latitude': 42.6598, 'longitude': -94.8979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50007', 'place_name': 'Alleman', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.8159, 'longitude': -93.6063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50009', 'place_name': 'Altoona', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6475, 'longitude': -93.4724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50021', 'place_name': 'Ankeny', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.7212, 'longitude': -93.5682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50023', 'place_name': 'Ankeny', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.7194, 'longitude': -93.6266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50032', 'place_name': 'Berwick', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6658, 'longitude': -93.5432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50035', 'place_name': 'Bondurant', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.7017, 'longitude': -93.4527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50073', 'place_name': 'Elkhart', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.7917, 'longitude': -93.5222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50111', 'place_name': 'Grimes', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.7018, 'longitude': -93.7821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50131', 'place_name': 'Johnston', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.673, 'longitude': -93.7028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50169', 'place_name': 'Mitchellville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6609, 'longitude': -93.37, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50226', 'place_name': 'Polk City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.7549, 'longitude': -93.6893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50237', 'place_name': 'Runnells', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5515, 'longitude': -93.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50243', 'place_name': 'Sheldahl', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.8571, 'longitude': -93.6973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50265', 'place_name': 'West Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5805, 'longitude': -93.7447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50266', 'place_name': 'West Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5695, 'longitude': -93.7994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50301', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50302', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50303', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50304', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50305', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50306', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50307', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6005, 'longitude': -93.6091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50308', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50309', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5887, 'longitude': -93.6212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50310', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6255, 'longitude': -93.6736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50311', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.601, 'longitude': -93.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50312', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5855, 'longitude': -93.6719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50313', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6381, 'longitude': -93.6203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50314', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.603, 'longitude': -93.633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50315', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5444, 'longitude': -93.6192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50316', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6092, 'longitude': -93.6, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50317', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6122, 'longitude': -93.5296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50318', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50319', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5921, 'longitude': -93.604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50320', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5487, 'longitude': -93.5827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50321', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5476, 'longitude': -93.6618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50322', 'place_name': 'Urbandale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6295, 'longitude': -93.723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50323', 'place_name': 'Urbandale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6294, 'longitude': -93.7717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50324', 'place_name': 'Windsor Heights', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6032, 'longitude': -93.7152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50325', 'place_name': 'Clive', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6067, 'longitude': -93.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50327', 'place_name': 'Pleasant Hill', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5839, 'longitude': -93.5199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50328', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50329', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50330', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50331', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50332', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50333', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50334', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50335', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50336', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50339', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50340', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50359', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50360', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50361', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50362', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50363', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50364', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50367', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50368', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50369', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50380', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50381', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50391', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50392', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.5878, 'longitude': -93.6274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50393', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50394', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50395', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50396', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50398', 'place_name': 'Urbandale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6267, 'longitude': -93.7122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50936', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50940', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50947', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50950', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50980', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50981', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6727, 'longitude': -93.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50982', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6006, 'longitude': -93.6089, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '50983', 'place_name': 'Des Moines', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Polk', 'locality_code': '153', 'latitude': 41.6006, 'longitude': -93.6089, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '51501', 'place_name': 'Council Bluffs', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.2324, 'longitude': -95.8751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51502', 'place_name': 'Council Bluffs', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.2619, 'longitude': -95.8608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51503', 'place_name': 'Council Bluffs', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.2616, 'longitude': -95.8251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51510', 'place_name': 'Carter Lake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.2925, 'longitude': -95.9141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51521', 'place_name': 'Avoca', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.4768, 'longitude': -95.3509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51525', 'place_name': 'Carson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.2367, 'longitude': -95.4181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51526', 'place_name': 'Crescent', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.3644, 'longitude': -95.8276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51536', 'place_name': 'Hancock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.3832, 'longitude': -95.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51542', 'place_name': 'Honey Creek', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.463, 'longitude': -95.8802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51548', 'place_name': 'Mc Clelland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.2932, 'longitude': -95.6813, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '51549', 'place_name': 'Macedonia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.1916, 'longitude': -95.4314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51553', 'place_name': 'Minden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.4654, 'longitude': -95.5519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51559', 'place_name': 'Neola', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.4564, 'longitude': -95.6794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51560', 'place_name': 'Oakland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.312, 'longitude': -95.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51570', 'place_name': 'Shelby', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.5339, 'longitude': -95.4469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51575', 'place_name': 'Treynor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.2307, 'longitude': -95.6086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51576', 'place_name': 'Underwood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.3603, 'longitude': -95.627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51577', 'place_name': 'Walnut', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.4623, 'longitude': -95.218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51593', 'place_name': 'Harlan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Pottawattamie', 'locality_code': '155', 'latitude': 41.498, 'longitude': -95.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50112', 'place_name': 'Grinnell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.7421, 'longitude': -92.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50157', 'place_name': 'Malcom', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.7695, 'longitude': -92.5354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50171', 'place_name': 'Montezuma', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.5928, 'longitude': -92.5276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50242', 'place_name': 'Searsboro', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.5656, 'longitude': -92.6987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52211', 'place_name': 'Brooklyn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.7321, 'longitude': -92.4285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52221', 'place_name': 'Guernsey', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.6378, 'longitude': -92.3479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52222', 'place_name': 'Deep River', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.5717, 'longitude': -92.3645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52232', 'place_name': 'Hartwick', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Poweshiek', 'locality_code': '157', 'latitude': 41.808, 'longitude': -92.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50074', 'place_name': 'Ellston', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ringgold', 'locality_code': '159', 'latitude': 40.8505, 'longitude': -94.0841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50133', 'place_name': 'Kellerton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ringgold', 'locality_code': '159', 'latitude': 40.6861, 'longitude': -94.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50835', 'place_name': 'Benton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ringgold', 'locality_code': '159', 'latitude': 40.7082, 'longitude': -94.3689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50845', 'place_name': 'Diagonal', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ringgold', 'locality_code': '159', 'latitude': 40.8226, 'longitude': -94.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50854', 'place_name': 'Mount Ayr', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ringgold', 'locality_code': '159', 'latitude': 40.7142, 'longitude': -94.2321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50860', 'place_name': 'Redding', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ringgold', 'locality_code': '159', 'latitude': 40.6053, 'longitude': -94.3595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50863', 'place_name': 'Tingley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Ringgold', 'locality_code': '159', 'latitude': 40.8516, 'longitude': -94.1908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50535', 'place_name': 'Early', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.4483, 'longitude': -95.1726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50567', 'place_name': 'Nemaha', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.518, 'longitude': -95.0939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50583', 'place_name': 'Sac City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.4262, 'longitude': -94.9796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51053', 'place_name': 'Schaller', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.5055, 'longitude': -95.2846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51433', 'place_name': 'Auburn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.2763, 'longitude': -94.8711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51450', 'place_name': 'Lake View', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.3154, 'longitude': -95.0486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51458', 'place_name': 'Odebolt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.3095, 'longitude': -95.2501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51466', 'place_name': 'Wall Lake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sac', 'locality_code': '161', 'latitude': 42.2653, 'longitude': -95.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52722', 'place_name': 'Bettendorf', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5509, 'longitude': -90.4942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52726', 'place_name': 'Blue Grass', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5112, 'longitude': -90.738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52728', 'place_name': 'Buffalo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.4564, 'longitude': -90.7235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52745', 'place_name': 'Dixon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.7113, 'longitude': -90.7553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52746', 'place_name': 'Donahue', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.7093, 'longitude': -90.6829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52748', 'place_name': 'Eldridge', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.6635, 'longitude': -90.5634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52753', 'place_name': 'Le Claire', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.6082, 'longitude': -90.3628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52756', 'place_name': 'Long Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.7213, 'longitude': -90.5534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52758', 'place_name': 'Mc Causland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.743, 'longitude': -90.4539, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '52765', 'place_name': 'New Liberty', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.7132, 'longitude': -90.8599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52767', 'place_name': 'Pleasant Valley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5746, 'longitude': -90.4213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52768', 'place_name': 'Princeton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.6858, 'longitude': -90.3706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52773', 'place_name': 'Walcott', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.6453, 'longitude': -90.7256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52801', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5208, 'longitude': -90.5745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52802', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5164, 'longitude': -90.6141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52803', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5385, 'longitude': -90.5613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52804', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5386, 'longitude': -90.6115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52805', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.613, 'longitude': -90.6063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52806', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5733, 'longitude': -90.6038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52807', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.5618, 'longitude': -90.5403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52808', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.613, 'longitude': -90.6063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52809', 'place_name': 'Davenport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Scott', 'locality_code': '163', 'latitude': 41.613, 'longitude': -90.6063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51446', 'place_name': 'Irwin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.7751, 'longitude': -95.1919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51447', 'place_name': 'Kirkman', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.7308, 'longitude': -95.2671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51527', 'place_name': 'Defiance', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.8053, 'longitude': -95.3537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51530', 'place_name': 'Earling', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.7925, 'longitude': -95.421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51531', 'place_name': 'Elk Horn', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.5829, 'longitude': -95.07, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51537', 'place_name': 'Harlan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.6437, 'longitude': -95.3111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51562', 'place_name': 'Panama', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.7288, 'longitude': -95.487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51565', 'place_name': 'Portsmouth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.6484, 'longitude': -95.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51578', 'place_name': 'Westphalia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Shelby', 'locality_code': '165', 'latitude': 41.7199, 'longitude': -95.3952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51003', 'place_name': 'Alton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 42.9782, 'longitude': -96.0173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51011', 'place_name': 'Chatsworth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 42.9163, 'longitude': -96.5145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51022', 'place_name': 'Granville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 42.9693, 'longitude': -95.8972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51023', 'place_name': 'Hawarden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.0013, 'longitude': -96.473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51027', 'place_name': 'Ireton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 42.9666, 'longitude': -96.3232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51036', 'place_name': 'Maurice', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 42.9626, 'longitude': -96.1655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51041', 'place_name': 'Orange City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.0185, 'longitude': -96.0565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51234', 'place_name': 'Boyden', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.2034, 'longitude': -95.9823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51238', 'place_name': 'Hospers', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.0793, 'longitude': -95.9142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51239', 'place_name': 'Hull', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.1952, 'longitude': -96.1392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51244', 'place_name': 'Matlock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.2439, 'longitude': -95.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51247', 'place_name': 'Rock Valley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.2014, 'longitude': -96.3103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51250', 'place_name': 'Sioux Center', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Sioux', 'locality_code': '167', 'latitude': 43.0814, 'longitude': -96.18, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50010', 'place_name': 'Ames', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.0379, 'longitude': -93.6003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50011', 'place_name': 'Ames', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.036, 'longitude': -93.4652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50012', 'place_name': 'Ames', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.0236, 'longitude': -93.6485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50013', 'place_name': 'Ames', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.0235, 'longitude': -93.6408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50014', 'place_name': 'Ames', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.0486, 'longitude': -93.6945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50046', 'place_name': 'Cambridge', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 41.9025, 'longitude': -93.5305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50055', 'place_name': 'Collins', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 41.9032, 'longitude': -93.3008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50056', 'place_name': 'Colo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.0131, 'longitude': -93.3071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50105', 'place_name': 'Gilbert', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.1148, 'longitude': -93.6399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50124', 'place_name': 'Huxley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 41.8994, 'longitude': -93.6024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50134', 'place_name': 'Kelley', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 41.9488, 'longitude': -93.6644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50154', 'place_name': 'Mc Callsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.1665, 'longitude': -93.3978, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '50161', 'place_name': 'Maxwell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 41.8967, 'longitude': -93.4001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50201', 'place_name': 'Nevada', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.019, 'longitude': -93.4462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50236', 'place_name': 'Roland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.1646, 'longitude': -93.5063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50244', 'place_name': 'Slater', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 41.8765, 'longitude': -93.6812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50248', 'place_name': 'Story City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.1835, 'longitude': -93.5988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50278', 'place_name': 'Zearing', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Story', 'locality_code': '169', 'latitude': 42.1535, 'longitude': -93.2928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50173', 'place_name': 'Montour', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 41.9709, 'longitude': -92.7006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50612', 'place_name': 'Buckingham', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.2552, 'longitude': -92.4098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50632', 'place_name': 'Garwin', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.0872, 'longitude': -92.6894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50635', 'place_name': 'Gladbrook', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.1774, 'longitude': -92.7141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50652', 'place_name': 'Lincoln', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.2643, 'longitude': -92.693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50675', 'place_name': 'Traer', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.1847, 'longitude': -92.4827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52215', 'place_name': 'Chelsea', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 41.9131, 'longitude': -92.4078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52217', 'place_name': 'Clutier', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.0789, 'longitude': -92.3763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52224', 'place_name': 'Dysart', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.169, 'longitude': -92.3187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52225', 'place_name': 'Elberon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.0088, 'longitude': -92.3314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52339', 'place_name': 'Tama', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 41.9616, 'longitude': -92.58, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52342', 'place_name': 'Toledo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 42.0077, 'longitude': -92.5662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52348', 'place_name': 'Vining', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Tama', 'locality_code': '171', 'latitude': 41.99, 'longitude': -92.3799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50833', 'place_name': 'Bedford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Taylor', 'locality_code': '173', 'latitude': 40.6683, 'longitude': -94.7324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50836', 'place_name': 'Blockton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Taylor', 'locality_code': '173', 'latitude': 40.6242, 'longitude': -94.5049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50840', 'place_name': 'Clearfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Taylor', 'locality_code': '173', 'latitude': 40.7935, 'longitude': -94.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50848', 'place_name': 'Gravity', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Taylor', 'locality_code': '173', 'latitude': 40.7909, 'longitude': -94.7506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50851', 'place_name': 'Lenox', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Taylor', 'locality_code': '173', 'latitude': 40.8841, 'longitude': -94.5612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50862', 'place_name': 'Sharpsburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Taylor', 'locality_code': '173', 'latitude': 40.795, 'longitude': -94.6416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51646', 'place_name': 'New Market', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Taylor', 'locality_code': '173', 'latitude': 40.7422, 'longitude': -94.8917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50149', 'place_name': 'Lorimor', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Union', 'locality_code': '175', 'latitude': 41.1233, 'longitude': -94.0639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50254', 'place_name': 'Thayer', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Union', 'locality_code': '175', 'latitude': 41.0029, 'longitude': -94.0686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50801', 'place_name': 'Creston', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Union', 'locality_code': '175', 'latitude': 41.0499, 'longitude': -94.3471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50830', 'place_name': 'Afton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Union', 'locality_code': '175', 'latitude': 41.0401, 'longitude': -94.194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50831', 'place_name': 'Arispe', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Union', 'locality_code': '175', 'latitude': 40.9314, 'longitude': -94.2193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50842', 'place_name': 'Cromwell', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Union', 'locality_code': '175', 'latitude': 41.0398, 'longitude': -94.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50861', 'place_name': 'Shannon City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Union', 'locality_code': '175', 'latitude': 40.9017, 'longitude': -94.2633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52535', 'place_name': 'Birmingham', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.8626, 'longitude': -91.9534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52542', 'place_name': 'Cantril', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.6546, 'longitude': -92.0465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52551', 'place_name': 'Douds', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.8378, 'longitude': -92.0859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52565', 'place_name': 'Keosauqua', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.7424, 'longitude': -91.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52570', 'place_name': 'Milton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.6721, 'longitude': -92.1438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52573', 'place_name': 'Mount Sterling', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.6458, 'longitude': -91.9027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52588', 'place_name': 'Selma', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.864, 'longitude': -92.1736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52620', 'place_name': 'Bonaparte', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.7148, 'longitude': -91.7897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52626', 'place_name': 'Farmington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.6397, 'longitude': -91.7447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52651', 'place_name': 'Stockport', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Van Buren', 'locality_code': '177', 'latitude': 40.8584, 'longitude': -91.8141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52501', 'place_name': 'Ottumwa', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wapello', 'locality_code': '179', 'latitude': 41.0309, 'longitude': -92.4098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52530', 'place_name': 'Agency', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wapello', 'locality_code': '179', 'latitude': 40.9957, 'longitude': -92.3162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52536', 'place_name': 'Blakesburg', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wapello', 'locality_code': '179', 'latitude': 40.9555, 'longitude': -92.6195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52548', 'place_name': 'Chillicothe', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wapello', 'locality_code': '179', 'latitude': 41.086, 'longitude': -92.5303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52553', 'place_name': 'Eddyville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wapello', 'locality_code': '179', 'latitude': 41.1533, 'longitude': -92.6221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52554', 'place_name': 'Eldon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wapello', 'locality_code': '179', 'latitude': 40.9261, 'longitude': -92.2268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52566', 'place_name': 'Kirkville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wapello', 'locality_code': '179', 'latitude': 41.1438, 'longitude': -92.5006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50001', 'place_name': 'Ackworth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.3737, 'longitude': -93.3767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50047', 'place_name': 'Carlisle', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.4814, 'longitude': -93.4921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50061', 'place_name': 'Cumming', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.4849, 'longitude': -93.7539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50118', 'place_name': 'Hartford', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.4596, 'longitude': -93.4022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50125', 'place_name': 'Indianola', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.3143, 'longitude': -93.588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50139', 'place_name': 'Lacona', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.1988, 'longitude': -93.3838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50145', 'place_name': 'Liberty Center', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.2071, 'longitude': -93.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50160', 'place_name': 'Martensdale', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.373, 'longitude': -93.7358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50166', 'place_name': 'Milo', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.2904, 'longitude': -93.4454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50210', 'place_name': 'New Virginia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.1883, 'longitude': -93.6976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50211', 'place_name': 'Norwalk', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.4861, 'longitude': -93.6573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50229', 'place_name': 'Prole', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.383, 'longitude': -93.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50241', 'place_name': 'Saint Marys', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Warren', 'locality_code': '181', 'latitude': 41.3084, 'longitude': -93.7369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52201', 'place_name': 'Ainsworth', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.3202, 'longitude': -91.5472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52247', 'place_name': 'Kalona', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.4823, 'longitude': -91.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52327', 'place_name': 'Riverside', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.4758, 'longitude': -91.5741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52353', 'place_name': 'Washington', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.3015, 'longitude': -91.6987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52356', 'place_name': 'Wellman', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.47, 'longitude': -91.84, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52359', 'place_name': 'West Chester', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.3585, 'longitude': -91.8075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52540', 'place_name': 'Brighton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.1543, 'longitude': -91.8284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52621', 'place_name': 'Crawfordsville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Washington', 'locality_code': '183', 'latitude': 41.2093, 'longitude': -91.5414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50008', 'place_name': 'Allerton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.7023, 'longitude': -93.3724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50052', 'place_name': 'Clio', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.6342, 'longitude': -93.448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50060', 'place_name': 'Corydon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.7771, 'longitude': -93.3274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50123', 'place_name': 'Humeston', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.8469, 'longitude': -93.5101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50147', 'place_name': 'Lineville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.6004, 'longitude': -93.4862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50165', 'place_name': 'Millerton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.8494, 'longitude': -93.3055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52583', 'place_name': 'Promise City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.7585, 'longitude': -93.1527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52590', 'place_name': 'Seymour', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wayne', 'locality_code': '185', 'latitude': 40.6724, 'longitude': -93.1368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50501', 'place_name': 'Fort Dodge', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.5088, 'longitude': -94.1807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50516', 'place_name': 'Badger', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.6144, 'longitude': -94.1461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50518', 'place_name': 'Barnum', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.5159, 'longitude': -94.3703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50521', 'place_name': 'Burnside', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.3413, 'longitude': -94.1143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50523', 'place_name': 'Callender', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.3494, 'longitude': -94.282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50524', 'place_name': 'Clare', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.5954, 'longitude': -94.308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50530', 'place_name': 'Dayton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.2594, 'longitude': -94.061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50532', 'place_name': 'Duncombe', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.4493, 'longitude': -94.0592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50543', 'place_name': 'Gowrie', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.2767, 'longitude': -94.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50544', 'place_name': 'Harcourt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.2531, 'longitude': -94.1961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50557', 'place_name': 'Lehigh', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.3526, 'longitude': -94.0342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50566', 'place_name': 'Moorland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.434, 'longitude': -94.3199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50569', 'place_name': 'Otho', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.4031, 'longitude': -94.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50594', 'place_name': 'Vincent', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Webster', 'locality_code': '187', 'latitude': 42.5623, 'longitude': -94.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50424', 'place_name': 'Buffalo Center', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winnebago', 'locality_code': '189', 'latitude': 43.3732, 'longitude': -93.9376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50436', 'place_name': 'Forest City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winnebago', 'locality_code': '189', 'latitude': 43.2692, 'longitude': -93.6356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50450', 'place_name': 'Lake Mills', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winnebago', 'locality_code': '189', 'latitude': 43.4167, 'longitude': -93.5336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50453', 'place_name': 'Leland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winnebago', 'locality_code': '189', 'latitude': 43.3425, 'longitude': -93.6895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50465', 'place_name': 'Rake', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winnebago', 'locality_code': '189', 'latitude': 43.4767, 'longitude': -93.9171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50473', 'place_name': 'Scarville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winnebago', 'locality_code': '189', 'latitude': 43.4673, 'longitude': -93.6423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50478', 'place_name': 'Thompson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winnebago', 'locality_code': '189', 'latitude': 43.3875, 'longitude': -93.7517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52101', 'place_name': 'Decorah', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.3227, 'longitude': -91.7939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52132', 'place_name': 'Calmar', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.1974, 'longitude': -91.9126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52133', 'place_name': 'Castalia', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.1361, 'longitude': -91.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52144', 'place_name': 'Fort Atkinson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.1339, 'longitude': -91.9134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52149', 'place_name': 'Highlandville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.4638, 'longitude': -91.6899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52161', 'place_name': 'Ossian', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.1379, 'longitude': -91.7734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52165', 'place_name': 'Ridgeway', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.2979, 'longitude': -92.0034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '52168', 'place_name': 'Spillville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Winneshiek', 'locality_code': '191', 'latitude': 43.2032, 'longitude': -91.9441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51004', 'place_name': 'Anthon', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.387, 'longitude': -95.8948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51007', 'place_name': 'Bronson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4292, 'longitude': -96.1986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51015', 'place_name': 'Climbing Hill', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.345, 'longitude': -96.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51016', 'place_name': 'Correctionville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4743, 'longitude': -95.7804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51018', 'place_name': 'Cushing', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4642, 'longitude': -95.6775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51019', 'place_name': 'Danbury', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.2693, 'longitude': -95.7263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51026', 'place_name': 'Hornick', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.2897, 'longitude': -96.0796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51030', 'place_name': 'Lawton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.5047, 'longitude': -96.2189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51039', 'place_name': 'Moville', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4819, 'longitude': -96.0656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51044', 'place_name': 'Oto', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.2646, 'longitude': -95.8616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51048', 'place_name': 'Pierson', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.5335, 'longitude': -95.8922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51052', 'place_name': 'Salix', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.3306, 'longitude': -96.2879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51054', 'place_name': 'Sergeant Bluff', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4019, 'longitude': -96.3534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51055', 'place_name': 'Sloan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.2427, 'longitude': -96.2306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51056', 'place_name': 'Smithland', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.2408, 'longitude': -95.9486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51101', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4972, 'longitude': -96.4029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51102', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.3684, 'longitude': -96.318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51103', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.5068, 'longitude': -96.4295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51104', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.5254, 'longitude': -96.4005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51105', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.5032, 'longitude': -96.3829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51106', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4671, 'longitude': -96.3528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51108', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.5469, 'longitude': -96.3617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51109', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.5173, 'longitude': -96.4803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '51111', 'place_name': 'Sioux City', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Woodbury', 'locality_code': '193', 'latitude': 42.4089, 'longitude': -96.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50434', 'place_name': 'Fertile', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Worth', 'locality_code': '195', 'latitude': 43.2644, 'longitude': -93.4183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50440', 'place_name': 'Grafton', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Worth', 'locality_code': '195', 'latitude': 43.311, 'longitude': -93.0797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50444', 'place_name': 'Hanlontown', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Worth', 'locality_code': '195', 'latitude': 43.2802, 'longitude': -93.3788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50446', 'place_name': 'Joice', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Worth', 'locality_code': '195', 'latitude': 43.3761, 'longitude': -93.4454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50448', 'place_name': 'Kensett', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Worth', 'locality_code': '195', 'latitude': 43.3536, 'longitude': -93.2105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50456', 'place_name': 'Manly', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Worth', 'locality_code': '195', 'latitude': 43.2891, 'longitude': -93.2018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50459', 'place_name': 'Northwood', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Worth', 'locality_code': '195', 'latitude': 43.4506, 'longitude': -93.2419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50071', 'place_name': 'Dows', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.661, 'longitude': -93.5058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50101', 'place_name': 'Galt', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.6912, 'longitude': -93.6035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50421', 'place_name': 'Belmond', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.8511, 'longitude': -93.62, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50470', 'place_name': 'Rowan', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.7596, 'longitude': -93.557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50525', 'place_name': 'Clarion', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.7271, 'longitude': -93.7277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50526', 'place_name': 'Clarion', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.733, 'longitude': -93.7352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50533', 'place_name': 'Eagle Grove', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.6609, 'longitude': -93.9049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50542', 'place_name': 'Goldfield', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.7581, 'longitude': -93.9194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '50599', 'place_name': 'Woolstock', 'state': 'Iowa', 'state_ab': 'IA', 'county': 'Wright', 'locality_code': '197', 'latitude': 42.5844, 'longitude': -93.8216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83616', 'place_name': 'Eagle', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.7069, 'longitude': -116.362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83634', 'place_name': 'Kuna', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.487, 'longitude': -116.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83642', 'place_name': 'Meridian', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.615, 'longitude': -116.3975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83669', 'place_name': 'Star', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.7013, 'longitude': -116.4967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83680', 'place_name': 'Meridian', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6121, 'longitude': -116.3915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83701', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6038, 'longitude': -116.2729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83702', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6322, 'longitude': -116.2052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83703', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6601, 'longitude': -116.2524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83704', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.633, 'longitude': -116.2951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83705', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.5851, 'longitude': -116.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83706', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.5885, 'longitude': -116.191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83707', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6135, 'longitude': -116.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83708', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83709', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.5741, 'longitude': -116.2941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83711', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83712', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6023, 'longitude': -116.1649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83713', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.634, 'longitude': -116.3419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83714', 'place_name': 'Garden City', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.7318, 'longitude': -116.2797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83715', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83716', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.5345, 'longitude': -115.9711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83717', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83719', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83720', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83722', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83724', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6195, 'longitude': -116.1952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83725', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83726', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83728', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6135, 'longitude': -116.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83729', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83731', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83732', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83735', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6135, 'longitude': -116.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83756', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.4599, 'longitude': -116.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83799', 'place_name': 'Boise', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Ada', 'locality_code': '1', 'latitude': 43.6135, 'longitude': -116.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83612', 'place_name': 'Council', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Adams', 'locality_code': '3', 'latitude': 44.7628, 'longitude': -116.4518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83632', 'place_name': 'Indian Valley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Adams', 'locality_code': '3', 'latitude': 44.5491, 'longitude': -116.443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83643', 'place_name': 'Mesa', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Adams', 'locality_code': '3', 'latitude': 44.6255, 'longitude': -116.4493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83654', 'place_name': 'New Meadows', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Adams', 'locality_code': '3', 'latitude': 44.994, 'longitude': -116.2874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83201', 'place_name': 'Pocatello', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.8876, 'longitude': -112.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83202', 'place_name': 'Pocatello', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.9357, 'longitude': -112.4679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83204', 'place_name': 'Pocatello', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.8465, 'longitude': -112.4434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83205', 'place_name': 'Pocatello', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.8062, 'longitude': -112.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83206', 'place_name': 'Pocatello', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.8713, 'longitude': -112.4455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83209', 'place_name': 'Pocatello', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.6395, 'longitude': -112.3138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83214', 'place_name': 'Arimo', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.56, 'longitude': -112.1746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83234', 'place_name': 'Downey', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.4181, 'longitude': -112.109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83245', 'place_name': 'Inkom', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.7964, 'longitude': -112.2465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83246', 'place_name': 'Lava Hot Springs', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.6185, 'longitude': -112.0176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83250', 'place_name': 'McCammon', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.6336, 'longitude': -112.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83281', 'place_name': 'Swanlake', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bannock', 'locality_code': '5', 'latitude': 42.3195, 'longitude': -111.9781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83220', 'place_name': 'Bern', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.3191, 'longitude': -111.3926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83223', 'place_name': 'Bloomington', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.184, 'longitude': -111.4086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83233', 'place_name': 'Dingle', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.1774, 'longitude': -111.2174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83238', 'place_name': 'Geneva', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.3136, 'longitude': -111.0722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83239', 'place_name': 'Georgetown', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.4821, 'longitude': -111.3708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83254', 'place_name': 'Montpelier', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.352, 'longitude': -111.3195, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83261', 'place_name': 'Paris', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.2242, 'longitude': -111.4208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83272', 'place_name': 'Saint Charles', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.1128, 'longitude': -111.3897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83287', 'place_name': 'Fish Haven', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bear Lake', 'locality_code': '7', 'latitude': 42.0459, 'longitude': -111.4633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83824', 'place_name': 'Desmet', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Benewah', 'locality_code': '9', 'latitude': 47.126, 'longitude': -116.8937, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83830', 'place_name': 'Fernwood', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Benewah', 'locality_code': '9', 'latitude': 47.116, 'longitude': -116.3831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83851', 'place_name': 'Plummer', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Benewah', 'locality_code': '9', 'latitude': 47.3278, 'longitude': -116.8662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83861', 'place_name': 'Saint Maries', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Benewah', 'locality_code': '9', 'latitude': 47.2977, 'longitude': -116.5681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83866', 'place_name': 'Santa', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Benewah', 'locality_code': '9', 'latitude': 47.1544, 'longitude': -116.431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83870', 'place_name': 'Tensed', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Benewah', 'locality_code': '9', 'latitude': 47.1707, 'longitude': -116.9027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83203', 'place_name': 'Fort Hall', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.0331, 'longitude': -112.4285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83210', 'place_name': 'Aberdeen', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.0049, 'longitude': -112.84, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83215', 'place_name': 'Atomic City', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.4449, 'longitude': -112.8128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83218', 'place_name': 'Basalt', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.3155, 'longitude': -112.1644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83221', 'place_name': 'Blackfoot', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.1943, 'longitude': -112.3615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83236', 'place_name': 'Firth', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.3021, 'longitude': -112.1588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83256', 'place_name': 'Moreland', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.2226, 'longitude': -112.4423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83262', 'place_name': 'Pingree', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.1336, 'longitude': -112.6295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83274', 'place_name': 'Shelley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.3769, 'longitude': -112.1075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83277', 'place_name': 'Springfield', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bingham', 'locality_code': '11', 'latitude': 43.0803, 'longitude': -112.673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83313', 'place_name': 'Bellevue', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Blaine', 'locality_code': '13', 'latitude': 43.4397, 'longitude': -114.2498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83320', 'place_name': 'Carey', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Blaine', 'locality_code': '13', 'latitude': 43.2744, 'longitude': -113.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83333', 'place_name': 'Hailey', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Blaine', 'locality_code': '13', 'latitude': 43.5239, 'longitude': -114.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83340', 'place_name': 'Ketchum', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Blaine', 'locality_code': '13', 'latitude': 43.6692, 'longitude': -114.4858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83348', 'place_name': 'Picabo', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Blaine', 'locality_code': '13', 'latitude': 43.3101, 'longitude': -114.0861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83353', 'place_name': 'Sun Valley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Blaine', 'locality_code': '13', 'latitude': 43.6853, 'longitude': -114.3313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83354', 'place_name': 'Sun Valley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Blaine', 'locality_code': '13', 'latitude': 43.5946, 'longitude': -114.3226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83602', 'place_name': 'Banks', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boise', 'locality_code': '15', 'latitude': 44.0804, 'longitude': -116.124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83622', 'place_name': 'Garden Valley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boise', 'locality_code': '15', 'latitude': 44.0909, 'longitude': -115.8243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83629', 'place_name': 'Horseshoe Bend', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boise', 'locality_code': '15', 'latitude': 43.9229, 'longitude': -116.1809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83631', 'place_name': 'Idaho City', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boise', 'locality_code': '15', 'latitude': 43.8834, 'longitude': -115.708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83637', 'place_name': 'Lowman', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boise', 'locality_code': '15', 'latitude': 44.1106, 'longitude': -115.5285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83646', 'place_name': 'Meridian', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boise', 'locality_code': '15', 'latitude': 43.6498, 'longitude': -116.4306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83666', 'place_name': 'Placerville', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boise', 'locality_code': '15', 'latitude': 43.9633, 'longitude': -115.9759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83804', 'place_name': 'Blanchard', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.0223, 'longitude': -116.9909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83809', 'place_name': 'Careywood', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.0482, 'longitude': -116.5939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83811', 'place_name': 'Clark Fork', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.1405, 'longitude': -116.1699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83813', 'place_name': 'Cocolalla', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.1248, 'longitude': -116.6571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83821', 'place_name': 'Coolin', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.5228, 'longitude': -116.8408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83822', 'place_name': 'Oldtown', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.1552, 'longitude': -116.9781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83825', 'place_name': 'Dover', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.2516, 'longitude': -116.611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83836', 'place_name': 'Hope', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.2444, 'longitude': -116.2795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83840', 'place_name': 'Kootenai', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.3102, 'longitude': -116.5135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83841', 'place_name': 'Laclede', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.1702, 'longitude': -116.756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83848', 'place_name': 'Nordman', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.6339, 'longitude': -116.9473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83852', 'place_name': 'Ponderay', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.3055, 'longitude': -116.5338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83856', 'place_name': 'Priest River', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.1664, 'longitude': -116.9066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83860', 'place_name': 'Sagle', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.2035, 'longitude': -116.5455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83864', 'place_name': 'Sandpoint', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.312, 'longitude': -116.5332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83865', 'place_name': 'Colburn', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonner', 'locality_code': '17', 'latitude': 48.3633, 'longitude': -116.6256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83401', 'place_name': 'Idaho Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.5518, 'longitude': -111.8919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83402', 'place_name': 'Idaho Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.4934, 'longitude': -112.0578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83403', 'place_name': 'Idaho Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.4666, 'longitude': -112.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83404', 'place_name': 'Idaho Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.475, 'longitude': -112.0124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83405', 'place_name': 'Idaho Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.4666, 'longitude': -112.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83406', 'place_name': 'Idaho Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.4732, 'longitude': -111.9661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83415', 'place_name': 'Idaho Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.4666, 'longitude': -112.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83427', 'place_name': 'Iona', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.5263, 'longitude': -111.933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83428', 'place_name': 'Irwin', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.3861, 'longitude': -111.2527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83449', 'place_name': 'Swan Valley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.456, 'longitude': -111.3416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83454', 'place_name': 'Ucon', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Bonneville', 'locality_code': '19', 'latitude': 43.5936, 'longitude': -111.9573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83805', 'place_name': 'Bonners Ferry', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boundary', 'locality_code': '21', 'latitude': 48.7306, 'longitude': -116.3322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83826', 'place_name': 'Eastport', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boundary', 'locality_code': '21', 'latitude': 48.9994, 'longitude': -116.1813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83845', 'place_name': 'Moyie Springs', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boundary', 'locality_code': '21', 'latitude': 48.7464, 'longitude': -116.1796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83847', 'place_name': 'Naples', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boundary', 'locality_code': '21', 'latitude': 48.6049, 'longitude': -116.3196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83853', 'place_name': 'Porthill', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Boundary', 'locality_code': '21', 'latitude': 48.992, 'longitude': -116.4775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83213', 'place_name': 'Arco', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Butte', 'locality_code': '23', 'latitude': 43.6355, 'longitude': -113.3176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83244', 'place_name': 'Howe', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Butte', 'locality_code': '23', 'latitude': 43.9087, 'longitude': -113.0878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83255', 'place_name': 'Moore', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Butte', 'locality_code': '23', 'latitude': 43.7296, 'longitude': -113.4544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83322', 'place_name': 'Corral', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Camas', 'locality_code': '25', 'latitude': 43.5282, 'longitude': -114.7307, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83327', 'place_name': 'Fairfield', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Camas', 'locality_code': '25', 'latitude': 43.3675, 'longitude': -114.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83337', 'place_name': 'Hill City', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Camas', 'locality_code': '25', 'latitude': 43.3005, 'longitude': -115.0512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83605', 'place_name': 'Caldwell', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.6627, 'longitude': -116.7, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83606', 'place_name': 'Caldwell', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.7249, 'longitude': -116.7989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83607', 'place_name': 'Caldwell', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.6186, 'longitude': -116.7501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83626', 'place_name': 'Greenleaf', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.669, 'longitude': -116.8315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83630', 'place_name': 'Huston', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.6027, 'longitude': -116.7903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83641', 'place_name': 'Melba', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.3784, 'longitude': -116.5489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83644', 'place_name': 'Middleton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.7191, 'longitude': -116.6112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83651', 'place_name': 'Nampa', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.5834, 'longitude': -116.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83652', 'place_name': 'Nampa', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.7071, 'longitude': -116.6208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83653', 'place_name': 'Nampa', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.5851, 'longitude': -116.753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83656', 'place_name': 'Notus', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.7259, 'longitude': -116.7997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83660', 'place_name': 'Parma', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.7896, 'longitude': -116.9401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83676', 'place_name': 'Wilder', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.6579, 'longitude': -116.9122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83686', 'place_name': 'Nampa', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.5441, 'longitude': -116.566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83687', 'place_name': 'Nampa', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Canyon', 'locality_code': '27', 'latitude': 43.5937, 'longitude': -116.536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83217', 'place_name': 'Bancroft', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Caribou', 'locality_code': '29', 'latitude': 42.7205, 'longitude': -111.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83230', 'place_name': 'Conda', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Caribou', 'locality_code': '29', 'latitude': 42.7191, 'longitude': -111.5967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83241', 'place_name': 'Grace', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Caribou', 'locality_code': '29', 'latitude': 42.55, 'longitude': -111.74, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83276', 'place_name': 'Soda Springs', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Caribou', 'locality_code': '29', 'latitude': 42.6718, 'longitude': -111.5699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83285', 'place_name': 'Wayan', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Caribou', 'locality_code': '29', 'latitude': 43.0269, 'longitude': -111.2541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83311', 'place_name': 'Albion', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Cassia', 'locality_code': '31', 'latitude': 42.3896, 'longitude': -113.5567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83312', 'place_name': 'Almo', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Cassia', 'locality_code': '31', 'latitude': 42.0846, 'longitude': -113.6283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83318', 'place_name': 'Burley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Cassia', 'locality_code': '31', 'latitude': 42.5244, 'longitude': -113.7931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83323', 'place_name': 'Declo', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Cassia', 'locality_code': '31', 'latitude': 42.5245, 'longitude': -113.4338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83342', 'place_name': 'Malta', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Cassia', 'locality_code': '31', 'latitude': 42.2741, 'longitude': -113.3927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83346', 'place_name': 'Oakley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Cassia', 'locality_code': '31', 'latitude': 42.194, 'longitude': -113.872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83423', 'place_name': 'Dubois', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clark', 'locality_code': '33', 'latitude': 44.1858, 'longitude': -112.3259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83446', 'place_name': 'Spencer', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clark', 'locality_code': '33', 'latitude': 44.3605, 'longitude': -112.1869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83520', 'place_name': 'Ahsahka', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clearwater', 'locality_code': '35', 'latitude': 46.5394, 'longitude': -116.3233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83541', 'place_name': 'Lenore', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clearwater', 'locality_code': '35', 'latitude': 46.5354, 'longitude': -116.513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83544', 'place_name': 'Orofino', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clearwater', 'locality_code': '35', 'latitude': 46.4952, 'longitude': -116.2404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83546', 'place_name': 'Pierce', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clearwater', 'locality_code': '35', 'latitude': 46.4924, 'longitude': -115.8071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83553', 'place_name': 'Weippe', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clearwater', 'locality_code': '35', 'latitude': 46.3807, 'longitude': -115.9386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83827', 'place_name': 'Elk River', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Clearwater', 'locality_code': '35', 'latitude': 46.7835, 'longitude': -116.1799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83226', 'place_name': 'Challis', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Custer', 'locality_code': '37', 'latitude': 44.4969, 'longitude': -114.1946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83227', 'place_name': 'Clayton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Custer', 'locality_code': '37', 'latitude': 44.2733, 'longitude': -114.4102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83235', 'place_name': 'Ellis', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Custer', 'locality_code': '37', 'latitude': 44.6919, 'longitude': -114.0484, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83251', 'place_name': 'Mackay', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Custer', 'locality_code': '37', 'latitude': 43.9111, 'longitude': -113.612, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83278', 'place_name': 'Stanley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Custer', 'locality_code': '37', 'latitude': 44.3714, 'longitude': -114.8561, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83601', 'place_name': 'Atlanta', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Elmore', 'locality_code': '39', 'latitude': 43.8479, 'longitude': -115.2538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83623', 'place_name': 'Glenns Ferry', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Elmore', 'locality_code': '39', 'latitude': 42.9622, 'longitude': -115.316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83627', 'place_name': 'Hammett', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Elmore', 'locality_code': '39', 'latitude': 42.9457, 'longitude': -115.4662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83633', 'place_name': 'King Hill', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Elmore', 'locality_code': '39', 'latitude': 42.9799, 'longitude': -115.1899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83647', 'place_name': 'Mountain Home', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Elmore', 'locality_code': '39', 'latitude': 43.1392, 'longitude': -115.6963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83648', 'place_name': 'Mountain Home Afb', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Elmore', 'locality_code': '39', 'latitude': 43.7914, 'longitude': -116.4012, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83228', 'place_name': 'Clifton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Franklin', 'locality_code': '41', 'latitude': 42.216, 'longitude': -111.9957, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83232', 'place_name': 'Dayton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Franklin', 'locality_code': '41', 'latitude': 42.1184, 'longitude': -111.9858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83237', 'place_name': 'Franklin', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Franklin', 'locality_code': '41', 'latitude': 42.0288, 'longitude': -111.7871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83263', 'place_name': 'Preston', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Franklin', 'locality_code': '41', 'latitude': 42.1109, 'longitude': -111.8565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83283', 'place_name': 'Thatcher', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Franklin', 'locality_code': '41', 'latitude': 42.3794, 'longitude': -111.6841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83286', 'place_name': 'Weston', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Franklin', 'locality_code': '41', 'latitude': 42.0446, 'longitude': -111.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83420', 'place_name': 'Ashton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 44.0153, 'longitude': -111.4253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83421', 'place_name': 'Chester', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 44.0011, 'longitude': -111.5351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83429', 'place_name': 'Island Park', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 44.4466, 'longitude': -111.3679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83433', 'place_name': 'Macks Inn', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 44.3192, 'longitude': -111.6017, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83436', 'place_name': 'Newdale', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 43.8881, 'longitude': -111.6042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83438', 'place_name': 'Parker', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 43.9594, 'longitude': -111.7577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83445', 'place_name': 'Saint Anthony', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 43.963, 'longitude': -111.7036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83451', 'place_name': 'Teton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Fremont', 'locality_code': '43', 'latitude': 43.8907, 'longitude': -111.6504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83617', 'place_name': 'Emmett', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gem', 'locality_code': '45', 'latitude': 43.9089, 'longitude': -116.4927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83636', 'place_name': 'Letha', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gem', 'locality_code': '45', 'latitude': 43.8963, 'longitude': -116.6462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83657', 'place_name': 'Ola', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gem', 'locality_code': '45', 'latitude': 44.2418, 'longitude': -116.2732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83670', 'place_name': 'Sweet', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gem', 'locality_code': '45', 'latitude': 43.9948, 'longitude': -116.3232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83314', 'place_name': 'Bliss', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gooding', 'locality_code': '47', 'latitude': 42.9449, 'longitude': -114.9104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83330', 'place_name': 'Gooding', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gooding', 'locality_code': '47', 'latitude': 42.9373, 'longitude': -114.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83332', 'place_name': 'Hagerman', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gooding', 'locality_code': '47', 'latitude': 42.8142, 'longitude': -114.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83355', 'place_name': 'Wendell', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Gooding', 'locality_code': '47', 'latitude': 42.7579, 'longitude': -114.7154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83522', 'place_name': 'Cottonwood', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 46.0448, 'longitude': -116.3733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83525', 'place_name': 'Elk City', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.7896, 'longitude': -115.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83526', 'place_name': 'Ferdinand', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 46.1349, 'longitude': -116.3982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83530', 'place_name': 'Grangeville', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.9272, 'longitude': -116.1076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83531', 'place_name': 'Fenn', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.9632, 'longitude': -116.2563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83533', 'place_name': 'Greencreek', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 46.1155, 'longitude': -116.2724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83539', 'place_name': 'Kooskia', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 46.116, 'longitude': -115.9459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83542', 'place_name': 'Lucile', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.557, 'longitude': -116.2669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83547', 'place_name': 'Pollock', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.3068, 'longitude': -116.3517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83549', 'place_name': 'Riggins', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.397, 'longitude': -116.3006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83552', 'place_name': 'Stites', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 46.002, 'longitude': -115.9269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83554', 'place_name': 'White Bird', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.7521, 'longitude': -116.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83671', 'place_name': 'Warren', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Idaho', 'locality_code': '49', 'latitude': 45.2641, 'longitude': -115.6765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83425', 'place_name': 'Hamer', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.9308, 'longitude': -112.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83431', 'place_name': 'Lewisville', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.6725, 'longitude': -112.0189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83434', 'place_name': 'Menan', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.7266, 'longitude': -111.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83435', 'place_name': 'Monteview', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.9862, 'longitude': -112.5783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83442', 'place_name': 'Rigby', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.6715, 'longitude': -111.9005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83443', 'place_name': 'Ririe', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.5197, 'longitude': -111.5266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83444', 'place_name': 'Roberts', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.7116, 'longitude': -112.1196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83450', 'place_name': 'Terreton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jefferson', 'locality_code': '51', 'latitude': 43.8586, 'longitude': -112.42, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83325', 'place_name': 'Eden', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jerome', 'locality_code': '53', 'latitude': 42.5868, 'longitude': -114.2467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83335', 'place_name': 'Hazelton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jerome', 'locality_code': '53', 'latitude': 42.5955, 'longitude': -114.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83338', 'place_name': 'Jerome', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Jerome', 'locality_code': '53', 'latitude': 42.7178, 'longitude': -114.5012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83801', 'place_name': 'Athol', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.9267, 'longitude': -116.7318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83803', 'place_name': 'Bayview', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.9822, 'longitude': -116.5494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83810', 'place_name': 'Cataldo', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.5522, 'longitude': -116.4431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83814', 'place_name': "Coeur d'Alene", 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.6928, 'longitude': -116.785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83815', 'place_name': "Coeur d'Alene", 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.7248, 'longitude': -116.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83816', 'place_name': "Coeur d'Alene", 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.6777, 'longitude': -116.7805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83833', 'place_name': 'Harrison', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.5017, 'longitude': -116.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83835', 'place_name': 'Hayden', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.7989, 'longitude': -116.7423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83842', 'place_name': 'Medimont', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.4625, 'longitude': -116.5683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83854', 'place_name': 'Post Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.7205, 'longitude': -116.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83858', 'place_name': 'Rathdrum', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.8241, 'longitude': -116.8873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83869', 'place_name': 'Spirit Lake', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.9657, 'longitude': -116.868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83876', 'place_name': 'Worley', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.4292, 'longitude': -116.9056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83877', 'place_name': 'Post Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Kootenai', 'locality_code': '55', 'latitude': 47.718, 'longitude': -116.9516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83535', 'place_name': 'Juliaetta', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.5754, 'longitude': -116.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83537', 'place_name': 'Kendrick', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.6286, 'longitude': -116.6049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83806', 'place_name': 'Bovill', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.8588, 'longitude': -116.3935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83823', 'place_name': 'Deary', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.8061, 'longitude': -116.5238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83832', 'place_name': 'Genesee', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.5714, 'longitude': -116.929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83834', 'place_name': 'Harvard', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.9376, 'longitude': -116.7025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83843', 'place_name': 'Moscow', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.7309, 'longitude': -116.9897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83844', 'place_name': 'Moscow', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.7324, 'longitude': -117.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83855', 'place_name': 'Potlatch', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.9448, 'longitude': -116.9141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83857', 'place_name': 'Princeton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.8996, 'longitude': -116.8287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83871', 'place_name': 'Troy', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.7426, 'longitude': -116.7681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83872', 'place_name': 'Viola', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Latah', 'locality_code': '57', 'latitude': 46.8583, 'longitude': -116.9732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83229', 'place_name': 'Cobalt', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 45.093, 'longitude': -114.2317, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83253', 'place_name': 'May', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 44.6044, 'longitude': -113.912, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83462', 'place_name': 'Carmen', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 45.255, 'longitude': -113.8573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83463', 'place_name': 'Gibbonsville', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 45.5704, 'longitude': -113.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83464', 'place_name': 'Leadore', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 44.7389, 'longitude': -113.4926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83465', 'place_name': 'Lemhi', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 44.8516, 'longitude': -113.6198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83466', 'place_name': 'North Fork', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 45.4242, 'longitude': -114.0419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83467', 'place_name': 'Salmon', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 45.1571, 'longitude': -113.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83468', 'place_name': 'Tendoy', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 44.9681, 'longitude': -113.8167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83469', 'place_name': 'Shoup', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lemhi', 'locality_code': '59', 'latitude': 45.3769, 'longitude': -114.277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83523', 'place_name': 'Craigmont', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lewis', 'locality_code': '61', 'latitude': 46.2453, 'longitude': -116.4677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83536', 'place_name': 'Kamiah', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lewis', 'locality_code': '61', 'latitude': 46.2186, 'longitude': -116.0347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83543', 'place_name': 'Nezperce', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lewis', 'locality_code': '61', 'latitude': 46.2475, 'longitude': -116.2393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83548', 'place_name': 'Reubens', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lewis', 'locality_code': '61', 'latitude': 46.3361, 'longitude': -116.5333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83555', 'place_name': 'Winchester', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lewis', 'locality_code': '61', 'latitude': 46.2383, 'longitude': -116.6204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83324', 'place_name': 'Dietrich', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lincoln', 'locality_code': '63', 'latitude': 42.9125, 'longitude': -114.2664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83349', 'place_name': 'Richfield', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lincoln', 'locality_code': '63', 'latitude': 43.0588, 'longitude': -114.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83352', 'place_name': 'Shoshone', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Lincoln', 'locality_code': '63', 'latitude': 42.9474, 'longitude': -114.3822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83440', 'place_name': 'Rexburg', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Madison', 'locality_code': '65', 'latitude': 43.81, 'longitude': -111.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83441', 'place_name': 'Rexburg', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Madison', 'locality_code': '65', 'latitude': 43.7761, 'longitude': -111.691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83448', 'place_name': 'Sugar City', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Madison', 'locality_code': '65', 'latitude': 43.8477, 'longitude': -111.6932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83460', 'place_name': 'Rexburg', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Madison', 'locality_code': '65', 'latitude': 43.826, 'longitude': -111.7897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83336', 'place_name': 'Heyburn', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Minidoka', 'locality_code': '67', 'latitude': 42.5599, 'longitude': -113.7709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83343', 'place_name': 'Minidoka', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Minidoka', 'locality_code': '67', 'latitude': 42.773, 'longitude': -113.5098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83347', 'place_name': 'Paul', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Minidoka', 'locality_code': '67', 'latitude': 42.624, 'longitude': -113.7971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83350', 'place_name': 'Rupert', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Minidoka', 'locality_code': '67', 'latitude': 42.6888, 'longitude': -113.6481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83501', 'place_name': 'Lewiston', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Nez Perce', 'locality_code': '69', 'latitude': 46.3646, 'longitude': -116.8609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83524', 'place_name': 'Culdesac', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Nez Perce', 'locality_code': '69', 'latitude': 46.378, 'longitude': -116.6536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83540', 'place_name': 'Lapwai', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Nez Perce', 'locality_code': '69', 'latitude': 46.4124, 'longitude': -116.7902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83545', 'place_name': 'Peck', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Nez Perce', 'locality_code': '69', 'latitude': 46.4807, 'longitude': -116.4114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83243', 'place_name': 'Holbrook', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Oneida', 'locality_code': '71', 'latitude': 42.1619, 'longitude': -112.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83252', 'place_name': 'Malad City', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Oneida', 'locality_code': '71', 'latitude': 42.1808, 'longitude': -112.262, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83604', 'place_name': 'Bruneau', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Owyhee', 'locality_code': '73', 'latitude': 42.614, 'longitude': -115.8419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83624', 'place_name': 'Grand View', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Owyhee', 'locality_code': '73', 'latitude': 42.9896, 'longitude': -116.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83628', 'place_name': 'Homedale', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Owyhee', 'locality_code': '73', 'latitude': 43.6138, 'longitude': -116.9472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83639', 'place_name': 'Marsing', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Owyhee', 'locality_code': '73', 'latitude': 43.5399, 'longitude': -116.824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83650', 'place_name': 'Murphy', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Owyhee', 'locality_code': '73', 'latitude': 42.8481, 'longitude': -116.6371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83619', 'place_name': 'Fruitland', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Payette', 'locality_code': '75', 'latitude': 44.0027, 'longitude': -116.9143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83655', 'place_name': 'New Plymouth', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Payette', 'locality_code': '75', 'latitude': 43.959, 'longitude': -116.8048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83661', 'place_name': 'Payette', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Payette', 'locality_code': '75', 'latitude': 44.0782, 'longitude': -116.9203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83211', 'place_name': 'American Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Power', 'locality_code': '77', 'latitude': 42.6352, 'longitude': -112.9458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83212', 'place_name': 'Arbon', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Power', 'locality_code': '77', 'latitude': 42.5026, 'longitude': -112.5585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83271', 'place_name': 'Rockland', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Power', 'locality_code': '77', 'latitude': 42.5556, 'longitude': -112.854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83802', 'place_name': 'Avery', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.2714, 'longitude': -115.866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83808', 'place_name': 'Calder', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.3219, 'longitude': -116.0703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83812', 'place_name': 'Clarkia', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.0107, 'longitude': -116.2529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83837', 'place_name': 'Kellogg', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.5431, 'longitude': -116.1253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83839', 'place_name': 'Kingston', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.5509, 'longitude': -116.2887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83846', 'place_name': 'Mullan', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.4709, 'longitude': -115.7926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83849', 'place_name': 'Osburn', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.5211, 'longitude': -116.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83850', 'place_name': 'Pinehurst', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.5018, 'longitude': -116.2647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83867', 'place_name': 'Silverton', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.4981, 'longitude': -115.9657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83868', 'place_name': 'Smelterville', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.5362, 'longitude': -116.2062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83873', 'place_name': 'Wallace', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.4908, 'longitude': -115.962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83874', 'place_name': 'Murray', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Shoshone', 'locality_code': '79', 'latitude': 47.6271, 'longitude': -115.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83422', 'place_name': 'Driggs', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Teton', 'locality_code': '81', 'latitude': 43.7263, 'longitude': -111.1199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83424', 'place_name': 'Felt', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Teton', 'locality_code': '81', 'latitude': 43.8724, 'longitude': -111.1895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83452', 'place_name': 'Tetonia', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Teton', 'locality_code': '81', 'latitude': 43.7814, 'longitude': -111.2118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83455', 'place_name': 'Victor', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Teton', 'locality_code': '81', 'latitude': 43.6148, 'longitude': -111.1259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83301', 'place_name': 'Twin Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.5565, 'longitude': -114.4693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83302', 'place_name': 'Rogerson', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.218, 'longitude': -114.5942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83303', 'place_name': 'Twin Falls', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.563, 'longitude': -114.4609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83316', 'place_name': 'Buhl', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.6008, 'longitude': -114.7825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83321', 'place_name': 'Castleford', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.521, 'longitude': -114.8734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83328', 'place_name': 'Filer', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.5653, 'longitude': -114.614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83334', 'place_name': 'Hansen', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.5249, 'longitude': -114.2994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83341', 'place_name': 'Kimberly', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.5287, 'longitude': -114.3657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83344', 'place_name': 'Murtaugh', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Twin Falls', 'locality_code': '83', 'latitude': 42.4776, 'longitude': -114.1606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83611', 'place_name': 'Cascade', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Valley', 'locality_code': '85', 'latitude': 44.6927, 'longitude': -115.6417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83615', 'place_name': 'Donnelly', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Valley', 'locality_code': '85', 'latitude': 44.6659, 'longitude': -116.0369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83635', 'place_name': 'Lake Fork', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Valley', 'locality_code': '85', 'latitude': 44.8327, 'longitude': -116.0848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83638', 'place_name': 'McCall', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Valley', 'locality_code': '85', 'latitude': 44.8918, 'longitude': -116.0789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83677', 'place_name': 'Yellow Pine', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Valley', 'locality_code': '85', 'latitude': 44.9698, 'longitude': -115.4963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83610', 'place_name': 'Cambridge', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Washington', 'locality_code': '87', 'latitude': 44.5922, 'longitude': -116.6757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83645', 'place_name': 'Midvale', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Washington', 'locality_code': '87', 'latitude': 44.442, 'longitude': -116.7038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83672', 'place_name': 'Weiser', 'state': 'Idaho', 'state_ab': 'ID', 'county': 'Washington', 'locality_code': '87', 'latitude': 44.2522, 'longitude': -116.9651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62301', 'place_name': 'Quincy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9307, 'longitude': -91.3763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62305', 'place_name': 'Quincy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9601, 'longitude': -91.3026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62306', 'place_name': 'Quincy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9356, 'longitude': -91.4099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62320', 'place_name': 'Camp Point', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0293, 'longitude': -91.0769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62324', 'place_name': 'Clayton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0133, 'longitude': -90.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62325', 'place_name': 'Coatsburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0554, 'longitude': -91.1747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62338', 'place_name': 'Fowler', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9925, 'longitude': -91.2452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62339', 'place_name': 'Golden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.1203, 'longitude': -91.0296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62346', 'place_name': 'La Prairie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.1572, 'longitude': -90.9844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62347', 'place_name': 'Liberty', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8892, 'longitude': -91.0869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62348', 'place_name': 'Lima', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.1775, 'longitude': -91.3785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62349', 'place_name': 'Loraine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.1532, 'longitude': -91.213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62351', 'place_name': 'Mendon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0857, 'longitude': -91.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62359', 'place_name': 'Paloma', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0366, 'longitude': -91.2053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62360', 'place_name': 'Payson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8153, 'longitude': -91.2627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62365', 'place_name': 'Plainville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8004, 'longitude': -91.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62376', 'place_name': 'Ursa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0809, 'longitude': -91.3733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62914', 'place_name': 'Cairo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Alexander', 'locality_code': '3', 'latitude': 37.0123, 'longitude': -89.1811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62957', 'place_name': 'Mc Clure', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Alexander', 'locality_code': '3', 'latitude': 37.302, 'longitude': -89.4531, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62962', 'place_name': 'Miller City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Alexander', 'locality_code': '3', 'latitude': 37.1034, 'longitude': -89.3494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62969', 'place_name': 'Olive Branch', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Alexander', 'locality_code': '3', 'latitude': 37.1674, 'longitude': -89.3537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62988', 'place_name': 'Tamms', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Alexander', 'locality_code': '3', 'latitude': 37.2345, 'longitude': -89.2763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62990', 'place_name': 'Thebes', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Alexander', 'locality_code': '3', 'latitude': 37.221, 'longitude': -89.4599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62993', 'place_name': 'Unity', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Alexander', 'locality_code': '3', 'latitude': 37.1528, 'longitude': -89.3256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62019', 'place_name': 'Donnellson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bond', 'locality_code': '5', 'latitude': 39.0344, 'longitude': -89.4909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62086', 'place_name': 'Sorento', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bond', 'locality_code': '5', 'latitude': 38.9693, 'longitude': -89.5653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62246', 'place_name': 'Greenville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bond', 'locality_code': '5', 'latitude': 38.8933, 'longitude': -89.4052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62262', 'place_name': 'Mulberry Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bond', 'locality_code': '5', 'latitude': 38.9311, 'longitude': -89.2463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62273', 'place_name': 'Pierron', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bond', 'locality_code': '5', 'latitude': 38.78, 'longitude': -89.5981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62275', 'place_name': 'Pocahontas', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bond', 'locality_code': '5', 'latitude': 38.7846, 'longitude': -89.5247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62284', 'place_name': 'Smithboro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bond', 'locality_code': '5', 'latitude': 38.8739, 'longitude': -89.3266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61008', 'place_name': 'Belvidere', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Boone', 'locality_code': '7', 'latitude': 42.2595, 'longitude': -88.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61011', 'place_name': 'Caledonia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Boone', 'locality_code': '7', 'latitude': 42.3835, 'longitude': -88.9185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61012', 'place_name': 'Capron', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Boone', 'locality_code': '7', 'latitude': 42.4087, 'longitude': -88.7465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61038', 'place_name': 'Garden Prairie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Boone', 'locality_code': '7', 'latitude': 42.251, 'longitude': -88.7437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61065', 'place_name': 'Poplar Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Boone', 'locality_code': '7', 'latitude': 42.3594, 'longitude': -88.8428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62353', 'place_name': 'Mount Sterling', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Brown', 'locality_code': '9', 'latitude': 39.9803, 'longitude': -90.7414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62375', 'place_name': 'Timewell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Brown', 'locality_code': '9', 'latitude': 40.0117, 'longitude': -90.8661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62378', 'place_name': 'Versailles', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Brown', 'locality_code': '9', 'latitude': 39.8883, 'longitude': -90.6741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61312', 'place_name': 'Arlington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.4437, 'longitude': -89.2219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61314', 'place_name': 'Buda', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.314, 'longitude': -89.6795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61315', 'place_name': 'Bureau', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.2894, 'longitude': -89.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61317', 'place_name': 'Cherry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.4264, 'longitude': -89.2126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61320', 'place_name': 'Dalzell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3547, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61322', 'place_name': 'Depue', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3092, 'longitude': -89.3252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61323', 'place_name': 'Dover', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.4362, 'longitude': -89.396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61328', 'place_name': 'Kasbeer', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.505, 'longitude': -89.4634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61329', 'place_name': 'Ladd', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3825, 'longitude': -89.219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61330', 'place_name': 'La Moille', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.5376, 'longitude': -89.297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61337', 'place_name': 'Malden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.4245, 'longitude': -89.3693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61338', 'place_name': 'Manlius', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.4555, 'longitude': -89.6697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61344', 'place_name': 'Mineral', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.4036, 'longitude': -89.8201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61345', 'place_name': 'Neponset', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.2905, 'longitude': -89.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61346', 'place_name': 'New Bedford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.5122, 'longitude': -89.7199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61349', 'place_name': 'Ohio', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.5371, 'longitude': -89.4574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61356', 'place_name': 'Princeton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3629, 'longitude': -89.427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61359', 'place_name': 'Seatonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3613, 'longitude': -89.2691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61361', 'place_name': 'Sheffield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3949, 'longitude': -89.7115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61362', 'place_name': 'Spring Valley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3279, 'longitude': -89.2042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61368', 'place_name': 'Tiskilwa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.2891, 'longitude': -89.508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61374', 'place_name': 'Van Orin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.55, 'longitude': -89.3534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61376', 'place_name': 'Walnut', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.5394, 'longitude': -89.6092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61379', 'place_name': 'Wyanet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Bureau', 'locality_code': '11', 'latitude': 41.3785, 'longitude': -89.5744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62006', 'place_name': 'Batchtown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 39.0725, 'longitude': -90.6591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62013', 'place_name': 'Brussels', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.9495, 'longitude': -90.5887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62036', 'place_name': 'Golden Eagle', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.8961, 'longitude': -90.5602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62045', 'place_name': 'Hamburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 39.2235, 'longitude': -90.6995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62047', 'place_name': 'Hardin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 39.1547, 'longitude': -90.624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62053', 'place_name': 'Kampsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 39.3064, 'longitude': -90.6269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62065', 'place_name': 'Michael', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 39.2353, 'longitude': -90.6235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62070', 'place_name': 'Mozier', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 39.2925, 'longitude': -90.7493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61014', 'place_name': 'Chadwick', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Carroll', 'locality_code': '15', 'latitude': 41.9962, 'longitude': -89.8963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61046', 'place_name': 'Lanark', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Carroll', 'locality_code': '15', 'latitude': 42.0935, 'longitude': -89.8247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61051', 'place_name': 'Milledgeville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Carroll', 'locality_code': '15', 'latitude': 41.9674, 'longitude': -89.7801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61053', 'place_name': 'Mount Carroll', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Carroll', 'locality_code': '15', 'latitude': 42.1053, 'longitude': -89.9845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61074', 'place_name': 'Savanna', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Carroll', 'locality_code': '15', 'latitude': 42.0956, 'longitude': -90.1401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61078', 'place_name': 'Shannon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Carroll', 'locality_code': '15', 'latitude': 42.161, 'longitude': -89.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61285', 'place_name': 'Thomson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Carroll', 'locality_code': '15', 'latitude': 41.9816, 'longitude': -90.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62611', 'place_name': 'Arenzville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cass', 'locality_code': '17', 'latitude': 39.8979, 'longitude': -90.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62612', 'place_name': 'Ashland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cass', 'locality_code': '17', 'latitude': 39.9386, 'longitude': -90.0792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62618', 'place_name': 'Beardstown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.0044, 'longitude': -90.4229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62622', 'place_name': 'Bluff Springs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cass', 'locality_code': '17', 'latitude': 39.9796, 'longitude': -90.3524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62627', 'place_name': 'Chandlerville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.0374, 'longitude': -90.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62691', 'place_name': 'Virginia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cass', 'locality_code': '17', 'latitude': 39.9512, 'longitude': -90.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60949', 'place_name': 'Ludlow', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.3747, 'longitude': -88.138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61801', 'place_name': 'Urbana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1095, 'longitude': -88.2036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61802', 'place_name': 'Urbana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.0746, 'longitude': -88.1691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61803', 'place_name': 'Urbana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1059, 'longitude': -88.2247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61815', 'place_name': 'Bondville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1134, 'longitude': -88.3695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61816', 'place_name': 'Broadlands', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 39.9142, 'longitude': -87.9948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61820', 'place_name': 'Champaign', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.111, 'longitude': -88.2407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61821', 'place_name': 'Champaign', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1073, 'longitude': -88.2788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61822', 'place_name': 'Champaign', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1317, 'longitude': -88.2854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61824', 'place_name': 'Champaign', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1164, 'longitude': -88.2434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61825', 'place_name': 'Champaign', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1164, 'longitude': -88.2434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61826', 'place_name': 'Champaign', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1131, 'longitude': -88.3613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61840', 'place_name': 'Dewey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.3131, 'longitude': -88.277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61843', 'place_name': 'Fisher', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.2991, 'longitude': -88.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61845', 'place_name': 'Foosland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.3554, 'longitude': -88.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61847', 'place_name': 'Gifford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.3028, 'longitude': -88.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61849', 'place_name': 'Homer', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.0346, 'longitude': -87.9627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61851', 'place_name': 'Ivesdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 39.9502, 'longitude': -88.4451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61852', 'place_name': 'Longview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 39.9012, 'longitude': -88.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61853', 'place_name': 'Mahomet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1964, 'longitude': -88.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61859', 'place_name': 'Ogden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1401, 'longitude': -87.9665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61862', 'place_name': 'Penfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.3101, 'longitude': -87.957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61863', 'place_name': 'Pesotum', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 39.9151, 'longitude': -88.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61864', 'place_name': 'Philo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.0052, 'longitude': -88.1595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61866', 'place_name': 'Rantoul', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.3107, 'longitude': -88.1462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61871', 'place_name': 'Royal', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1924, 'longitude': -87.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61872', 'place_name': 'Sadorus', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 39.9613, 'longitude': -88.3447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61873', 'place_name': 'Saint Joseph', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.1207, 'longitude': -88.0472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61874', 'place_name': 'Savoy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.0654, 'longitude': -88.2528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61875', 'place_name': 'Seymour', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.107, 'longitude': -88.4267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61877', 'place_name': 'Sidney', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.0232, 'longitude': -88.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61878', 'place_name': 'Thomasboro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 40.2402, 'longitude': -88.183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61880', 'place_name': 'Tolono', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Champaign', 'locality_code': '19', 'latitude': 39.985, 'longitude': -88.2596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62083', 'place_name': 'Rosamond', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.3743, 'longitude': -89.1983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62510', 'place_name': 'Assumption', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.5095, 'longitude': -89.0398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62517', 'place_name': 'Bulpitt', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.5917, 'longitude': -89.424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62531', 'place_name': 'Edinburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.6612, 'longitude': -89.3779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62540', 'place_name': 'Kincaid', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.5838, 'longitude': -89.4185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62546', 'place_name': 'Morrisonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.4153, 'longitude': -89.4541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62547', 'place_name': 'Mount Auburn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.769, 'longitude': -89.2489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62555', 'place_name': 'Owaneco', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.4775, 'longitude': -89.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62556', 'place_name': 'Palmer', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.4699, 'longitude': -89.3733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62557', 'place_name': 'Pana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.3971, 'longitude': -89.1048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62567', 'place_name': 'Stonington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.6405, 'longitude': -89.1913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62568', 'place_name': 'Taylorville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.5489, 'longitude': -89.2945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62570', 'place_name': 'Tovey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Christian', 'locality_code': '21', 'latitude': 39.588, 'longitude': -89.4495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62420', 'place_name': 'Casey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.3017, 'longitude': -87.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62423', 'place_name': 'Dennison', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.449, 'longitude': -87.5867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62441', 'place_name': 'Marshall', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.422, 'longitude': -87.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62442', 'place_name': 'Martinsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.3174, 'longitude': -87.8707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62474', 'place_name': 'Westfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.4564, 'longitude': -87.9961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62477', 'place_name': 'West Union', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.2402, 'longitude': -87.6512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62434', 'place_name': 'Ingraham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clay', 'locality_code': '25', 'latitude': 38.8284, 'longitude': -88.3204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62824', 'place_name': 'Clay City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clay', 'locality_code': '25', 'latitude': 38.6695, 'longitude': -88.3516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62839', 'place_name': 'Flora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clay', 'locality_code': '25', 'latitude': 38.6703, 'longitude': -88.4919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62858', 'place_name': 'Louisville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clay', 'locality_code': '25', 'latitude': 38.7718, 'longitude': -88.5065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62879', 'place_name': 'Sailor Springs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clay', 'locality_code': '25', 'latitude': 38.7639, 'longitude': -88.3631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62899', 'place_name': 'Xenia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clay', 'locality_code': '25', 'latitude': 38.6359, 'longitude': -88.6348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62215', 'place_name': 'Albers', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.532, 'longitude': -89.6202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62216', 'place_name': 'Aviston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.6089, 'longitude': -89.6034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62218', 'place_name': 'Bartelso', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.5385, 'longitude': -89.4578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62219', 'place_name': 'Beckemeyer', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.6058, 'longitude': -89.4319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62230', 'place_name': 'Breese', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.6188, 'longitude': -89.5284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62231', 'place_name': 'Carlyle', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.6066, 'longitude': -89.3805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62245', 'place_name': 'Germantown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.5487, 'longitude': -89.5413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62250', 'place_name': 'Hoffman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.5408, 'longitude': -89.2661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62252', 'place_name': 'Huey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.6018, 'longitude': -89.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62253', 'place_name': 'Keyesport', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.7769, 'longitude': -89.2975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62265', 'place_name': 'New Baden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.5315, 'longitude': -89.6922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62266', 'place_name': 'New Memphis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.4857, 'longitude': -89.6816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62293', 'place_name': 'Trenton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Clinton', 'locality_code': '27', 'latitude': 38.6191, 'longitude': -89.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61912', 'place_name': 'Ashmore', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Coles', 'locality_code': '29', 'latitude': 39.5254, 'longitude': -88.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61920', 'place_name': 'Charleston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Coles', 'locality_code': '29', 'latitude': 39.4869, 'longitude': -88.1761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61931', 'place_name': 'Humboldt', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Coles', 'locality_code': '29', 'latitude': 39.6012, 'longitude': -88.3141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61938', 'place_name': 'Mattoon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Coles', 'locality_code': '29', 'latitude': 39.4802, 'longitude': -88.3762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61943', 'place_name': 'Oakland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Coles', 'locality_code': '29', 'latitude': 39.6516, 'longitude': -88.0253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62440', 'place_name': 'Lerna', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Coles', 'locality_code': '29', 'latitude': 39.3958, 'longitude': -88.253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62469', 'place_name': 'Trilla', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Coles', 'locality_code': '29', 'latitude': 39.3938, 'longitude': -88.3488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60004', 'place_name': 'Arlington Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.112, 'longitude': -87.9792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60005', 'place_name': 'Arlington Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0639, 'longitude': -87.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60006', 'place_name': 'Arlington Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0884, 'longitude': -87.9806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60007', 'place_name': 'Elk Grove Village', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0076, 'longitude': -87.9931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60008', 'place_name': 'Rolling Meadows', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.073, 'longitude': -88.0191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60009', 'place_name': 'Elk Grove Village', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0039, 'longitude': -87.9703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60016', 'place_name': 'Des Plaines', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0467, 'longitude': -87.8859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60017', 'place_name': 'Des Plaines', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0288, 'longitude': -87.8944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60018', 'place_name': 'Des Plaines', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0155, 'longitude': -87.8687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60019', 'place_name': 'Des Plaines', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0243, 'longitude': -87.9071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60022', 'place_name': 'Glencoe', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1333, 'longitude': -87.7615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60025', 'place_name': 'Glenview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0758, 'longitude': -87.8223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60026', 'place_name': 'Glenview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0698, 'longitude': -87.7878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60029', 'place_name': 'Golf', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.058, 'longitude': -87.7916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60038', 'place_name': 'Palatine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.098, 'longitude': -88.0141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60043', 'place_name': 'Kenilworth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0884, 'longitude': -87.7165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60053', 'place_name': 'Morton Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0431, 'longitude': -87.7899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60055', 'place_name': 'Palatine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.098, 'longitude': -88.0141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60056', 'place_name': 'Mount Prospect', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0624, 'longitude': -87.9377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60062', 'place_name': 'Northbrook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1254, 'longitude': -87.8465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60065', 'place_name': 'Northbrook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1275, 'longitude': -87.829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60067', 'place_name': 'Palatine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1139, 'longitude': -88.0429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60068', 'place_name': 'Park Ridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0122, 'longitude': -87.8417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60070', 'place_name': 'Prospect Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1058, 'longitude': -87.9395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60074', 'place_name': 'Palatine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1458, 'longitude': -88.023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60076', 'place_name': 'Skokie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0362, 'longitude': -87.7328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60077', 'place_name': 'Skokie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0345, 'longitude': -87.7541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60078', 'place_name': 'Palatine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1103, 'longitude': -88.0342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60082', 'place_name': 'Techny', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1164, 'longitude': -87.8121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60090', 'place_name': 'Wheeling', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.134, 'longitude': -87.9341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60091', 'place_name': 'Wilmette', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0765, 'longitude': -87.7246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60093', 'place_name': 'Winnetka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1054, 'longitude': -87.7535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60094', 'place_name': 'Palatine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1103, 'longitude': -88.0342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60095', 'place_name': 'Palatine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.1103, 'longitude': -88.0342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60103', 'place_name': 'Bartlett', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9794, 'longitude': -88.2063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60104', 'place_name': 'Bellwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8825, 'longitude': -87.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60107', 'place_name': 'Streamwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0225, 'longitude': -88.169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60130', 'place_name': 'Forest Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8744, 'longitude': -87.8106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60131', 'place_name': 'Franklin Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9339, 'longitude': -87.8734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60141', 'place_name': 'Hines', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8623, 'longitude': -87.8355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60153', 'place_name': 'Maywood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8793, 'longitude': -87.8433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60154', 'place_name': 'Westchester', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8524, 'longitude': -87.8845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60155', 'place_name': 'Broadview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8577, 'longitude': -87.8562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60159', 'place_name': 'Schaumburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0334, 'longitude': -88.0834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60160', 'place_name': 'Melrose Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9003, 'longitude': -87.8581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60161', 'place_name': 'Melrose Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9006, 'longitude': -87.8567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60162', 'place_name': 'Hillside', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8725, 'longitude': -87.9016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60163', 'place_name': 'Berkeley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8888, 'longitude': -87.909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60164', 'place_name': 'Melrose Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9214, 'longitude': -87.8924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60165', 'place_name': 'Stone Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.903, 'longitude': -87.8811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60168', 'place_name': 'Schaumburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0334, 'longitude': -88.0834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60169', 'place_name': 'Hoffman Estates', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0493, 'longitude': -88.1065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60171', 'place_name': 'River Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9279, 'longitude': -87.8387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60173', 'place_name': 'Schaumburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0581, 'longitude': -88.0482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60176', 'place_name': 'Schiller Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9563, 'longitude': -87.8692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60179', 'place_name': 'Hoffman Estates', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0793, 'longitude': -88.2237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60192', 'place_name': 'Hoffman Estates', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0428, 'longitude': -88.0798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60193', 'place_name': 'Schaumburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0144, 'longitude': -88.0935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60194', 'place_name': 'Schaumburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0289, 'longitude': -88.1167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60195', 'place_name': 'Schaumburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0764, 'longitude': -88.1093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60196', 'place_name': 'Schaumburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0564, 'longitude': -88.0725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60201', 'place_name': 'Evanston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0546, 'longitude': -87.6943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60202', 'place_name': 'Evanston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0302, 'longitude': -87.6865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60203', 'place_name': 'Evanston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0485, 'longitude': -87.7176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60204', 'place_name': 'Evanston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0411, 'longitude': -87.6901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60208', 'place_name': 'Evanston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0586, 'longitude': -87.6845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60209', 'place_name': 'Evanston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0497, 'longitude': -87.6794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60301', 'place_name': 'Oak Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8886, 'longitude': -87.7986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60302', 'place_name': 'Oak Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8925, 'longitude': -87.7895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60303', 'place_name': 'Oak Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.885, 'longitude': -87.7845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60304', 'place_name': 'Oak Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8725, 'longitude': -87.7877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60305', 'place_name': 'River Forest', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8951, 'longitude': -87.8159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60402', 'place_name': 'Berwyn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8347, 'longitude': -87.7914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60406', 'place_name': 'Blue Island', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6582, 'longitude': -87.6795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60409', 'place_name': 'Calumet City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6153, 'longitude': -87.5483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60411', 'place_name': 'Chicago Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5087, 'longitude': -87.5904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60412', 'place_name': 'Chicago Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5061, 'longitude': -87.6356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60415', 'place_name': 'Chicago Ridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7017, 'longitude': -87.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60418', 'place_name': 'Crestwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6446, 'longitude': -87.7415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60419', 'place_name': 'Dolton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6257, 'longitude': -87.598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60422', 'place_name': 'Flossmoor', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5406, 'longitude': -87.6837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60425', 'place_name': 'Glenwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5467, 'longitude': -87.6126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60426', 'place_name': 'Harvey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6103, 'longitude': -87.6534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60429', 'place_name': 'Hazel Crest', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5738, 'longitude': -87.6849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60430', 'place_name': 'Homewood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5556, 'longitude': -87.6616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60438', 'place_name': 'Lansing', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.566, 'longitude': -87.5446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60443', 'place_name': 'Matteson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5102, 'longitude': -87.7406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60445', 'place_name': 'Midlothian', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.635, 'longitude': -87.7362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60452', 'place_name': 'Oak Forest', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6077, 'longitude': -87.7542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60453', 'place_name': 'Oak Lawn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7143, 'longitude': -87.7516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60454', 'place_name': 'Oak Lawn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60455', 'place_name': 'Bridgeview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7431, 'longitude': -87.8066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60456', 'place_name': 'Hometown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7311, 'longitude': -87.7315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60457', 'place_name': 'Hickory Hills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7262, 'longitude': -87.8289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60458', 'place_name': 'Justice', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7447, 'longitude': -87.8346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60459', 'place_name': 'Burbank', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7447, 'longitude': -87.7699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60461', 'place_name': 'Olympia Fields', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5134, 'longitude': -87.6742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60462', 'place_name': 'Orland Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6194, 'longitude': -87.8423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60463', 'place_name': 'Palos Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6621, 'longitude': -87.7927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60464', 'place_name': 'Palos Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6624, 'longitude': -87.8521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60465', 'place_name': 'Palos Hills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7004, 'longitude': -87.8263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60466', 'place_name': 'Park Forest', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.479, 'longitude': -87.6828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60467', 'place_name': 'Orland Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6018, 'longitude': -87.8899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60469', 'place_name': 'Posen', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6277, 'longitude': -87.6872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60471', 'place_name': 'Richton Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.4819, 'longitude': -87.7238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60472', 'place_name': 'Robbins', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6423, 'longitude': -87.7089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60473', 'place_name': 'South Holland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5979, 'longitude': -87.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60475', 'place_name': 'Steger', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.4686, 'longitude': -87.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60476', 'place_name': 'Thornton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5727, 'longitude': -87.6078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60477', 'place_name': 'Tinley Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5825, 'longitude': -87.805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60478', 'place_name': 'Country Club Hills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.5637, 'longitude': -87.7247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60480', 'place_name': 'Willow Springs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7364, 'longitude': -87.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60482', 'place_name': 'Worth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6895, 'longitude': -87.7863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60499', 'place_name': 'Bedford Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60501', 'place_name': 'Summit Argo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7801, 'longitude': -87.824, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '60513', 'place_name': 'Brookfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8217, 'longitude': -87.8492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60525', 'place_name': 'La Grange', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7842, 'longitude': -87.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60526', 'place_name': 'La Grange Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8318, 'longitude': -87.874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60534', 'place_name': 'Lyons', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.813, 'longitude': -87.8236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60546', 'place_name': 'Riverside', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8379, 'longitude': -87.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60558', 'place_name': 'Western Springs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8049, 'longitude': -87.8995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60601', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8858, 'longitude': -87.6181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60602', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8829, 'longitude': -87.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60603', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8798, 'longitude': -87.6285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60604', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8785, 'longitude': -87.633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60605', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8713, 'longitude': -87.6277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60606', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8868, 'longitude': -87.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60607', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8721, 'longitude': -87.6578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60608', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8515, 'longitude': -87.6694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60609', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8097, 'longitude': -87.6533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60610', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9033, 'longitude': -87.6336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60611', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8971, 'longitude': -87.6223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60612', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8805, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60613', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9543, 'longitude': -87.6575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60614', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9229, 'longitude': -87.6483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60615', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8022, 'longitude': -87.6006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60616', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8426, 'longitude': -87.6306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60617', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7257, 'longitude': -87.556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60618', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9464, 'longitude': -87.7042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60619', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7458, 'longitude': -87.6054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60620', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7411, 'longitude': -87.6543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60621', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.775, 'longitude': -87.6421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60622', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9019, 'longitude': -87.6779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60623', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.849, 'longitude': -87.7157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60624', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8804, 'longitude': -87.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60625', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9703, 'longitude': -87.7042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60626', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0095, 'longitude': -87.6689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60628', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6934, 'longitude': -87.6243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60629', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7781, 'longitude': -87.7069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60630', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9699, 'longitude': -87.7603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60631', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9951, 'longitude': -87.8082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60632', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8093, 'longitude': -87.7052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60633', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6642, 'longitude': -87.5612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60634', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9463, 'longitude': -87.8061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60636', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.776, 'longitude': -87.6674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60637', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7813, 'longitude': -87.6051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60638', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7814, 'longitude': -87.7705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60639', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9202, 'longitude': -87.7535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60640', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9719, 'longitude': -87.6624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60641', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9453, 'longitude': -87.7474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60642', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9008, 'longitude': -87.6528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60643', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6996, 'longitude': -87.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60644', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8829, 'longitude': -87.7582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60645', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0086, 'longitude': -87.6947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60646', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.993, 'longitude': -87.7596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60647', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9209, 'longitude': -87.7043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60649', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.762, 'longitude': -87.5703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60651', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9025, 'longitude': -87.7393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60652', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.7454, 'longitude': -87.7135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60653', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8196, 'longitude': -87.6126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60654', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8923, 'longitude': -87.6373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60655', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6948, 'longitude': -87.7038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60656', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9735, 'longitude': -87.8658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60657', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9399, 'longitude': -87.6528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60659', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9972, 'longitude': -87.7166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60660', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9909, 'longitude': -87.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60661', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8814, 'longitude': -87.643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60664', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60666', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.85, 'longitude': -87.6501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60668', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60669', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60670', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60673', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60674', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60675', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60677', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60678', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60680', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60681', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60682', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.837, 'longitude': -87.685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60684', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60685', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60686', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8756, 'longitude': -87.6378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60687', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60688', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8724, 'longitude': -87.6688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60689', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8745, 'longitude': -87.6353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60690', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60691', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60693', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.85, 'longitude': -87.6501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60694', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60695', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8839, 'longitude': -87.6317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60696', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8684, 'longitude': -87.6649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60697', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60699', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60701', 'place_name': 'Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8119, 'longitude': -87.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60706', 'place_name': 'Harwood Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9643, 'longitude': -87.8162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60707', 'place_name': 'Elmwood Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.9232, 'longitude': -87.8185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60712', 'place_name': 'Lincolnwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.008, 'longitude': -87.7361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60714', 'place_name': 'Niles', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 42.0312, 'longitude': -87.8112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60803', 'place_name': 'Alsip', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6721, 'longitude': -87.7357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60804', 'place_name': 'Cicero', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.8378, 'longitude': -87.7602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60805', 'place_name': 'Evergreen Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.722, 'longitude': -87.7024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60827', 'place_name': 'Riverdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cook', 'locality_code': '31', 'latitude': 41.6496, 'longitude': -87.6301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62413', 'place_name': 'Annapolis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 39.1179, 'longitude': -87.8029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62427', 'place_name': 'Flat Rock', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 38.9096, 'longitude': -87.6837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62433', 'place_name': 'Hutsonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 39.1064, 'longitude': -87.6695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62449', 'place_name': 'Oblong', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 39.001, 'longitude': -87.895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62451', 'place_name': 'Palestine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 39.0028, 'longitude': -87.6157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62454', 'place_name': 'Robinson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 39.007, 'longitude': -87.7484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62464', 'place_name': 'Stoy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 38.9898, 'longitude': -87.8396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62478', 'place_name': 'West York', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Crawford', 'locality_code': '33', 'latitude': 39.1938, 'longitude': -87.7131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62428', 'place_name': 'Greenup', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 39.274, 'longitude': -88.1246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62435', 'place_name': 'Janesville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 39.3743, 'longitude': -88.2445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62436', 'place_name': 'Jewett', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 39.2076, 'longitude': -88.2474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62447', 'place_name': 'Neoga', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 39.322, 'longitude': -88.4503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62468', 'place_name': 'Toledo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 39.2772, 'longitude': -88.2468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60111', 'place_name': 'Clare', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 42.0086, 'longitude': -88.8306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60112', 'place_name': 'Cortland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.92, 'longitude': -88.6887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60115', 'place_name': 'Dekalb', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.9008, 'longitude': -88.7548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60129', 'place_name': 'Esmond', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 42.0225, 'longitude': -88.9439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60135', 'place_name': 'Genoa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 42.0981, 'longitude': -88.6908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60145', 'place_name': 'Kingston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 42.1057, 'longitude': -88.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60146', 'place_name': 'Kirkland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 42.1014, 'longitude': -88.8685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60150', 'place_name': 'Malta', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.9183, 'longitude': -88.8688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60178', 'place_name': 'Sycamore', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.9911, 'longitude': -88.6928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60520', 'place_name': 'Hinckley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.7691, 'longitude': -88.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60548', 'place_name': 'Sandwich', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.6353, 'longitude': -88.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60550', 'place_name': 'Shabbona', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.7638, 'longitude': -88.8752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60552', 'place_name': 'Somonauk', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.6383, 'longitude': -88.6816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60556', 'place_name': 'Waterman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DeKalb', 'locality_code': '37', 'latitude': 41.7504, 'longitude': -88.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61727', 'place_name': 'Clinton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.1487, 'longitude': -88.9627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61735', 'place_name': 'Dewitt', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.1848, 'longitude': -88.7637, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '61749', 'place_name': 'Kenney', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.0967, 'longitude': -89.0859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61750', 'place_name': 'Lane', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.1235, 'longitude': -88.8597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61777', 'place_name': 'Wapella', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.2323, 'longitude': -88.9673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61778', 'place_name': 'Waynesville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.2437, 'longitude': -89.1143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61842', 'place_name': 'Farmer City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.2447, 'longitude': -88.6634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61882', 'place_name': 'Weldon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'De Witt', 'locality_code': '39', 'latitude': 40.1177, 'longitude': -88.7531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61910', 'place_name': 'Arcola', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.687, 'longitude': -88.3037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61911', 'place_name': 'Arthur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.7077, 'longitude': -88.4555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61913', 'place_name': 'Atwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.8044, 'longitude': -88.4494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61919', 'place_name': 'Camargo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.8, 'longitude': -88.1468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61930', 'place_name': 'Hindsboro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.7018, 'longitude': -88.1486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61941', 'place_name': 'Murdock', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.8009, 'longitude': -88.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61942', 'place_name': 'Newman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.7848, 'longitude': -88.0001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61953', 'place_name': 'Tuscola', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.7995, 'longitude': -88.2816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61956', 'place_name': 'Villa Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Douglas', 'locality_code': '41', 'latitude': 39.8687, 'longitude': -88.1616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60101', 'place_name': 'Addison', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9335, 'longitude': -88.0054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60105', 'place_name': 'Bensenville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.955, 'longitude': -87.9401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60106', 'place_name': 'Bensenville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9501, 'longitude': -87.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60108', 'place_name': 'Bloomingdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9483, 'longitude': -88.0782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60116', 'place_name': 'Carol Stream', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9125, 'longitude': -88.1348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60117', 'place_name': 'Bloomingdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60126', 'place_name': 'Elmhurst', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8927, 'longitude': -87.941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60128', 'place_name': 'Carol Stream', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60132', 'place_name': 'Carol Stream', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60133', 'place_name': 'Hanover Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9995, 'longitude': -88.1451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60137', 'place_name': 'Glen Ellyn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8661, 'longitude': -88.0648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60138', 'place_name': 'Glen Ellyn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8775, 'longitude': -88.067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60139', 'place_name': 'Glendale Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9205, 'longitude': -88.0793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60143', 'place_name': 'Itasca', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.972, 'longitude': -88.0202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60148', 'place_name': 'Lombard', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8721, 'longitude': -88.016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60157', 'place_name': 'Medinah', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9814, 'longitude': -88.0512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60172', 'place_name': 'Roselle', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9798, 'longitude': -88.0857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60181', 'place_name': 'Villa Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8799, 'longitude': -87.9782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60184', 'place_name': 'Wayne', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9525, 'longitude': -88.2536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60185', 'place_name': 'West Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8886, 'longitude': -88.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60186', 'place_name': 'West Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8848, 'longitude': -88.204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60187', 'place_name': 'Wheaton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8724, 'longitude': -88.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60188', 'place_name': 'Carol Stream', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9178, 'longitude': -88.137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60189', 'place_name': 'Wheaton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60190', 'place_name': 'Winfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8744, 'longitude': -88.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60191', 'place_name': 'Wood Dale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9602, 'longitude': -87.981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60197', 'place_name': 'Carol Stream', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9125, 'longitude': -88.1348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60199', 'place_name': 'Carol Stream', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60399', 'place_name': 'Wood Dale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.9545, 'longitude': -87.9377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60439', 'place_name': 'Lemont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7074, 'longitude': -87.9756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60504', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7523, 'longitude': -88.2453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60514', 'place_name': 'Clarendon Hills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7965, 'longitude': -87.9569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60515', 'place_name': 'Downers Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8034, 'longitude': -88.0138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60516', 'place_name': 'Downers Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7602, 'longitude': -88.0159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60517', 'place_name': 'Woodridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7518, 'longitude': -88.0489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60519', 'place_name': 'Eola', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7775, 'longitude': -88.2428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60521', 'place_name': 'Hinsdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8001, 'longitude': -87.9287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60522', 'place_name': 'Hinsdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60523', 'place_name': 'Oak Brook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8371, 'longitude': -87.9638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60527', 'place_name': 'Willowbrook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7447, 'longitude': -87.9334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60532', 'place_name': 'Lisle', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7862, 'longitude': -88.0879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60540', 'place_name': 'Naperville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7662, 'longitude': -88.141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60555', 'place_name': 'Warrenville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.828, 'longitude': -88.1921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60559', 'place_name': 'Westmont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7728, 'longitude': -87.9757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60561', 'place_name': 'Darien', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7434, 'longitude': -87.9805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60563', 'place_name': 'Naperville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7895, 'longitude': -88.169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60565', 'place_name': 'Naperville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7328, 'longitude': -88.1282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60566', 'place_name': 'Naperville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60567', 'place_name': 'Naperville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7859, 'longitude': -88.1473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60569', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8122, 'longitude': -88.2172, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '60572', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.7606, 'longitude': -88.3201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60598', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60599', 'place_name': 'Fox Valley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'DuPage', 'locality_code': '43', 'latitude': 41.8397, 'longitude': -88.0887, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '61917', 'place_name': 'Brocton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.6923, 'longitude': -87.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61924', 'place_name': 'Chrisman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.7996, 'longitude': -87.6556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61932', 'place_name': 'Hume', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.8009, 'longitude': -87.8747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61933', 'place_name': 'Kansas', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.5525, 'longitude': -87.9352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61940', 'place_name': 'Metcalf', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.8008, 'longitude': -87.7955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61944', 'place_name': 'Paris', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.6132, 'longitude': -87.6976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61949', 'place_name': 'Redmon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.6453, 'longitude': -87.8617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61955', 'place_name': 'Vermilion', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edgar', 'locality_code': '45', 'latitude': 39.5811, 'longitude': -87.5889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62476', 'place_name': 'West Salem', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edwards', 'locality_code': '47', 'latitude': 38.5209, 'longitude': -88.0048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62806', 'place_name': 'Albion', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edwards', 'locality_code': '47', 'latitude': 38.374, 'longitude': -88.0636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62815', 'place_name': 'Bone Gap', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edwards', 'locality_code': '47', 'latitude': 38.449, 'longitude': -88.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62818', 'place_name': 'Browns', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edwards', 'locality_code': '47', 'latitude': 38.3764, 'longitude': -87.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62833', 'place_name': 'Ellery', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Edwards', 'locality_code': '47', 'latitude': 38.365, 'longitude': -88.1335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62401', 'place_name': 'Effingham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 39.1217, 'longitude': -88.5611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62411', 'place_name': 'Altamont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 39.0634, 'longitude': -88.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62414', 'place_name': 'Beecher City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 39.1835, 'longitude': -88.8038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62424', 'place_name': 'Dieterich', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 39.0319, 'longitude': -88.4074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62426', 'place_name': 'Edgewood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 38.9021, 'longitude': -88.6645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62443', 'place_name': 'Mason', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 38.9645, 'longitude': -88.6234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62445', 'place_name': 'Montrose', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 39.1573, 'longitude': -88.335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62461', 'place_name': 'Shumway', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 39.1881, 'longitude': -88.6418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62467', 'place_name': 'Teutopolis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 39.132, 'longitude': -88.4767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62473', 'place_name': 'Watson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Effingham', 'locality_code': '49', 'latitude': 38.9906, 'longitude': -88.5584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62011', 'place_name': 'Bingham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.1128, 'longitude': -89.2125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62080', 'place_name': 'Ramsey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.1445, 'longitude': -89.1087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62247', 'place_name': 'Hagarstown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 38.9434, 'longitude': -89.1684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62418', 'place_name': 'Brownstown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 38.9891, 'longitude': -88.9494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62458', 'place_name': 'Saint Elmo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.0315, 'longitude': -88.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62471', 'place_name': 'Vandalia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 38.9439, 'longitude': -89.1041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62838', 'place_name': 'Farina', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 38.8469, 'longitude': -88.7614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62880', 'place_name': 'Saint Peter', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 38.8697, 'longitude': -88.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62885', 'place_name': 'Shobonier', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fayette', 'locality_code': '51', 'latitude': 38.8446, 'longitude': -89.079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60919', 'place_name': 'Cabery', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.9819, 'longitude': -88.1921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60933', 'place_name': 'Elliott', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.4648, 'longitude': -88.2712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60936', 'place_name': 'Gibson City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.4659, 'longitude': -88.3609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60946', 'place_name': 'Kempton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.9126, 'longitude': -88.209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60952', 'place_name': 'Melvin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.5714, 'longitude': -88.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60957', 'place_name': 'Paxton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.4565, 'longitude': -88.099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60959', 'place_name': 'Piper City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.7556, 'longitude': -88.1873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60962', 'place_name': 'Roberts', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.6193, 'longitude': -88.1804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61773', 'place_name': 'Sibley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ford', 'locality_code': '53', 'latitude': 40.5823, 'longitude': -88.3815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62812', 'place_name': 'Benton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 38, 'longitude': -88.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62819', 'place_name': 'Buckner', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.9764, 'longitude': -89.0209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62822', 'place_name': 'Christopher', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.9849, 'longitude': -89.0574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62825', 'place_name': 'Coello', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.9946, 'longitude': -89.0672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62836', 'place_name': 'Ewing', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 38.0702, 'longitude': -88.8504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62840', 'place_name': 'Frankfort Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.9943, 'longitude': -88.9417, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62856', 'place_name': 'Logan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.9559, 'longitude': -88.8403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62865', 'place_name': 'Mulkeytown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.9687, 'longitude': -89.1159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62874', 'place_name': 'Orient', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.9182, 'longitude': -88.9767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62884', 'place_name': 'Sesser', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 38.0894, 'longitude': -89.0574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62890', 'place_name': 'Thompsonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.8804, 'longitude': -88.7684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62891', 'place_name': 'Valier', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 38.0222, 'longitude': -89.0351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62896', 'place_name': 'West Frankfort', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.8979, 'longitude': -88.9307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62897', 'place_name': 'Whittington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 38.0872, 'longitude': -88.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62983', 'place_name': 'Royalton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.879, 'longitude': -89.1141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62999', 'place_name': 'Zeigler', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Franklin', 'locality_code': '55', 'latitude': 37.8991, 'longitude': -89.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61415', 'place_name': 'Avon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.6549, 'longitude': -90.4461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61427', 'place_name': 'Cuba', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.4995, 'longitude': -90.1811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61431', 'place_name': 'Ellisville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.6047, 'longitude': -90.2875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61432', 'place_name': 'Fairview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.6442, 'longitude': -90.1653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61433', 'place_name': 'Fiatt', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.5603, 'longitude': -90.1798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61441', 'place_name': 'Ipava', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.3594, 'longitude': -90.2967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61459', 'place_name': 'Marietta', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.4978, 'longitude': -90.3885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61477', 'place_name': 'Smithfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.4855, 'longitude': -90.2856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61482', 'place_name': 'Table Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.3784, 'longitude': -90.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61484', 'place_name': 'Vermont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.3062, 'longitude': -90.422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61501', 'place_name': 'Astoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.2311, 'longitude': -90.3443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61519', 'place_name': 'Bryant', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.4663, 'longitude': -90.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61520', 'place_name': 'Canton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.5601, 'longitude': -90.0242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61524', 'place_name': 'Dunfermline', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.4912, 'longitude': -90.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61531', 'place_name': 'Farmington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.6832, 'longitude': -90.035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61542', 'place_name': 'Lewistown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.383, 'longitude': -90.1563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61543', 'place_name': 'Liverpool', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.3902, 'longitude': -90.0026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61544', 'place_name': 'London Mills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.695, 'longitude': -90.2616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61553', 'place_name': 'Norris', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.6259, 'longitude': -90.0323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61563', 'place_name': 'Saint David', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.4912, 'longitude': -90.0505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62867', 'place_name': 'New Haven', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Gallatin', 'locality_code': '59', 'latitude': 37.8999, 'longitude': -88.1285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62871', 'place_name': 'Omaha', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Gallatin', 'locality_code': '59', 'latitude': 37.8904, 'longitude': -88.2865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62934', 'place_name': 'Equality', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Gallatin', 'locality_code': '59', 'latitude': 37.7278, 'longitude': -88.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62954', 'place_name': 'Junction', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Gallatin', 'locality_code': '59', 'latitude': 37.6952, 'longitude': -88.2491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62979', 'place_name': 'Ridgway', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Gallatin', 'locality_code': '59', 'latitude': 37.8042, 'longitude': -88.2612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62984', 'place_name': 'Shawneetown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Gallatin', 'locality_code': '59', 'latitude': 37.7132, 'longitude': -88.1785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62016', 'place_name': 'Carrollton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.3009, 'longitude': -90.4092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62027', 'place_name': 'Eldred', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.2836, 'longitude': -90.5329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62044', 'place_name': 'Greenfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.3491, 'longitude': -90.2089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62050', 'place_name': 'Hillview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.4674, 'longitude': -90.5128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62054', 'place_name': 'Kane', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.2037, 'longitude': -90.3719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62078', 'place_name': 'Patterson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.4806, 'longitude': -90.4829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62081', 'place_name': 'Rockbridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.2831, 'longitude': -90.2558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62082', 'place_name': 'Roodhouse', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.4846, 'longitude': -90.3498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62092', 'place_name': 'White Hall', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.4288, 'longitude': -90.4019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62098', 'place_name': 'Wrights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Greene', 'locality_code': '61', 'latitude': 39.3762, 'longitude': -90.2933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60407', 'place_name': 'Braceville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.2288, 'longitude': -88.269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60416', 'place_name': 'Coal City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.2908, 'longitude': -88.2823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60424', 'place_name': 'Gardner', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.1775, 'longitude': -88.338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60437', 'place_name': 'Kinsman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.1631, 'longitude': -88.5535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60444', 'place_name': 'Mazon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.2264, 'longitude': -88.4217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60447', 'place_name': 'Minooka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.4615, 'longitude': -88.2786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60450', 'place_name': 'Morris', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.3672, 'longitude': -88.4178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60474', 'place_name': 'South Wilmington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.1728, 'longitude': -88.2767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60479', 'place_name': 'Verona', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Grundy', 'locality_code': '63', 'latitude': 41.2501, 'longitude': -88.517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62817', 'place_name': 'Broughton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 37.9546, 'longitude': -88.4678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62828', 'place_name': 'Dahlgren', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 38.1975, 'longitude': -88.6363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62829', 'place_name': 'Dale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 37.995, 'longitude': -88.4917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62859', 'place_name': 'Mc Leansboro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 38.0939, 'longitude': -88.5286, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62860', 'place_name': 'Macedonia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 38.013, 'longitude': -88.6961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61450', 'place_name': 'La Harpe', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.5846, 'longitude': -90.9687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62311', 'place_name': 'Augusta', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.2341, 'longitude': -90.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62313', 'place_name': 'Basco', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.3283, 'longitude': -91.197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62316', 'place_name': 'Bowen', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.2341, 'longitude': -91.0705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62321', 'place_name': 'Carthage', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.4129, 'longitude': -91.1005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62329', 'place_name': 'Colusa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.5714, 'longitude': -91.1682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62330', 'place_name': 'Dallas City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.572, 'longitude': -91.1255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62334', 'place_name': 'Elvaston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.395, 'longitude': -91.2496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62336', 'place_name': 'Ferris', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.4689, 'longitude': -91.1704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62341', 'place_name': 'Hamilton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.3964, 'longitude': -91.339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62354', 'place_name': 'Nauvoo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.5261, 'longitude': -91.3318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62358', 'place_name': 'Niota', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.5978, 'longitude': -91.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62367', 'place_name': 'Plymouth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.3236, 'longitude': -90.9672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62373', 'place_name': 'Sutter', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.2865, 'longitude': -91.3726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62379', 'place_name': 'Warsaw', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.3544, 'longitude': -91.4348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62380', 'place_name': 'West Point', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hancock', 'locality_code': '67', 'latitude': 40.255, 'longitude': -91.1826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62919', 'place_name': 'Cave In Rock', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hardin', 'locality_code': '69', 'latitude': 37.4692, 'longitude': -88.1653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62931', 'place_name': 'Elizabethtown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hardin', 'locality_code': '69', 'latitude': 37.4665, 'longitude': -88.2867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62955', 'place_name': 'Karbers Ridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hardin', 'locality_code': '69', 'latitude': 37.5008, 'longitude': -88.2383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62982', 'place_name': 'Rosiclare', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Hardin', 'locality_code': '69', 'latitude': 37.424, 'longitude': -88.3462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61418', 'place_name': 'Biggsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.8531, 'longitude': -90.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61425', 'place_name': 'Carman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.7551, 'longitude': -91.0564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61437', 'place_name': 'Gladstone', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.8377, 'longitude': -90.9941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61454', 'place_name': 'Lomax', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.6761, 'longitude': -91.0391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61460', 'place_name': 'Media', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.7618, 'longitude': -90.857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61469', 'place_name': 'Oquawka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.9442, 'longitude': -90.9302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61471', 'place_name': 'Raritan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.6959, 'longitude': -90.8274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61480', 'place_name': 'Stronghurst', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henderson', 'locality_code': '71', 'latitude': 40.7523, 'longitude': -90.9257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61233', 'place_name': 'Andover', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.2954, 'longitude': -90.2905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61234', 'place_name': 'Annawan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.398, 'longitude': -89.9129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61235', 'place_name': 'Atkinson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.4162, 'longitude': -90.0225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61238', 'place_name': 'Cambridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.3114, 'longitude': -90.1805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61241', 'place_name': 'Colona', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.4885, 'longitude': -90.321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61254', 'place_name': 'Geneseo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.4688, 'longitude': -90.1711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61258', 'place_name': 'Hooppole', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.522, 'longitude': -89.9122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61262', 'place_name': 'Lynn Center', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.2888, 'longitude': -90.3304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61273', 'place_name': 'Orion', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.3634, 'longitude': -90.3849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61274', 'place_name': 'Osco', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.3637, 'longitude': -90.2681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61413', 'place_name': 'Alpha', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.193, 'longitude': -90.3821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61419', 'place_name': 'Bishop Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.1977, 'longitude': -90.1183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61434', 'place_name': 'Galva', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.1656, 'longitude': -90.0481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61443', 'place_name': 'Kewanee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.2411, 'longitude': -89.9274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61468', 'place_name': 'Ophiem', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.2525, 'longitude': -90.3876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61490', 'place_name': 'Woodhull', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Henry', 'locality_code': '73', 'latitude': 41.1849, 'longitude': -90.2833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60911', 'place_name': 'Ashkum', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.8844, 'longitude': -87.9411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60912', 'place_name': 'Beaverville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.9672, 'longitude': -87.6217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60918', 'place_name': 'Buckley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.6018, 'longitude': -88.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60922', 'place_name': 'Chebanse', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 41.0254, 'longitude': -87.8959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60924', 'place_name': 'Cissna Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.5858, 'longitude': -87.8759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60926', 'place_name': 'Claytonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.5676, 'longitude': -87.804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60927', 'place_name': 'Clifton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.9394, 'longitude': -87.9202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60928', 'place_name': 'Crescent City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.7417, 'longitude': -87.849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60930', 'place_name': 'Danforth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.8244, 'longitude': -87.9868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60931', 'place_name': 'Donovan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.8891, 'longitude': -87.6046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60938', 'place_name': 'Gilman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.768, 'longitude': -87.9933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60939', 'place_name': 'Goodwine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.5673, 'longitude': -87.7845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60945', 'place_name': 'Iroquois', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.8269, 'longitude': -87.5847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60948', 'place_name': 'Loda', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.5241, 'longitude': -88.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60951', 'place_name': 'Martinton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.9052, 'longitude': -87.7443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60953', 'place_name': 'Milford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.6293, 'longitude': -87.6853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60955', 'place_name': 'Onarga', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.712, 'longitude': -87.9958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60956', 'place_name': 'Papineau', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.967, 'longitude': -87.7161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60966', 'place_name': 'Sheldon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.7803, 'longitude': -87.5736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60967', 'place_name': 'Stockland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.6145, 'longitude': -87.5928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60968', 'place_name': 'Thawville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.684, 'longitude': -88.0999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60970', 'place_name': 'Watseka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.7734, 'longitude': -87.7309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60973', 'place_name': 'Wellington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.5339, 'longitude': -87.6561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60974', 'place_name': 'Woodland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Iroquois', 'locality_code': '75', 'latitude': 40.7151, 'longitude': -87.7307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62901', 'place_name': 'Carbondale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.72, 'longitude': -89.2158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62902', 'place_name': 'Carbondale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.6636, 'longitude': -89.1173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62903', 'place_name': 'Carbondale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.6704, 'longitude': -89.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62907', 'place_name': 'Ava', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.8793, 'longitude': -89.4654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62916', 'place_name': 'Campbell Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.9228, 'longitude': -89.5799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62924', 'place_name': 'De Soto', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.8147, 'longitude': -89.2218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62927', 'place_name': 'Dowell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.9398, 'longitude': -89.2379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62932', 'place_name': 'Elkville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.9155, 'longitude': -89.2336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62940', 'place_name': 'Gorham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.7406, 'longitude': -89.444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62942', 'place_name': 'Grand Tower', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.6322, 'longitude': -89.4999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62950', 'place_name': 'Jacob', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.7437, 'longitude': -89.5444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62958', 'place_name': 'Makanda', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.6176, 'longitude': -89.209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62966', 'place_name': 'Murphysboro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.7655, 'longitude': -89.3317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62971', 'place_name': 'Oraville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.8651, 'longitude': -89.3834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62975', 'place_name': 'Pomona', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.6501, 'longitude': -89.3693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62994', 'place_name': 'Vergennes', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jackson', 'locality_code': '77', 'latitude': 37.9051, 'longitude': -89.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62432', 'place_name': 'Hidalgo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jasper', 'locality_code': '79', 'latitude': 39.1228, 'longitude': -88.1397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62448', 'place_name': 'Newton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jasper', 'locality_code': '79', 'latitude': 38.9847, 'longitude': -88.1704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62459', 'place_name': 'Sainte Marie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jasper', 'locality_code': '79', 'latitude': 38.928, 'longitude': -88.0291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62475', 'place_name': 'West Liberty', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jasper', 'locality_code': '79', 'latitude': 38.895, 'longitude': -88.0979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62479', 'place_name': 'Wheeler', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jasper', 'locality_code': '79', 'latitude': 39.0182, 'longitude': -88.3175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62480', 'place_name': 'Willow Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jasper', 'locality_code': '79', 'latitude': 38.9757, 'longitude': -88.0172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62481', 'place_name': 'Yale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jasper', 'locality_code': '79', 'latitude': 39.13, 'longitude': -88.0105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62810', 'place_name': 'Belle Rive', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.2153, 'longitude': -88.7558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62814', 'place_name': 'Bluford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.3531, 'longitude': -88.7587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62816', 'place_name': 'Bonnie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.198, 'longitude': -88.9229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62830', 'place_name': 'Dix', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.4333, 'longitude': -88.9657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62846', 'place_name': 'Ina', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.1527, 'longitude': -88.8894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62864', 'place_name': 'Mount Vernon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.317, 'longitude': -88.9105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62866', 'place_name': 'Nason', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.1654, 'longitude': -88.9676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62872', 'place_name': 'Opdyke', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.275, 'longitude': -88.775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62883', 'place_name': 'Scheller', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.1731, 'longitude': -89.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62889', 'place_name': 'Texico', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.425, 'longitude': -88.8702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62894', 'place_name': 'Waltonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.2089, 'longitude': -89.039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62898', 'place_name': 'Woodlawn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 38.3844, 'longitude': -89.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62012', 'place_name': 'Brighton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 39.0361, 'longitude': -90.1443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62022', 'place_name': 'Dow', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 39.0312, 'longitude': -90.3011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62028', 'place_name': 'Elsah', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 38.9594, 'longitude': -90.3541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62030', 'place_name': 'Fidelity', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 39.1546, 'longitude': -90.1642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62031', 'place_name': 'Fieldon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 39.1086, 'longitude': -90.5297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62037', 'place_name': 'Grafton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 39.0021, 'longitude': -90.4323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62052', 'place_name': 'Jerseyville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 39.1213, 'longitude': -90.3338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62063', 'place_name': 'Medora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jersey', 'locality_code': '83', 'latitude': 39.1986, 'longitude': -90.1542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61001', 'place_name': 'Apple River', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.4714, 'longitude': -90.1201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61025', 'place_name': 'East Dubuque', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.4875, 'longitude': -90.6046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61028', 'place_name': 'Elizabeth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.3089, 'longitude': -90.1986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61036', 'place_name': 'Galena', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.4182, 'longitude': -90.4195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61041', 'place_name': 'Hanover', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.2594, 'longitude': -90.2897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61059', 'place_name': 'Nora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.4558, 'longitude': -89.9454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61075', 'place_name': 'Scales Mound', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.4715, 'longitude': -90.258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61085', 'place_name': 'Stockton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.3492, 'longitude': -90.0202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61087', 'place_name': 'Warren', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Jo Daviess', 'locality_code': '85', 'latitude': 42.489, 'longitude': -89.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62908', 'place_name': 'Belknap', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.3266, 'longitude': -88.9507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62909', 'place_name': 'Boles', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.4472, 'longitude': -88.8768, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62912', 'place_name': 'Buncombe', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.4637, 'longitude': -88.9806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62923', 'place_name': 'Cypress', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.365, 'longitude': -88.9747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62939', 'place_name': 'Goreville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.575, 'longitude': -88.9655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62943', 'place_name': 'Grantsburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.3794, 'longitude': -88.7583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62967', 'place_name': 'New Burnside', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.578, 'longitude': -88.7454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62972', 'place_name': 'Ozark', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.5367, 'longitude': -88.7688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62985', 'place_name': 'Simpson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.4673, 'longitude': -88.7551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62995', 'place_name': 'Vienna', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Johnson', 'locality_code': '87', 'latitude': 37.4205, 'longitude': -88.8879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60109', 'place_name': 'Burlington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0458, 'longitude': -88.539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60110', 'place_name': 'Carpentersville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.123, 'longitude': -88.2606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60118', 'place_name': 'Dundee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0962, 'longitude': -88.2902, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '60119', 'place_name': 'Elburn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.8824, 'longitude': -88.4611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60120', 'place_name': 'Elgin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0384, 'longitude': -88.2606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60121', 'place_name': 'Elgin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0372, 'longitude': -88.2812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60122', 'place_name': 'Elgin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0671, 'longitude': -88.305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60123', 'place_name': 'Elgin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0376, 'longitude': -88.3186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60124', 'place_name': 'Elgin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0293, 'longitude': -88.3747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60134', 'place_name': 'Geneva', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.886, 'longitude': -88.311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60136', 'place_name': 'Gilberts', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0984, 'longitude': -88.3691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60140', 'place_name': 'Hampshire', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 42.0807, 'longitude': -88.517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60144', 'place_name': 'Kaneville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.8353, 'longitude': -88.522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60147', 'place_name': 'Lafox', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.937, 'longitude': -88.4202, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '60151', 'place_name': 'Maple Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.9232, 'longitude': -88.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60174', 'place_name': 'Saint Charles', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.9194, 'longitude': -88.307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60175', 'place_name': 'Saint Charles', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.9478, 'longitude': -88.3918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60177', 'place_name': 'South Elgin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.9969, 'longitude': -88.2986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60183', 'place_name': 'Wasco', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.937, 'longitude': -88.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60502', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.7845, 'longitude': -88.2616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60505', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.7582, 'longitude': -88.2971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60506', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.7664, 'longitude': -88.3446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60507', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.7606, 'longitude': -88.3201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60510', 'place_name': 'Batavia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.8482, 'longitude': -88.3098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60511', 'place_name': 'Big Rock', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.7593, 'longitude': -88.5376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60539', 'place_name': 'Mooseheart', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.8241, 'longitude': -88.3315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60542', 'place_name': 'North Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.8089, 'longitude': -88.3274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60554', 'place_name': 'Sugar Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.7741, 'longitude': -88.4397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60568', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kane', 'locality_code': '89', 'latitude': 41.7606, 'longitude': -88.3201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60901', 'place_name': 'Kankakee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1166, 'longitude': -87.8696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60910', 'place_name': 'Aroma Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.0798, 'longitude': -87.8114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60913', 'place_name': 'Bonfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1573, 'longitude': -88.0619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60914', 'place_name': 'Bourbonnais', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1661, 'longitude': -87.879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60915', 'place_name': 'Bradley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1454, 'longitude': -87.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60917', 'place_name': 'Buckingham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.0433, 'longitude': -88.1772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60935', 'place_name': 'Essex', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1676, 'longitude': -88.1845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60940', 'place_name': 'Grant Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.2477, 'longitude': -87.648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60941', 'place_name': 'Herscher', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.0464, 'longitude': -88.0858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60944', 'place_name': 'Hopkins Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.0634, 'longitude': -87.625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60950', 'place_name': 'Manteno', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.2514, 'longitude': -87.8468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60954', 'place_name': 'Momence', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1593, 'longitude': -87.6575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60958', 'place_name': 'Pembroke Township', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.0646, 'longitude': -87.5917, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '60961', 'place_name': 'Reddick', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1005, 'longitude': -88.2089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60964', 'place_name': 'Saint Anne', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.0487, 'longitude': -87.6564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60969', 'place_name': 'Union Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kankakee', 'locality_code': '91', 'latitude': 41.1088, 'longitude': -88.1465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60512', 'place_name': 'Bristol', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.7016, 'longitude': -88.4398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60536', 'place_name': 'Millbrook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.5984, 'longitude': -88.5529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60537', 'place_name': 'Millington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.5614, 'longitude': -88.5975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60538', 'place_name': 'Montgomery', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.7177, 'longitude': -88.332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60541', 'place_name': 'Newark', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.5267, 'longitude': -88.527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60543', 'place_name': 'Oswego', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.6849, 'longitude': -88.3453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60545', 'place_name': 'Plano', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.667, 'longitude': -88.5384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60560', 'place_name': 'Yorkville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Kendall', 'locality_code': '93', 'latitude': 41.6387, 'longitude': -88.4438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61401', 'place_name': 'Galesburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.9521, 'longitude': -90.3698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61402', 'place_name': 'Galesburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.9478, 'longitude': -90.3712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61410', 'place_name': 'Abingdon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.8023, 'longitude': -90.4009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61414', 'place_name': 'Altona', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 41.1128, 'longitude': -90.1598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61428', 'place_name': 'Dahinda', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.9551, 'longitude': -90.1398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61430', 'place_name': 'East Galesburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.9402, 'longitude': -90.3109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61436', 'place_name': 'Gilson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.8765, 'longitude': -90.1747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61439', 'place_name': 'Henderson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 41.0276, 'longitude': -90.3575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61448', 'place_name': 'Knoxville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.9107, 'longitude': -90.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61458', 'place_name': 'Maquon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.7849, 'longitude': -90.2008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61467', 'place_name': 'Oneida', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 41.0832, 'longitude': -90.2391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61472', 'place_name': 'Rio', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 41.1103, 'longitude': -90.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61474', 'place_name': 'Saint Augustine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.7289, 'longitude': -90.3798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61485', 'place_name': 'Victoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 41.0256, 'longitude': -90.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61488', 'place_name': 'Wataga', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 41.0224, 'longitude': -90.2723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61489', 'place_name': 'Williamsfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.9277, 'longitude': -90.0267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61572', 'place_name': 'Yates City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Knox', 'locality_code': '95', 'latitude': 40.7878, 'longitude': -90.0265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60002', 'place_name': 'Antioch', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.4648, 'longitude': -88.1178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60010', 'place_name': 'Barrington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.1614, 'longitude': -88.1383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60011', 'place_name': 'Barrington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3228, 'longitude': -87.6101, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '60015', 'place_name': 'Deerfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.1705, 'longitude': -87.859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60020', 'place_name': 'Fox Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3937, 'longitude': -88.1648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60030', 'place_name': 'Grayslake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3524, 'longitude': -88.0545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60031', 'place_name': 'Gurnee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3669, 'longitude': -87.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60035', 'place_name': 'Highland Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.1794, 'longitude': -87.8059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60037', 'place_name': 'Fort Sheridan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2097, 'longitude': -87.8056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60040', 'place_name': 'Highwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2035, 'longitude': -87.8141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60041', 'place_name': 'Ingleside', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3631, 'longitude': -88.1587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60042', 'place_name': 'Island Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2742, 'longitude': -88.1926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60044', 'place_name': 'Lake Bluff', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.282, 'longitude': -87.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60045', 'place_name': 'Lake Forest', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2374, 'longitude': -87.8482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60046', 'place_name': 'Lake Villa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3813, 'longitude': -87.9991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60047', 'place_name': 'Lake Zurich', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2165, 'longitude': -88.0769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60048', 'place_name': 'Libertyville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.281, 'longitude': -87.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60060', 'place_name': 'Mundelein', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2636, 'longitude': -88.0048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60061', 'place_name': 'Vernon Hills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2288, 'longitude': -87.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60064', 'place_name': 'North Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3247, 'longitude': -87.8564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60069', 'place_name': 'Lincolnshire', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.1976, 'longitude': -87.9261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60073', 'place_name': 'Round Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3668, 'longitude': -88.0888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60075', 'place_name': 'Russell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.4906, 'longitude': -87.9126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60079', 'place_name': 'Waukegan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3636, 'longitude': -87.8448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60083', 'place_name': 'Wadsworth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.446, 'longitude': -87.904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60084', 'place_name': 'Wauconda', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.2636, 'longitude': -88.1333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60085', 'place_name': 'Waukegan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3542, 'longitude': -87.8651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60086', 'place_name': 'North Chicago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.4333, 'longitude': -87.7766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60087', 'place_name': 'Waukegan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3989, 'longitude': -87.8554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60088', 'place_name': 'Great Lakes', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.3032, 'longitude': -87.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60089', 'place_name': 'Buffalo Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.1598, 'longitude': -87.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60096', 'place_name': 'Winthrop Harbor', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.4793, 'longitude': -87.8318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60099', 'place_name': 'Zion', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lake', 'locality_code': '97', 'latitude': 42.4442, 'longitude': -87.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60470', 'place_name': 'Ransom', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.153, 'longitude': -88.6502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60518', 'place_name': 'Earlville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.5859, 'longitude': -88.9103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60531', 'place_name': 'Leland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.6066, 'longitude': -88.7716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60549', 'place_name': 'Serena', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.4995, 'longitude': -88.7509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60551', 'place_name': 'Sheridan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.5164, 'longitude': -88.6706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60557', 'place_name': 'Wedron', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.4409, 'longitude': -88.7703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61301', 'place_name': 'La Salle', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.3442, 'longitude': -89.0955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61316', 'place_name': 'Cedar Point', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.2617, 'longitude': -89.1237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61321', 'place_name': 'Dana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 40.9547, 'longitude': -88.9628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61325', 'place_name': 'Grand Ridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.2386, 'longitude': -88.8168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61332', 'place_name': 'Leonore', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.1895, 'longitude': -88.9806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61334', 'place_name': 'Lostant', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.145, 'longitude': -89.075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61341', 'place_name': 'Marseilles', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.3302, 'longitude': -88.6947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61342', 'place_name': 'Mendota', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.5443, 'longitude': -89.1083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61348', 'place_name': 'Oglesby', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.2928, 'longitude': -89.0553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61350', 'place_name': 'Ottawa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.3526, 'longitude': -88.8416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61354', 'place_name': 'Peru', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.333, 'longitude': -89.1265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61358', 'place_name': 'Rutland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 40.9844, 'longitude': -89.0388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61360', 'place_name': 'Seneca', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.3152, 'longitude': -88.61, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61364', 'place_name': 'Streator', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.1225, 'longitude': -88.8307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61370', 'place_name': 'Tonica', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.2327, 'longitude': -89.089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61371', 'place_name': 'Triumph', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.4991, 'longitude': -89.0219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61372', 'place_name': 'Troy Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.4678, 'longitude': -89.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61373', 'place_name': 'Utica', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'LaSalle', 'locality_code': '99', 'latitude': 41.363, 'longitude': -89.0008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62417', 'place_name': 'Bridgeport', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lawrence', 'locality_code': '101', 'latitude': 38.7067, 'longitude': -87.7657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62439', 'place_name': 'Lawrenceville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lawrence', 'locality_code': '101', 'latitude': 38.7309, 'longitude': -87.6784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62460', 'place_name': 'Saint Francisville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lawrence', 'locality_code': '101', 'latitude': 38.5921, 'longitude': -87.6487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62466', 'place_name': 'Sumner', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lawrence', 'locality_code': '101', 'latitude': 38.7171, 'longitude': -87.8638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60530', 'place_name': 'Lee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.7864, 'longitude': -88.9714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60553', 'place_name': 'Steward', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.8475, 'longitude': -89.0151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61006', 'place_name': 'Ashton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.8643, 'longitude': -89.2086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61021', 'place_name': 'Dixon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.8478, 'longitude': -89.4893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61031', 'place_name': 'Franklin Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.858, 'longitude': -89.3171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61042', 'place_name': 'Harmon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.6973, 'longitude': -89.5695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61057', 'place_name': 'Nachusa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.8316, 'longitude': -89.3896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61310', 'place_name': 'Amboy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.7042, 'longitude': -89.3472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61318', 'place_name': 'Compton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.685, 'longitude': -89.0877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61324', 'place_name': 'Eldena', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.7711, 'longitude': -89.4123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61331', 'place_name': 'Lee Center', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.7488, 'longitude': -89.2827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61353', 'place_name': 'Paw Paw', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.6852, 'longitude': -88.9674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61367', 'place_name': 'Sublette', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.6331, 'longitude': -89.2354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61378', 'place_name': 'West Brooklyn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Lee', 'locality_code': '103', 'latitude': 41.7292, 'longitude': -89.1909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60420', 'place_name': 'Dwight', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 41.0887, 'longitude': -88.4159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60460', 'place_name': 'Odell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 41.0238, 'longitude': -88.5156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60920', 'place_name': 'Campus', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 41.0248, 'longitude': -88.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60921', 'place_name': 'Chatsworth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.7484, 'longitude': -88.2937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60929', 'place_name': 'Cullom', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.8781, 'longitude': -88.2765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60934', 'place_name': 'Emington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.9692, 'longitude': -88.3589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61311', 'place_name': 'Ancona', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 41.0426, 'longitude': -88.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61313', 'place_name': 'Blackstone', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 41.0719, 'longitude': -88.6498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61319', 'place_name': 'Cornell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 41.031, 'longitude': -88.7668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61333', 'place_name': 'Long Point', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.9896, 'longitude': -88.8811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61739', 'place_name': 'Fairbury', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.745, 'longitude': -88.5165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61740', 'place_name': 'Flanagan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.879, 'longitude': -88.862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61741', 'place_name': 'Forrest', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.7513, 'longitude': -88.4111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61743', 'place_name': 'Graymont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.8757, 'longitude': -88.7817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61764', 'place_name': 'Pontiac', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.8764, 'longitude': -88.6328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61769', 'place_name': 'Saunemin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.8885, 'longitude': -88.4094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61775', 'place_name': 'Strawn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Livingston', 'locality_code': '105', 'latitude': 40.6476, 'longitude': -88.404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61723', 'place_name': 'Atlanta', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.2586, 'longitude': -89.23, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61751', 'place_name': 'Lawndale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.2193, 'longitude': -89.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62512', 'place_name': 'Beason', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.1437, 'longitude': -89.1948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62518', 'place_name': 'Chestnut', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.0582, 'longitude': -89.19, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62519', 'place_name': 'Cornland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 39.9374, 'longitude': -89.4023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62541', 'place_name': 'Lake Fork', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 39.9706, 'longitude': -89.3505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62543', 'place_name': 'Latham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 39.9711, 'longitude': -89.1725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62548', 'place_name': 'Mount Pulaski', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.0045, 'longitude': -89.2935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62634', 'place_name': 'Elkhart', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.0132, 'longitude': -89.452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62635', 'place_name': 'Emden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.2967, 'longitude': -89.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62643', 'place_name': 'Hartsburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.2451, 'longitude': -89.4519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62656', 'place_name': 'Lincoln', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.1451, 'longitude': -89.3684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62666', 'place_name': 'Middletown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.0967, 'longitude': -89.5818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62671', 'place_name': 'New Holland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Logan', 'locality_code': '107', 'latitude': 40.1682, 'longitude': -89.5604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61411', 'place_name': 'Adair', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.3852, 'longitude': -90.5037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61416', 'place_name': 'Bardolph', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.495, 'longitude': -90.5646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61420', 'place_name': 'Blandinsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.5516, 'longitude': -90.8595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61422', 'place_name': 'Bushnell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.5539, 'longitude': -90.506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61438', 'place_name': 'Good Hope', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.5578, 'longitude': -90.6735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61440', 'place_name': 'Industry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.3256, 'longitude': -90.6105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61455', 'place_name': 'Macomb', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.4617, 'longitude': -90.6787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61470', 'place_name': 'Prairie City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.618, 'longitude': -90.4727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61475', 'place_name': 'Sciota', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.5832, 'longitude': -90.7316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62326', 'place_name': 'Colchester', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.4156, 'longitude': -90.7846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62374', 'place_name': 'Tennessee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McDonough', 'locality_code': '109', 'latitude': 40.414, 'longitude': -90.8556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60001', 'place_name': 'Alden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.3248, 'longitude': -88.4525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60012', 'place_name': 'Crystal Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.2662, 'longitude': -88.3213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60013', 'place_name': 'Cary', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.2196, 'longitude': -88.2426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60014', 'place_name': 'Crystal Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.2308, 'longitude': -88.3324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60021', 'place_name': 'Fox River Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.1936, 'longitude': -88.2205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60033', 'place_name': 'Harvard', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.4227, 'longitude': -88.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60034', 'place_name': 'Hebron', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.4642, 'longitude': -88.4176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60039', 'place_name': 'Crystal Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.3248, 'longitude': -88.4525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60050', 'place_name': 'Mchenry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.3311, 'longitude': -88.2955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60051', 'place_name': 'Mchenry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.3542, 'longitude': -88.2294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60071', 'place_name': 'Richmond', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.4669, 'longitude': -88.29, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60072', 'place_name': 'Ringwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.4048, 'longitude': -88.3054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60081', 'place_name': 'Spring Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.4413, 'longitude': -88.2237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60097', 'place_name': 'Wonder Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.3849, 'longitude': -88.3534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60098', 'place_name': 'Woodstock', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.3198, 'longitude': -88.4477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60102', 'place_name': 'Algonquin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.1641, 'longitude': -88.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60142', 'place_name': 'Huntley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.1756, 'longitude': -88.4268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60152', 'place_name': 'Marengo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.2442, 'longitude': -88.6074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60156', 'place_name': 'Lake In The Hills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.1817, 'longitude': -88.3304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60180', 'place_name': 'Union', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McHenry', 'locality_code': '111', 'latitude': 42.2103, 'longitude': -88.5283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61701', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4783, 'longitude': -88.9893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61702', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5192, 'longitude': -88.8643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61704', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4705, 'longitude': -88.9433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61705', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.44, 'longitude': -89.067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61709', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4614, 'longitude': -88.953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61710', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4777, 'longitude': -88.9542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61720', 'place_name': 'Anchor', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5441, 'longitude': -88.5266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61722', 'place_name': 'Arrowsmith', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.412, 'longitude': -88.6296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61724', 'place_name': 'Bellflower', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.3401, 'longitude': -88.5227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61725', 'place_name': 'Carlock', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.6029, 'longitude': -89.1098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61726', 'place_name': 'Chenoa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.7446, 'longitude': -88.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61728', 'place_name': 'Colfax', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5704, 'longitude': -88.62, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61730', 'place_name': 'Cooksville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.536, 'longitude': -88.735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61731', 'place_name': 'Cropsey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.603, 'longitude': -88.4943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61732', 'place_name': 'Danvers', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5364, 'longitude': -89.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61736', 'place_name': 'Downs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.3989, 'longitude': -88.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61737', 'place_name': 'Ellsworth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4432, 'longitude': -88.7371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61744', 'place_name': 'Gridley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.7439, 'longitude': -88.884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61745', 'place_name': 'Heyworth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.3307, 'longitude': -88.9776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61748', 'place_name': 'Hudson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.6205, 'longitude': -88.9759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61752', 'place_name': 'Le Roy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.3468, 'longitude': -88.7598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61753', 'place_name': 'Lexington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.6357, 'longitude': -88.8062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61754', 'place_name': 'Mc Lean', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.3282, 'longitude': -89.1645, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '61758', 'place_name': 'Merna', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5167, 'longitude': -88.8259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61761', 'place_name': 'Normal', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5124, 'longitude': -88.9883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61770', 'place_name': 'Saybrook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.432, 'longitude': -88.5247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61772', 'place_name': 'Shirley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4174, 'longitude': -89.0822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61774', 'place_name': 'Stanford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4376, 'longitude': -89.2164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61776', 'place_name': 'Towanda', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5533, 'longitude': -88.8886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61790', 'place_name': 'Normal', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5103, 'longitude': -88.998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61791', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.5192, 'longitude': -88.8643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61799', 'place_name': 'Bloomington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'McLean', 'locality_code': '113', 'latitude': 40.4885, 'longitude': -88.9396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61756', 'place_name': 'Maroa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 40.0342, 'longitude': -88.9578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62501', 'place_name': 'Argenta', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.934, 'longitude': -88.8052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62513', 'place_name': 'Blue Mound', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.6978, 'longitude': -89.1136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62514', 'place_name': 'Boody', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.7624, 'longitude': -89.0507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62521', 'place_name': 'Decatur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.8395, 'longitude': -88.9465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62522', 'place_name': 'Decatur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.8432, 'longitude': -88.9861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62523', 'place_name': 'Decatur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.8417, 'longitude': -88.9534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62524', 'place_name': 'Decatur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.854, 'longitude': -88.9815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62525', 'place_name': 'Decatur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.854, 'longitude': -88.9815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62526', 'place_name': 'Decatur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.8583, 'longitude': -88.9382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62532', 'place_name': 'Elwin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.78, 'longitude': -88.9808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62535', 'place_name': 'Forsyth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.9248, 'longitude': -88.9691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62537', 'place_name': 'Harristown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.8567, 'longitude': -89.085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62544', 'place_name': 'Macon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.7041, 'longitude': -88.988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62549', 'place_name': 'Mt Zion', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.7705, 'longitude': -88.8659, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62551', 'place_name': 'Niantic', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.8582, 'longitude': -89.1701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62554', 'place_name': 'Oreana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.9351, 'longitude': -88.8547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62573', 'place_name': 'Warrensburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macon', 'locality_code': '115', 'latitude': 39.9454, 'longitude': -89.0741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62009', 'place_name': 'Benld', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.0939, 'longitude': -89.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62014', 'place_name': 'Bunker Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.0408, 'longitude': -89.9624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62023', 'place_name': 'Eagarville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.1118, 'longitude': -89.7855, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62033', 'place_name': 'Gillespie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.1341, 'longitude': -89.8442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62069', 'place_name': 'Mount Olive', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.0705, 'longitude': -89.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62079', 'place_name': 'Piasa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.1159, 'longitude': -90.1237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62085', 'place_name': 'Sawyerville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.0828, 'longitude': -89.8043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62088', 'place_name': 'Staunton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.0135, 'longitude': -89.7857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62093', 'place_name': 'Wilsonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.0695, 'longitude': -89.8565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62626', 'place_name': 'Carlinville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.2885, 'longitude': -89.8661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62630', 'place_name': 'Chesterfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.2608, 'longitude': -90.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62640', 'place_name': 'Girard', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.3838, 'longitude': -89.8501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62649', 'place_name': 'Hettick', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.3752, 'longitude': -90.0672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62667', 'place_name': 'Modesto', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.476, 'longitude': -89.9794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62672', 'place_name': 'Nilwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.398, 'longitude': -89.8045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62674', 'place_name': 'Palmyra', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.4227, 'longitude': -90.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62683', 'place_name': 'Scottville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.4803, 'longitude': -90.1048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62685', 'place_name': 'Shipman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.1952, 'longitude': -89.9607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62690', 'place_name': 'Virden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Macoupin', 'locality_code': '117', 'latitude': 39.5064, 'longitude': -89.7783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62001', 'place_name': 'Alhambra', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8822, 'longitude': -89.7441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62002', 'place_name': 'Alton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.9087, 'longitude': -90.1568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62010', 'place_name': 'Bethalto', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.9074, 'longitude': -90.0344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62018', 'place_name': 'Cottage Hills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.9124, 'longitude': -90.0826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62021', 'place_name': 'Dorsey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.9832, 'longitude': -89.9786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62024', 'place_name': 'East Alton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8803, 'longitude': -90.083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62025', 'place_name': 'Edwardsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.805, 'longitude': -89.9637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62026', 'place_name': 'Edwardsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8114, 'longitude': -89.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62034', 'place_name': 'Glen Carbon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.7609, 'longitude': -89.9706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62035', 'place_name': 'Godfrey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.946, 'longitude': -90.206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62040', 'place_name': 'Granite City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.7261, 'longitude': -90.1106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62046', 'place_name': 'Hamel', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8901, 'longitude': -89.8457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62048', 'place_name': 'Hartford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8278, 'longitude': -90.0926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62058', 'place_name': 'Livingston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.969, 'longitude': -89.7668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62060', 'place_name': 'Madison', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.6811, 'longitude': -90.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62061', 'place_name': 'Marine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.7793, 'longitude': -89.7786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62062', 'place_name': 'Maryville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.7138, 'longitude': -89.9658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62067', 'place_name': 'Moro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.9318, 'longitude': -89.9618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62074', 'place_name': 'New Douglas', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.9676, 'longitude': -89.7392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62084', 'place_name': 'Roxana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8482, 'longitude': -90.0798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62087', 'place_name': 'South Roxana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8225, 'longitude': -90.0583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62090', 'place_name': 'Venice', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.6706, 'longitude': -90.1689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62095', 'place_name': 'Wood River', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.8643, 'longitude': -90.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62097', 'place_name': 'Worden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.9449, 'longitude': -89.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62234', 'place_name': 'Collinsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.6835, 'longitude': -89.9853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62249', 'place_name': 'Highland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.7631, 'longitude': -89.6789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62281', 'place_name': 'Saint Jacob', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.7059, 'longitude': -89.7925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62294', 'place_name': 'Troy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Madison', 'locality_code': '119', 'latitude': 38.7243, 'longitude': -89.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62801', 'place_name': 'Centralia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.5241, 'longitude': -89.1365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62807', 'place_name': 'Alma', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.7231, 'longitude': -88.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62849', 'place_name': 'Iuka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.6136, 'longitude': -88.7689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62853', 'place_name': 'Kell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.5147, 'longitude': -88.9127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62854', 'place_name': 'Kinmundy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.7559, 'longitude': -88.813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62870', 'place_name': 'Odin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.6088, 'longitude': -89.0552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62875', 'place_name': 'Patoka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.7549, 'longitude': -89.0942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62881', 'place_name': 'Salem', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.6264, 'longitude': -88.9481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62882', 'place_name': 'Sandoval', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.6131, 'longitude': -89.114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62892', 'place_name': 'Vernon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.8033, 'longitude': -89.083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62893', 'place_name': 'Walnut Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marion', 'locality_code': '121', 'latitude': 38.467, 'longitude': -89.0328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61369', 'place_name': 'Toluca', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 41.0046, 'longitude': -89.1348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61375', 'place_name': 'Varna', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 41.0327, 'longitude': -89.2483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61377', 'place_name': 'Wenona', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 41.0548, 'longitude': -89.0416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61424', 'place_name': 'Camp Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 41.078, 'longitude': -89.6332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61537', 'place_name': 'Henry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 41.1115, 'longitude': -89.3743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61540', 'place_name': 'Lacon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 41.0216, 'longitude': -89.4008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61541', 'place_name': 'La Rose', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 40.9823, 'longitude': -89.2354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61565', 'place_name': 'Sparland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 41.0134, 'longitude': -89.4571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61570', 'place_name': 'Washburn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Marshall', 'locality_code': '123', 'latitude': 40.9141, 'longitude': -89.283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61532', 'place_name': 'Forest City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.3594, 'longitude': -89.8334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61546', 'place_name': 'Manito', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.416, 'longitude': -89.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61567', 'place_name': 'Topeka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.3303, 'longitude': -89.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62617', 'place_name': 'Bath', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.1536, 'longitude': -90.1661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62633', 'place_name': 'Easton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.2279, 'longitude': -89.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62644', 'place_name': 'Havana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.3, 'longitude': -90.061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62655', 'place_name': 'Kilbourne', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.1587, 'longitude': -90.0043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62664', 'place_name': 'Mason City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.2023, 'longitude': -89.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62682', 'place_name': 'San Jose', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mason', 'locality_code': '125', 'latitude': 40.3011, 'longitude': -89.6872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62910', 'place_name': 'Brookport', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Massac', 'locality_code': '127', 'latitude': 37.1542, 'longitude': -88.5334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62953', 'place_name': 'Joppa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Massac', 'locality_code': '127', 'latitude': 37.2092, 'longitude': -88.8442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62960', 'place_name': 'Metropolis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Massac', 'locality_code': '127', 'latitude': 37.1753, 'longitude': -88.7252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62613', 'place_name': 'Athens', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Menard', 'locality_code': '129', 'latitude': 39.9917, 'longitude': -89.6684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62642', 'place_name': 'Greenview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Menard', 'locality_code': '129', 'latitude': 40.1017, 'longitude': -89.7469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62659', 'place_name': "Lincoln's New Salem", 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Menard', 'locality_code': '129', 'latitude': 40.0311, 'longitude': -89.7867, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62673', 'place_name': 'Oakford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Menard', 'locality_code': '129', 'latitude': 40.0994, 'longitude': -89.9601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62675', 'place_name': 'Petersburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Menard', 'locality_code': '129', 'latitude': 40.0117, 'longitude': -89.8482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62688', 'place_name': 'Tallula', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Menard', 'locality_code': '129', 'latitude': 39.9445, 'longitude': -89.9373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61231', 'place_name': 'Aledo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.2008, 'longitude': -90.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61260', 'place_name': 'Joy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.2262, 'longitude': -90.8518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61263', 'place_name': 'Matherville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.2599, 'longitude': -90.6128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61272', 'place_name': 'New Boston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.2153, 'longitude': -90.9879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61276', 'place_name': 'Preemption', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.2996, 'longitude': -90.5866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61281', 'place_name': 'Sherrard', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.3027, 'longitude': -90.4939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61412', 'place_name': 'Alexis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.0521, 'longitude': -90.5436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61442', 'place_name': 'Keithsburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.1043, 'longitude': -90.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61465', 'place_name': 'New Windsor', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.1987, 'longitude': -90.4598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61466', 'place_name': 'North Henderson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.1006, 'longitude': -90.4736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61476', 'place_name': 'Seaton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.0732, 'longitude': -90.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61486', 'place_name': 'Viola', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Mercer', 'locality_code': '131', 'latitude': 41.2024, 'longitude': -90.5936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62236', 'place_name': 'Columbia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Monroe', 'locality_code': '133', 'latitude': 38.4325, 'longitude': -90.2027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62244', 'place_name': 'Fults', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Monroe', 'locality_code': '133', 'latitude': 38.1797, 'longitude': -90.1974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62248', 'place_name': 'Hecker', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Monroe', 'locality_code': '133', 'latitude': 38.3044, 'longitude': -89.9935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62256', 'place_name': 'Maeystown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Monroe', 'locality_code': '133', 'latitude': 38.3043, 'longitude': -90.1356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62279', 'place_name': 'Renault', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Monroe', 'locality_code': '133', 'latitude': 38.1521, 'longitude': -90.1346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62295', 'place_name': 'Valmeyer', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Monroe', 'locality_code': '133', 'latitude': 38.2805, 'longitude': -90.3122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62298', 'place_name': 'Waterloo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Monroe', 'locality_code': '133', 'latitude': 38.3223, 'longitude': -90.1478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62015', 'place_name': 'Butler', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.2114, 'longitude': -89.5305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62017', 'place_name': 'Coffeen', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.0908, 'longitude': -89.3945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62032', 'place_name': 'Fillmore', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.1039, 'longitude': -89.2946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62049', 'place_name': 'Hillsboro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.1494, 'longitude': -89.4881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62051', 'place_name': 'Irving', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.2089, 'longitude': -89.4104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62056', 'place_name': 'Litchfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.1793, 'longitude': -89.6499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62075', 'place_name': 'Nokomis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.3036, 'longitude': -89.2853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62076', 'place_name': 'Ohlman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.3434, 'longitude': -89.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62077', 'place_name': 'Panama', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.0317, 'longitude': -89.5237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62089', 'place_name': 'Taylor Springs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.1309, 'longitude': -89.492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62091', 'place_name': 'Walshville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.0473, 'longitude': -89.635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62094', 'place_name': 'Witt', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.2469, 'longitude': -89.3414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62533', 'place_name': 'Farmersville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.4401, 'longitude': -89.617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62538', 'place_name': 'Harvel', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.3719, 'longitude': -89.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62560', 'place_name': 'Raymond', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.3106, 'longitude': -89.5851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62572', 'place_name': 'Waggoner', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Montgomery', 'locality_code': '135', 'latitude': 39.3688, 'longitude': -89.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62601', 'place_name': 'Alexander', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.7517, 'longitude': -90.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62628', 'place_name': 'Chapin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.7716, 'longitude': -90.4113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62631', 'place_name': 'Concord', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.823, 'longitude': -90.3722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62638', 'place_name': 'Franklin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.6222, 'longitude': -90.0889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62650', 'place_name': 'Jacksonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.7339, 'longitude': -90.229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62651', 'place_name': 'Jacksonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.6983, 'longitude': -90.2615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62660', 'place_name': 'Literberry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.8589, 'longitude': -90.2007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62665', 'place_name': 'Meredosia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.8173, 'longitude': -90.5339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62668', 'place_name': 'Murrayville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.5723, 'longitude': -90.2379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62692', 'place_name': 'Waverly', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.587, 'longitude': -89.9449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62695', 'place_name': 'Woodson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Morgan', 'locality_code': '137', 'latitude': 39.6289, 'longitude': -90.219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61914', 'place_name': 'Bethany', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Moultrie', 'locality_code': '139', 'latitude': 39.6348, 'longitude': -88.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61925', 'place_name': 'Dalton City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Moultrie', 'locality_code': '139', 'latitude': 39.7119, 'longitude': -88.7975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61928', 'place_name': 'Gays', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Moultrie', 'locality_code': '139', 'latitude': 39.4796, 'longitude': -88.5242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61937', 'place_name': 'Lovington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Moultrie', 'locality_code': '139', 'latitude': 39.7192, 'longitude': -88.6417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61951', 'place_name': 'Sullivan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Moultrie', 'locality_code': '139', 'latitude': 39.5934, 'longitude': -88.6038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60113', 'place_name': 'Creston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 41.9312, 'longitude': -88.9566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61007', 'place_name': 'Baileyville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.1905, 'longitude': -89.5939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61010', 'place_name': 'Byron', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.1292, 'longitude': -89.2659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61015', 'place_name': 'Chana', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 41.9933, 'longitude': -89.2117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61020', 'place_name': 'Davis Junction', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.0979, 'longitude': -89.0838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61030', 'place_name': 'Forreston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.1229, 'longitude': -89.5831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61043', 'place_name': 'Holcomb', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.0647, 'longitude': -89.0957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61047', 'place_name': 'Leaf River', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.1532, 'longitude': -89.3959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61049', 'place_name': 'Lindenwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.0507, 'longitude': -89.034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61052', 'place_name': 'Monroe Center', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.105, 'longitude': -89.0169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61054', 'place_name': 'Mount Morris', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.0479, 'longitude': -89.4346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61061', 'place_name': 'Oregon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.0095, 'longitude': -89.3444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61064', 'place_name': 'Polo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 41.989, 'longitude': -89.5984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61068', 'place_name': 'Rochelle', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 41.9282, 'longitude': -89.071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61084', 'place_name': 'Stillman Valley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 42.1183, 'longitude': -89.1898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61091', 'place_name': 'Woosung', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Ogle', 'locality_code': '141', 'latitude': 41.9034, 'longitude': -89.5409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61451', 'place_name': 'Laura', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.9335, 'longitude': -89.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61517', 'place_name': 'Brimfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.8407, 'longitude': -89.897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61523', 'place_name': 'Chillicothe', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.9013, 'longitude': -89.5068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61525', 'place_name': 'Dunlap', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.8444, 'longitude': -89.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61526', 'place_name': 'Edelstein', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.9454, 'longitude': -89.5858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61528', 'place_name': 'Edwards', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.779, 'longitude': -89.723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61529', 'place_name': 'Elmwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7726, 'longitude': -89.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61533', 'place_name': 'Glasford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.576, 'longitude': -89.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61536', 'place_name': 'Hanna City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6798, 'longitude': -89.7952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61539', 'place_name': 'Kingston Mines', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.5571, 'longitude': -89.7685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61547', 'place_name': 'Mapleton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6117, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61552', 'place_name': 'Mossville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.818, 'longitude': -89.568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61562', 'place_name': 'Rome', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.8743, 'longitude': -89.5067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61569', 'place_name': 'Trivoli', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6795, 'longitude': -89.9135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61601', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6931, 'longitude': -89.5898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61602', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6936, 'longitude': -89.589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61603', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7132, 'longitude': -89.577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61604', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7111, 'longitude': -89.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61605', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6775, 'longitude': -89.6263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61606', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6989, 'longitude': -89.6122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61607', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6321, 'longitude': -89.6903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61612', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61613', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7425, 'longitude': -89.6279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61614', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7681, 'longitude': -89.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61615', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7661, 'longitude': -89.645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61616', 'place_name': 'Peoria Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7473, 'longitude': -89.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61625', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6963, 'longitude': -89.6166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61629', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.692, 'longitude': -89.5887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61630', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61633', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7312, 'longitude': -89.6031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61634', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6896, 'longitude': -89.5926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61636', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.6999, 'longitude': -89.5951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61637', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7025, 'longitude': -89.5898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61638', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7969, 'longitude': -89.6111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61639', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7098, 'longitude': -89.5636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61641', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.64, 'longitude': -89.652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61643', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61650', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61651', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61652', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.8767, 'longitude': -89.5091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61653', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61654', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61655', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61656', 'place_name': 'Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Peoria', 'locality_code': '143', 'latitude': 40.7442, 'longitude': -89.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62238', 'place_name': 'Cutler', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Perry', 'locality_code': '145', 'latitude': 38.0427, 'longitude': -89.5661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62274', 'place_name': 'Pinckneyville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Perry', 'locality_code': '145', 'latitude': 38.0903, 'longitude': -89.3858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62832', 'place_name': 'Du Quoin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Perry', 'locality_code': '145', 'latitude': 38.0137, 'longitude': -89.2333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62888', 'place_name': 'Tamaroa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Perry', 'locality_code': '145', 'latitude': 38.138, 'longitude': -89.2231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62997', 'place_name': 'Willisville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Perry', 'locality_code': '145', 'latitude': 37.9848, 'longitude': -89.5899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61813', 'place_name': 'Bement', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 39.9222, 'longitude': -88.5688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61818', 'place_name': 'Cerro Gordo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 39.8681, 'longitude': -88.7256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61830', 'place_name': 'Cisco', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 39.9972, 'longitude': -88.6962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61839', 'place_name': 'De Land', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 40.1107, 'longitude': -88.6392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61854', 'place_name': 'Mansfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 40.2147, 'longitude': -88.5179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61855', 'place_name': 'Milmine', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 39.9238, 'longitude': -88.6599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61856', 'place_name': 'Monticello', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 40.0263, 'longitude': -88.5686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61884', 'place_name': 'White Heath', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 40.1009, 'longitude': -88.5193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61929', 'place_name': 'Hammond', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 39.7946, 'longitude': -88.5793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61936', 'place_name': 'La Place', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Piatt', 'locality_code': '147', 'latitude': 39.7983, 'longitude': -88.7272, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62312', 'place_name': 'Barry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.7047, 'longitude': -91.0265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62314', 'place_name': 'Baylis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.7612, 'longitude': -90.8832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62323', 'place_name': 'Chambersburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.8071, 'longitude': -90.663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62340', 'place_name': 'Griggsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.7084, 'longitude': -90.7249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62343', 'place_name': 'Hull', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.7186, 'longitude': -91.2338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62345', 'place_name': 'Kinderhook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.6953, 'longitude': -91.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62352', 'place_name': 'Milton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.5645, 'longitude': -90.6504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62355', 'place_name': 'Nebo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.4202, 'longitude': -90.7692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62356', 'place_name': 'New Canton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.6342, 'longitude': -91.0886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62357', 'place_name': 'New Salem', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.6996, 'longitude': -90.844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62361', 'place_name': 'Pearl', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.4441, 'longitude': -90.638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62362', 'place_name': 'Perry', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.7823, 'longitude': -90.7471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62363', 'place_name': 'Pittsfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.6013, 'longitude': -90.8073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62366', 'place_name': 'Pleasant Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.4467, 'longitude': -90.877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62370', 'place_name': 'Rockport', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pike', 'locality_code': '149', 'latitude': 39.5328, 'longitude': -90.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62928', 'place_name': 'Eddyville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pope', 'locality_code': '151', 'latitude': 37.4829, 'longitude': -88.5791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62938', 'place_name': 'Golconda', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pope', 'locality_code': '151', 'latitude': 37.3602, 'longitude': -88.4886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62947', 'place_name': 'Herod', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pope', 'locality_code': '151', 'latitude': 37.5634, 'longitude': -88.44, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62941', 'place_name': 'Grand Chain', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.251, 'longitude': -89.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62956', 'place_name': 'Karnak', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.2911, 'longitude': -88.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62963', 'place_name': 'Mound City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.0865, 'longitude': -89.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62964', 'place_name': 'Mounds', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.1188, 'longitude': -89.2001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62970', 'place_name': 'Olmsted', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.1935, 'longitude': -89.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62973', 'place_name': 'Perks', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.3113, 'longitude': -89.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62976', 'place_name': 'Pulaski', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.2146, 'longitude': -89.1968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62992', 'place_name': 'Ullin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.277, 'longitude': -89.1834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62996', 'place_name': 'Villa Ridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Pulaski', 'locality_code': '153', 'latitude': 37.1578, 'longitude': -89.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61326', 'place_name': 'Granville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Putnam', 'locality_code': '155', 'latitude': 41.2642, 'longitude': -89.225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61327', 'place_name': 'Hennepin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Putnam', 'locality_code': '155', 'latitude': 41.2352, 'longitude': -89.3218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61335', 'place_name': 'Mc Nabb', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Putnam', 'locality_code': '155', 'latitude': 41.173, 'longitude': -89.2187, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '61336', 'place_name': 'Magnolia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Putnam', 'locality_code': '155', 'latitude': 41.1164, 'longitude': -89.227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61340', 'place_name': 'Mark', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Putnam', 'locality_code': '155', 'latitude': 41.266, 'longitude': -89.2491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61363', 'place_name': 'Standard', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Putnam', 'locality_code': '155', 'latitude': 41.2567, 'longitude': -89.1778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61560', 'place_name': 'Putnam', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Putnam', 'locality_code': '155', 'latitude': 41.1949, 'longitude': -89.4409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62217', 'place_name': 'Baldwin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.1754, 'longitude': -89.8414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62233', 'place_name': 'Chester', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 37.9188, 'longitude': -89.8218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62237', 'place_name': 'Coulterville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.1753, 'longitude': -89.6479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62241', 'place_name': 'Ellis Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.0054, 'longitude': -89.9008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62242', 'place_name': 'Evansville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.0926, 'longitude': -89.917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62259', 'place_name': 'Menard', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 37.9101, 'longitude': -89.8398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62261', 'place_name': 'Modoc', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.0507, 'longitude': -90.0163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62272', 'place_name': 'Percy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.0126, 'longitude': -89.617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62277', 'place_name': 'Prairie Du Rocher', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.0831, 'longitude': -90.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62278', 'place_name': 'Red Bud', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.1907, 'longitude': -89.9884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62280', 'place_name': 'Rockwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 37.8322, 'longitude': -89.6214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62286', 'place_name': 'Sparta', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.1318, 'longitude': -89.7035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62288', 'place_name': 'Steeleville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.0057, 'longitude': -89.6665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62292', 'place_name': 'Tilden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.2122, 'longitude': -89.6895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62297', 'place_name': 'Walsh', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Randolph', 'locality_code': '157', 'latitude': 38.0203, 'longitude': -89.8297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62419', 'place_name': 'Calhoun', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Richland', 'locality_code': '159', 'latitude': 38.6351, 'longitude': -88.0037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62421', 'place_name': 'Claremont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Richland', 'locality_code': '159', 'latitude': 38.7429, 'longitude': -87.9727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62425', 'place_name': 'Dundas', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Richland', 'locality_code': '159', 'latitude': 38.8306, 'longitude': -88.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62450', 'place_name': 'Olney', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Richland', 'locality_code': '159', 'latitude': 38.7334, 'longitude': -88.0809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62452', 'place_name': 'Parkersburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Richland', 'locality_code': '159', 'latitude': 38.59, 'longitude': -88.0647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62868', 'place_name': 'Noble', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Richland', 'locality_code': '159', 'latitude': 38.7119, 'longitude': -88.219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61201', 'place_name': 'Rock Island', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.4913, 'longitude': -90.5648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61204', 'place_name': 'Rock Island', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5549, 'longitude': -90.616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61232', 'place_name': 'Andalusia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.4392, 'longitude': -90.7176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61236', 'place_name': 'Barstow', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5147, 'longitude': -90.3577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61237', 'place_name': 'Buffalo Prairie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.3368, 'longitude': -90.8522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61239', 'place_name': 'Carbon Cliff', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.4948, 'longitude': -90.3907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61240', 'place_name': 'Coal Valley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.4351, 'longitude': -90.4652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61242', 'place_name': 'Cordova', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.6928, 'longitude': -90.3071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61244', 'place_name': 'East Moline', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5118, 'longitude': -90.4321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61256', 'place_name': 'Hampton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5559, 'longitude': -90.4093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61257', 'place_name': 'Hillsdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5929, 'longitude': -90.2263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61259', 'place_name': 'Illinois City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.3892, 'longitude': -90.8925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61264', 'place_name': 'Milan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.4262, 'longitude': -90.5739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61265', 'place_name': 'Moline', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.4906, 'longitude': -90.498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61266', 'place_name': 'Moline', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5067, 'longitude': -90.5151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61275', 'place_name': 'Port Byron', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.6013, 'longitude': -90.3263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61278', 'place_name': 'Rapids City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5817, 'longitude': -90.3435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61279', 'place_name': 'Reynolds', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.3277, 'longitude': -90.6384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61282', 'place_name': 'Silvis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5007, 'longitude': -90.4126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61284', 'place_name': 'Taylor Ridge', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.3828, 'longitude': -90.734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61299', 'place_name': 'Rock Island', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Rock Island', 'locality_code': '161', 'latitude': 41.5203, 'longitude': -90.5416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62059', 'place_name': 'Lovejoy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.44, 'longitude': -89.9835, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62071', 'place_name': 'National Stock Yards', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.6516, 'longitude': -90.1639, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62201', 'place_name': 'East Saint Louis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.6427, 'longitude': -90.1387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62202', 'place_name': 'East Saint Louis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.6163, 'longitude': -90.1591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62203', 'place_name': 'East Saint Louis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5992, 'longitude': -90.0744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62204', 'place_name': 'East Saint Louis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.6308, 'longitude': -90.095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62205', 'place_name': 'East Saint Louis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.6149, 'longitude': -90.1275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62206', 'place_name': 'East Saint Louis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5514, 'longitude': -90.1544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62207', 'place_name': 'East Saint Louis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.587, 'longitude': -90.1278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62208', 'place_name': 'Fairview Heights', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.596, 'longitude': -90.0071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62220', 'place_name': 'Belleville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5127, 'longitude': -89.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62221', 'place_name': 'Belleville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5396, 'longitude': -89.9583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62222', 'place_name': 'Belleville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.44, 'longitude': -89.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62223', 'place_name': 'Belleville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5456, 'longitude': -90.0378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62225', 'place_name': 'Scott Air Force Base', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5432, 'longitude': -89.859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62226', 'place_name': 'Belleville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5352, 'longitude': -90.0006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62232', 'place_name': 'Caseyville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.6345, 'longitude': -90.0135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62239', 'place_name': 'Dupo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5162, 'longitude': -90.2104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62240', 'place_name': 'East Carondelet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5349, 'longitude': -90.2208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62243', 'place_name': 'Freeburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.408, 'longitude': -89.9181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62254', 'place_name': 'Lebanon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.6053, 'longitude': -89.7992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62255', 'place_name': 'Lenzburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.295, 'longitude': -89.7922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62257', 'place_name': 'Marissa', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.2455, 'longitude': -89.7501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62258', 'place_name': 'Mascoutah', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.4745, 'longitude': -89.7877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62260', 'place_name': 'Millstadt', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.4443, 'longitude': -90.0888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62264', 'place_name': 'New Athens', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.316, 'longitude': -89.8728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62269', 'place_name': 'O Fallon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5718, 'longitude': -89.8957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62282', 'place_name': 'Saint Libory', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.3632, 'longitude': -89.7139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62285', 'place_name': 'Smithton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.4231, 'longitude': -89.9896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62289', 'place_name': 'Summerfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'St. Clair', 'locality_code': '163', 'latitude': 38.5967, 'longitude': -89.7512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62917', 'place_name': 'Carrier Mills', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Saline', 'locality_code': '165', 'latitude': 37.6842, 'longitude': -88.6328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62930', 'place_name': 'Eldorado', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Saline', 'locality_code': '165', 'latitude': 37.8139, 'longitude': -88.4434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62935', 'place_name': 'Galatia', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Saline', 'locality_code': '165', 'latitude': 37.8274, 'longitude': -88.6235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62946', 'place_name': 'Harrisburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Saline', 'locality_code': '165', 'latitude': 37.7257, 'longitude': -88.544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62965', 'place_name': 'Muddy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Saline', 'locality_code': '165', 'latitude': 37.765, 'longitude': -88.5167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62977', 'place_name': 'Raleigh', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Saline', 'locality_code': '165', 'latitude': 37.8256, 'longitude': -88.5324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62987', 'place_name': 'Stonefort', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Saline', 'locality_code': '165', 'latitude': 37.6432, 'longitude': -88.6228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62515', 'place_name': 'Buffalo', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8499, 'longitude': -89.3879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62520', 'place_name': 'Dawson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8563, 'longitude': -89.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62530', 'place_name': 'Divernon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.5692, 'longitude': -89.6626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62536', 'place_name': 'Glenarm', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.6327, 'longitude': -89.6581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62539', 'place_name': 'Illiopolis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8499, 'longitude': -89.2513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62545', 'place_name': 'Mechanicsburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7778, 'longitude': -89.4064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62558', 'place_name': 'Pawnee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.6086, 'longitude': -89.5678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62561', 'place_name': 'Riverton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8663, 'longitude': -89.5087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62563', 'place_name': 'Rochester', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7182, 'longitude': -89.5649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62615', 'place_name': 'Auburn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.5918, 'longitude': -89.744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62625', 'place_name': 'Cantrall', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.9169, 'longitude': -89.6891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62629', 'place_name': 'Chatham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.6737, 'longitude': -89.7112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62661', 'place_name': 'Loami', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.6704, 'longitude': -89.8588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62662', 'place_name': 'Lowder', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.5509, 'longitude': -89.8459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62670', 'place_name': 'New Berlin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7681, 'longitude': -89.855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62677', 'place_name': 'Pleasant Plains', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8331, 'longitude': -89.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62684', 'place_name': 'Sherman', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.9121, 'longitude': -89.5877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62689', 'place_name': 'Thayer', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.5394, 'longitude': -89.7621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62693', 'place_name': 'Williamsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.9542, 'longitude': -89.5487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62701', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8, 'longitude': -89.6495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62702', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8317, 'longitude': -89.6465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62703', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7622, 'longitude': -89.6275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62704', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7725, 'longitude': -89.6889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62705', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8017, 'longitude': -89.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62706', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7989, 'longitude': -89.6534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62707', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8544, 'longitude': -89.6544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62708', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8061, 'longitude': -89.5864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62711', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7655, 'longitude': -89.7293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62712', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7533, 'longitude': -89.58, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62715', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8017, 'longitude': -89.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62716', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8482, 'longitude': -89.5364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62719', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62722', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62723', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62726', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62736', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62739', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8017, 'longitude': -89.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62756', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62757', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8017, 'longitude': -89.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62761', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8524, 'longitude': -89.541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62762', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62763', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62764', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62765', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8017, 'longitude': -89.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62766', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62767', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62769', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.8017, 'longitude': -89.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62776', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62777', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62781', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62786', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62791', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62794', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62796', 'place_name': 'Springfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Sangamon', 'locality_code': '167', 'latitude': 39.7495, 'longitude': -89.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61452', 'place_name': 'Littleton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Schuyler', 'locality_code': '169', 'latitude': 40.2339, 'longitude': -90.619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62319', 'place_name': 'Camden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Schuyler', 'locality_code': '169', 'latitude': 40.1511, 'longitude': -90.7544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62344', 'place_name': 'Huntsville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Schuyler', 'locality_code': '169', 'latitude': 40.1544, 'longitude': -90.8531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62624', 'place_name': 'Browning', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Schuyler', 'locality_code': '169', 'latitude': 40.1289, 'longitude': -90.3721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62639', 'place_name': 'Frederick', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Schuyler', 'locality_code': '169', 'latitude': 40.07, 'longitude': -90.429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62681', 'place_name': 'Rushville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Schuyler', 'locality_code': '169', 'latitude': 40.1133, 'longitude': -90.5432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62610', 'place_name': 'Alsey', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Scott', 'locality_code': '171', 'latitude': 39.5606, 'longitude': -90.434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62621', 'place_name': 'Bluffs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Scott', 'locality_code': '171', 'latitude': 39.7296, 'longitude': -90.5313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62663', 'place_name': 'Manchester', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Scott', 'locality_code': '171', 'latitude': 39.5405, 'longitude': -90.3317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62694', 'place_name': 'Winchester', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Scott', 'locality_code': '171', 'latitude': 39.6266, 'longitude': -90.4664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61957', 'place_name': 'Windsor', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.4302, 'longitude': -88.5857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62422', 'place_name': 'Cowden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.2326, 'longitude': -88.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62431', 'place_name': 'Herrick', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.2245, 'longitude': -88.9812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62438', 'place_name': 'Lakewood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.3134, 'longitude': -88.8715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62444', 'place_name': 'Mode', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.2664, 'longitude': -88.7337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62462', 'place_name': 'Sigel', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.2176, 'longitude': -88.4803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62463', 'place_name': 'Stewardson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.272, 'longitude': -88.6319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62465', 'place_name': 'Strasburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.3641, 'longitude': -88.6279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62534', 'place_name': 'Findlay', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.5193, 'longitude': -88.7468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62550', 'place_name': 'Moweaqua', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.6248, 'longitude': -89.019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62553', 'place_name': 'Oconee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.2884, 'longitude': -89.0836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62565', 'place_name': 'Shelbyville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.458, 'longitude': -88.8058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62571', 'place_name': 'Tower Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Shelby', 'locality_code': '173', 'latitude': 39.39, 'longitude': -88.9597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61421', 'place_name': 'Bradford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stark', 'locality_code': '175', 'latitude': 41.1532, 'longitude': -89.6521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61426', 'place_name': 'Castleton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stark', 'locality_code': '175', 'latitude': 41.1183, 'longitude': -89.7071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61449', 'place_name': 'La Fayette', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stark', 'locality_code': '175', 'latitude': 41.1095, 'longitude': -89.9575, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '61479', 'place_name': 'Speer', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stark', 'locality_code': '175', 'latitude': 40.9872, 'longitude': -89.652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61483', 'place_name': 'Toulon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stark', 'locality_code': '175', 'latitude': 41.1009, 'longitude': -89.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61491', 'place_name': 'Wyoming', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stark', 'locality_code': '175', 'latitude': 41.0599, 'longitude': -89.7782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61559', 'place_name': 'Princeville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stark', 'locality_code': '175', 'latitude': 40.9093, 'longitude': -89.7723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61013', 'place_name': 'Cedarville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.3761, 'longitude': -89.6365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61018', 'place_name': 'Dakota', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.4031, 'longitude': -89.5468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61019', 'place_name': 'Davis', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.4422, 'longitude': -89.4067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61027', 'place_name': 'Eleroy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.332, 'longitude': -89.7612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61032', 'place_name': 'Freeport', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.2991, 'longitude': -89.6345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61039', 'place_name': 'German Valley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.2176, 'longitude': -89.4712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61044', 'place_name': 'Kent', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.3155, 'longitude': -89.9195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61048', 'place_name': 'Lena', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.3791, 'longitude': -89.8253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61050', 'place_name': 'Mc Connell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.4281, 'longitude': -89.7643, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '61060', 'place_name': 'Orangeville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.4728, 'longitude': -89.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61062', 'place_name': 'Pearl City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.261, 'longitude': -89.8393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61067', 'place_name': 'Ridott', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.2996, 'longitude': -89.4627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61070', 'place_name': 'Rock City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.4103, 'longitude': -89.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61089', 'place_name': 'Winslow', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Stephenson', 'locality_code': '177', 'latitude': 42.4838, 'longitude': -89.806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61534', 'place_name': 'Green Valley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.4198, 'longitude': -89.6549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61535', 'place_name': 'Groveland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.5925, 'longitude': -89.5345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61550', 'place_name': 'Morton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.6148, 'longitude': -89.4604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61554', 'place_name': 'Pekin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.5674, 'longitude': -89.6243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61555', 'place_name': 'Pekin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.5607, 'longitude': -89.6502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61558', 'place_name': 'Pekin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.5675, 'longitude': -89.6407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61564', 'place_name': 'South Pekin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.4945, 'longitude': -89.6518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61568', 'place_name': 'Tremont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.5053, 'longitude': -89.4833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61571', 'place_name': 'Washington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.7034, 'longitude': -89.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61610', 'place_name': 'Creve Coeur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.6428, 'longitude': -89.5988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61611', 'place_name': 'East Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.6731, 'longitude': -89.5514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61635', 'place_name': 'East Peoria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.6661, 'longitude': -89.5801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61721', 'place_name': 'Armington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.3613, 'longitude': -89.3231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61733', 'place_name': 'Deer Creek', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.6224, 'longitude': -89.3323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61734', 'place_name': 'Delavan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.369, 'longitude': -89.5321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61747', 'place_name': 'Hopedale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.4273, 'longitude': -89.4214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61755', 'place_name': 'Mackinaw', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.5396, 'longitude': -89.3458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61759', 'place_name': 'Minier', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Tazewell', 'locality_code': '179', 'latitude': 40.4359, 'longitude': -89.3165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62905', 'place_name': 'Alto Pass', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Union', 'locality_code': '181', 'latitude': 37.5681, 'longitude': -89.3172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62906', 'place_name': 'Anna', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Union', 'locality_code': '181', 'latitude': 37.4668, 'longitude': -89.2207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62920', 'place_name': 'Cobden', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Union', 'locality_code': '181', 'latitude': 37.5424, 'longitude': -89.2457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62926', 'place_name': 'Dongola', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Union', 'locality_code': '181', 'latitude': 37.3712, 'longitude': -89.1349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62952', 'place_name': 'Jonesboro', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Union', 'locality_code': '181', 'latitude': 37.4461, 'longitude': -89.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62961', 'place_name': 'Millcreek', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Union', 'locality_code': '181', 'latitude': 37.3409, 'longitude': -89.2542, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '62998', 'place_name': 'Wolf Lake', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Union', 'locality_code': '181', 'latitude': 37.512, 'longitude': -89.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60932', 'place_name': 'East Lynn', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.4633, 'longitude': -87.8056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60942', 'place_name': 'Hoopeston', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.4639, 'longitude': -87.6662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60960', 'place_name': 'Rankin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.4559, 'longitude': -87.8884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60963', 'place_name': 'Rossville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.3625, 'longitude': -87.6692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61810', 'place_name': 'Allerton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 39.9188, 'longitude': -87.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61811', 'place_name': 'Alvin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.3007, 'longitude': -87.608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61812', 'place_name': 'Armstrong', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.2175, 'longitude': -87.8943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61814', 'place_name': 'Bismarck', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.2552, 'longitude': -87.6138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61817', 'place_name': 'Catlin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.0699, 'longitude': -87.7113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61831', 'place_name': 'Collison', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.2207, 'longitude': -87.7987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61832', 'place_name': 'Danville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.137, 'longitude': -87.6217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61833', 'place_name': 'Tilton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.0964, 'longitude': -87.644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61834', 'place_name': 'Danville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.1602, 'longitude': -87.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61841', 'place_name': 'Fairmount', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.0373, 'longitude': -87.8365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61844', 'place_name': 'Fithian', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.1192, 'longitude': -87.8797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61846', 'place_name': 'Georgetown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 39.9792, 'longitude': -87.6365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61848', 'place_name': 'Henning', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.304, 'longitude': -87.7007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61850', 'place_name': 'Indianola', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 39.9268, 'longitude': -87.7388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61857', 'place_name': 'Muncie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.1165, 'longitude': -87.8447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61858', 'place_name': 'Oakwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.1167, 'longitude': -87.7825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61865', 'place_name': 'Potomac', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.309, 'longitude': -87.8232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61870', 'place_name': 'Ridge Farm', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 39.9155, 'longitude': -87.6346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61876', 'place_name': 'Sidell', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 39.911, 'longitude': -87.8248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61883', 'place_name': 'Westville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Vermilion', 'locality_code': '183', 'latitude': 40.0451, 'longitude': -87.636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62410', 'place_name': 'Allendale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wabash', 'locality_code': '185', 'latitude': 38.5232, 'longitude': -87.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62811', 'place_name': 'Bellmont', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wabash', 'locality_code': '185', 'latitude': 38.3845, 'longitude': -87.9081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62852', 'place_name': 'Keensburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wabash', 'locality_code': '185', 'latitude': 38.3514, 'longitude': -87.8661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62855', 'place_name': 'Lancaster', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wabash', 'locality_code': '185', 'latitude': 38.4034, 'longitude': -87.8187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62863', 'place_name': 'Mount Carmel', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wabash', 'locality_code': '185', 'latitude': 38.4147, 'longitude': -87.7911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61417', 'place_name': 'Berwick', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 40.7799, 'longitude': -90.5059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61423', 'place_name': 'Cameron', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 40.889, 'longitude': -90.5001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61435', 'place_name': 'Gerlaw', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 40.9863, 'longitude': -90.5491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61447', 'place_name': 'Kirkwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 40.8638, 'longitude': -90.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61453', 'place_name': 'Little York', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 41.0153, 'longitude': -90.7364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61462', 'place_name': 'Monmouth', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 40.9107, 'longitude': -90.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61473', 'place_name': 'Roseville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 40.7238, 'longitude': -90.6514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61478', 'place_name': 'Smithshire', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Warren', 'locality_code': '187', 'latitude': 40.7579, 'longitude': -90.7606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62214', 'place_name': 'Addieville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.3815, 'longitude': -89.5794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62263', 'place_name': 'Nashville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.3352, 'longitude': -89.3841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62268', 'place_name': 'Oakdale', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.2573, 'longitude': -89.596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62271', 'place_name': 'Okawville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.4319, 'longitude': -89.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62803', 'place_name': 'Hoyleton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.4455, 'longitude': -89.3069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62808', 'place_name': 'Ashley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.306, 'longitude': -89.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62831', 'place_name': 'Du Bois', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.2239, 'longitude': -89.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62848', 'place_name': 'Irvington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.4366, 'longitude': -89.1648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62876', 'place_name': 'Radom', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.2607, 'longitude': -89.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62877', 'place_name': 'Richview', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Washington', 'locality_code': '189', 'latitude': 38.4082, 'longitude': -89.1756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62446', 'place_name': 'Mount Erie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.5222, 'longitude': -88.2185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62809', 'place_name': 'Barnhill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.2845, 'longitude': -88.3642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62823', 'place_name': 'Cisne', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.5159, 'longitude': -88.4375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62837', 'place_name': 'Fairfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.3782, 'longitude': -88.3593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62842', 'place_name': 'Geff', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.4413, 'longitude': -88.4144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62843', 'place_name': 'Golden Gate', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.3645, 'longitude': -88.2075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62850', 'place_name': 'Johnsonville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.5223, 'longitude': -88.537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62851', 'place_name': 'Keenes', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.3691, 'longitude': -88.6481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62878', 'place_name': 'Rinard', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.5806, 'longitude': -88.4641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62886', 'place_name': 'Sims', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.3923, 'longitude': -88.5306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62895', 'place_name': 'Wayne City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Wayne', 'locality_code': '191', 'latitude': 38.3328, 'longitude': -88.5833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62820', 'place_name': 'Burnt Prairie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.2082, 'longitude': -88.2147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62821', 'place_name': 'Carmi', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.0808, 'longitude': -88.167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62827', 'place_name': 'Crossville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.166, 'longitude': -88.0595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62834', 'place_name': 'Emma', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 37.9762, 'longitude': -88.1202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62835', 'place_name': 'Enfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.0927, 'longitude': -88.3325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62844', 'place_name': 'Grayville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.2627, 'longitude': -88.0035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62861', 'place_name': 'Maunie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.0356, 'longitude': -88.0456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62862', 'place_name': 'Mill Shoals', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.2447, 'longitude': -88.3338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62869', 'place_name': 'Norris City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 37.9773, 'longitude': -88.3243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62887', 'place_name': 'Springerton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'White', 'locality_code': '193', 'latitude': 38.1699, 'longitude': -88.3726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61037', 'place_name': 'Galt', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.7865, 'longitude': -89.761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61071', 'place_name': 'Rock Falls', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.7665, 'longitude': -89.6925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61081', 'place_name': 'Sterling', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.8055, 'longitude': -89.7054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61230', 'place_name': 'Albany', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.7659, 'longitude': -90.2081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61243', 'place_name': 'Deer Grove', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.6316, 'longitude': -89.6972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61250', 'place_name': 'Erie', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.656, 'longitude': -90.0843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61251', 'place_name': 'Fenton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.7285, 'longitude': -90.0457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61252', 'place_name': 'Fulton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.8522, 'longitude': -90.1507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61261', 'place_name': 'Lyndon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.7199, 'longitude': -89.9169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61270', 'place_name': 'Morrison', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.8167, 'longitude': -89.969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61277', 'place_name': 'Prophetstown', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.6312, 'longitude': -89.9467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61283', 'place_name': 'Tampico', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Whiteside', 'locality_code': '195', 'latitude': 41.6522, 'longitude': -89.7948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60401', 'place_name': 'Beecher', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.3444, 'longitude': -87.6115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60403', 'place_name': 'Crest Hill', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5548, 'longitude': -88.0987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60404', 'place_name': 'Shorewood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5076, 'longitude': -88.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60408', 'place_name': 'Braidwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.2657, 'longitude': -88.2231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60410', 'place_name': 'Channahon', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.4347, 'longitude': -88.2138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60417', 'place_name': 'Crete', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.439, 'longitude': -87.6027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60421', 'place_name': 'Elwood', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.426, 'longitude': -88.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60423', 'place_name': 'Frankfort', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5094, 'longitude': -87.8248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60428', 'place_name': 'Markham', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5998, 'longitude': -87.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60431', 'place_name': 'Joliet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.4712, 'longitude': -87.9391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60432', 'place_name': 'Joliet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5378, 'longitude': -88.0572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60433', 'place_name': 'Joliet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5119, 'longitude': -88.0569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60434', 'place_name': 'Joliet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5254, 'longitude': -88.0842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60435', 'place_name': 'Joliet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5454, 'longitude': -88.1299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60436', 'place_name': 'Joliet', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.4884, 'longitude': -88.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60440', 'place_name': 'Bolingbrook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.6976, 'longitude': -88.0873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60441', 'place_name': 'Lockport', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.593, 'longitude': -88.0507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60442', 'place_name': 'Manhattan', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.4289, 'longitude': -87.9771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60446', 'place_name': 'Romeoville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.6404, 'longitude': -88.0696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60448', 'place_name': 'Mokena', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5342, 'longitude': -87.8911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60449', 'place_name': 'Monee', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.4191, 'longitude': -87.7748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60451', 'place_name': 'New Lenox', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5067, 'longitude': -87.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60468', 'place_name': 'Peotone', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.3361, 'longitude': -87.7897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60481', 'place_name': 'Wilmington', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.3078, 'longitude': -88.1467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60484', 'place_name': 'University Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.4418, 'longitude': -87.7101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60487', 'place_name': 'Tinley Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5636, 'longitude': -87.8342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60490', 'place_name': 'Bolingbrook', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.679, 'longitude': -88.1403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60491', 'place_name': 'Homer Glen', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.6028, 'longitude': -87.9599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60503', 'place_name': 'Aurora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.7199, 'longitude': -88.2548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60544', 'place_name': 'Plainfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.6009, 'longitude': -88.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60564', 'place_name': 'Naperville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.704, 'longitude': -88.1952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60585', 'place_name': 'Plainfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.6558, 'longitude': -88.2203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '60586', 'place_name': 'Plainfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Will', 'locality_code': '197', 'latitude': 41.5642, 'longitude': -88.2178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62841', 'place_name': 'Freeman Spur', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.8612, 'longitude': -88.9973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62915', 'place_name': 'Cambria', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.7814, 'longitude': -89.1192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62918', 'place_name': 'Carterville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.7748, 'longitude': -89.0978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62921', 'place_name': 'Colp', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.8053, 'longitude': -89.0801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62922', 'place_name': 'Creal Springs', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.6195, 'longitude': -88.8367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62933', 'place_name': 'Energy', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.7726, 'longitude': -89.025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62948', 'place_name': 'Herrin', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.8019, 'longitude': -89.0232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62949', 'place_name': 'Hurst', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.8366, 'longitude': -89.1424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62951', 'place_name': 'Johnston City', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.8245, 'longitude': -88.9209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62959', 'place_name': 'Marion', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.7257, 'longitude': -88.9294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '62974', 'place_name': 'Pittsburg', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Williamson', 'locality_code': '199', 'latitude': 37.8047, 'longitude': -88.8081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61016', 'place_name': 'Cherry Valley', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2206, 'longitude': -88.9619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61024', 'place_name': 'Durand', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.4337, 'longitude': -89.3094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61063', 'place_name': 'Pecatonica', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3051, 'longitude': -89.3472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61072', 'place_name': 'Rockton', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.4544, 'longitude': -89.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61073', 'place_name': 'Roscoe', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.4217, 'longitude': -88.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61077', 'place_name': 'Seward', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2368, 'longitude': -89.358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61079', 'place_name': 'Shirland', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.4445, 'longitude': -89.1976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61080', 'place_name': 'South Beloit', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.4837, 'longitude': -89.0298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61088', 'place_name': 'Winnebago', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2727, 'longitude': -89.2373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61101', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2922, 'longitude': -89.1161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61102', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2547, 'longitude': -89.1247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61103', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.301, 'longitude': -89.0833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61104', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2554, 'longitude': -89.0768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61105', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2711, 'longitude': -89.094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61106', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3254, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61107', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2786, 'longitude': -89.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61108', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2514, 'longitude': -89.0235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61109', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2166, 'longitude': -89.0512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61110', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3254, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61111', 'place_name': 'Loves Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3295, 'longitude': -89.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61112', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.2456, 'longitude': -88.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61114', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3185, 'longitude': -88.9972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61115', 'place_name': 'Machesney Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3545, 'longitude': -89.0397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61125', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3254, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61126', 'place_name': 'Rockford', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3254, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61130', 'place_name': 'Loves Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3254, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61131', 'place_name': 'Loves Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3254, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61132', 'place_name': 'Loves Park', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Winnebago', 'locality_code': '201', 'latitude': 42.3254, 'longitude': -89.1705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61516', 'place_name': 'Benson', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.8306, 'longitude': -89.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61530', 'place_name': 'Eureka', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.7152, 'longitude': -89.2706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61545', 'place_name': 'Lowpoint', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.8793, 'longitude': -89.3703, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '61548', 'place_name': 'Metamora', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.7844, 'longitude': -89.4309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61561', 'place_name': 'Roanoke', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.7956, 'longitude': -89.2093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61729', 'place_name': 'Congerville', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.6208, 'longitude': -89.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61738', 'place_name': 'El Paso', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.7389, 'longitude': -89.012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61742', 'place_name': 'Goodfield', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.6329, 'longitude': -89.2727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61760', 'place_name': 'Minonk', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.8985, 'longitude': -89.0349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '61771', 'place_name': 'Secor', 'state': 'Illinois', 'state_ab': 'IL', 'county': 'Woodford', 'locality_code': '203', 'latitude': 40.7224, 'longitude': -89.1271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46711', 'place_name': 'Berne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.6716, 'longitude': -84.9343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46733', 'place_name': 'Decatur', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.8273, 'longitude': -84.9314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46740', 'place_name': 'Geneva', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.6071, 'longitude': -84.9621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46769', 'place_name': 'Linn Grove', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.645, 'longitude': -85.033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46772', 'place_name': 'Monroe', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.7005, 'longitude': -84.8441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46780', 'place_name': 'Pleasant Mills', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.7778, 'longitude': -84.8422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46782', 'place_name': 'Preble', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.832, 'longitude': -85.0054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46704', 'place_name': 'Arcola', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1038, 'longitude': -85.2925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46741', 'place_name': 'Grabill', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.2108, 'longitude': -84.9406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46743', 'place_name': 'Harlan', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.2285, 'longitude': -84.8386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46745', 'place_name': 'Hoagland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.9524, 'longitude': -85.0075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46748', 'place_name': 'Huntertown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.2391, 'longitude': -85.1677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46765', 'place_name': 'Leo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.2249, 'longitude': -85.0301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46773', 'place_name': 'Monroeville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.987, 'longitude': -84.8937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46774', 'place_name': 'New Haven', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0699, 'longitude': -85.0117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46797', 'place_name': 'Woodburn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1253, 'longitude': -84.8533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46798', 'place_name': 'Yoder', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.9371, 'longitude': -85.1958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46799', 'place_name': 'Zanesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.9188, 'longitude': -85.2824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46801', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46802', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0707, 'longitude': -85.1543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46803', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0695, 'longitude': -85.1074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46804', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0508, 'longitude': -85.256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46805', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0977, 'longitude': -85.1189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46806', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.048, 'longitude': -85.1135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46807', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0491, 'longitude': -85.1462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46808', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0939, 'longitude': -85.1621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46809', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0254, 'longitude': -85.1834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46814', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0456, 'longitude': -85.3058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46815', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1053, 'longitude': -85.0624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46816', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0165, 'longitude': -85.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46818', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1468, 'longitude': -85.2067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46819', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0052, 'longitude': -85.1527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46825', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1465, 'longitude': -85.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46835', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1371, 'longitude': -85.0685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46845', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1958, 'longitude': -85.1191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46850', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46851', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46852', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46853', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46854', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46855', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46856', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46857', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46858', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46859', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46860', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46861', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46862', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46863', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46864', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46865', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.1263, 'longitude': -85.0907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46866', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46867', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46868', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46869', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46885', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46895', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46896', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46897', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46898', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46899', 'place_name': 'Fort Wayne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Allen', 'locality_code': '3', 'latitude': 41.0938, 'longitude': -85.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47201', 'place_name': 'Columbus', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.2055, 'longitude': -85.9317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47202', 'place_name': 'Columbus', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.2014, 'longitude': -85.9214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47203', 'place_name': 'Columbus', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.2301, 'longitude': -85.8855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47226', 'place_name': 'Clifford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.2826, 'longitude': -85.8685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47232', 'place_name': 'Elizabethtown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.1243, 'longitude': -85.8153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47236', 'place_name': 'Grammer', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.1522, 'longitude': -85.7261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47244', 'place_name': 'Hartsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.2676, 'longitude': -85.698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47246', 'place_name': 'Hope', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.3039, 'longitude': -85.7714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47247', 'place_name': 'Jonesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.0593, 'longitude': -85.8886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47280', 'place_name': 'Taylorsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Bartholomew', 'locality_code': '5', 'latitude': 39.2953, 'longitude': -85.9498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47917', 'place_name': 'Ambia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.4793, 'longitude': -87.4796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47921', 'place_name': 'Boswell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.518, 'longitude': -87.3789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47942', 'place_name': 'Earl Park', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.6945, 'longitude': -87.4232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47944', 'place_name': 'Fowler', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.6255, 'longitude': -87.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47970', 'place_name': 'Otterbein', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.517, 'longitude': -87.1225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47971', 'place_name': 'Oxford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.5217, 'longitude': -87.2526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47984', 'place_name': 'Talbot', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.5053, 'longitude': -87.4542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47986', 'place_name': 'Templeton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Benton', 'locality_code': '7', 'latitude': 40.5055, 'longitude': -87.207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47348', 'place_name': 'Hartford City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Blackford', 'locality_code': '9', 'latitude': 40.4541, 'longitude': -85.3758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47359', 'place_name': 'Montpelier', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Blackford', 'locality_code': '9', 'latitude': 40.5577, 'longitude': -85.2513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46052', 'place_name': 'Lebanon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Boone', 'locality_code': '11', 'latitude': 40.0449, 'longitude': -86.4641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46071', 'place_name': 'Thorntown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Boone', 'locality_code': '11', 'latitude': 40.1133, 'longitude': -86.5898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46075', 'place_name': 'Whitestown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Boone', 'locality_code': '11', 'latitude': 40, 'longitude': -86.3507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46077', 'place_name': 'Zionsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Boone', 'locality_code': '11', 'latitude': 39.9561, 'longitude': -86.2767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46102', 'place_name': 'Advance', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Boone', 'locality_code': '11', 'latitude': 39.9956, 'longitude': -86.6198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46147', 'place_name': 'Jamestown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Boone', 'locality_code': '11', 'latitude': 39.9579, 'longitude': -86.6236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46160', 'place_name': 'Morgantown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.3628, 'longitude': -86.2803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47435', 'place_name': 'Helmsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.1963, 'longitude': -86.2302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47448', 'place_name': 'Nashville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.2367, 'longitude': -86.222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46913', 'place_name': 'Bringhurst', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.5163, 'longitude': -86.5204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46915', 'place_name': 'Burlington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.4777, 'longitude': -86.3866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46916', 'place_name': 'Burrows', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.6767, 'longitude': -86.5075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46917', 'place_name': 'Camden', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.5996, 'longitude': -86.5152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46920', 'place_name': 'Cutler', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.4785, 'longitude': -86.4462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46923', 'place_name': 'Delphi', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.5734, 'longitude': -86.6788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46929', 'place_name': 'Flora', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.5445, 'longitude': -86.5016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46977', 'place_name': 'Rockfield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.6411, 'longitude': -86.5739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47997', 'place_name': 'Yeoman', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Carroll', 'locality_code': '15', 'latitude': 40.6677, 'longitude': -86.7236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46932', 'place_name': 'Galveston', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.5862, 'longitude': -86.1972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46942', 'place_name': 'Lake Cicott', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.7361, 'longitude': -86.3734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46947', 'place_name': 'Logansport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.7604, 'longitude': -86.3599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46950', 'place_name': 'Lucerne', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.8614, 'longitude': -86.4077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46961', 'place_name': 'New Waverly', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.7621, 'longitude': -86.1936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46967', 'place_name': 'Onward', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.6947, 'longitude': -86.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46978', 'place_name': 'Royal Center', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.8645, 'longitude': -86.5078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46988', 'place_name': 'Twelve Mile', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.8547, 'longitude': -86.2126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46994', 'place_name': 'Walton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.6772, 'longitude': -86.2805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46998', 'place_name': 'Young America', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Cass', 'locality_code': '17', 'latitude': 40.5686, 'longitude': -86.3467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47104', 'place_name': 'Bethlehem', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.5399, 'longitude': -85.4218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47106', 'place_name': 'Borden', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.4362, 'longitude': -85.9215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47111', 'place_name': 'Charlestown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.4568, 'longitude': -85.6606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47126', 'place_name': 'Henryville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.5398, 'longitude': -85.7734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47129', 'place_name': 'Clarksville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.311, 'longitude': -85.7645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47130', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.3078, 'longitude': -85.7359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47131', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.437, 'longitude': -85.705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47132', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.2868, 'longitude': -85.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47133', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.2868, 'longitude': -85.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47134', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.2868, 'longitude': -85.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47141', 'place_name': 'Marysville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.5856, 'longitude': -85.6436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47143', 'place_name': 'Memphis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.4642, 'longitude': -85.7775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47144', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.2868, 'longitude': -85.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47147', 'place_name': 'Nabb', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.6128, 'longitude': -85.5217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47162', 'place_name': 'New Washington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.5575, 'longitude': -85.4599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47163', 'place_name': 'Otisco', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.5423, 'longitude': -85.6647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47172', 'place_name': 'Sellersburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.4046, 'longitude': -85.788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47177', 'place_name': 'Underwood', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.6037, 'longitude': -85.7744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47190', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.437, 'longitude': -85.705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47199', 'place_name': 'Jeffersonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clark', 'locality_code': '19', 'latitude': 38.2868, 'longitude': -85.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47833', 'place_name': 'Bowling Green', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.3812, 'longitude': -87.0052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47834', 'place_name': 'Brazil', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.521, 'longitude': -87.1278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47837', 'place_name': 'Carbon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.5913, 'longitude': -87.1132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47840', 'place_name': 'Centerpoint', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.391, 'longitude': -87.0935, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '47841', 'place_name': 'Clay City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.2727, 'longitude': -87.1082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47845', 'place_name': 'Coalmont', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.1934, 'longitude': -87.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47846', 'place_name': 'Cory', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.3435, 'longitude': -87.1956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47853', 'place_name': 'Harmony', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.5372, 'longitude': -87.0729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47857', 'place_name': 'Knightsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.5269, 'longitude': -87.0869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47868', 'place_name': 'Poland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.4462, 'longitude': -86.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47881', 'place_name': 'Staunton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clay', 'locality_code': '21', 'latitude': 39.4875, 'longitude': -87.1889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46035', 'place_name': 'Colfax', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.1956, 'longitude': -86.6593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46039', 'place_name': 'Forest', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.3757, 'longitude': -86.3201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46041', 'place_name': 'Frankfort', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.3044, 'longitude': -86.4689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46050', 'place_name': 'Kirklin', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.2031, 'longitude': -86.3324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46057', 'place_name': 'Michigantown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.3108, 'longitude': -86.3753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46058', 'place_name': 'Mulberry', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.3433, 'longitude': -86.6613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46065', 'place_name': 'Rossville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.4109, 'longitude': -86.608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46067', 'place_name': 'Sedalia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Clinton', 'locality_code': '23', 'latitude': 40.4156, 'longitude': -86.5147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47116', 'place_name': 'Eckerty', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.3185, 'longitude': -86.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47118', 'place_name': 'English', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.3258, 'longitude': -86.4429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47123', 'place_name': 'Grantsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.282, 'longitude': -86.4843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47137', 'place_name': 'Leavenworth', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.1865, 'longitude': -86.3838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47140', 'place_name': 'Marengo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.3736, 'longitude': -86.3578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47145', 'place_name': 'Milltown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.3445, 'longitude': -86.3003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47174', 'place_name': 'Sulphur', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.2259, 'longitude': -86.4908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47175', 'place_name': 'Taswell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Crawford', 'locality_code': '25', 'latitude': 38.3463, 'longitude': -86.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47501', 'place_name': 'Washington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Daviess', 'locality_code': '27', 'latitude': 38.6536, 'longitude': -87.1707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47519', 'place_name': 'Cannelburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Daviess', 'locality_code': '27', 'latitude': 38.6698, 'longitude': -86.9983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47529', 'place_name': 'Elnora', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Daviess', 'locality_code': '27', 'latitude': 38.8772, 'longitude': -87.085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47558', 'place_name': 'Montgomery', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Daviess', 'locality_code': '27', 'latitude': 38.6521, 'longitude': -87.0476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47562', 'place_name': 'Odon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Daviess', 'locality_code': '27', 'latitude': 38.8187, 'longitude': -86.9752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47568', 'place_name': 'Plainville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Daviess', 'locality_code': '27', 'latitude': 38.8062, 'longitude': -87.1522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47001', 'place_name': 'Aurora', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dearborn', 'locality_code': '29', 'latitude': 39.0719, 'longitude': -84.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47018', 'place_name': 'Dillsboro', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dearborn', 'locality_code': '29', 'latitude': 38.9962, 'longitude': -85.055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47022', 'place_name': 'Guilford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dearborn', 'locality_code': '29', 'latitude': 39.2059, 'longitude': -84.9616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47025', 'place_name': 'Lawrenceburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dearborn', 'locality_code': '29', 'latitude': 39.1401, 'longitude': -84.8658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47032', 'place_name': 'Moores Hill', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dearborn', 'locality_code': '29', 'latitude': 39.0945, 'longitude': -85.0638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47060', 'place_name': 'West Harrison', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dearborn', 'locality_code': '29', 'latitude': 39.3008, 'longitude': -84.881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47225', 'place_name': 'Clarksburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Decatur', 'locality_code': '31', 'latitude': 39.4241, 'longitude': -85.3477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47240', 'place_name': 'Greensburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Decatur', 'locality_code': '31', 'latitude': 39.2998, 'longitude': -85.4918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47261', 'place_name': 'Millhousen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Decatur', 'locality_code': '31', 'latitude': 39.292, 'longitude': -85.4918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47263', 'place_name': 'New Point', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Decatur', 'locality_code': '31', 'latitude': 39.3083, 'longitude': -85.3297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47272', 'place_name': 'Saint Paul', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Decatur', 'locality_code': '31', 'latitude': 39.4277, 'longitude': -85.5994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47283', 'place_name': 'Westport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Decatur', 'locality_code': '31', 'latitude': 39.1749, 'longitude': -85.5856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46705', 'place_name': 'Ashley', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.5347, 'longitude': -85.0504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46706', 'place_name': 'Auburn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.359, 'longitude': -85.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46721', 'place_name': 'Butler', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.4287, 'longitude': -84.8787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46730', 'place_name': 'Corunna', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.4504, 'longitude': -85.137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46738', 'place_name': 'Garrett', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.3482, 'longitude': -85.1347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46785', 'place_name': 'Saint Joe', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.324, 'longitude': -84.9043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46788', 'place_name': 'Spencerville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.2696, 'longitude': -84.9398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46793', 'place_name': 'Waterloo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'DeKalb', 'locality_code': '33', 'latitude': 41.4402, 'longitude': -85.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47302', 'place_name': 'Muncie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.1684, 'longitude': -85.3807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47303', 'place_name': 'Muncie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.218, 'longitude': -85.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47304', 'place_name': 'Muncie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.2111, 'longitude': -85.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47305', 'place_name': 'Muncie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.1933, 'longitude': -85.3862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47306', 'place_name': 'Muncie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.2023, 'longitude': -85.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47307', 'place_name': 'Muncie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.1621, 'longitude': -85.4428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47308', 'place_name': 'Muncie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.2279, 'longitude': -85.3967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47320', 'place_name': 'Albany', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.292, 'longitude': -85.258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47334', 'place_name': 'Daleville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.1257, 'longitude': -85.511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47338', 'place_name': 'Eaton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.3377, 'longitude': -85.3544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47342', 'place_name': 'Gaston', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.2948, 'longitude': -85.4898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47367', 'place_name': 'Oakville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.0792, 'longitude': -85.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47383', 'place_name': 'Selma', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.1693, 'longitude': -85.2738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47396', 'place_name': 'Yorktown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Delaware', 'locality_code': '35', 'latitude': 40.1836, 'longitude': -85.496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47513', 'place_name': 'Birdseye', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.3006, 'longitude': -86.7102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47521', 'place_name': 'Celestine', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.3878, 'longitude': -86.7568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47527', 'place_name': 'Dubois', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.4728, 'longitude': -86.7832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47532', 'place_name': 'Ferdinand', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.2336, 'longitude': -86.8607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47541', 'place_name': 'Holland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.2456, 'longitude': -87.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47542', 'place_name': 'Huntingburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.2979, 'longitude': -86.9533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47545', 'place_name': 'Ireland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.4137, 'longitude': -87.0009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47546', 'place_name': 'Jasper', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.3604, 'longitude': -86.9295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47547', 'place_name': 'Jasper', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.3647, 'longitude': -86.8762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47549', 'place_name': 'Jasper', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.3647, 'longitude': -86.8762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47575', 'place_name': 'Saint Anthony', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.3211, 'longitude': -86.8234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47580', 'place_name': 'Schnellville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Dubois', 'locality_code': '37', 'latitude': 38.3414, 'longitude': -86.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46507', 'place_name': 'Bristol', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.7169, 'longitude': -85.8262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46514', 'place_name': 'Elkhart', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.7101, 'longitude': -85.9729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46515', 'place_name': 'Elkhart', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.682, 'longitude': -85.9767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46516', 'place_name': 'Elkhart', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.6763, 'longitude': -85.9621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46517', 'place_name': 'Elkhart', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.6469, 'longitude': -85.9728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46526', 'place_name': 'Goshen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.5848, 'longitude': -85.8581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46527', 'place_name': 'Goshen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.5977, 'longitude': -85.8581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46528', 'place_name': 'Goshen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.6248, 'longitude': -85.8391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46540', 'place_name': 'Middlebury', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.6754, 'longitude': -85.7114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46543', 'place_name': 'Millersburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.5335, 'longitude': -85.7072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46550', 'place_name': 'Nappanee', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.4493, 'longitude': -85.9945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46553', 'place_name': 'New Paris', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.4917, 'longitude': -85.8338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46573', 'place_name': 'Wakarusa', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Elkhart', 'locality_code': '39', 'latitude': 41.5401, 'longitude': -86.0205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46133', 'place_name': 'Glenwood', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fayette', 'locality_code': '41', 'latitude': 39.6124, 'longitude': -85.2735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47322', 'place_name': 'Bentonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fayette', 'locality_code': '41', 'latitude': 39.657, 'longitude': -85.168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47331', 'place_name': 'Connersville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fayette', 'locality_code': '41', 'latitude': 39.6435, 'longitude': -85.1464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47119', 'place_name': 'Floyds Knobs', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Floyd', 'locality_code': '43', 'latitude': 38.351, 'longitude': -85.8996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47122', 'place_name': 'Georgetown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Floyd', 'locality_code': '43', 'latitude': 38.3029, 'longitude': -85.9617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47124', 'place_name': 'Greenville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Floyd', 'locality_code': '43', 'latitude': 38.3535, 'longitude': -86.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47146', 'place_name': 'Mount Saint Francis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Floyd', 'locality_code': '43', 'latitude': 38.2985, 'longitude': -85.897, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '47150', 'place_name': 'New Albany', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Floyd', 'locality_code': '43', 'latitude': 38.3089, 'longitude': -85.8221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47151', 'place_name': 'New Albany', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Floyd', 'locality_code': '43', 'latitude': 38.2856, 'longitude': -85.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47918', 'place_name': 'Attica', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 40.2811, 'longitude': -87.2241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47932', 'place_name': 'Covington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 40.1326, 'longitude': -87.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47949', 'place_name': 'Hillsboro', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 40.0835, 'longitude': -87.1545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47952', 'place_name': 'Kingman', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 40.0174, 'longitude': -87.2569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47958', 'place_name': 'Mellott', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 40.1641, 'longitude': -87.1475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47969', 'place_name': 'Newtown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 40.2035, 'longitude': -87.147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47987', 'place_name': 'Veedersburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 40.1186, 'longitude': -87.2602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47988', 'place_name': 'Wallace', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fountain', 'locality_code': '45', 'latitude': 39.9865, 'longitude': -87.1477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47003', 'place_name': 'West College Corner', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.5676, 'longitude': -84.8161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47010', 'place_name': 'Bath', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.4992, 'longitude': -84.836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47012', 'place_name': 'Brookville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.4213, 'longitude': -84.9994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47016', 'place_name': 'Cedar Grove', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.3459, 'longitude': -84.8924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47024', 'place_name': 'Laurel', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.4916, 'longitude': -85.208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47030', 'place_name': 'Metamora', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.4288, 'longitude': -85.1504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47035', 'place_name': 'New Trenton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.31, 'longitude': -84.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47036', 'place_name': 'Oldenburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Franklin', 'locality_code': '47', 'latitude': 39.3862, 'longitude': -85.2385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46910', 'place_name': 'Akron', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 41.0389, 'longitude': -86.0395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46912', 'place_name': 'Athens', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 41.0537, 'longitude': -86.1253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46922', 'place_name': 'Delong', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 41.1384, 'longitude': -86.4164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46931', 'place_name': 'Fulton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 40.9473, 'longitude': -86.2628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46935', 'place_name': 'Grass Creek', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 40.9475, 'longitude': -86.4044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46939', 'place_name': 'Kewanna', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 41.0087, 'longitude': -86.4061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46945', 'place_name': 'Leiters Ford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 41.1217, 'longitude': -86.3858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46975', 'place_name': 'Rochester', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Fulton', 'locality_code': '49', 'latitude': 41.0655, 'longitude': -86.231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47639', 'place_name': 'Haubstadt', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.1895, 'longitude': -87.5798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47640', 'place_name': 'Hazleton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.4623, 'longitude': -87.4983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47647', 'place_name': 'Buckskin', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.2284, 'longitude': -87.412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47648', 'place_name': 'Fort Branch', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.2471, 'longitude': -87.5682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47649', 'place_name': 'Francisco', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.333, 'longitude': -87.4536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47654', 'place_name': 'Mackey', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.2523, 'longitude': -87.3917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47660', 'place_name': 'Oakland City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.3361, 'longitude': -87.3519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47665', 'place_name': 'Owensville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.2744, 'longitude': -87.7091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47666', 'place_name': 'Patoka', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.4143, 'longitude': -87.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47670', 'place_name': 'Princeton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.3525, 'longitude': -87.5691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47683', 'place_name': 'Somerville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Gibson', 'locality_code': '51', 'latitude': 38.2764, 'longitude': -87.3778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46928', 'place_name': 'Fairmount', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.4188, 'longitude': -85.6713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46930', 'place_name': 'Fowlerton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.4099, 'longitude': -85.571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46933', 'place_name': 'Gas City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.4879, 'longitude': -85.6055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46938', 'place_name': 'Jonesboro', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.4815, 'longitude': -85.6365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46952', 'place_name': 'Marion', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.5743, 'longitude': -85.6741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46953', 'place_name': 'Marion', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.5359, 'longitude': -85.6616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46957', 'place_name': 'Matthews', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.3887, 'longitude': -85.4994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46986', 'place_name': 'Swayzee', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.5112, 'longitude': -85.8265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46987', 'place_name': 'Sweetser', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.5647, 'longitude': -85.7656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46989', 'place_name': 'Upland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.4548, 'longitude': -85.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46991', 'place_name': 'Van Buren', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Grant', 'locality_code': '53', 'latitude': 40.6174, 'longitude': -85.5148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47424', 'place_name': 'Bloomfield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.0295, 'longitude': -86.8675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47438', 'place_name': 'Jasonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.1723, 'longitude': -87.2023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47439', 'place_name': 'Koleen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.0371, 'longitude': -86.9616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47441', 'place_name': 'Linton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.0461, 'longitude': -87.1723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47443', 'place_name': 'Lyons', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 38.9717, 'longitude': -87.1016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47445', 'place_name': 'Midland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.122, 'longitude': -87.1917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47449', 'place_name': 'Newberry', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 38.9229, 'longitude': -87.0081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47453', 'place_name': 'Owensburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 38.9253, 'longitude': -86.7742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47457', 'place_name': 'Scotland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 38.9128, 'longitude': -86.9039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47459', 'place_name': 'Solsberry', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.119, 'longitude': -86.7378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47465', 'place_name': 'Switz City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.0369, 'longitude': -87.0502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47471', 'place_name': 'Worthington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Greene', 'locality_code': '55', 'latitude': 39.123, 'longitude': -86.9991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46030', 'place_name': 'Arcadia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.1776, 'longitude': -86.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46031', 'place_name': 'Atlanta', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.2103, 'longitude': -86.019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46032', 'place_name': 'Carmel', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9712, 'longitude': -86.1245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46033', 'place_name': 'Carmel', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9744, 'longitude': -86.0829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46034', 'place_name': 'Cicero', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.1298, 'longitude': -86.0381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46037', 'place_name': 'Fishers', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9559, 'longitude': -85.9601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46038', 'place_name': 'Fishers', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9575, 'longitude': -86.023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46060', 'place_name': 'Noblesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.0563, 'longitude': -86.0163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46061', 'place_name': 'Noblesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.0725, 'longitude': -86.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46062', 'place_name': 'Noblesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.0617, 'longitude': -86.0555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46069', 'place_name': 'Sheridan', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.135, 'longitude': -86.2205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46074', 'place_name': 'Westfield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.0489, 'longitude': -86.1499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46082', 'place_name': 'Carmel', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 40.0725, 'longitude': -86.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46085', 'place_name': 'Fishers', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9556, 'longitude': -86.0139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46262', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.7684, 'longitude': -86.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46280', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9416, 'longitude': -86.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46288', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9347, 'longitude': -86.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46290', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hamilton', 'locality_code': '57', 'latitude': 39.9347, 'longitude': -86.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46040', 'place_name': 'Fortville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.9323, 'longitude': -85.848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46055', 'place_name': 'Mccordsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.9081, 'longitude': -85.9228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46117', 'place_name': 'Charlottesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.8388, 'longitude': -85.6258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46129', 'place_name': 'Finly', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.8215, 'longitude': -85.7652, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '46140', 'place_name': 'Greenfield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.7902, 'longitude': -85.8141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46154', 'place_name': 'Maxwell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.8568, 'longitude': -85.7684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46163', 'place_name': 'New Palestine', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.7233, 'longitude': -85.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46186', 'place_name': 'Wilkinson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hancock', 'locality_code': '59', 'latitude': 39.8957, 'longitude': -85.6144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47107', 'place_name': 'Bradford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.3678, 'longitude': -86.0619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47110', 'place_name': 'Central', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.097, 'longitude': -86.1723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47112', 'place_name': 'Corydon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.2189, 'longitude': -86.1145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47114', 'place_name': 'Crandall', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.2876, 'longitude': -86.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47115', 'place_name': 'Depauw', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.3361, 'longitude': -86.2109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47117', 'place_name': 'Elizabeth', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.1244, 'longitude': -85.9589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47135', 'place_name': 'Laconia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.0527, 'longitude': -86.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47136', 'place_name': 'Lanesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.2448, 'longitude': -85.9593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47142', 'place_name': 'Mauckport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.0437, 'longitude': -86.1846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47160', 'place_name': 'New Middletown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.1645, 'longitude': -86.051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47161', 'place_name': 'New Salisbury', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.3399, 'longitude': -86.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47164', 'place_name': 'Palmyra', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.4105, 'longitude': -86.0888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47166', 'place_name': 'Ramsey', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Harrison', 'locality_code': '61', 'latitude': 38.3034, 'longitude': -86.169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46103', 'place_name': 'Amo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.6886, 'longitude': -86.6136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46112', 'place_name': 'Brownsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.8466, 'longitude': -86.3869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46118', 'place_name': 'Clayton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.6682, 'longitude': -86.4959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46121', 'place_name': 'Coatesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.6878, 'longitude': -86.6703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46122', 'place_name': 'Danville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.7628, 'longitude': -86.5343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46123', 'place_name': 'Avon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.7629, 'longitude': -86.3996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46149', 'place_name': 'Lizton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.8843, 'longitude': -86.5429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46165', 'place_name': 'North Salem', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.8671, 'longitude': -86.6388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46167', 'place_name': 'Pittsboro', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.8615, 'longitude': -86.4645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46168', 'place_name': 'Plainfield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.6893, 'longitude': -86.3919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46180', 'place_name': 'Stilesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Hendricks', 'locality_code': '63', 'latitude': 39.6391, 'longitude': -86.6182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46148', 'place_name': 'Knightstown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.806, 'longitude': -85.5261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47337', 'place_name': 'Dunreith', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.8031, 'longitude': -85.4371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47344', 'place_name': 'Greensboro', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.8789, 'longitude': -85.464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47351', 'place_name': 'Kennard', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.904, 'longitude': -85.5205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47352', 'place_name': 'Lewisville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.8283, 'longitude': -85.3621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47356', 'place_name': 'Middletown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 40.0475, 'longitude': -85.5368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47360', 'place_name': 'Mooreland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.9941, 'longitude': -85.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47361', 'place_name': 'Mount Summit', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 40.0042, 'longitude': -85.3851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47362', 'place_name': 'New Castle', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.9208, 'longitude': -85.3663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47366', 'place_name': 'New Lisbon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.8634, 'longitude': -85.263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47384', 'place_name': 'Shirley', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.9158, 'longitude': -85.5182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47385', 'place_name': 'Spiceland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.8271, 'longitude': -85.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47386', 'place_name': 'Springport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 40.0527, 'longitude': -85.3833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47387', 'place_name': 'Straughn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 39.8319, 'longitude': -85.2724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47388', 'place_name': 'Sulphur Springs', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Henry', 'locality_code': '65', 'latitude': 40.006, 'longitude': -85.4434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46901', 'place_name': 'Kokomo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4988, 'longitude': -86.1453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46902', 'place_name': 'Kokomo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4509, 'longitude': -86.1352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46903', 'place_name': 'Kokomo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4696, 'longitude': -86.1189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46904', 'place_name': 'Kokomo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4696, 'longitude': -86.1189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46936', 'place_name': 'Greentown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4791, 'longitude': -85.9582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46937', 'place_name': 'Hemlock', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4187, 'longitude': -86.0181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46965', 'place_name': 'Oakford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4127, 'longitude': -86.1015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46979', 'place_name': 'Russiaville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4151, 'longitude': -86.2675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46995', 'place_name': 'West Middleton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Howard', 'locality_code': '67', 'latitude': 40.4421, 'longitude': -86.2155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46702', 'place_name': 'Andrews', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Huntington', 'locality_code': '69', 'latitude': 40.8618, 'longitude': -85.6067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46713', 'place_name': 'Bippus', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Huntington', 'locality_code': '69', 'latitude': 40.9442, 'longitude': -85.6239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46750', 'place_name': 'Huntington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Huntington', 'locality_code': '69', 'latitude': 40.8811, 'longitude': -85.5054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46770', 'place_name': 'Markle', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Huntington', 'locality_code': '69', 'latitude': 40.8331, 'longitude': -85.319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46783', 'place_name': 'Roanoke', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Huntington', 'locality_code': '69', 'latitude': 40.96, 'longitude': -85.3526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46792', 'place_name': 'Warren', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Huntington', 'locality_code': '69', 'latitude': 40.6886, 'longitude': -85.4183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47220', 'place_name': 'Brownstown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.8836, 'longitude': -86.0486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47228', 'place_name': 'Cortland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.9745, 'longitude': -85.9628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47229', 'place_name': 'Crothersville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.8067, 'longitude': -85.847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47235', 'place_name': 'Freetown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.9957, 'longitude': -86.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47249', 'place_name': 'Kurtz', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.9606, 'longitude': -86.2033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47260', 'place_name': 'Medora', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.8255, 'longitude': -86.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47264', 'place_name': 'Norman', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.9526, 'longitude': -86.275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47274', 'place_name': 'Seymour', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.9571, 'longitude': -85.8825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47281', 'place_name': 'Vallonia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jackson', 'locality_code': '71', 'latitude': 38.8174, 'longitude': -86.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46310', 'place_name': 'Demotte', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jasper', 'locality_code': '73', 'latitude': 41.1713, 'longitude': -87.2491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46380', 'place_name': 'Tefft', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jasper', 'locality_code': '73', 'latitude': 41.1948, 'longitude': -86.9686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46392', 'place_name': 'Wheatfield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jasper', 'locality_code': '73', 'latitude': 41.1779, 'longitude': -87.0699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47943', 'place_name': 'Fair Oaks', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jasper', 'locality_code': '73', 'latitude': 41.075, 'longitude': -87.2575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47977', 'place_name': 'Remington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jasper', 'locality_code': '73', 'latitude': 40.7667, 'longitude': -87.1599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47978', 'place_name': 'Rensselaer', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jasper', 'locality_code': '73', 'latitude': 40.9948, 'longitude': -87.1037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47326', 'place_name': 'Bryant', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jay', 'locality_code': '75', 'latitude': 40.5446, 'longitude': -84.9117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47336', 'place_name': 'Dunkirk', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jay', 'locality_code': '75', 'latitude': 40.3883, 'longitude': -85.2255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47369', 'place_name': 'Pennville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jay', 'locality_code': '75', 'latitude': 40.5082, 'longitude': -85.1492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47371', 'place_name': 'Portland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jay', 'locality_code': '75', 'latitude': 40.4306, 'longitude': -84.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47373', 'place_name': 'Redkey', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jay', 'locality_code': '75', 'latitude': 40.3265, 'longitude': -85.162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47381', 'place_name': 'Salamonia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jay', 'locality_code': '75', 'latitude': 40.3818, 'longitude': -84.8669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47224', 'place_name': 'Canaan', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jefferson', 'locality_code': '77', 'latitude': 38.887, 'longitude': -85.2213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47230', 'place_name': 'Deputy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jefferson', 'locality_code': '77', 'latitude': 38.7759, 'longitude': -85.6304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47231', 'place_name': 'Dupont', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jefferson', 'locality_code': '77', 'latitude': 38.8905, 'longitude': -85.5092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47243', 'place_name': 'Hanover', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jefferson', 'locality_code': '77', 'latitude': 38.7138, 'longitude': -85.4763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47250', 'place_name': 'Madison', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jefferson', 'locality_code': '77', 'latitude': 38.7649, 'longitude': -85.407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47223', 'place_name': 'Butlerville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jennings', 'locality_code': '79', 'latitude': 39.0491, 'longitude': -85.4789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47227', 'place_name': 'Commiskey', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jennings', 'locality_code': '79', 'latitude': 38.8526, 'longitude': -85.6434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47245', 'place_name': 'Hayden', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jennings', 'locality_code': '79', 'latitude': 38.9831, 'longitude': -85.7405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47265', 'place_name': 'North Vernon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jennings', 'locality_code': '79', 'latitude': 39.0018, 'longitude': -85.6272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47270', 'place_name': 'Paris Crossing', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jennings', 'locality_code': '79', 'latitude': 38.8558, 'longitude': -85.7487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47273', 'place_name': 'Scipio', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jennings', 'locality_code': '79', 'latitude': 39.0665, 'longitude': -85.7129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47282', 'place_name': 'Vernon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Jennings', 'locality_code': '79', 'latitude': 38.9848, 'longitude': -85.6094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46106', 'place_name': 'Bargersville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.5, 'longitude': -86.1797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46124', 'place_name': 'Edinburgh', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.3626, 'longitude': -85.9707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46131', 'place_name': 'Franklin', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.4854, 'longitude': -86.0608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46142', 'place_name': 'Greenwood', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.6224, 'longitude': -86.149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46143', 'place_name': 'Greenwood', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.596, 'longitude': -86.1309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46162', 'place_name': 'Needham', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.5605, 'longitude': -85.9656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46164', 'place_name': 'Nineveh', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.3656, 'longitude': -86.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46181', 'place_name': 'Trafalgar', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.3696, 'longitude': -86.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46184', 'place_name': 'Whiteland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Johnson', 'locality_code': '81', 'latitude': 39.5611, 'longitude': -86.0723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47512', 'place_name': 'Bicknell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.7727, 'longitude': -87.3137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47516', 'place_name': 'Bruceville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.7563, 'longitude': -87.4313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47524', 'place_name': 'Decker', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.5076, 'longitude': -87.5537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47528', 'place_name': 'Edwardsport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.8106, 'longitude': -87.2519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47535', 'place_name': 'Freelandville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.8627, 'longitude': -87.3127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47557', 'place_name': 'Monroe City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.6001, 'longitude': -87.3641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47561', 'place_name': 'Oaktown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.8579, 'longitude': -87.3879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47573', 'place_name': 'Ragsdale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.7441, 'longitude': -87.3214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47578', 'place_name': 'Sandborn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.8817, 'longitude': -87.2025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47591', 'place_name': 'Vincennes', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.6734, 'longitude': -87.5098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47596', 'place_name': 'Westphalia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.8628, 'longitude': -87.2256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47597', 'place_name': 'Wheatland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Knox', 'locality_code': '83', 'latitude': 38.6671, 'longitude': -87.3062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46502', 'place_name': 'Atwood', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.254, 'longitude': -85.9697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46508', 'place_name': 'Burket', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.1547, 'longitude': -85.9693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46510', 'place_name': 'Claypool', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.1165, 'longitude': -85.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46524', 'place_name': 'Etna Green', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.2918, 'longitude': -86.035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46538', 'place_name': 'Leesburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.3266, 'longitude': -85.816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46539', 'place_name': 'Mentone', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.1615, 'longitude': -86.0299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46542', 'place_name': 'Milford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.4011, 'longitude': -85.8554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46555', 'place_name': 'North Webster', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.3326, 'longitude': -85.7103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46562', 'place_name': 'Pierceton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.2124, 'longitude': -85.7061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46567', 'place_name': 'Syracuse', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.4065, 'longitude': -85.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46580', 'place_name': 'Warsaw', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.2438, 'longitude': -85.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46581', 'place_name': 'Warsaw', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.2394, 'longitude': -85.8643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46582', 'place_name': 'Warsaw', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.2842, 'longitude': -85.8547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46590', 'place_name': 'Winona Lake', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.211, 'longitude': -85.8305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46982', 'place_name': 'Silver Lake', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Kosciusko', 'locality_code': '85', 'latitude': 41.0743, 'longitude': -85.8792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46565', 'place_name': 'Shipshewana', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.6633, 'longitude': -85.5932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46571', 'place_name': 'Topeka', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.5634, 'longitude': -85.5317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46746', 'place_name': 'Howe', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.7286, 'longitude': -85.4727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46761', 'place_name': 'Lagrange', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.652, 'longitude': -85.404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46771', 'place_name': 'Mongo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.6848, 'longitude': -85.2797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46786', 'place_name': 'South Milford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.5326, 'longitude': -85.2722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46789', 'place_name': 'Stroh', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.5835, 'longitude': -85.1992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46795', 'place_name': 'Wolcottville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaGrange', 'locality_code': '87', 'latitude': 41.557, 'longitude': -85.315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46303', 'place_name': 'Cedar Lake', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.3713, 'longitude': -87.4764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46307', 'place_name': 'Crown Point', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.4236, 'longitude': -87.3556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46308', 'place_name': 'Crown Point', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.417, 'longitude': -87.3653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46311', 'place_name': 'Dyer', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.492, 'longitude': -87.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46312', 'place_name': 'East Chicago', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.6349, 'longitude': -87.4627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46319', 'place_name': 'Griffith', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5335, 'longitude': -87.4228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46320', 'place_name': 'Hammond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.6099, 'longitude': -87.5079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46321', 'place_name': 'Munster', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5544, 'longitude': -87.5011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46322', 'place_name': 'Highland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.55, 'longitude': -87.4569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46323', 'place_name': 'Hammond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5878, 'longitude': -87.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46324', 'place_name': 'Hammond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.584, 'longitude': -87.5034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46325', 'place_name': 'Hammond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.4615, 'longitude': -87.3728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46327', 'place_name': 'Hammond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.6327, 'longitude': -87.5113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46342', 'place_name': 'Hobart', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5263, 'longitude': -87.2525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46355', 'place_name': 'Leroy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.3594, 'longitude': -87.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46356', 'place_name': 'Lowell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.2845, 'longitude': -87.4191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46373', 'place_name': 'Saint John', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.4495, 'longitude': -87.4764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46375', 'place_name': 'Schererville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.4922, 'longitude': -87.4605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46376', 'place_name': 'Schneider', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.19, 'longitude': -87.4779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46377', 'place_name': 'Shelby', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.1917, 'longitude': -87.3398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46394', 'place_name': 'Whiting', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.6787, 'longitude': -87.5005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46401', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5907, 'longitude': -87.3199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46402', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5997, 'longitude': -87.3385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46403', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.6036, 'longitude': -87.259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46404', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5899, 'longitude': -87.3732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46405', 'place_name': 'Lake Station', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5686, 'longitude': -87.2622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46406', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5878, 'longitude': -87.4062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46407', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5804, 'longitude': -87.335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46408', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5422, 'longitude': -87.3588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46409', 'place_name': 'Gary', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.5412, 'longitude': -87.3271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46410', 'place_name': 'Merrillville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.4957, 'longitude': -87.3509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46411', 'place_name': 'Merrillville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lake', 'locality_code': '89', 'latitude': 41.4615, 'longitude': -87.3728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46340', 'place_name': 'Hanna', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.4088, 'longitude': -86.7759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46345', 'place_name': 'Kingsbury', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.526, 'longitude': -86.6997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46346', 'place_name': 'Kingsford Heights', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.4802, 'longitude': -86.6919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46348', 'place_name': 'La Crosse', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.3157, 'longitude': -86.8682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46350', 'place_name': 'La Porte', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.5994, 'longitude': -86.7077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46352', 'place_name': 'La Porte', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.499, 'longitude': -86.7099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46360', 'place_name': 'Michigan City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.698, 'longitude': -86.8699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46361', 'place_name': 'Michigan City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.7035, 'longitude': -86.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46365', 'place_name': 'Mill Creek', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.6091, 'longitude': -86.544, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '46371', 'place_name': 'Rolling Prairie', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.7229, 'longitude': -86.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46382', 'place_name': 'Union Mills', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.4602, 'longitude': -86.8355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46390', 'place_name': 'Wanatah', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.3845, 'longitude': -86.8764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46391', 'place_name': 'Westville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'LaPorte', 'locality_code': '91', 'latitude': 41.5365, 'longitude': -86.9013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47420', 'place_name': 'Avoca', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.9132, 'longitude': -86.5489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47421', 'place_name': 'Bedford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.8729, 'longitude': -86.4871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47436', 'place_name': 'Heltonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.948, 'longitude': -86.3703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47437', 'place_name': 'Huron', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.7222, 'longitude': -86.671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47446', 'place_name': 'Mitchell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.7426, 'longitude': -86.4761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47451', 'place_name': 'Oolitic', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.8938, 'longitude': -86.5246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47462', 'place_name': 'Springville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.9507, 'longitude': -86.6139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47467', 'place_name': 'Tunnelton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.7687, 'longitude': -86.3428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47470', 'place_name': 'Williams', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Lawrence', 'locality_code': '93', 'latitude': 38.7735, 'longitude': -86.6285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46001', 'place_name': 'Alexandria', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.2561, 'longitude': -85.6681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46011', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.1146, 'longitude': -85.7253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46012', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.1309, 'longitude': -85.6536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46013', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.0619, 'longitude': -85.6801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46014', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.1617, 'longitude': -85.7197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46015', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.0938, 'longitude': -85.6578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46016', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.0988, 'longitude': -85.6846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46017', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.0742, 'longitude': -85.6069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46018', 'place_name': 'Anderson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.1617, 'longitude': -85.7197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46036', 'place_name': 'Elwood', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.2803, 'longitude': -85.8391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46044', 'place_name': 'Frankton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.2285, 'longitude': -85.7791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46048', 'place_name': 'Ingalls', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 39.9573, 'longitude': -85.7981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46051', 'place_name': 'Lapel', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.0854, 'longitude': -85.844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46056', 'place_name': 'Markleville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 39.9944, 'longitude': -85.6227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46063', 'place_name': 'Orestes', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.2715, 'longitude': -85.7281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46064', 'place_name': 'Pendleton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 39.9975, 'longitude': -85.7466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46070', 'place_name': 'Summitville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Madison', 'locality_code': '95', 'latitude': 40.3398, 'longitude': -85.6403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46107', 'place_name': 'Beech Grove', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7154, 'longitude': -86.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46113', 'place_name': 'Camby', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.6405, 'longitude': -86.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46183', 'place_name': 'West Newton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.6531, 'longitude': -86.2828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46201', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.775, 'longitude': -86.1093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46202', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7851, 'longitude': -86.1595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46203', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.743, 'longitude': -86.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46204', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.772, 'longitude': -86.1535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46205', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8268, 'longitude': -86.1386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46206', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7613, 'longitude': -86.1613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46207', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7673, 'longitude': -86.1606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46208', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8299, 'longitude': -86.1794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46209', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46211', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46213', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.9213, 'longitude': -86.0344, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '46214', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7924, 'longitude': -86.2875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46216', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8647, 'longitude': -86.0136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46217', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.6782, 'longitude': -86.1976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46218', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8082, 'longitude': -86.1014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46219', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7821, 'longitude': -86.0495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46220', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8647, 'longitude': -86.1181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46221', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7509, 'longitude': -86.1924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46222', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.789, 'longitude': -86.2136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46224', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.794, 'longitude': -86.2707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46225', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7406, 'longitude': -86.1569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46226', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8326, 'longitude': -86.0836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46227', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.6789, 'longitude': -86.1302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46228', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8462, 'longitude': -86.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46229', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7886, 'longitude': -85.9779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46230', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46231', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7038, 'longitude': -86.3029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46234', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8088, 'longitude': -86.3163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46235', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8471, 'longitude': -85.9741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46236', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8689, 'longitude': -85.9765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46237', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.673, 'longitude': -86.0757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46239', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7265, 'longitude': -86.0005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46240', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.9069, 'longitude': -86.1238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46241', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7096, 'longitude': -86.2614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46242', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46244', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46247', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46249', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.859, 'longitude': -86.0061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46250', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.9048, 'longitude': -86.0673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46251', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46253', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46254', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.849, 'longitude': -86.272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46255', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7684, 'longitude': -86.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46256', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8977, 'longitude': -86.0094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46259', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.667, 'longitude': -85.9981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46260', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8977, 'longitude': -86.1797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46266', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7684, 'longitude': -86.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46268', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8682, 'longitude': -86.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46274', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46275', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46277', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46278', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.8726, 'longitude': -86.2768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46282', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46283', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46285', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46291', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46295', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46296', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.796, 'longitude': -86.1495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46298', 'place_name': 'Indianapolis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marion', 'locality_code': '97', 'latitude': 39.7795, 'longitude': -86.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46501', 'place_name': 'Argos', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.2308, 'longitude': -86.2506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46504', 'place_name': 'Bourbon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.3098, 'longitude': -86.1174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46506', 'place_name': 'Bremen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.4467, 'longitude': -86.1932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46511', 'place_name': 'Culver', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.22, 'longitude': -86.4269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46513', 'place_name': 'Donaldson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.3619, 'longitude': -86.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46537', 'place_name': 'Lapaz', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.4599, 'longitude': -86.3102, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '46563', 'place_name': 'Plymouth', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.353, 'longitude': -86.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46570', 'place_name': 'Tippecanoe', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.2166, 'longitude': -86.1095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46572', 'place_name': 'Tyner', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Marshall', 'locality_code': '99', 'latitude': 41.4098, 'longitude': -86.4025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47522', 'place_name': 'Crane', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Martin', 'locality_code': '101', 'latitude': 38.8949, 'longitude': -86.9002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47553', 'place_name': 'Loogootee', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Martin', 'locality_code': '101', 'latitude': 38.6629, 'longitude': -86.9137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47581', 'place_name': 'Shoals', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Martin', 'locality_code': '101', 'latitude': 38.6791, 'longitude': -86.7761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46911', 'place_name': 'Amboy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.6105, 'longitude': -85.9497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46914', 'place_name': 'Bunker Hill', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.6423, 'longitude': -86.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46919', 'place_name': 'Converse', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.577, 'longitude': -85.8763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46921', 'place_name': 'Deedsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.9103, 'longitude': -86.1011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46926', 'place_name': 'Denver', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.867, 'longitude': -86.0752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46951', 'place_name': 'Macy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.9618, 'longitude': -86.1264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46958', 'place_name': 'Mexico', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.8224, 'longitude': -86.1162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46959', 'place_name': 'Miami', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.6147, 'longitude': -86.1064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46970', 'place_name': 'Peru', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.7492, 'longitude': -86.068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46971', 'place_name': 'Grissom Arb', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Miami', 'locality_code': '103', 'latitude': 40.6683, 'longitude': -86.1378, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '47401', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.1401, 'longitude': -86.5083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47402', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.1732, 'longitude': -86.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47403', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.1263, 'longitude': -86.5769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47404', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.195, 'longitude': -86.5757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47405', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.1682, 'longitude': -86.5186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47406', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.1745, 'longitude': -86.5183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47407', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.1732, 'longitude': -86.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47408', 'place_name': 'Bloomington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.2303, 'longitude': -86.4692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47426', 'place_name': 'Clear Creek', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.1732, 'longitude': -86.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47429', 'place_name': 'Ellettsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.2545, 'longitude': -86.6196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47434', 'place_name': 'Harrodsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.013, 'longitude': -86.5457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47458', 'place_name': 'Smithville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.0712, 'longitude': -86.5069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47463', 'place_name': 'Stanford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.0859, 'longitude': -86.6689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47464', 'place_name': 'Stinesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.2998, 'longitude': -86.6482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47468', 'place_name': 'Unionville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Monroe', 'locality_code': '105', 'latitude': 39.2514, 'longitude': -86.4189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47916', 'place_name': 'Alamo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 39.9836, 'longitude': -87.0554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47933', 'place_name': 'Crawfordsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 40.0325, 'longitude': -86.9074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47940', 'place_name': 'Darlington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 40.1118, 'longitude': -86.7645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47954', 'place_name': 'Ladoga', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 39.9132, 'longitude': -86.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47955', 'place_name': 'Linden', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 40.1833, 'longitude': -86.8905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47965', 'place_name': 'New Market', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 39.9524, 'longitude': -86.9206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47967', 'place_name': 'New Richmond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 40.1812, 'longitude': -86.9789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47968', 'place_name': 'New Ross', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 39.9883, 'longitude': -86.7528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47989', 'place_name': 'Waveland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 39.902, 'longitude': -87.0178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47990', 'place_name': 'Waynetown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 40.0858, 'longitude': -87.0512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47994', 'place_name': 'Wingate', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Montgomery', 'locality_code': '107', 'latitude': 40.1666, 'longitude': -87.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46111', 'place_name': 'Brooklyn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Morgan', 'locality_code': '109', 'latitude': 39.5396, 'longitude': -86.3701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46125', 'place_name': 'Eminence', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Morgan', 'locality_code': '109', 'latitude': 39.5214, 'longitude': -86.6414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46151', 'place_name': 'Martinsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Morgan', 'locality_code': '109', 'latitude': 39.4776, 'longitude': -86.4668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46157', 'place_name': 'Monrovia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Morgan', 'locality_code': '109', 'latitude': 39.5714, 'longitude': -86.4894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46158', 'place_name': 'Mooresville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Morgan', 'locality_code': '109', 'latitude': 39.5915, 'longitude': -86.3642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46166', 'place_name': 'Paragon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Morgan', 'locality_code': '109', 'latitude': 39.4042, 'longitude': -86.5779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46349', 'place_name': 'Lake Village', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 41.1387, 'longitude': -87.4454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46372', 'place_name': 'Roselawn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 41.1434, 'longitude': -87.322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46379', 'place_name': 'Sumava Resorts', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 41.1671, 'longitude': -87.4335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46381', 'place_name': 'Thayer', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 41.1711, 'longitude': -87.3313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47922', 'place_name': 'Brook', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 40.8655, 'longitude': -87.3527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47948', 'place_name': 'Goodland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 40.7669, 'longitude': -87.2999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47951', 'place_name': 'Kentland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 40.7877, 'longitude': -87.4471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47963', 'place_name': 'Morocco', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 40.9645, 'longitude': -87.4187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47964', 'place_name': 'Mount Ayr', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Newton', 'locality_code': '111', 'latitude': 40.9521, 'longitude': -87.2986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46701', 'place_name': 'Albion', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.3482, 'longitude': -85.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46710', 'place_name': 'Avilla', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.3689, 'longitude': -85.2414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46732', 'place_name': 'Cromwell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.3751, 'longitude': -85.6031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46755', 'place_name': 'Kendallville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.4482, 'longitude': -85.2609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46760', 'place_name': 'Kimmell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.3953, 'longitude': -85.5483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46763', 'place_name': 'Laotto', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.2991, 'longitude': -85.1901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46767', 'place_name': 'Ligonier', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.4662, 'longitude': -85.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46784', 'place_name': 'Rome City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.4849, 'longitude': -85.3743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46794', 'place_name': 'Wawaka', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.457, 'longitude': -85.4822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46796', 'place_name': 'Wolflake', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Noble', 'locality_code': '113', 'latitude': 41.3361, 'longitude': -85.5002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47040', 'place_name': 'Rising Sun', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ohio', 'locality_code': '115', 'latitude': 38.9567, 'longitude': -84.8807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47432', 'place_name': 'French Lick', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Orange', 'locality_code': '117', 'latitude': 38.5324, 'longitude': -86.6196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47452', 'place_name': 'Orleans', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Orange', 'locality_code': '117', 'latitude': 38.6535, 'longitude': -86.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47454', 'place_name': 'Paoli', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Orange', 'locality_code': '117', 'latitude': 38.5507, 'longitude': -86.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47469', 'place_name': 'West Baden Springs', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Orange', 'locality_code': '117', 'latitude': 38.6208, 'longitude': -86.5899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47427', 'place_name': 'Coal City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Owen', 'locality_code': '119', 'latitude': 39.2303, 'longitude': -87.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47431', 'place_name': 'Freedom', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Owen', 'locality_code': '119', 'latitude': 39.2151, 'longitude': -86.85, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47433', 'place_name': 'Gosport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Owen', 'locality_code': '119', 'latitude': 39.345, 'longitude': -86.6583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47455', 'place_name': 'Patricksburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Owen', 'locality_code': '119', 'latitude': 39.3165, 'longitude': -86.9562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47456', 'place_name': 'Quincy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Owen', 'locality_code': '119', 'latitude': 39.4429, 'longitude': -86.6696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47460', 'place_name': 'Spencer', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Owen', 'locality_code': '119', 'latitude': 39.2891, 'longitude': -86.7789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47830', 'place_name': 'Bellmore', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.7791, 'longitude': -87.2218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47832', 'place_name': 'Bloomingdale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.8348, 'longitude': -87.256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47836', 'place_name': 'Bridgeton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.645, 'longitude': -87.1775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47859', 'place_name': 'Marshall', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.9062, 'longitude': -87.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47860', 'place_name': 'Mecca', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.7219, 'longitude': -87.3303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47862', 'place_name': 'Montezuma', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.7961, 'longitude': -87.3607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47872', 'place_name': 'Rockville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.7682, 'longitude': -87.1978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47874', 'place_name': 'Rosedale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Parke', 'locality_code': '121', 'latitude': 39.6239, 'longitude': -87.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47514', 'place_name': 'Branchville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 38.1572, 'longitude': -86.5859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47515', 'place_name': 'Bristow', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 38.1981, 'longitude': -86.6821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47520', 'place_name': 'Cannelton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 37.9495, 'longitude': -86.7156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47525', 'place_name': 'Derby', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 38.0239, 'longitude': -86.577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47551', 'place_name': 'Leopold', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 38.1011, 'longitude': -86.6044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47574', 'place_name': 'Rome', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 37.9372, 'longitude': -86.534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47576', 'place_name': 'Saint Croix', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 38.1834, 'longitude': -86.6058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47586', 'place_name': 'Tell City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Perry', 'locality_code': '123', 'latitude': 37.9655, 'longitude': -86.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47564', 'place_name': 'Otwell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pike', 'locality_code': '125', 'latitude': 38.4662, 'longitude': -87.0985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47567', 'place_name': 'Petersburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pike', 'locality_code': '125', 'latitude': 38.4789, 'longitude': -87.2883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47584', 'place_name': 'Spurgeon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pike', 'locality_code': '125', 'latitude': 38.2523, 'longitude': -87.2572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47585', 'place_name': 'Stendal', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pike', 'locality_code': '125', 'latitude': 38.2835, 'longitude': -87.1205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47590', 'place_name': 'Velpen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pike', 'locality_code': '125', 'latitude': 38.368, 'longitude': -87.099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47598', 'place_name': 'Winslow', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pike', 'locality_code': '125', 'latitude': 38.364, 'longitude': -87.2223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46301', 'place_name': 'Beverly Shores', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.6925, 'longitude': -86.9775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46302', 'place_name': 'Boone Grove', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.3542, 'longitude': -87.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46304', 'place_name': 'Chesterton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.6143, 'longitude': -87.047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46341', 'place_name': 'Hebron', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.3155, 'longitude': -87.2088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46347', 'place_name': 'Kouts', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.3091, 'longitude': -87.024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46368', 'place_name': 'Portage', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.5672, 'longitude': -87.1757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46383', 'place_name': 'Valparaiso', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.4547, 'longitude': -87.0656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46384', 'place_name': 'Valparaiso', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.4905, 'longitude': -87.0761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46385', 'place_name': 'Valparaiso', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.4706, 'longitude': -87.0783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46393', 'place_name': 'Wheeler', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Porter', 'locality_code': '127', 'latitude': 41.5116, 'longitude': -87.1792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47612', 'place_name': 'Cynthiana', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Posey', 'locality_code': '129', 'latitude': 38.193, 'longitude': -87.6992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47616', 'place_name': 'Griffin', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Posey', 'locality_code': '129', 'latitude': 38.2069, 'longitude': -87.9166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47620', 'place_name': 'Mount Vernon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Posey', 'locality_code': '129', 'latitude': 37.9506, 'longitude': -87.8569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47631', 'place_name': 'New Harmony', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Posey', 'locality_code': '129', 'latitude': 38.1245, 'longitude': -87.9172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47633', 'place_name': 'Poseyville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Posey', 'locality_code': '129', 'latitude': 38.172, 'longitude': -87.8027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47638', 'place_name': 'Wadesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Posey', 'locality_code': '129', 'latitude': 38.0828, 'longitude': -87.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46960', 'place_name': 'Monterey', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pulaski', 'locality_code': '131', 'latitude': 41.1383, 'longitude': -86.5179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46985', 'place_name': 'Star City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pulaski', 'locality_code': '131', 'latitude': 40.9602, 'longitude': -86.5404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46996', 'place_name': 'Winamac', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pulaski', 'locality_code': '131', 'latitude': 41.0562, 'longitude': -86.6307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47946', 'place_name': 'Francesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pulaski', 'locality_code': '131', 'latitude': 40.9709, 'longitude': -86.8553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47957', 'place_name': 'Medaryville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Pulaski', 'locality_code': '131', 'latitude': 41.0897, 'longitude': -86.8808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46105', 'place_name': 'Bainbridge', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.7612, 'longitude': -86.812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46120', 'place_name': 'Cloverdale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.5148, 'longitude': -86.7939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46128', 'place_name': 'Fillmore', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.6475, 'longitude': -86.7469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46135', 'place_name': 'Greencastle', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.6495, 'longitude': -86.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46170', 'place_name': 'Putnamville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.5742, 'longitude': -86.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46171', 'place_name': 'Reelsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.5464, 'longitude': -86.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46172', 'place_name': 'Roachdale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.8325, 'longitude': -86.7902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46175', 'place_name': 'Russellville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Putnam', 'locality_code': '133', 'latitude': 39.8366, 'longitude': -86.967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47340', 'place_name': 'Farmland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.1945, 'longitude': -85.1254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47354', 'place_name': 'Losantville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.0475, 'longitude': -85.2108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47355', 'place_name': 'Lynn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.0519, 'longitude': -84.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47358', 'place_name': 'Modoc', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.0582, 'longitude': -85.0919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47368', 'place_name': 'Parker City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.1938, 'longitude': -85.1963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47380', 'place_name': 'Ridgeville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.2804, 'longitude': -85.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47382', 'place_name': 'Saratoga', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.2347, 'longitude': -84.9185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47390', 'place_name': 'Union City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.2024, 'longitude': -84.8268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47394', 'place_name': 'Winchester', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Randolph', 'locality_code': '135', 'latitude': 40.1696, 'longitude': -85.0044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47006', 'place_name': 'Batesville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.3001, 'longitude': -85.2221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47017', 'place_name': 'Cross Plains', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 38.949, 'longitude': -85.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47021', 'place_name': 'Friendship', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 38.9703, 'longitude': -85.1504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47023', 'place_name': 'Holton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.0498, 'longitude': -85.3739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47031', 'place_name': 'Milan', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.1503, 'longitude': -85.1324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47033', 'place_name': 'Morris', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.2814, 'longitude': -85.1739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47034', 'place_name': 'Napoleon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.2048, 'longitude': -85.327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47037', 'place_name': 'Osgood', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.1573, 'longitude': -85.2938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47039', 'place_name': 'Pierceville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.1116, 'longitude': -85.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47041', 'place_name': 'Sunman', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.237, 'longitude': -85.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47042', 'place_name': 'Versailles', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Ripley', 'locality_code': '137', 'latitude': 39.0511, 'longitude': -85.2235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46104', 'place_name': 'Arlington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.6488, 'longitude': -85.5828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46115', 'place_name': 'Carthage', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.7466, 'longitude': -85.5754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46127', 'place_name': 'Falmouth', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.729, 'longitude': -85.3331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46146', 'place_name': 'Homer', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.5781, 'longitude': -85.578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46150', 'place_name': 'Manilla', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.5742, 'longitude': -85.6194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46155', 'place_name': 'Mays', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.7437, 'longitude': -85.43, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46156', 'place_name': 'Milroy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.4955, 'longitude': -85.5044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46173', 'place_name': 'Rushville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Rush', 'locality_code': '139', 'latitude': 39.6192, 'longitude': -85.4321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46530', 'place_name': 'Granger', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.7427, 'longitude': -86.1411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46536', 'place_name': 'Lakeville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.5253, 'longitude': -86.2714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46544', 'place_name': 'Mishawaka', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6507, 'longitude': -86.1623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46545', 'place_name': 'Mishawaka', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6835, 'longitude': -86.1682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46546', 'place_name': 'Mishawaka', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.662, 'longitude': -86.1586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46552', 'place_name': 'New Carlisle', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.7051, 'longitude': -86.4838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46554', 'place_name': 'North Liberty', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.5425, 'longitude': -86.4133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46556', 'place_name': 'Notre Dame', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.7002, 'longitude': -86.2379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46561', 'place_name': 'Osceola', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6695, 'longitude': -86.087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46574', 'place_name': 'Walkerton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.4667, 'longitude': -86.4831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46595', 'place_name': 'Wyatt', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.5259, 'longitude': -86.1694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46601', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6727, 'longitude': -86.2535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46613', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6546, 'longitude': -86.2479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46614', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6255, 'longitude': -86.2433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46615', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6741, 'longitude': -86.2104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46616', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6919, 'longitude': -86.2647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46617', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.685, 'longitude': -86.2351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46619', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6674, 'longitude': -86.3153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46624', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.7332, 'longitude': -86.2833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46626', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.6774, 'longitude': -86.2525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46628', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.7015, 'longitude': -86.2949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46634', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.5968, 'longitude': -86.293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46635', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.7168, 'longitude': -86.2078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46637', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.7299, 'longitude': -86.2407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46660', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.5968, 'longitude': -86.293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46680', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.5968, 'longitude': -86.293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46699', 'place_name': 'South Bend', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'St. Joseph', 'locality_code': '141', 'latitude': 41.5968, 'longitude': -86.293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47102', 'place_name': 'Austin', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Scott', 'locality_code': '143', 'latitude': 38.7478, 'longitude': -85.7962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47138', 'place_name': 'Lexington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Scott', 'locality_code': '143', 'latitude': 38.6523, 'longitude': -85.6252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47170', 'place_name': 'Scottsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Scott', 'locality_code': '143', 'latitude': 38.6885, 'longitude': -85.7987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46110', 'place_name': 'Boggstown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.5666, 'longitude': -85.9141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46126', 'place_name': 'Fairland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.6295, 'longitude': -85.8913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46130', 'place_name': 'Fountaintown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.6751, 'longitude': -85.7848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46144', 'place_name': 'Gwynneville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.6617, 'longitude': -85.6476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46161', 'place_name': 'Morristown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.6675, 'longitude': -85.6934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46176', 'place_name': 'Shelbyville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.5043, 'longitude': -85.7875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46182', 'place_name': 'Waldron', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.4688, 'longitude': -85.6644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47234', 'place_name': 'Flat Rock', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Shelby', 'locality_code': '145', 'latitude': 39.3774, 'longitude': -85.7679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47523', 'place_name': 'Dale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.1706, 'longitude': -87.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47531', 'place_name': 'Evanston', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.0224, 'longitude': -86.8364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47536', 'place_name': 'Fulda', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.1114, 'longitude': -86.8361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47537', 'place_name': 'Gentryville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.0855, 'longitude': -87.0441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47550', 'place_name': 'Lamar', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.0429, 'longitude': -86.9497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47552', 'place_name': 'Lincoln City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.1242, 'longitude': -86.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47556', 'place_name': 'Mariah Hill', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.1664, 'longitude': -86.9172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47577', 'place_name': 'Saint Meinrad', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.1712, 'longitude': -86.8092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47579', 'place_name': 'Santa Claus', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.1176, 'longitude': -86.9286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47588', 'place_name': 'Troy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.0331, 'longitude': -86.7981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47611', 'place_name': 'Chrisney', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 38.0148, 'longitude': -87.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47615', 'place_name': 'Grandview', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 37.9703, 'longitude': -86.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47617', 'place_name': 'Hatfield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 37.9036, 'longitude': -87.2499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47634', 'place_name': 'Richland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 37.9136, 'longitude': -87.201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47635', 'place_name': 'Rockport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Spencer', 'locality_code': '147', 'latitude': 37.8858, 'longitude': -87.077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46366', 'place_name': 'North Judson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Starke', 'locality_code': '149', 'latitude': 41.215, 'longitude': -86.7759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46374', 'place_name': 'San Pierre', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Starke', 'locality_code': '149', 'latitude': 41.2111, 'longitude': -86.8725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46531', 'place_name': 'Grovertown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Starke', 'locality_code': '149', 'latitude': 41.3496, 'longitude': -86.5243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46532', 'place_name': 'Hamlet', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Starke', 'locality_code': '149', 'latitude': 41.3931, 'longitude': -86.5948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46534', 'place_name': 'Knox', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Starke', 'locality_code': '149', 'latitude': 41.2809, 'longitude': -86.6082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46968', 'place_name': 'Ora', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Starke', 'locality_code': '149', 'latitude': 41.1756, 'longitude': -86.5543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46703', 'place_name': 'Angola', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Steuben', 'locality_code': '151', 'latitude': 41.6563, 'longitude': -85.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46737', 'place_name': 'Fremont', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Steuben', 'locality_code': '151', 'latitude': 41.7331, 'longitude': -84.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46742', 'place_name': 'Hamilton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Steuben', 'locality_code': '151', 'latitude': 41.5566, 'longitude': -84.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46747', 'place_name': 'Hudson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Steuben', 'locality_code': '151', 'latitude': 41.5328, 'longitude': -85.0811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46776', 'place_name': 'Orland', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Steuben', 'locality_code': '151', 'latitude': 41.7309, 'longitude': -85.1465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46779', 'place_name': 'Pleasant Lake', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Steuben', 'locality_code': '151', 'latitude': 41.5843, 'longitude': -85.0213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47838', 'place_name': 'Carlisle', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 38.9763, 'longitude': -87.3667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47848', 'place_name': 'Dugger', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.0691, 'longitude': -87.2599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47849', 'place_name': 'Fairbanks', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.1901, 'longitude': -87.547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47850', 'place_name': 'Farmersburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.2685, 'longitude': -87.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47852', 'place_name': 'Graysville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.0805, 'longitude': -87.4496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47855', 'place_name': 'Hymera', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.1833, 'longitude': -87.2994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47861', 'place_name': 'Merom', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.0564, 'longitude': -87.5675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47865', 'place_name': 'Paxton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.0212, 'longitude': -87.3886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47879', 'place_name': 'Shelburn', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.1784, 'longitude': -87.3936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47882', 'place_name': 'Sullivan', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Sullivan', 'locality_code': '153', 'latitude': 39.101, 'longitude': -87.4102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47011', 'place_name': 'Bennington', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Switzerland', 'locality_code': '155', 'latitude': 38.876, 'longitude': -85.0719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47019', 'place_name': 'East Enterprise', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Switzerland', 'locality_code': '155', 'latitude': 38.8728, 'longitude': -84.988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47020', 'place_name': 'Florence', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Switzerland', 'locality_code': '155', 'latitude': 38.8224, 'longitude': -84.9399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47038', 'place_name': 'Patriot', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Switzerland', 'locality_code': '155', 'latitude': 38.8537, 'longitude': -84.8515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47043', 'place_name': 'Vevay', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Switzerland', 'locality_code': '155', 'latitude': 38.7724, 'longitude': -85.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47901', 'place_name': 'Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.4177, 'longitude': -86.8884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47902', 'place_name': 'Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.3887, 'longitude': -86.8949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47903', 'place_name': 'Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.3044, 'longitude': -86.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47904', 'place_name': 'Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.4276, 'longitude': -86.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47905', 'place_name': 'Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.4001, 'longitude': -86.8602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47906', 'place_name': 'West Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.444, 'longitude': -86.9237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47907', 'place_name': 'West Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.4249, 'longitude': -86.9162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47909', 'place_name': 'Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.3228, 'longitude': -86.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47920', 'place_name': 'Battle Ground', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.5248, 'longitude': -86.8238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47924', 'place_name': 'Buck Creek', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.4876, 'longitude': -86.7631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47930', 'place_name': 'Clarks Hill', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.247, 'longitude': -86.725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47941', 'place_name': 'Dayton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.3761, 'longitude': -86.774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47962', 'place_name': 'Montmorenci', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.4732, 'longitude': -87.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47981', 'place_name': 'Romney', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.258, 'longitude': -86.9208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47983', 'place_name': 'Stockwell', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.2845, 'longitude': -86.7724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47992', 'place_name': 'Westpoint', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.3581, 'longitude': -87.0575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47996', 'place_name': 'West Lafayette', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tippecanoe', 'locality_code': '157', 'latitude': 40.3887, 'longitude': -86.8949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46045', 'place_name': 'Goldsmith', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tipton', 'locality_code': '159', 'latitude': 40.2898, 'longitude': -86.1494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46047', 'place_name': 'Hobbs', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tipton', 'locality_code': '159', 'latitude': 40.2836, 'longitude': -85.9475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46049', 'place_name': 'Kempton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tipton', 'locality_code': '159', 'latitude': 40.2884, 'longitude': -86.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46068', 'place_name': 'Sharpsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tipton', 'locality_code': '159', 'latitude': 40.3732, 'longitude': -86.1086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46072', 'place_name': 'Tipton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tipton', 'locality_code': '159', 'latitude': 40.2817, 'longitude': -86.0433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46076', 'place_name': 'Windfall', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Tipton', 'locality_code': '159', 'latitude': 40.3669, 'longitude': -85.9476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47325', 'place_name': 'Brownsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Union', 'locality_code': '161', 'latitude': 39.6845, 'longitude': -84.9881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47353', 'place_name': 'Liberty', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Union', 'locality_code': '161', 'latitude': 39.6126, 'longitude': -84.9089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47618', 'place_name': 'Inglefield', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 38.1081, 'longitude': -87.5589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47701', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47702', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47703', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47704', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47705', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47706', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47708', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9718, 'longitude': -87.572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47710', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 38.0086, 'longitude': -87.5746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47711', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 38.0617, 'longitude': -87.5548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47712', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.929, 'longitude': -87.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47713', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9623, 'longitude': -87.5577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47714', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9591, 'longitude': -87.5293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47715', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9678, 'longitude': -87.4855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47716', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47719', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47720', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 38.0599, 'longitude': -87.638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47721', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.978, 'longitude': -87.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47722', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9702, 'longitude': -87.542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47724', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47725', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 38.1071, 'longitude': -87.5256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47728', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47730', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47731', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47732', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47733', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47734', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47735', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47736', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47737', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47740', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47747', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9971, 'longitude': -87.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47750', 'place_name': 'Evansville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vanderburgh', 'locality_code': '163', 'latitude': 37.9623, 'longitude': -87.5055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47831', 'place_name': 'Blanford', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.665, 'longitude': -87.5206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47842', 'place_name': 'Clinton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.6591, 'longitude': -87.4208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47847', 'place_name': 'Dana', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.839, 'longitude': -87.4712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47854', 'place_name': 'Hillsdale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.7712, 'longitude': -87.4041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47875', 'place_name': 'Saint Bernice', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.8778, 'longitude': -87.4436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47884', 'place_name': 'Universal', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.6221, 'longitude': -87.4548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47928', 'place_name': 'Cayuga', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.93, 'longitude': -87.459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47966', 'place_name': 'Newport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 39.8842, 'longitude': -87.4086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47974', 'place_name': 'Perrysville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vermillion', 'locality_code': '165', 'latitude': 40.0737, 'longitude': -87.4648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47801', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.4667, 'longitude': -87.4139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47802', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.407, 'longitude': -87.402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47803', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.4657, 'longitude': -87.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47804', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.4937, 'longitude': -87.3945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47805', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.5327, 'longitude': -87.3255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47807', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.471, 'longitude': -87.4009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47808', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.4336, 'longitude': -87.4101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47809', 'place_name': 'Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.471, 'longitude': -87.4111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47851', 'place_name': 'Fontanet', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.5737, 'longitude': -87.2454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47858', 'place_name': 'Lewis', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.2733, 'longitude': -87.2637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47863', 'place_name': 'New Goshen', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.5803, 'longitude': -87.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47866', 'place_name': 'Pimento', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.2929, 'longitude': -87.3355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47869', 'place_name': 'Prairie Creek', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.275, 'longitude': -87.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47870', 'place_name': 'Prairieton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.3712, 'longitude': -87.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47871', 'place_name': 'Riley', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.39, 'longitude': -87.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47876', 'place_name': 'Saint Mary Of The Woods', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.5109, 'longitude': -87.4672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47878', 'place_name': 'Seelyville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.4928, 'longitude': -87.2665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47880', 'place_name': 'Shepardsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.6006, 'longitude': -87.4196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47885', 'place_name': 'West Terre Haute', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Vigo', 'locality_code': '167', 'latitude': 39.4984, 'longitude': -87.4688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46940', 'place_name': 'La Fontaine', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.6909, 'longitude': -85.6971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46941', 'place_name': 'Lagro', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.8199, 'longitude': -85.7204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46943', 'place_name': 'Laketon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.9743, 'longitude': -85.8375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46946', 'place_name': 'Liberty Mills', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 41.0356, 'longitude': -85.7358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46962', 'place_name': 'North Manchester', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.9986, 'longitude': -85.7842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46974', 'place_name': 'Roann', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.9482, 'longitude': -85.9301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46980', 'place_name': 'Servia', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.9567, 'longitude': -85.7405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46984', 'place_name': 'Somerset', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.6714, 'longitude': -85.8288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46990', 'place_name': 'Urbana', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.8987, 'longitude': -85.7485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46992', 'place_name': 'Wabash', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wabash', 'locality_code': '169', 'latitude': 40.7909, 'longitude': -85.8321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47975', 'place_name': 'Pine Village', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warren', 'locality_code': '171', 'latitude': 40.4328, 'longitude': -87.2317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47982', 'place_name': 'State Line', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warren', 'locality_code': '171', 'latitude': 40.1967, 'longitude': -87.5265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47991', 'place_name': 'West Lebanon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warren', 'locality_code': '171', 'latitude': 40.2659, 'longitude': -87.4384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47993', 'place_name': 'Williamsport', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warren', 'locality_code': '171', 'latitude': 40.3142, 'longitude': -87.4039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47601', 'place_name': 'Boonville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warrick', 'locality_code': '173', 'latitude': 38.0474, 'longitude': -87.262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47610', 'place_name': 'Chandler', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warrick', 'locality_code': '173', 'latitude': 38.0423, 'longitude': -87.3756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47613', 'place_name': 'Elberfeld', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warrick', 'locality_code': '173', 'latitude': 38.2053, 'longitude': -87.4179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47619', 'place_name': 'Lynnville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warrick', 'locality_code': '173', 'latitude': 38.1961, 'longitude': -87.2935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47629', 'place_name': 'Newburgh', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warrick', 'locality_code': '173', 'latitude': 38.0624, 'longitude': -87.2452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47630', 'place_name': 'Newburgh', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warrick', 'locality_code': '173', 'latitude': 37.9637, 'longitude': -87.3938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47637', 'place_name': 'Tennyson', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Warrick', 'locality_code': '173', 'latitude': 38.1232, 'longitude': -87.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47108', 'place_name': 'Campbellsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Washington', 'locality_code': '175', 'latitude': 38.669, 'longitude': -86.2358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47120', 'place_name': 'Fredericksburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Washington', 'locality_code': '175', 'latitude': 38.4331, 'longitude': -86.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47125', 'place_name': 'Hardinsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Washington', 'locality_code': '175', 'latitude': 38.4626, 'longitude': -86.318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47165', 'place_name': 'Pekin', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Washington', 'locality_code': '175', 'latitude': 38.4931, 'longitude': -86.017, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '47167', 'place_name': 'Salem', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Washington', 'locality_code': '175', 'latitude': 38.6071, 'longitude': -86.0787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47324', 'place_name': 'Boston', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.7412, 'longitude': -84.8519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47327', 'place_name': 'Cambridge City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.8182, 'longitude': -85.1685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47330', 'place_name': 'Centerville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.8081, 'longitude': -85.0032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47335', 'place_name': 'Dublin', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.8127, 'longitude': -85.2044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47339', 'place_name': 'Economy', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.9781, 'longitude': -85.088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47341', 'place_name': 'Fountain City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.9634, 'longitude': -84.909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47345', 'place_name': 'Greens Fork', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.8916, 'longitude': -85.0494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47346', 'place_name': 'Hagerstown', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.9228, 'longitude': -85.1601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47357', 'place_name': 'Milton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.7763, 'longitude': -85.1423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47370', 'place_name': 'Pershing', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.8613, 'longitude': -85.1474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47374', 'place_name': 'Richmond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.8324, 'longitude': -84.8936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47375', 'place_name': 'Richmond', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.8289, 'longitude': -84.8902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47392', 'place_name': 'Webster', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.9119, 'longitude': -84.9351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47393', 'place_name': 'Williamsburg', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wayne', 'locality_code': '177', 'latitude': 39.958, 'longitude': -84.9984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46714', 'place_name': 'Bluffton', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.7368, 'longitude': -85.1622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46731', 'place_name': 'Craigville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.793, 'longitude': -85.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46759', 'place_name': 'Keystone', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.5897, 'longitude': -85.2767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46766', 'place_name': 'Liberty Center', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.7002, 'longitude': -85.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46777', 'place_name': 'Ossian', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.8806, 'longitude': -85.157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46778', 'place_name': 'Petroleum', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.6114, 'longitude': -85.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46781', 'place_name': 'Poneto', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.6419, 'longitude': -85.2562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46791', 'place_name': 'Uniondale', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Wells', 'locality_code': '179', 'latitude': 40.8369, 'longitude': -85.2403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47923', 'place_name': 'Brookston', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.6011, 'longitude': -86.8753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47925', 'place_name': 'Buffalo', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.8825, 'longitude': -86.7453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47926', 'place_name': 'Burnettsville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.7612, 'longitude': -86.5936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47929', 'place_name': 'Chalmers', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.6693, 'longitude': -86.8626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47950', 'place_name': 'Idaville', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.7674, 'longitude': -86.6556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47959', 'place_name': 'Monon', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.8612, 'longitude': -86.8635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47960', 'place_name': 'Monticello', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.7626, 'longitude': -86.755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47980', 'place_name': 'Reynolds', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.7606, 'longitude': -86.8691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '47995', 'place_name': 'Wolcott', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'White', 'locality_code': '181', 'latitude': 40.7516, 'longitude': -87.029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46723', 'place_name': 'Churubusco', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Whitley', 'locality_code': '183', 'latitude': 41.229, 'longitude': -85.3244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46725', 'place_name': 'Columbia City', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Whitley', 'locality_code': '183', 'latitude': 41.1619, 'longitude': -85.4737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46764', 'place_name': 'Larwill', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Whitley', 'locality_code': '183', 'latitude': 41.1646, 'longitude': -85.6139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '46787', 'place_name': 'South Whitley', 'state': 'Indiana', 'state_ab': 'IN', 'county': 'Whitley', 'locality_code': '183', 'latitude': 41.0726, 'longitude': -85.6143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66732', 'place_name': 'Elsmore', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Allen', 'locality_code': '1', 'latitude': 37.8035, 'longitude': -95.1546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66742', 'place_name': 'Gas', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Allen', 'locality_code': '1', 'latitude': 37.9232, 'longitude': -95.3467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66748', 'place_name': 'Humboldt', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Allen', 'locality_code': '1', 'latitude': 37.8045, 'longitude': -95.422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66749', 'place_name': 'Iola', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Allen', 'locality_code': '1', 'latitude': 37.9245, 'longitude': -95.4, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66751', 'place_name': 'La Harpe', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Allen', 'locality_code': '1', 'latitude': 37.917, 'longitude': -95.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66755', 'place_name': 'Moran', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Allen', 'locality_code': '1', 'latitude': 37.9342, 'longitude': -95.1647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66772', 'place_name': 'Savonburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Allen', 'locality_code': '1', 'latitude': 37.7517, 'longitude': -95.1545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66015', 'place_name': 'Colony', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Anderson', 'locality_code': '3', 'latitude': 38.0761, 'longitude': -95.3287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66032', 'place_name': 'Garnett', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Anderson', 'locality_code': '3', 'latitude': 38.2859, 'longitude': -95.2594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66033', 'place_name': 'Greeley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Anderson', 'locality_code': '3', 'latitude': 38.3524, 'longitude': -95.1188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66039', 'place_name': 'Kincaid', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Anderson', 'locality_code': '3', 'latitude': 38.1104, 'longitude': -95.1886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66091', 'place_name': 'Welda', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Anderson', 'locality_code': '3', 'latitude': 38.1686, 'longitude': -95.3096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66093', 'place_name': 'Westphalia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Anderson', 'locality_code': '3', 'latitude': 38.1718, 'longitude': -95.4665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66002', 'place_name': 'Atchison', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Atchison', 'locality_code': '5', 'latitude': 39.5594, 'longitude': -95.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66016', 'place_name': 'Cummings', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Atchison', 'locality_code': '5', 'latitude': 39.483, 'longitude': -95.2863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66023', 'place_name': 'Effingham', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Atchison', 'locality_code': '5', 'latitude': 39.5222, 'longitude': -95.4008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66041', 'place_name': 'Lancaster', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Atchison', 'locality_code': '5', 'latitude': 39.5952, 'longitude': -95.3036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66058', 'place_name': 'Muscotah', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Atchison', 'locality_code': '5', 'latitude': 39.5388, 'longitude': -95.5175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67057', 'place_name': 'Hardtner', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.03, 'longitude': -98.6547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67061', 'place_name': 'Hazelton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.0984, 'longitude': -98.4003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67065', 'place_name': 'Isabel', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.4485, 'longitude': -98.5351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67070', 'place_name': 'Kiowa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.0172, 'longitude': -98.4859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67071', 'place_name': 'Lake City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.3569, 'longitude': -98.8098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67104', 'place_name': 'Medicine Lodge', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.2845, 'longitude': -98.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67138', 'place_name': 'Sharon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.2492, 'longitude': -98.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67143', 'place_name': 'Sun City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barber', 'locality_code': '7', 'latitude': 37.3786, 'longitude': -98.9159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67511', 'place_name': 'Albert', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barton', 'locality_code': '9', 'latitude': 38.4528, 'longitude': -99.0115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67525', 'place_name': 'Claflin', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barton', 'locality_code': '9', 'latitude': 38.5409, 'longitude': -98.5372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67526', 'place_name': 'Ellinwood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barton', 'locality_code': '9', 'latitude': 38.3565, 'longitude': -98.5849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67530', 'place_name': 'Great Bend', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barton', 'locality_code': '9', 'latitude': 38.3936, 'longitude': -98.7751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67544', 'place_name': 'Hoisington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barton', 'locality_code': '9', 'latitude': 38.4789, 'longitude': -98.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67564', 'place_name': 'Olmitz', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barton', 'locality_code': '9', 'latitude': 38.5167, 'longitude': -98.9365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67567', 'place_name': 'Pawnee Rock', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Barton', 'locality_code': '9', 'latitude': 38.2782, 'longitude': -98.9814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66701', 'place_name': 'Fort Scott', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Bourbon', 'locality_code': '11', 'latitude': 37.8216, 'longitude': -94.7148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66716', 'place_name': 'Bronson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Bourbon', 'locality_code': '11', 'latitude': 37.9214, 'longitude': -95.0303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66738', 'place_name': 'Fulton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Bourbon', 'locality_code': '11', 'latitude': 38.0134, 'longitude': -94.7183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66741', 'place_name': 'Garland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Bourbon', 'locality_code': '11', 'latitude': 37.7175, 'longitude': -94.6613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66754', 'place_name': 'Mapleton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Bourbon', 'locality_code': '11', 'latitude': 38.0228, 'longitude': -94.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66769', 'place_name': 'Redfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Bourbon', 'locality_code': '11', 'latitude': 37.8367, 'longitude': -94.8805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66779', 'place_name': 'Uniontown', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Bourbon', 'locality_code': '11', 'latitude': 37.8473, 'longitude': -94.9752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66424', 'place_name': 'Everest', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.688, 'longitude': -95.4138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66425', 'place_name': 'Fairview', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.8445, 'longitude': -95.711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66434', 'place_name': 'Hiawatha', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.7914, 'longitude': -95.6004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66439', 'place_name': 'Horton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.6789, 'longitude': -95.5299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66515', 'place_name': 'Morrill', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.9356, 'longitude': -95.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66527', 'place_name': 'Powhattan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.7177, 'longitude': -95.6751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66532', 'place_name': 'Robinson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Brown', 'locality_code': '13', 'latitude': 39.8182, 'longitude': -95.4567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66842', 'place_name': 'Cassoday', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 38.0298, 'longitude': -96.6746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67002', 'place_name': 'Andover', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.6985, 'longitude': -97.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67010', 'place_name': 'Augusta', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.6836, 'longitude': -96.9648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67012', 'place_name': 'Beaumont', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.658, 'longitude': -96.5329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67017', 'place_name': 'Benton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.7946, 'longitude': -97.0971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67039', 'place_name': 'Douglass', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.5195, 'longitude': -96.9948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67041', 'place_name': 'Elbing', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 38.0545, 'longitude': -97.1284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67042', 'place_name': 'El Dorado', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.8226, 'longitude': -96.8543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67072', 'place_name': 'Latham', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.531, 'longitude': -96.6791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67074', 'place_name': 'Leon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.6813, 'longitude': -96.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67123', 'place_name': 'Potwin', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.9389, 'longitude': -97.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67132', 'place_name': 'Rosalia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.796, 'longitude': -96.6482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67133', 'place_name': 'Rose Hill', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.5784, 'longitude': -97.1173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67144', 'place_name': 'Towanda', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.8005, 'longitude': -96.9918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67154', 'place_name': 'Whitewater', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Butler', 'locality_code': '15', 'latitude': 37.9612, 'longitude': -97.1308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66843', 'place_name': 'Cedar Point', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chase', 'locality_code': '17', 'latitude': 38.26, 'longitude': -96.8228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66845', 'place_name': 'Cottonwood Falls', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chase', 'locality_code': '17', 'latitude': 38.3565, 'longitude': -96.5418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66850', 'place_name': 'Elmdale', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chase', 'locality_code': '17', 'latitude': 38.3779, 'longitude': -96.6675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66862', 'place_name': 'Matfield Green', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chase', 'locality_code': '17', 'latitude': 38.1448, 'longitude': -96.5541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66869', 'place_name': 'Strong City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chase', 'locality_code': '17', 'latitude': 38.4129, 'longitude': -96.5172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67024', 'place_name': 'Cedar Vale', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chautauqua', 'locality_code': '19', 'latitude': 37.1265, 'longitude': -96.4701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67334', 'place_name': 'Chautauqua', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chautauqua', 'locality_code': '19', 'latitude': 37.0262, 'longitude': -96.1783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67355', 'place_name': 'Niotaze', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chautauqua', 'locality_code': '19', 'latitude': 37.037, 'longitude': -96.0121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67360', 'place_name': 'Peru', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chautauqua', 'locality_code': '19', 'latitude': 37.0568, 'longitude': -96.1404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67361', 'place_name': 'Sedan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Chautauqua', 'locality_code': '19', 'latitude': 37.1297, 'longitude': -96.1732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66713', 'place_name': 'Baxter Springs', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.0281, 'longitude': -94.7393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66725', 'place_name': 'Columbus', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.1699, 'longitude': -94.8899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66728', 'place_name': 'Crestline', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.1694, 'longitude': -94.7041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66739', 'place_name': 'Galena', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.0632, 'longitude': -94.6557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66770', 'place_name': 'Riverton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.081, 'longitude': -94.7175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66773', 'place_name': 'Scammon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.2809, 'longitude': -94.8092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66778', 'place_name': 'Treece', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.0005, 'longitude': -94.8409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66781', 'place_name': 'Weir', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.2912, 'longitude': -94.7286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66782', 'place_name': 'West Mineral', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 37.2851, 'longitude': -94.9261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67731', 'place_name': 'Bird City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cheyenne', 'locality_code': '23', 'latitude': 39.7579, 'longitude': -101.5319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67756', 'place_name': 'Saint Francis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cheyenne', 'locality_code': '23', 'latitude': 39.6804, 'longitude': -101.9093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67831', 'place_name': 'Ashland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clark', 'locality_code': '25', 'latitude': 37.1823, 'longitude': -99.759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67840', 'place_name': 'Englewood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clark', 'locality_code': '25', 'latitude': 37.0384, 'longitude': -99.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67865', 'place_name': 'Minneola', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clark', 'locality_code': '25', 'latitude': 37.4425, 'longitude': -100.0088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67432', 'place_name': 'Clay Center', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clay', 'locality_code': '27', 'latitude': 39.3844, 'longitude': -97.1278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67447', 'place_name': 'Green', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clay', 'locality_code': '27', 'latitude': 39.4803, 'longitude': -97.0149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67458', 'place_name': 'Longford', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clay', 'locality_code': '27', 'latitude': 39.1834, 'longitude': -97.2499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67468', 'place_name': 'Morganville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clay', 'locality_code': '27', 'latitude': 39.4607, 'longitude': -97.2467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67487', 'place_name': 'Wakefield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Clay', 'locality_code': '27', 'latitude': 39.2249, 'longitude': -97.0229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66901', 'place_name': 'Concordia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cloud', 'locality_code': '29', 'latitude': 39.5516, 'longitude': -97.6568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66938', 'place_name': 'Clyde', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cloud', 'locality_code': '29', 'latitude': 39.5758, 'longitude': -97.408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66948', 'place_name': 'Jamestown', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cloud', 'locality_code': '29', 'latitude': 39.6021, 'longitude': -97.8631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67417', 'place_name': 'Aurora', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cloud', 'locality_code': '29', 'latitude': 39.4472, 'longitude': -97.5304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67445', 'place_name': 'Glasco', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cloud', 'locality_code': '29', 'latitude': 39.3621, 'longitude': -97.8418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67466', 'place_name': 'Miltonvale', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cloud', 'locality_code': '29', 'latitude': 39.3481, 'longitude': -97.4579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66839', 'place_name': 'Burlington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Coffey', 'locality_code': '31', 'latitude': 38.2363, 'longitude': -95.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66852', 'place_name': 'Gridley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Coffey', 'locality_code': '31', 'latitude': 38.1012, 'longitude': -95.8874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66856', 'place_name': 'Lebo', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Coffey', 'locality_code': '31', 'latitude': 38.4161, 'longitude': -95.8222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66857', 'place_name': 'Le Roy', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Coffey', 'locality_code': '31', 'latitude': 38.0874, 'longitude': -95.6227, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66871', 'place_name': 'Waverly', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Coffey', 'locality_code': '31', 'latitude': 38.3782, 'longitude': -95.5982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67029', 'place_name': 'Coldwater', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Comanche', 'locality_code': '33', 'latitude': 37.2479, 'longitude': -99.3115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67127', 'place_name': 'Protection', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Comanche', 'locality_code': '33', 'latitude': 37.1968, 'longitude': -99.4816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67155', 'place_name': 'Wilmore', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Comanche', 'locality_code': '33', 'latitude': 37.3318, 'longitude': -99.1846, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '67005', 'place_name': 'Arkansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.0676, 'longitude': -97.0357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67008', 'place_name': 'Atlanta', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.4343, 'longitude': -96.7661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67019', 'place_name': 'Burden', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.3209, 'longitude': -96.757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67023', 'place_name': 'Cambridge', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.3161, 'longitude': -96.6645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67038', 'place_name': 'Dexter', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.1641, 'longitude': -96.6917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67102', 'place_name': 'Maple City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.2377, 'longitude': -96.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67131', 'place_name': 'Rock', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.4413, 'longitude': -97.0059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67146', 'place_name': 'Udall', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.3939, 'longitude': -97.1108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67156', 'place_name': 'Winfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Cowley', 'locality_code': '35', 'latitude': 37.2416, 'longitude': -96.98, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66711', 'place_name': 'Arcadia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.6341, 'longitude': -94.6548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66712', 'place_name': 'Arma', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.5573, 'longitude': -94.6949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66724', 'place_name': 'Cherokee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.3694, 'longitude': -94.8424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66734', 'place_name': 'Farlington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.6163, 'longitude': -94.8479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66735', 'place_name': 'Franklin', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.5219, 'longitude': -94.7096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66743', 'place_name': 'Girard', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.5091, 'longitude': -94.8569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66746', 'place_name': 'Hepler', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.6576, 'longitude': -94.9892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66753', 'place_name': 'Mc Cune', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.3468, 'longitude': -95.0376, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66756', 'place_name': 'Mulberry', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.5442, 'longitude': -94.6839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66760', 'place_name': 'Opolis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.342, 'longitude': -94.6199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66762', 'place_name': 'Pittsburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.3951, 'longitude': -94.7105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66763', 'place_name': 'Frontenac', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.4466, 'longitude': -94.6916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66780', 'place_name': 'Walnut', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Crawford', 'locality_code': '37', 'latitude': 37.5967, 'longitude': -95.0455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67635', 'place_name': 'Dresden', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Decatur', 'locality_code': '39', 'latitude': 39.6094, 'longitude': -100.4112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67643', 'place_name': 'Jennings', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Decatur', 'locality_code': '39', 'latitude': 39.6762, 'longitude': -100.2834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67653', 'place_name': 'Norcatur', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Decatur', 'locality_code': '39', 'latitude': 39.8447, 'longitude': -100.2007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67749', 'place_name': 'Oberlin', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Decatur', 'locality_code': '39', 'latitude': 39.8275, 'longitude': -100.5314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67410', 'place_name': 'Abilene', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 38.9371, 'longitude': -97.2063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67431', 'place_name': 'Chapman', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 38.9722, 'longitude': -97.017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67441', 'place_name': 'Enterprise', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 38.9063, 'longitude': -97.1122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67449', 'place_name': 'Herington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 38.6767, 'longitude': -96.8941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67451', 'place_name': 'Hope', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 38.6776, 'longitude': -97.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67480', 'place_name': 'Solomon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 38.9194, 'longitude': -97.3518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67482', 'place_name': 'Talmage', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 39.0269, 'longitude': -97.2597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67492', 'place_name': 'Woodbine', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Dickinson', 'locality_code': '41', 'latitude': 38.8131, 'longitude': -96.9619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66008', 'place_name': 'Bendena', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Doniphan', 'locality_code': '43', 'latitude': 39.7174, 'longitude': -95.1765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66017', 'place_name': 'Denton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Doniphan', 'locality_code': '43', 'latitude': 39.7154, 'longitude': -95.2744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66024', 'place_name': 'Elwood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Doniphan', 'locality_code': '43', 'latitude': 39.7573, 'longitude': -94.8824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66035', 'place_name': 'Highland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Doniphan', 'locality_code': '43', 'latitude': 39.8608, 'longitude': -95.2583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66087', 'place_name': 'Troy', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Doniphan', 'locality_code': '43', 'latitude': 39.7906, 'longitude': -95.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66090', 'place_name': 'Wathena', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Doniphan', 'locality_code': '43', 'latitude': 39.7625, 'longitude': -94.9255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66094', 'place_name': 'White Cloud', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Doniphan', 'locality_code': '43', 'latitude': 39.9627, 'longitude': -95.2982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66006', 'place_name': 'Baldwin City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 38.7953, 'longitude': -95.2276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66025', 'place_name': 'Eudora', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 38.933, 'longitude': -95.1022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66044', 'place_name': 'Lawrence', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 39.0289, 'longitude': -95.2086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66045', 'place_name': 'Lawrence', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 38.959, 'longitude': -95.2499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66046', 'place_name': 'Lawrence', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 38.9369, 'longitude': -95.242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66047', 'place_name': 'Lawrence', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 38.9407, 'longitude': -95.2779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66049', 'place_name': 'Lawrence', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 38.9704, 'longitude': -95.2769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66050', 'place_name': 'Lecompton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Douglas', 'locality_code': '45', 'latitude': 39.0154, 'longitude': -95.4392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67519', 'place_name': 'Belpre', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Edwards', 'locality_code': '47', 'latitude': 37.9347, 'longitude': -99.0936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67547', 'place_name': 'Kinsley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Edwards', 'locality_code': '47', 'latitude': 37.9247, 'longitude': -99.4116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67552', 'place_name': 'Lewis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Edwards', 'locality_code': '47', 'latitude': 37.9062, 'longitude': -99.248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67563', 'place_name': 'Offerle', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Edwards', 'locality_code': '47', 'latitude': 37.8828, 'longitude': -99.5498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67345', 'place_name': 'Elk Falls', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Elk', 'locality_code': '49', 'latitude': 37.3745, 'longitude': -96.1959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67346', 'place_name': 'Grenola', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Elk', 'locality_code': '49', 'latitude': 37.3668, 'longitude': -96.4396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67349', 'place_name': 'Howard', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Elk', 'locality_code': '49', 'latitude': 37.4809, 'longitude': -96.2563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67352', 'place_name': 'Longton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Elk', 'locality_code': '49', 'latitude': 37.3905, 'longitude': -96.0814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67353', 'place_name': 'Moline', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Elk', 'locality_code': '49', 'latitude': 37.3649, 'longitude': -96.3069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67601', 'place_name': 'Hays', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellis', 'locality_code': '51', 'latitude': 38.8782, 'longitude': -99.3348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67627', 'place_name': 'Catharine', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellis', 'locality_code': '51', 'latitude': 38.9276, 'longitude': -99.2161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67637', 'place_name': 'Ellis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellis', 'locality_code': '51', 'latitude': 38.9471, 'longitude': -99.5285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67660', 'place_name': 'Pfeifer', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellis', 'locality_code': '51', 'latitude': 38.7153, 'longitude': -99.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67667', 'place_name': 'Schoenchen', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellis', 'locality_code': '51', 'latitude': 38.7128, 'longitude': -99.3322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67671', 'place_name': 'Victoria', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellis', 'locality_code': '51', 'latitude': 38.8589, 'longitude': -99.1391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67674', 'place_name': 'Walker', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellis', 'locality_code': '51', 'latitude': 38.8672, 'longitude': -99.0759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67439', 'place_name': 'Ellsworth', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellsworth', 'locality_code': '53', 'latitude': 38.7312, 'longitude': -98.2057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67450', 'place_name': 'Holyrood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellsworth', 'locality_code': '53', 'latitude': 38.59, 'longitude': -98.4159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67454', 'place_name': 'Kanopolis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellsworth', 'locality_code': '53', 'latitude': 38.7091, 'longitude': -98.1575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67459', 'place_name': 'Lorraine', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellsworth', 'locality_code': '53', 'latitude': 38.5652, 'longitude': -98.29, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67490', 'place_name': 'Wilson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ellsworth', 'locality_code': '53', 'latitude': 38.8134, 'longitude': -98.4432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67846', 'place_name': 'Garden City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Finney', 'locality_code': '55', 'latitude': 37.9769, 'longitude': -100.8621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67851', 'place_name': 'Holcomb', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Finney', 'locality_code': '55', 'latitude': 37.9931, 'longitude': -100.9893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67868', 'place_name': 'Pierceville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Finney', 'locality_code': '55', 'latitude': 37.906, 'longitude': -100.7523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67801', 'place_name': 'Dodge City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ford', 'locality_code': '57', 'latitude': 37.7569, 'longitude': -100.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67834', 'place_name': 'Bucklin', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ford', 'locality_code': '57', 'latitude': 37.553, 'longitude': -99.6325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67842', 'place_name': 'Ford', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ford', 'locality_code': '57', 'latitude': 37.6323, 'longitude': -99.7642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67843', 'place_name': 'Fort Dodge', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ford', 'locality_code': '57', 'latitude': 37.7303, 'longitude': -99.937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67876', 'place_name': 'Spearville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ford', 'locality_code': '57', 'latitude': 37.8235, 'longitude': -99.737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67882', 'place_name': 'Wright', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ford', 'locality_code': '57', 'latitude': 37.7806, 'longitude': -99.8921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66042', 'place_name': 'Lane', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.4347, 'longitude': -95.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66067', 'place_name': 'Ottawa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.6142, 'longitude': -95.2745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66076', 'place_name': 'Pomona', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.6153, 'longitude': -95.4489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66078', 'place_name': 'Princeton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.4847, 'longitude': -95.2764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66079', 'place_name': 'Rantoul', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.5666, 'longitude': -95.1234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66080', 'place_name': 'Richmond', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.4074, 'longitude': -95.2489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66092', 'place_name': 'Wellsville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.7137, 'longitude': -95.0916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66095', 'place_name': 'Williamsburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Franklin', 'locality_code': '59', 'latitude': 38.4902, 'longitude': -95.4226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66441', 'place_name': 'Junction City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Geary', 'locality_code': '61', 'latitude': 39.0299, 'longitude': -96.8396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66442', 'place_name': 'Fort Riley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Geary', 'locality_code': '61', 'latitude': 39.0619, 'longitude': -96.7873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66514', 'place_name': 'Milford', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Geary', 'locality_code': '61', 'latitude': 39.1692, 'longitude': -96.91, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67736', 'place_name': 'Gove', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gove', 'locality_code': '63', 'latitude': 38.887, 'longitude': -100.4867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67737', 'place_name': 'Grainfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gove', 'locality_code': '63', 'latitude': 39.103, 'longitude': -100.468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67738', 'place_name': 'Grinnell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gove', 'locality_code': '63', 'latitude': 39.0851, 'longitude': -100.6621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67751', 'place_name': 'Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gove', 'locality_code': '63', 'latitude': 39.0788, 'longitude': -100.3469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67752', 'place_name': 'Quinter', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gove', 'locality_code': '63', 'latitude': 39.0363, 'longitude': -100.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67625', 'place_name': 'Bogue', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Graham', 'locality_code': '65', 'latitude': 39.3782, 'longitude': -99.6788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67642', 'place_name': 'Hill City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Graham', 'locality_code': '65', 'latitude': 39.3566, 'longitude': -99.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67650', 'place_name': 'Morland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Graham', 'locality_code': '65', 'latitude': 39.3229, 'longitude': -100.0733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67659', 'place_name': 'Penokee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Graham', 'locality_code': '65', 'latitude': 39.3482, 'longitude': -99.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67880', 'place_name': 'Ulysses', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Grant', 'locality_code': '67', 'latitude': 37.5792, 'longitude': -101.3488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67835', 'place_name': 'Cimarron', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gray', 'locality_code': '69', 'latitude': 37.8127, 'longitude': -100.3438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67837', 'place_name': 'Copeland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gray', 'locality_code': '69', 'latitude': 37.568, 'longitude': -100.6148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67841', 'place_name': 'Ensign', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gray', 'locality_code': '69', 'latitude': 37.6414, 'longitude': -100.2496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67853', 'place_name': 'Ingalls', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gray', 'locality_code': '69', 'latitude': 37.8293, 'longitude': -100.5143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67867', 'place_name': 'Montezuma', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Gray', 'locality_code': '69', 'latitude': 37.6016, 'longitude': -100.4461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67879', 'place_name': 'Tribune', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greeley', 'locality_code': '71', 'latitude': 38.4962, 'longitude': -101.7656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66853', 'place_name': 'Hamilton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 37.9791, 'longitude': -96.1691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66855', 'place_name': 'Lamont', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 38.1125, 'longitude': -96.0267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66860', 'place_name': 'Madison', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 38.1278, 'longitude': -96.1213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66863', 'place_name': 'Neal', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 37.8329, 'longitude': -96.0818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66870', 'place_name': 'Virgil', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 37.8976, 'longitude': -96.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67045', 'place_name': 'Eureka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 37.8265, 'longitude': -96.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67047', 'place_name': 'Fall River', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 37.621, 'longitude': -96.0435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67122', 'place_name': 'Piedmont', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 37.6372, 'longitude': -96.3695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67137', 'place_name': 'Severy', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Greenwood', 'locality_code': '73', 'latitude': 37.617, 'longitude': -96.2252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67836', 'place_name': 'Coolidge', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Hamilton', 'locality_code': '75', 'latitude': 38.0215, 'longitude': -102.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67857', 'place_name': 'Kendall', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Hamilton', 'locality_code': '75', 'latitude': 37.9347, 'longitude': -101.546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67878', 'place_name': 'Syracuse', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Hamilton', 'locality_code': '75', 'latitude': 37.9826, 'longitude': -101.7687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67003', 'place_name': 'Anthony', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harper', 'locality_code': '77', 'latitude': 37.1512, 'longitude': -98.0285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67009', 'place_name': 'Attica', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harper', 'locality_code': '77', 'latitude': 37.2528, 'longitude': -98.2264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67018', 'place_name': 'Bluff City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harper', 'locality_code': '77', 'latitude': 37.0838, 'longitude': -97.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67036', 'place_name': 'Danville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harper', 'locality_code': '77', 'latitude': 37.2674, 'longitude': -97.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67049', 'place_name': 'Freeport', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harper', 'locality_code': '77', 'latitude': 37.1903, 'longitude': -97.8634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67058', 'place_name': 'Harper', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harper', 'locality_code': '77', 'latitude': 37.2909, 'longitude': -98.018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67150', 'place_name': 'Waldron', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harper', 'locality_code': '77', 'latitude': 37.0022, 'longitude': -98.1826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67020', 'place_name': 'Burrton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harvey', 'locality_code': '79', 'latitude': 38.0261, 'longitude': -97.6666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67056', 'place_name': 'Halstead', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harvey', 'locality_code': '79', 'latitude': 38.0064, 'longitude': -97.5118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67062', 'place_name': 'Hesston', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harvey', 'locality_code': '79', 'latitude': 38.136, 'longitude': -97.4495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67114', 'place_name': 'Newton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harvey', 'locality_code': '79', 'latitude': 38.0451, 'longitude': -97.3435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67117', 'place_name': 'North Newton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harvey', 'locality_code': '79', 'latitude': 38.0743, 'longitude': -97.3473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67135', 'place_name': 'Sedgwick', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harvey', 'locality_code': '79', 'latitude': 37.9167, 'longitude': -97.4225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67151', 'place_name': 'Walton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Harvey', 'locality_code': '79', 'latitude': 38.1239, 'longitude': -97.2361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67870', 'place_name': 'Satanta', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Haskell', 'locality_code': '81', 'latitude': 37.4409, 'longitude': -100.9691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67877', 'place_name': 'Sublette', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Haskell', 'locality_code': '81', 'latitude': 37.5221, 'longitude': -100.8208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67849', 'place_name': 'Hanston', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Hodgeman', 'locality_code': '83', 'latitude': 38.109, 'longitude': -99.6928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67854', 'place_name': 'Jetmore', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Hodgeman', 'locality_code': '83', 'latitude': 38.0738, 'longitude': -99.9327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66416', 'place_name': 'Circleville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.5155, 'longitude': -95.8517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66418', 'place_name': 'Delia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.2655, 'longitude': -95.9608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66419', 'place_name': 'Denison', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.354, 'longitude': -95.6127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66436', 'place_name': 'Holton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.4436, 'longitude': -95.7525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66440', 'place_name': 'Hoyt', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.2552, 'longitude': -95.6867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66509', 'place_name': 'Mayetta', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.3489, 'longitude': -95.6928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66516', 'place_name': 'Netawaka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.6063, 'longitude': -95.727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66540', 'place_name': 'Soldier', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.5013, 'longitude': -95.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66552', 'place_name': 'Whiting', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jackson', 'locality_code': '85', 'latitude': 39.5974, 'longitude': -95.6158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66054', 'place_name': 'Mc Louth', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.1668, 'longitude': -95.2183, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66060', 'place_name': 'Nortonville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.4095, 'longitude': -95.3236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66066', 'place_name': 'Oskaloosa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.2152, 'longitude': -95.3135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66070', 'place_name': 'Ozawkie', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.2136, 'longitude': -95.4404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66073', 'place_name': 'Perry', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.0875, 'longitude': -95.3731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66088', 'place_name': 'Valley Falls', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.3484, 'longitude': -95.467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66097', 'place_name': 'Winchester', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.3245, 'longitude': -95.2696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66429', 'place_name': 'Grantville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.0972, 'longitude': -95.5397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66512', 'place_name': 'Meriden', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jefferson', 'locality_code': '87', 'latitude': 39.2038, 'longitude': -95.5476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66936', 'place_name': 'Burr Oak', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jewell', 'locality_code': '89', 'latitude': 39.8932, 'longitude': -98.3499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66941', 'place_name': 'Esbon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jewell', 'locality_code': '89', 'latitude': 39.7562, 'longitude': -98.4462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66942', 'place_name': 'Formoso', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jewell', 'locality_code': '89', 'latitude': 39.7795, 'longitude': -97.9889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66949', 'place_name': 'Jewell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jewell', 'locality_code': '89', 'latitude': 39.6719, 'longitude': -98.1472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66956', 'place_name': 'Mankato', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jewell', 'locality_code': '89', 'latitude': 39.7833, 'longitude': -98.2152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66963', 'place_name': 'Randall', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jewell', 'locality_code': '89', 'latitude': 39.6286, 'longitude': -98.0661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66970', 'place_name': 'Webber', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Jewell', 'locality_code': '89', 'latitude': 39.935, 'longitude': -98.035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66018', 'place_name': 'De Soto', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9462, 'longitude': -94.9714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66021', 'place_name': 'Edgerton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.7811, 'longitude': -95.0094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66030', 'place_name': 'Gardner', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8075, 'longitude': -94.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66031', 'place_name': 'New Century', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8249, 'longitude': -94.8992, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66051', 'place_name': 'Olathe', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8999, 'longitude': -94.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66061', 'place_name': 'Olathe', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8865, 'longitude': -94.8204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66062', 'place_name': 'Olathe', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8733, 'longitude': -94.7752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66063', 'place_name': 'Olathe', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8999, 'longitude': -94.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66083', 'place_name': 'Spring Hill', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.7631, 'longitude': -94.8246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66085', 'place_name': 'Stilwell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.7902, 'longitude': -94.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66201', 'place_name': 'Mission', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0278, 'longitude': -94.6558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66202', 'place_name': 'Mission', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0278, 'longitude': -94.6558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66203', 'place_name': 'Shawnee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0417, 'longitude': -94.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66204', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9928, 'longitude': -94.6771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66205', 'place_name': 'Mission', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0278, 'longitude': -94.6558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66206', 'place_name': 'Leawood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9667, 'longitude': -94.6169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66207', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9575, 'longitude': -94.6452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66208', 'place_name': 'Prairie Village', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9917, 'longitude': -94.6336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66209', 'place_name': 'Leawood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9667, 'longitude': -94.6169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66210', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9273, 'longitude': -94.7143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66211', 'place_name': 'Leawood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9667, 'longitude': -94.6169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66212', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9568, 'longitude': -94.6832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66213', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8982, 'longitude': -94.7049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66214', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9649, 'longitude': -94.7209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66215', 'place_name': 'Lenexa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9536, 'longitude': -94.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66216', 'place_name': 'Shawnee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0417, 'longitude': -94.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66217', 'place_name': 'Shawnee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0417, 'longitude': -94.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66218', 'place_name': 'Shawnee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0417, 'longitude': -94.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66219', 'place_name': 'Lenexa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9536, 'longitude': -94.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66220', 'place_name': 'Lenexa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9536, 'longitude': -94.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66221', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8636, 'longitude': -94.7103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66222', 'place_name': 'Mission', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0278, 'longitude': -94.6558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66223', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8619, 'longitude': -94.661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66224', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8591, 'longitude': -94.6314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66225', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8999, 'longitude': -94.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66226', 'place_name': 'Shawnee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0417, 'longitude': -94.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66227', 'place_name': 'Lenexa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9536, 'longitude': -94.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66250', 'place_name': 'Lenexa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9536, 'longitude': -94.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66251', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8999, 'longitude': -94.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66276', 'place_name': 'Shawnee Mission', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8999, 'longitude': -94.832, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66282', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8999, 'longitude': -94.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66283', 'place_name': 'Overland Park', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.8999, 'longitude': -94.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66285', 'place_name': 'Lenexa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 38.9536, 'longitude': -94.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66286', 'place_name': 'Shawnee', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Johnson', 'locality_code': '91', 'latitude': 39.0417, 'longitude': -94.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67838', 'place_name': 'Deerfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kearny', 'locality_code': '93', 'latitude': 38.0068, 'longitude': -101.1431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67860', 'place_name': 'Lakin', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kearny', 'locality_code': '93', 'latitude': 37.9382, 'longitude': -101.2713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67035', 'place_name': 'Cunningham', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kingman', 'locality_code': '95', 'latitude': 37.6309, 'longitude': -98.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67068', 'place_name': 'Kingman', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kingman', 'locality_code': '95', 'latitude': 37.5964, 'longitude': -98.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67111', 'place_name': 'Murdock', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kingman', 'locality_code': '95', 'latitude': 37.6099, 'longitude': -97.9503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67112', 'place_name': 'Nashville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kingman', 'locality_code': '95', 'latitude': 37.4344, 'longitude': -98.4171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67118', 'place_name': 'Norwich', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kingman', 'locality_code': '95', 'latitude': 37.4501, 'longitude': -97.8662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67142', 'place_name': 'Spivey', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kingman', 'locality_code': '95', 'latitude': 37.441, 'longitude': -98.1751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67159', 'place_name': 'Zenda', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kingman', 'locality_code': '95', 'latitude': 37.4373, 'longitude': -98.2874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67054', 'place_name': 'Greensburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kiowa', 'locality_code': '97', 'latitude': 37.6084, 'longitude': -99.3011, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '67059', 'place_name': 'Haviland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kiowa', 'locality_code': '97', 'latitude': 37.6096, 'longitude': -99.134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67109', 'place_name': 'Mullinville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Kiowa', 'locality_code': '97', 'latitude': 37.5716, 'longitude': -99.4639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67330', 'place_name': 'Altamont', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.1873, 'longitude': -95.2983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67332', 'place_name': 'Bartlett', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.0601, 'longitude': -95.2115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67336', 'place_name': 'Chetopa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.0418, 'longitude': -95.0796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67341', 'place_name': 'Dennis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.3243, 'longitude': -95.4116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67342', 'place_name': 'Edna', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.0561, 'longitude': -95.3442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67354', 'place_name': 'Mound Valley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.2091, 'longitude': -95.4247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67356', 'place_name': 'Oswego', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.1823, 'longitude': -95.1335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67357', 'place_name': 'Parsons', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Labette', 'locality_code': '99', 'latitude': 37.3389, 'longitude': -95.2693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67839', 'place_name': 'Dighton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lane', 'locality_code': '101', 'latitude': 38.4742, 'longitude': -100.4647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67850', 'place_name': 'Healy', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lane', 'locality_code': '101', 'latitude': 38.5664, 'longitude': -100.6159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66007', 'place_name': 'Basehor', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Leavenworth', 'locality_code': '103', 'latitude': 39.1281, 'longitude': -94.957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66020', 'place_name': 'Easton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Leavenworth', 'locality_code': '103', 'latitude': 39.3391, 'longitude': -95.0999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66027', 'place_name': 'Fort Leavenworth', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Leavenworth', 'locality_code': '103', 'latitude': 39.3485, 'longitude': -94.9265, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66043', 'place_name': 'Lansing', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Leavenworth', 'locality_code': '103', 'latitude': 39.2502, 'longitude': -94.8994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66048', 'place_name': 'Leavenworth', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Leavenworth', 'locality_code': '103', 'latitude': 39.3015, 'longitude': -94.9339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66052', 'place_name': 'Linwood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Leavenworth', 'locality_code': '103', 'latitude': 39.0014, 'longitude': -95.0391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66086', 'place_name': 'Tonganoxie', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Leavenworth', 'locality_code': '103', 'latitude': 39.1026, 'longitude': -95.1051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67418', 'place_name': 'Barnard', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lincoln', 'locality_code': '105', 'latitude': 39.1816, 'longitude': -98.0711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67423', 'place_name': 'Beverly', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lincoln', 'locality_code': '105', 'latitude': 38.9844, 'longitude': -97.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67455', 'place_name': 'Lincoln', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lincoln', 'locality_code': '105', 'latitude': 39.1027, 'longitude': -98.2149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67481', 'place_name': 'Sylvan Grove', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lincoln', 'locality_code': '105', 'latitude': 39.0324, 'longitude': -98.373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66010', 'place_name': 'Blue Mound', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Linn', 'locality_code': '107', 'latitude': 38.0908, 'longitude': -95.0053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66014', 'place_name': 'Centerville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Linn', 'locality_code': '107', 'latitude': 38.213, 'longitude': -94.9934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66040', 'place_name': 'Lacygne', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Linn', 'locality_code': '107', 'latitude': 39.0478, 'longitude': -95.1538, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66056', 'place_name': 'Mound City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Linn', 'locality_code': '107', 'latitude': 38.156, 'longitude': -94.8186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66072', 'place_name': 'Parker', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Linn', 'locality_code': '107', 'latitude': 38.3303, 'longitude': -94.9871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66075', 'place_name': 'Pleasanton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Linn', 'locality_code': '107', 'latitude': 38.1823, 'longitude': -94.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66767', 'place_name': 'Prescott', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Linn', 'locality_code': '107', 'latitude': 38.0718, 'longitude': -94.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67747', 'place_name': 'Monument', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Logan', 'locality_code': '109', 'latitude': 39.079, 'longitude': -101.035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67748', 'place_name': 'Oakley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Logan', 'locality_code': '109', 'latitude': 39.1121, 'longitude': -100.858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67764', 'place_name': 'Winona', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Logan', 'locality_code': '109', 'latitude': 39.061, 'longitude': -101.2216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66801', 'place_name': 'Emporia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.4184, 'longitude': -96.1871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66830', 'place_name': 'Admire', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.6393, 'longitude': -96.1017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66833', 'place_name': 'Allen', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.652, 'longitude': -96.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66835', 'place_name': 'Americus', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.5098, 'longitude': -96.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66854', 'place_name': 'Hartford', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.2833, 'longitude': -95.9997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66864', 'place_name': 'Neosho Rapids', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.3948, 'longitude': -96.0168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66865', 'place_name': 'Olpe', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.2578, 'longitude': -96.1891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66868', 'place_name': 'Reading', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Lyon', 'locality_code': '111', 'latitude': 38.529, 'longitude': -95.9895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67107', 'place_name': 'Moundridge', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.206, 'longitude': -97.5088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67428', 'place_name': 'Canton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.3858, 'longitude': -97.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67443', 'place_name': 'Galva', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.3824, 'longitude': -97.5359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67456', 'place_name': 'Lindsborg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.5761, 'longitude': -97.6739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67460', 'place_name': 'Mcpherson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.3763, 'longitude': -97.6702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67464', 'place_name': 'Marquette', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.556, 'longitude': -97.8381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67476', 'place_name': 'Roxbury', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.5508, 'longitude': -97.4303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67491', 'place_name': 'Windom', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.3845, 'longitude': -97.8965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67546', 'place_name': 'Inman', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'McPherson', 'locality_code': '113', 'latitude': 38.2232, 'longitude': -97.7951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66840', 'place_name': 'Burns', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.1222, 'longitude': -96.8634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66851', 'place_name': 'Florence', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.2415, 'longitude': -96.9346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66858', 'place_name': 'Lincolnville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.4933, 'longitude': -96.9626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66859', 'place_name': 'Lost Springs', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.5657, 'longitude': -96.9799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66861', 'place_name': 'Marion', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.3554, 'longitude': -97.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66866', 'place_name': 'Peabody', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.1737, 'longitude': -97.1184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67053', 'place_name': 'Goessel', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.2468, 'longitude': -97.3463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67063', 'place_name': 'Hillsboro', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.3449, 'longitude': -97.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67073', 'place_name': 'Lehigh', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.3771, 'longitude': -97.3043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67438', 'place_name': 'Durham', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.5038, 'longitude': -97.2555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67475', 'place_name': 'Ramona', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.5777, 'longitude': -97.0759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67483', 'place_name': 'Tampa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marion', 'locality_code': '115', 'latitude': 38.5534, 'longitude': -97.1774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66403', 'place_name': 'Axtell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.8707, 'longitude': -96.2676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66406', 'place_name': 'Beattie', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.8988, 'longitude': -96.4286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66411', 'place_name': 'Blue Rapids', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.675, 'longitude': -96.6359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66412', 'place_name': 'Bremen', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.8775, 'longitude': -96.7458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66427', 'place_name': 'Frankfort', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.7333, 'longitude': -96.5223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66438', 'place_name': 'Home', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.8488, 'longitude': -96.5063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66508', 'place_name': 'Marysville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.8428, 'longitude': -96.6422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66518', 'place_name': 'Oketo', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.9598, 'longitude': -96.6235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66541', 'place_name': 'Summerfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.9798, 'longitude': -96.3279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66544', 'place_name': 'Vermillion', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.6946, 'longitude': -96.278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66548', 'place_name': 'Waterville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Marshall', 'locality_code': '117', 'latitude': 39.6971, 'longitude': -96.7498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67844', 'place_name': 'Fowler', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Meade', 'locality_code': '119', 'latitude': 37.3542, 'longitude': -100.1981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67864', 'place_name': 'Meade', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Meade', 'locality_code': '119', 'latitude': 37.2821, 'longitude': -100.3364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67869', 'place_name': 'Plains', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Meade', 'locality_code': '119', 'latitude': 37.2701, 'longitude': -100.5732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66013', 'place_name': 'Bucyrus', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Miami', 'locality_code': '121', 'latitude': 38.7283, 'longitude': -94.6887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66026', 'place_name': 'Fontana', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Miami', 'locality_code': '121', 'latitude': 38.4102, 'longitude': -94.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66036', 'place_name': 'Hillsdale', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Miami', 'locality_code': '121', 'latitude': 38.6581, 'longitude': -94.8521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66053', 'place_name': 'Louisburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Miami', 'locality_code': '121', 'latitude': 38.6073, 'longitude': -94.6829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66064', 'place_name': 'Osawatomie', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Miami', 'locality_code': '121', 'latitude': 38.4888, 'longitude': -94.962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66071', 'place_name': 'Paola', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Miami', 'locality_code': '121', 'latitude': 38.572, 'longitude': -94.8937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67420', 'place_name': 'Beloit', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Mitchell', 'locality_code': '123', 'latitude': 39.4416, 'longitude': -98.1192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67430', 'place_name': 'Cawker City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Mitchell', 'locality_code': '123', 'latitude': 39.5115, 'longitude': -98.4335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67446', 'place_name': 'Glen Elder', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Mitchell', 'locality_code': '123', 'latitude': 39.4958, 'longitude': -98.3155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67452', 'place_name': 'Hunter', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Mitchell', 'locality_code': '123', 'latitude': 39.243, 'longitude': -98.4017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67478', 'place_name': 'Simpson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Mitchell', 'locality_code': '123', 'latitude': 39.3851, 'longitude': -97.9328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67485', 'place_name': 'Tipton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Mitchell', 'locality_code': '123', 'latitude': 39.3436, 'longitude': -98.4644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67301', 'place_name': 'Independence', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.2292, 'longitude': -95.7165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67333', 'place_name': 'Caney', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.0224, 'longitude': -95.9091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67335', 'place_name': 'Cherryvale', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.2668, 'longitude': -95.559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67337', 'place_name': 'Coffeyville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.0441, 'longitude': -95.6328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67340', 'place_name': 'Dearing', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.0596, 'longitude': -95.7131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67344', 'place_name': 'Elk City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.3146, 'longitude': -95.9135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67347', 'place_name': 'Havana', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.0917, 'longitude': -95.9414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67351', 'place_name': 'Liberty', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.1576, 'longitude': -95.6017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67363', 'place_name': 'Sycamore', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.3281, 'longitude': -95.717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67364', 'place_name': 'Tyro', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 37.037, 'longitude': -95.8237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66838', 'place_name': 'Burdick', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morris', 'locality_code': '127', 'latitude': 38.5674, 'longitude': -96.8396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66846', 'place_name': 'Council Grove', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morris', 'locality_code': '127', 'latitude': 38.6959, 'longitude': -96.5469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66849', 'place_name': 'Dwight', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morris', 'locality_code': '127', 'latitude': 38.8389, 'longitude': -96.5802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66872', 'place_name': 'White City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morris', 'locality_code': '127', 'latitude': 38.789, 'longitude': -96.7637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66873', 'place_name': 'Wilsey', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morris', 'locality_code': '127', 'latitude': 38.6361, 'longitude': -96.6753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67950', 'place_name': 'Elkhart', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morton', 'locality_code': '129', 'latitude': 37.0154, 'longitude': -101.9012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67953', 'place_name': 'Richfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morton', 'locality_code': '129', 'latitude': 37.2834, 'longitude': -101.7004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67954', 'place_name': 'Rolla', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Morton', 'locality_code': '129', 'latitude': 37.1089, 'longitude': -101.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66404', 'place_name': 'Baileyville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.8816, 'longitude': -96.1801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66408', 'place_name': 'Bern', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.9571, 'longitude': -95.961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66415', 'place_name': 'Centralia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.7381, 'longitude': -96.1486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66417', 'place_name': 'Corning', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.6572, 'longitude': -96.0294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66428', 'place_name': 'Goff', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.6654, 'longitude': -95.9574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66522', 'place_name': 'Oneida', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.8639, 'longitude': -95.9392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66534', 'place_name': 'Sabetha', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.8993, 'longitude': -95.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66538', 'place_name': 'Seneca', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.8473, 'longitude': -96.0316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66550', 'place_name': 'Wetmore', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Nemaha', 'locality_code': '131', 'latitude': 39.6428, 'longitude': -95.8231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66720', 'place_name': 'Chanute', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Neosho', 'locality_code': '133', 'latitude': 37.6749, 'longitude': -95.457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66733', 'place_name': 'Erie', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Neosho', 'locality_code': '133', 'latitude': 37.6044, 'longitude': -95.2514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66740', 'place_name': 'Galesburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Neosho', 'locality_code': '133', 'latitude': 37.4724, 'longitude': -95.3707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66771', 'place_name': 'Saint Paul', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Neosho', 'locality_code': '133', 'latitude': 37.518, 'longitude': -95.1688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66775', 'place_name': 'Stark', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Neosho', 'locality_code': '133', 'latitude': 37.6811, 'longitude': -95.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66776', 'place_name': 'Thayer', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Neosho', 'locality_code': '133', 'latitude': 37.4527, 'longitude': -95.4671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67515', 'place_name': 'Arnold', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ness', 'locality_code': '135', 'latitude': 38.6403, 'longitude': -100.0462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67516', 'place_name': 'Bazine', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ness', 'locality_code': '135', 'latitude': 38.4565, 'longitude': -99.7016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67518', 'place_name': 'Beeler', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ness', 'locality_code': '135', 'latitude': 38.4445, 'longitude': -100.1949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67521', 'place_name': 'Brownell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ness', 'locality_code': '135', 'latitude': 38.6239, 'longitude': -99.7328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67560', 'place_name': 'Ness City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ness', 'locality_code': '135', 'latitude': 38.4388, 'longitude': -99.9029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67572', 'place_name': 'Ransom', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ness', 'locality_code': '135', 'latitude': 38.64, 'longitude': -99.9267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67584', 'place_name': 'Utica', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ness', 'locality_code': '135', 'latitude': 38.6411, 'longitude': -100.138, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '67622', 'place_name': 'Almena', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Norton', 'locality_code': '137', 'latitude': 39.8891, 'longitude': -99.7042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67629', 'place_name': 'Clayton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Norton', 'locality_code': '137', 'latitude': 39.7375, 'longitude': -100.1776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67645', 'place_name': 'Lenora', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Norton', 'locality_code': '137', 'latitude': 39.6105, 'longitude': -100.0028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67654', 'place_name': 'Norton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Norton', 'locality_code': '137', 'latitude': 39.8407, 'longitude': -99.8878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66413', 'place_name': 'Burlingame', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.7634, 'longitude': -95.84, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66414', 'place_name': 'Carbondale', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.8206, 'longitude': -95.6871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66451', 'place_name': 'Lyndon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.6356, 'longitude': -95.6802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66510', 'place_name': 'Melvern', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.5027, 'longitude': -95.629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66523', 'place_name': 'Osage City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.6269, 'longitude': -95.8303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66524', 'place_name': 'Overbrook', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.7922, 'longitude': -95.5616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66528', 'place_name': 'Quenemo', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.5785, 'longitude': -95.5362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66537', 'place_name': 'Scranton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.788, 'longitude': -95.748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66543', 'place_name': 'Vassar', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osage', 'locality_code': '139', 'latitude': 38.6419, 'longitude': -95.6012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67437', 'place_name': 'Downs', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osborne', 'locality_code': '141', 'latitude': 39.5028, 'longitude': -98.5441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67473', 'place_name': 'Osborne', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osborne', 'locality_code': '141', 'latitude': 39.4194, 'longitude': -98.6961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67474', 'place_name': 'Portis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osborne', 'locality_code': '141', 'latitude': 39.5455, 'longitude': -98.6904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67623', 'place_name': 'Alton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osborne', 'locality_code': '141', 'latitude': 39.4514, 'longitude': -98.9539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67651', 'place_name': 'Natoma', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Osborne', 'locality_code': '141', 'latitude': 39.2013, 'longitude': -98.9829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67422', 'place_name': 'Bennington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ottawa', 'locality_code': '143', 'latitude': 39.0224, 'longitude': -97.6031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67436', 'place_name': 'Delphos', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ottawa', 'locality_code': '143', 'latitude': 39.2731, 'longitude': -97.7717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67467', 'place_name': 'Minneapolis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ottawa', 'locality_code': '143', 'latitude': 39.1295, 'longitude': -97.6688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67484', 'place_name': 'Tescott', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Ottawa', 'locality_code': '143', 'latitude': 38.9916, 'longitude': -97.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67523', 'place_name': 'Burdett', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pawnee', 'locality_code': '145', 'latitude': 38.2104, 'longitude': -99.5275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67529', 'place_name': 'Garfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pawnee', 'locality_code': '145', 'latitude': 38.0649, 'longitude': -99.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67550', 'place_name': 'Larned', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pawnee', 'locality_code': '145', 'latitude': 38.1946, 'longitude': -99.101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67574', 'place_name': 'Rozel', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pawnee', 'locality_code': '145', 'latitude': 38.2148, 'longitude': -99.4048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67621', 'place_name': 'Agra', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Phillips', 'locality_code': '147', 'latitude': 39.8037, 'longitude': -99.1255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67639', 'place_name': 'Glade', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Phillips', 'locality_code': '147', 'latitude': 39.6704, 'longitude': -99.2996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67644', 'place_name': 'Kirwin', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Phillips', 'locality_code': '147', 'latitude': 39.6717, 'longitude': -99.1204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67646', 'place_name': 'Logan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Phillips', 'locality_code': '147', 'latitude': 39.6611, 'longitude': -99.5687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67647', 'place_name': 'Long Island', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Phillips', 'locality_code': '147', 'latitude': 39.9517, 'longitude': -99.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67661', 'place_name': 'Phillipsburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Phillips', 'locality_code': '147', 'latitude': 39.7623, 'longitude': -99.3328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67664', 'place_name': 'Prairie View', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Phillips', 'locality_code': '147', 'latitude': 39.837, 'longitude': -99.5683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66407', 'place_name': 'Belvue', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.2273, 'longitude': -96.1866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66422', 'place_name': 'Emmett', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.3048, 'longitude': -96.0593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66426', 'place_name': 'Fostoria', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.4398, 'longitude': -96.5068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66432', 'place_name': 'Havensville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.4942, 'longitude': -96.0769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66520', 'place_name': 'Olsburg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.4125, 'longitude': -96.6002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66521', 'place_name': 'Onaga', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.4889, 'longitude': -96.17, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66535', 'place_name': 'Saint George', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.2108, 'longitude': -96.4345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66536', 'place_name': 'Saint Marys', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.1987, 'longitude': -96.0683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66547', 'place_name': 'Wamego', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.21, 'longitude': -96.3153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66549', 'place_name': 'Westmoreland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pottawatomie', 'locality_code': '149', 'latitude': 39.4138, 'longitude': -96.4374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67021', 'place_name': 'Byers', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pratt', 'locality_code': '151', 'latitude': 37.7847, 'longitude': -98.9017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67028', 'place_name': 'Coats', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pratt', 'locality_code': '151', 'latitude': 37.5125, 'longitude': -98.8504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67066', 'place_name': 'Iuka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pratt', 'locality_code': '151', 'latitude': 37.7397, 'longitude': -98.7361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67124', 'place_name': 'Pratt', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pratt', 'locality_code': '151', 'latitude': 37.6502, 'longitude': -98.73, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67134', 'place_name': 'Sawyer', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Pratt', 'locality_code': '151', 'latitude': 37.5101, 'longitude': -98.6642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67730', 'place_name': 'Atwood', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rawlins', 'locality_code': '153', 'latitude': 39.7926, 'longitude': -101.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67739', 'place_name': 'Herndon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rawlins', 'locality_code': '153', 'latitude': 39.9036, 'longitude': -100.8139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67744', 'place_name': 'Ludell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rawlins', 'locality_code': '153', 'latitude': 39.863, 'longitude': -100.9604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67745', 'place_name': 'Mc Donald', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rawlins', 'locality_code': '153', 'latitude': 39.7923, 'longitude': -101.3227, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '67501', 'place_name': 'Hutchinson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 38.055, 'longitude': -97.9311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67502', 'place_name': 'Hutchinson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 38.1156, 'longitude': -97.8937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67504', 'place_name': 'Hutchinson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.9532, 'longitude': -98.0859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67505', 'place_name': 'South Hutchinson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 38.0282, 'longitude': -97.9431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67510', 'place_name': 'Abbyville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.9626, 'longitude': -98.2071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67514', 'place_name': 'Arlington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.8598, 'longitude': -98.159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67522', 'place_name': 'Buhler', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 38.1309, 'longitude': -97.7691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67543', 'place_name': 'Haven', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.8989, 'longitude': -97.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67561', 'place_name': 'Nickerson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 38.1412, 'longitude': -98.0674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67566', 'place_name': 'Partridge', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.9671, 'longitude': -98.0798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67568', 'place_name': 'Plevna', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.9658, 'longitude': -98.2988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67570', 'place_name': 'Pretty Prairie', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.7783, 'longitude': -97.9886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67581', 'place_name': 'Sylvia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.9557, 'longitude': -98.4068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67583', 'place_name': 'Turon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.8224, 'longitude': -98.3591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67585', 'place_name': 'Yoder', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Reno', 'locality_code': '155', 'latitude': 37.9412, 'longitude': -97.8711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66930', 'place_name': 'Agenda', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.7044, 'longitude': -97.4465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66935', 'place_name': 'Belleville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.8241, 'longitude': -97.629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66939', 'place_name': 'Courtland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.7851, 'longitude': -97.89, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66940', 'place_name': 'Cuba', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.7975, 'longitude': -97.4496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66959', 'place_name': 'Munden', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.9272, 'longitude': -97.5403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66960', 'place_name': 'Narka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.9582, 'longitude': -97.4243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66961', 'place_name': 'Norway', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.8279, 'longitude': -97.6509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66964', 'place_name': 'Republic', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.9376, 'longitude': -97.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66966', 'place_name': 'Scandia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Republic', 'locality_code': '157', 'latitude': 39.7939, 'longitude': -97.7786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67427', 'place_name': 'Bushton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.5018, 'longitude': -98.4016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67444', 'place_name': 'Geneseo', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.5037, 'longitude': -98.1858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67457', 'place_name': 'Little River', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.4079, 'longitude': -98.0113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67512', 'place_name': 'Alden', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.2343, 'longitude': -98.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67524', 'place_name': 'Chase', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.3635, 'longitude': -98.3556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67554', 'place_name': 'Lyons', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.3349, 'longitude': -98.1831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67573', 'place_name': 'Raymond', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.2877, 'longitude': -98.4119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67579', 'place_name': 'Sterling', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rice', 'locality_code': '159', 'latitude': 38.2126, 'longitude': -98.2055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66449', 'place_name': 'Leonardville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.3644, 'longitude': -96.8589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66502', 'place_name': 'Manhattan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.1938, 'longitude': -96.5858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66503', 'place_name': 'Manhattan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.2458, 'longitude': -96.6336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66505', 'place_name': 'Manhattan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.3049, 'longitude': -96.6753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66506', 'place_name': 'Manhattan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.196, 'longitude': -96.5839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66517', 'place_name': 'Ogden', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.1153, 'longitude': -96.7101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66531', 'place_name': 'Riley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.3005, 'longitude': -96.8222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66554', 'place_name': 'Randolph', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Riley', 'locality_code': '161', 'latitude': 39.4879, 'longitude': -96.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67632', 'place_name': 'Damar', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rooks', 'locality_code': '163', 'latitude': 39.3242, 'longitude': -99.5811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67657', 'place_name': 'Palco', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rooks', 'locality_code': '163', 'latitude': 39.2531, 'longitude': -99.5593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67663', 'place_name': 'Plainville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rooks', 'locality_code': '163', 'latitude': 39.2308, 'longitude': -99.3008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67669', 'place_name': 'Stockton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rooks', 'locality_code': '163', 'latitude': 39.4376, 'longitude': -99.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67675', 'place_name': 'Woodston', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rooks', 'locality_code': '163', 'latitude': 39.4431, 'longitude': -99.1037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67513', 'place_name': 'Alexander', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.457, 'longitude': -99.5378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67520', 'place_name': 'Bison', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.5193, 'longitude': -99.1986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67548', 'place_name': 'La Crosse', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.5311, 'longitude': -99.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67553', 'place_name': 'Liebenthal', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.6557, 'longitude': -99.3203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67556', 'place_name': 'Mc Cracken', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.5957, 'longitude': -99.554, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '67559', 'place_name': 'Nekoma', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.4372, 'longitude': -99.4234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67565', 'place_name': 'Otis', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.5353, 'longitude': -99.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67575', 'place_name': 'Rush Center', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Rush', 'locality_code': '165', 'latitude': 38.4533, 'longitude': -99.3079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67626', 'place_name': 'Bunker Hill', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 38.8758, 'longitude': -98.704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67634', 'place_name': 'Dorrance', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 38.8348, 'longitude': -98.5695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67640', 'place_name': 'Gorham', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 38.8722, 'longitude': -99.0112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67648', 'place_name': 'Lucas', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 39.0581, 'longitude': -98.5352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67649', 'place_name': 'Luray', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 39.1039, 'longitude': -98.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67658', 'place_name': 'Paradise', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 39.0756, 'longitude': -98.9207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67665', 'place_name': 'Russell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 38.8806, 'longitude': -98.8595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67673', 'place_name': 'Waldo', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Russell', 'locality_code': '167', 'latitude': 39.0877, 'longitude': -98.7785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67401', 'place_name': 'Salina', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Saline', 'locality_code': '169', 'latitude': 38.8237, 'longitude': -97.6421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67402', 'place_name': 'Salina', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Saline', 'locality_code': '169', 'latitude': 38.8403, 'longitude': -97.6114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67416', 'place_name': 'Assaria', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Saline', 'locality_code': '169', 'latitude': 38.6676, 'longitude': -97.6203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67425', 'place_name': 'Brookville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Saline', 'locality_code': '169', 'latitude': 38.7858, 'longitude': -97.863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67442', 'place_name': 'Falun', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Saline', 'locality_code': '169', 'latitude': 38.6648, 'longitude': -97.7554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67448', 'place_name': 'Gypsum', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Saline', 'locality_code': '169', 'latitude': 38.7047, 'longitude': -97.4338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67470', 'place_name': 'New Cambria', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Saline', 'locality_code': '169', 'latitude': 38.896, 'longitude': -97.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67871', 'place_name': 'Scott City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Scott', 'locality_code': '171', 'latitude': 38.4823, 'longitude': -100.9064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67001', 'place_name': 'Andale', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7797, 'longitude': -97.6366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67016', 'place_name': 'Bentley', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.8866, 'longitude': -97.5166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67025', 'place_name': 'Cheney', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6353, 'longitude': -97.7686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67026', 'place_name': 'Clearwater', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.5076, 'longitude': -97.5082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67030', 'place_name': 'Colwich', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7782, 'longitude': -97.5405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67037', 'place_name': 'Derby', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.553, 'longitude': -97.2549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67050', 'place_name': 'Garden Plain', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6767, 'longitude': -97.66, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67052', 'place_name': 'Goddard', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6597, 'longitude': -97.5753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67055', 'place_name': 'Greenwich', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7833, 'longitude': -97.2054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67060', 'place_name': 'Haysville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.5647, 'longitude': -97.3553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67067', 'place_name': 'Kechi', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7934, 'longitude': -97.2737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67101', 'place_name': 'Maize', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7747, 'longitude': -97.4689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67108', 'place_name': 'Mount Hope', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.8684, 'longitude': -97.6591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67120', 'place_name': 'Peck', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.5054, 'longitude': -97.3408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67147', 'place_name': 'Valley Center', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.8616, 'longitude': -97.2621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67149', 'place_name': 'Viola', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.5696, 'longitude': -97.6306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67201', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6922, 'longitude': -97.3375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67202', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6899, 'longitude': -97.3355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67203', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7048, 'longitude': -97.3638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67204', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7488, 'longitude': -97.3566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67205', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7639, 'longitude': -97.4269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67206', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7038, 'longitude': -97.2253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67207', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.671, 'longitude': -97.2179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67208', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7024, 'longitude': -97.2811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67209', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6779, 'longitude': -97.4235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67210', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6379, 'longitude': -97.2613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67211', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6662, 'longitude': -97.3165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67212', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7007, 'longitude': -97.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67213', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.668, 'longitude': -97.3591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67214', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7051, 'longitude': -97.3133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67215', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6333, 'longitude': -97.425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67216', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6223, 'longitude': -97.3136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67217', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6266, 'longitude': -97.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67218', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.669, 'longitude': -97.2802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67219', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7719, 'longitude': -97.3175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67220', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7667, 'longitude': -97.2805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67221', 'place_name': 'Mcconnell Afb', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6066, 'longitude': -97.2979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67223', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7367, 'longitude': -97.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67226', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7379, 'longitude': -97.2479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67227', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6281, 'longitude': -97.4916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67228', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7742, 'longitude': -97.1711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67230', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6808, 'longitude': -97.1558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67232', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6395, 'longitude': -97.1714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67235', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7149, 'longitude': -97.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67260', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.7194, 'longitude': -97.2936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67275', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6936, 'longitude': -97.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67276', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6936, 'longitude': -97.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67277', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6936, 'longitude': -97.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67278', 'place_name': 'Wichita', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sedgwick', 'locality_code': '173', 'latitude': 37.6922, 'longitude': -97.3375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67859', 'place_name': 'Kismet', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Seward', 'locality_code': '175', 'latitude': 37.2042, 'longitude': -100.7014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67901', 'place_name': 'Liberal', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Seward', 'locality_code': '175', 'latitude': 37.0438, 'longitude': -100.9286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67905', 'place_name': 'Liberal', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Seward', 'locality_code': '175', 'latitude': 37.0216, 'longitude': -100.938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66402', 'place_name': 'Auburn', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 38.9167, 'longitude': -95.8199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66409', 'place_name': 'Berryton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 38.9442, 'longitude': -95.5825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66420', 'place_name': 'Dover', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 38.9645, 'longitude': -95.9172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66533', 'place_name': 'Rossville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.1451, 'longitude': -95.9553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66539', 'place_name': 'Silver Lake', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.1102, 'longitude': -95.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66542', 'place_name': 'Tecumseh', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0217, 'longitude': -95.5379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66546', 'place_name': 'Wakarusa', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 38.9045, 'longitude': -95.7015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66601', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66603', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0553, 'longitude': -95.6802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66604', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0405, 'longitude': -95.7178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66605', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0151, 'longitude': -95.6439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66606', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0583, 'longitude': -95.7095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66607', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0421, 'longitude': -95.6449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66608', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0858, 'longitude': -95.6867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66609', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 38.9919, 'longitude': -95.6681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66610', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 38.9822, 'longitude': -95.7461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66611', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0142, 'longitude': -95.6981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66612', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0427, 'longitude': -95.6818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66614', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0154, 'longitude': -95.7469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66615', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0446, 'longitude': -95.7906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66616', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0645, 'longitude': -95.6413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66617', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.1271, 'longitude': -95.6384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66618', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.1329, 'longitude': -95.7023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66619', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 38.9536, 'longitude': -95.7236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66620', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0429, 'longitude': -95.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66621', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0333, 'longitude': -95.7015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66622', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0429, 'longitude': -95.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66624', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0429, 'longitude': -95.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66625', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66626', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66629', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66630', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66636', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66647', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0429, 'longitude': -95.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66667', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0429, 'longitude': -95.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66675', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0429, 'longitude': -95.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66683', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66699', 'place_name': 'Topeka', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Shawnee', 'locality_code': '177', 'latitude': 39.0483, 'longitude': -95.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67740', 'place_name': 'Hoxie', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sheridan', 'locality_code': '179', 'latitude': 39.3322, 'longitude': -100.4758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67757', 'place_name': 'Selden', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sheridan', 'locality_code': '179', 'latitude': 39.5216, 'longitude': -100.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67733', 'place_name': 'Edson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sherman', 'locality_code': '181', 'latitude': 39.3579, 'longitude': -101.521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67735', 'place_name': 'Goodland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sherman', 'locality_code': '181', 'latitude': 39.3491, 'longitude': -101.7164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67741', 'place_name': 'Kanorado', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sherman', 'locality_code': '181', 'latitude': 39.3438, 'longitude': -102.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66932', 'place_name': 'Athol', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Smith', 'locality_code': '183', 'latitude': 39.7719, 'longitude': -98.9077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66951', 'place_name': 'Kensington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Smith', 'locality_code': '183', 'latitude': 39.7692, 'longitude': -99.0308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66952', 'place_name': 'Lebanon', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Smith', 'locality_code': '183', 'latitude': 39.8077, 'longitude': -98.556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66967', 'place_name': 'Smith Center', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Smith', 'locality_code': '183', 'latitude': 39.8042, 'longitude': -98.7842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67628', 'place_name': 'Cedar', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Smith', 'locality_code': '183', 'latitude': 39.6602, 'longitude': -98.9369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67638', 'place_name': 'Gaylord', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Smith', 'locality_code': '183', 'latitude': 39.6439, 'longitude': -98.8476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67545', 'place_name': 'Hudson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stafford', 'locality_code': '185', 'latitude': 38.1485, 'longitude': -98.6408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67557', 'place_name': 'Macksville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stafford', 'locality_code': '185', 'latitude': 37.9433, 'longitude': -98.9481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67576', 'place_name': 'St John', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stafford', 'locality_code': '185', 'latitude': 38.0022, 'longitude': -98.7601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67578', 'place_name': 'Stafford', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stafford', 'locality_code': '185', 'latitude': 37.9554, 'longitude': -98.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67855', 'place_name': 'Johnson', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stanton', 'locality_code': '187', 'latitude': 37.5694, 'longitude': -101.7194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67862', 'place_name': 'Manter', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stanton', 'locality_code': '187', 'latitude': 37.5451, 'longitude': -101.9109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67951', 'place_name': 'Hugoton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stevens', 'locality_code': '189', 'latitude': 37.1682, 'longitude': -101.3346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67952', 'place_name': 'Moscow', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Stevens', 'locality_code': '189', 'latitude': 37.3172, 'longitude': -101.2427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67004', 'place_name': 'Argonia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.284, 'longitude': -97.7557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67013', 'place_name': 'Belle Plaine', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.4052, 'longitude': -97.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67022', 'place_name': 'Caldwell', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.0452, 'longitude': -97.6247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67031', 'place_name': 'Conway Springs', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.3903, 'longitude': -97.6284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67051', 'place_name': 'Geuda Springs', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.0809, 'longitude': -97.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67103', 'place_name': 'Mayfield', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.2518, 'longitude': -97.5416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67105', 'place_name': 'Milan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.2578, 'longitude': -97.6521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67106', 'place_name': 'Milton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.4401, 'longitude': -97.7592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67110', 'place_name': 'Mulvane', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.4764, 'longitude': -97.232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67119', 'place_name': 'Oxford', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.2653, 'longitude': -97.1761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67140', 'place_name': 'South Haven', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.05, 'longitude': -97.4042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67152', 'place_name': 'Wellington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Sumner', 'locality_code': '191', 'latitude': 37.2778, 'longitude': -97.391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67701', 'place_name': 'Colby', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Thomas', 'locality_code': '193', 'latitude': 39.383, 'longitude': -101.0442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67732', 'place_name': 'Brewster', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Thomas', 'locality_code': '193', 'latitude': 39.3655, 'longitude': -101.373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67734', 'place_name': 'Gem', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Thomas', 'locality_code': '193', 'latitude': 39.4296, 'longitude': -100.8948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67743', 'place_name': 'Levant', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Thomas', 'locality_code': '193', 'latitude': 39.3841, 'longitude': -101.2096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67753', 'place_name': 'Rexford', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Thomas', 'locality_code': '193', 'latitude': 39.4267, 'longitude': -100.7461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67631', 'place_name': 'Collyer', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Trego', 'locality_code': '195', 'latitude': 39.0038, 'longitude': -100.0862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67656', 'place_name': 'Ogallah', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Trego', 'locality_code': '195', 'latitude': 38.9914, 'longitude': -99.7323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67672', 'place_name': 'Wakeeney', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Trego', 'locality_code': '195', 'latitude': 39.025, 'longitude': -99.8796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66401', 'place_name': 'Alma', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wabaunsee', 'locality_code': '197', 'latitude': 39.0092, 'longitude': -96.2923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66423', 'place_name': 'Eskridge', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wabaunsee', 'locality_code': '197', 'latitude': 38.8514, 'longitude': -96.1016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66431', 'place_name': 'Harveyville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wabaunsee', 'locality_code': '197', 'latitude': 38.79, 'longitude': -95.9617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66501', 'place_name': 'Mc Farland', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wabaunsee', 'locality_code': '197', 'latitude': 39.0535, 'longitude': -96.2379, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '66507', 'place_name': 'Maple Hill', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wabaunsee', 'locality_code': '197', 'latitude': 39.0447, 'longitude': -96.0397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66526', 'place_name': 'Paxico', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wabaunsee', 'locality_code': '197', 'latitude': 39.0803, 'longitude': -96.1818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66834', 'place_name': 'Alta Vista', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wabaunsee', 'locality_code': '197', 'latitude': 38.8636, 'longitude': -96.48, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67758', 'place_name': 'Sharon Springs', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wallace', 'locality_code': '199', 'latitude': 38.8857, 'longitude': -101.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67761', 'place_name': 'Wallace', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wallace', 'locality_code': '199', 'latitude': 38.8747, 'longitude': -101.5735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67762', 'place_name': 'Weskan', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wallace', 'locality_code': '199', 'latitude': 38.8649, 'longitude': -101.9512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66933', 'place_name': 'Barnes', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.6841, 'longitude': -96.8676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66937', 'place_name': 'Clifton', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.6201, 'longitude': -97.2611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66943', 'place_name': 'Greenleaf', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.7061, 'longitude': -96.9775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66944', 'place_name': 'Haddam', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.852, 'longitude': -97.3081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66945', 'place_name': 'Hanover', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.8927, 'longitude': -96.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66946', 'place_name': 'Hollenberg', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.96, 'longitude': -96.9735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66953', 'place_name': 'Linn', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.6847, 'longitude': -97.0854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66955', 'place_name': 'Mahaska', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.9845, 'longitude': -97.3453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66958', 'place_name': 'Morrowville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.8616, 'longitude': -97.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66962', 'place_name': 'Palmer', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.6192, 'longitude': -97.1122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66968', 'place_name': 'Washington', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Washington', 'locality_code': '201', 'latitude': 39.8223, 'longitude': -97.0484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67861', 'place_name': 'Leoti', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wichita', 'locality_code': '203', 'latitude': 38.4987, 'longitude': -101.3589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '67863', 'place_name': 'Marienthal', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wichita', 'locality_code': '203', 'latitude': 38.4875, 'longitude': -101.2129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66710', 'place_name': 'Altoona', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wilson', 'locality_code': '205', 'latitude': 37.5197, 'longitude': -95.6483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66714', 'place_name': 'Benedict', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wilson', 'locality_code': '205', 'latitude': 37.6118, 'longitude': -95.7038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66717', 'place_name': 'Buffalo', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wilson', 'locality_code': '205', 'latitude': 37.7011, 'longitude': -95.7014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66736', 'place_name': 'Fredonia', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wilson', 'locality_code': '205', 'latitude': 37.5717, 'longitude': -95.7484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66757', 'place_name': 'Neodesha', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wilson', 'locality_code': '205', 'latitude': 37.4257, 'longitude': -95.6765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66759', 'place_name': 'New Albany', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wilson', 'locality_code': '205', 'latitude': 37.569, 'longitude': -95.9379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66758', 'place_name': 'Neosho Falls', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Woodson', 'locality_code': '207', 'latitude': 37.9669, 'longitude': -95.5497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66761', 'place_name': 'Piqua', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Woodson', 'locality_code': '207', 'latitude': 37.9228, 'longitude': -95.5353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66777', 'place_name': 'Toronto', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Woodson', 'locality_code': '207', 'latitude': 37.7953, 'longitude': -95.9368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66783', 'place_name': 'Yates Center', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Woodson', 'locality_code': '207', 'latitude': 37.8801, 'longitude': -95.7289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66012', 'place_name': 'Bonner Springs', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0672, 'longitude': -94.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66101', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.1157, 'longitude': -94.6271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66102', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.1132, 'longitude': -94.6693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66103', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0668, 'longitude': -94.6282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66104', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.1375, 'longitude': -94.6792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66105', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.085, 'longitude': -94.6356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66106', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0694, 'longitude': -94.7178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66109', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.1434, 'longitude': -94.7856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66110', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0966, 'longitude': -94.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66111', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0803, 'longitude': -94.7806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66112', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.116, 'longitude': -94.764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66113', 'place_name': 'Edwardsville', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0735, 'longitude': -94.7233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66115', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.1364, 'longitude': -94.616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66117', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.1142, 'longitude': -94.6275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66118', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.1011, 'longitude': -94.6144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66119', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0966, 'longitude': -94.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '66160', 'place_name': 'Kansas City', 'state': 'Kansas', 'state_ab': 'KS', 'county': 'Wyandotte', 'locality_code': '209', 'latitude': 39.0966, 'longitude': -94.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42715', 'place_name': 'Breeding', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Adair', 'locality_code': '1', 'latitude': 36.9553, 'longitude': -85.4036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42720', 'place_name': 'Cane Valley', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Adair', 'locality_code': '1', 'latitude': 37.1803, 'longitude': -85.3197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42728', 'place_name': 'Columbia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Adair', 'locality_code': '1', 'latitude': 37.1161, 'longitude': -85.2656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42741', 'place_name': 'Glens Fork', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Adair', 'locality_code': '1', 'latitude': 37.007, 'longitude': -85.2487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42742', 'place_name': 'Gradyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Adair', 'locality_code': '1', 'latitude': 37.0912, 'longitude': -85.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42753', 'place_name': 'Knifley', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Adair', 'locality_code': '1', 'latitude': 37.2313, 'longitude': -85.172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42120', 'place_name': 'Adolphus', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Allen', 'locality_code': '3', 'latitude': 36.6775, 'longitude': -86.2636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42153', 'place_name': 'Holland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Allen', 'locality_code': '3', 'latitude': 36.6673, 'longitude': -86.0498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42164', 'place_name': 'Scottsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Allen', 'locality_code': '3', 'latitude': 36.7614, 'longitude': -86.1929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40342', 'place_name': 'Lawrenceburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Anderson', 'locality_code': '5', 'latitude': 38.0189, 'longitude': -84.9299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42022', 'place_name': 'Bandana', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ballard', 'locality_code': '7', 'latitude': 37.1459, 'longitude': -88.9455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42024', 'place_name': 'Barlow', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ballard', 'locality_code': '7', 'latitude': 37.0493, 'longitude': -89.0408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42056', 'place_name': 'La Center', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ballard', 'locality_code': '7', 'latitude': 37.083, 'longitude': -88.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42060', 'place_name': 'Lovelaceville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ballard', 'locality_code': '7', 'latitude': 36.9687, 'longitude': -88.8309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42087', 'place_name': 'Wickliffe', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ballard', 'locality_code': '7', 'latitude': 36.968, 'longitude': -89.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42123', 'place_name': 'Austin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 36.8124, 'longitude': -85.985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42127', 'place_name': 'Cave City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 37.117, 'longitude': -85.9443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42130', 'place_name': 'Eighty Eight', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 36.913, 'longitude': -85.7753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42131', 'place_name': 'Etoile', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 36.8134, 'longitude': -85.9173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42141', 'place_name': 'Glasgow', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 36.9882, 'longitude': -85.9221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42142', 'place_name': 'Glasgow', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 36.9959, 'longitude': -85.9119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42152', 'place_name': 'Hiseville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 37.0988, 'longitude': -85.8165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42156', 'place_name': 'Lucas', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 36.8516, 'longitude': -86.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42160', 'place_name': 'Park City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Barren', 'locality_code': '9', 'latitude': 37.0939, 'longitude': -86.0464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40358', 'place_name': 'Olympia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bath', 'locality_code': '11', 'latitude': 38.0849, 'longitude': -83.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40360', 'place_name': 'Owingsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bath', 'locality_code': '11', 'latitude': 38.1532, 'longitude': -83.7564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40366', 'place_name': 'Preston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bath', 'locality_code': '11', 'latitude': 38.0867, 'longitude': -83.7571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40371', 'place_name': 'Salt Lick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bath', 'locality_code': '11', 'latitude': 38.104, 'longitude': -83.6316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40374', 'place_name': 'Sharpsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bath', 'locality_code': '11', 'latitude': 38.2147, 'longitude': -83.8932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40813', 'place_name': 'Calvin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.7223, 'longitude': -83.6221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40845', 'place_name': 'Hulen', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.7714, 'longitude': -83.5551, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40856', 'place_name': 'Miracle', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.7606, 'longitude': -83.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40902', 'place_name': 'Arjay', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.8283, 'longitude': -83.6415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40913', 'place_name': 'Beverly', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.9442, 'longitude': -83.556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40940', 'place_name': 'Frakes', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.607, 'longitude': -83.9484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40955', 'place_name': 'Ingram', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.7692, 'longitude': -83.7082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40958', 'place_name': 'Kettle Island', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.8093, 'longitude': -83.5892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40965', 'place_name': 'Middlesboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.6172, 'longitude': -83.7231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40977', 'place_name': 'Pineville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.7159, 'longitude': -83.7668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40988', 'place_name': 'Stoney Fork', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bell', 'locality_code': '13', 'latitude': 36.8323, 'longitude': -83.5346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41005', 'place_name': 'Burlington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 39.015, 'longitude': -84.7736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41021', 'place_name': 'Hebron', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 39.029, 'longitude': -84.6195, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41022', 'place_name': 'Florence', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 38.9624, 'longitude': -84.7478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41042', 'place_name': 'Florence', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 38.9941, 'longitude': -84.642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41048', 'place_name': 'Hebron', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 39.0755, 'longitude': -84.7007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41080', 'place_name': 'Petersburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 39.0416, 'longitude': -84.8371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41091', 'place_name': 'Union', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 38.9435, 'longitude': -84.7274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41092', 'place_name': 'Verona', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 38.839, 'longitude': -84.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41094', 'place_name': 'Walton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boone', 'locality_code': '15', 'latitude': 38.8875, 'longitude': -84.6328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40348', 'place_name': 'Millersburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bourbon', 'locality_code': '17', 'latitude': 38.2963, 'longitude': -84.1513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40357', 'place_name': 'North Middletown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bourbon', 'locality_code': '17', 'latitude': 38.1464, 'longitude': -84.1077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40361', 'place_name': 'Paris', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bourbon', 'locality_code': '17', 'latitude': 38.2083, 'longitude': -84.245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40362', 'place_name': 'Paris', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bourbon', 'locality_code': '17', 'latitude': 38.2098, 'longitude': -84.253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41101', 'place_name': 'Ashland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyd', 'locality_code': '19', 'latitude': 38.4722, 'longitude': -82.6461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41102', 'place_name': 'Ashland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyd', 'locality_code': '19', 'latitude': 38.4218, 'longitude': -82.7173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41105', 'place_name': 'Ashland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyd', 'locality_code': '19', 'latitude': 38.3703, 'longitude': -82.6948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41114', 'place_name': 'Ashland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyd', 'locality_code': '19', 'latitude': 38.3703, 'longitude': -82.6948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41129', 'place_name': 'Catlettsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyd', 'locality_code': '19', 'latitude': 38.3799, 'longitude': -82.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41168', 'place_name': 'Rush', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyd', 'locality_code': '19', 'latitude': 38.3089, 'longitude': -82.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40422', 'place_name': 'Danville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyle', 'locality_code': '21', 'latitude': 37.6465, 'longitude': -84.7747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40423', 'place_name': 'Danville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyle', 'locality_code': '21', 'latitude': 37.6456, 'longitude': -84.7722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40440', 'place_name': 'Junction City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyle', 'locality_code': '21', 'latitude': 37.5822, 'longitude': -84.8028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40452', 'place_name': 'Mitchellsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyle', 'locality_code': '21', 'latitude': 37.6033, 'longitude': -84.9492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40464', 'place_name': 'Parksville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyle', 'locality_code': '21', 'latitude': 37.5778, 'longitude': -84.9281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40468', 'place_name': 'Perryville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Boyle', 'locality_code': '21', 'latitude': 37.6375, 'longitude': -84.9665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41002', 'place_name': 'Augusta', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bracken', 'locality_code': '23', 'latitude': 38.763, 'longitude': -83.9954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41004', 'place_name': 'Brooksville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bracken', 'locality_code': '23', 'latitude': 38.6644, 'longitude': -84.0786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41043', 'place_name': 'Foster', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bracken', 'locality_code': '23', 'latitude': 38.7506, 'longitude': -84.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41044', 'place_name': 'Germantown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bracken', 'locality_code': '23', 'latitude': 38.6357, 'longitude': -83.99, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41061', 'place_name': 'Milford', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bracken', 'locality_code': '23', 'latitude': 38.5817, 'longitude': -84.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41310', 'place_name': 'Bays', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breathitt', 'locality_code': '25', 'latitude': 37.6405, 'longitude': -83.2441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41317', 'place_name': 'Clayhole', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breathitt', 'locality_code': '25', 'latitude': 37.4476, 'longitude': -83.1892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41339', 'place_name': 'Jackson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breathitt', 'locality_code': '25', 'latitude': 37.4868, 'longitude': -83.2913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41348', 'place_name': 'Lost Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breathitt', 'locality_code': '25', 'latitude': 37.4418, 'longitude': -83.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41366', 'place_name': 'Rousseau', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breathitt', 'locality_code': '25', 'latitude': 37.5946, 'longitude': -83.2187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41385', 'place_name': 'Vancleve', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breathitt', 'locality_code': '25', 'latitude': 37.6477, 'longitude': -83.3806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41390', 'place_name': 'Whick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breathitt', 'locality_code': '25', 'latitude': 37.4102, 'longitude': -83.3747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40111', 'place_name': 'Cloverport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.7731, 'longitude': -86.6282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40115', 'place_name': 'Custer', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.7358, 'longitude': -86.2378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40140', 'place_name': 'Garfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.7828, 'longitude': -86.3575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40143', 'place_name': 'Hardinsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.7512, 'longitude': -86.4537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40144', 'place_name': 'Harned', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.8023, 'longitude': -86.4148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40145', 'place_name': 'Hudson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.6506, 'longitude': -86.3012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40146', 'place_name': 'Irvington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.8762, 'longitude': -86.2965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40152', 'place_name': 'Mc Daniels', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.6194, 'longitude': -86.4491, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40153', 'place_name': 'Mc Quady', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.8023, 'longitude': -86.4148, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40170', 'place_name': 'Stephensport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.9048, 'longitude': -86.524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40171', 'place_name': 'Union Star', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.9616, 'longitude': -86.4615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40176', 'place_name': 'Webster', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.9237, 'longitude': -86.3441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40178', 'place_name': 'Westview', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Breckinridge', 'locality_code': '27', 'latitude': 37.6792, 'longitude': -86.4273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40047', 'place_name': 'Mount Washington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bullitt', 'locality_code': '29', 'latitude': 38.0452, 'longitude': -85.5586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40109', 'place_name': 'Brooks', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bullitt', 'locality_code': '29', 'latitude': 38.0546, 'longitude': -85.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40110', 'place_name': 'Clermont', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bullitt', 'locality_code': '29', 'latitude': 37.9346, 'longitude': -85.6555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40129', 'place_name': 'Hillview', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bullitt', 'locality_code': '29', 'latitude': 38.0764, 'longitude': -85.6774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40150', 'place_name': 'Lebanon Junction', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bullitt', 'locality_code': '29', 'latitude': 37.8511, 'longitude': -85.7246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40165', 'place_name': 'Shepherdsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bullitt', 'locality_code': '29', 'latitude': 38.0045, 'longitude': -85.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40166', 'place_name': 'Shepherdsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Bullitt', 'locality_code': '29', 'latitude': 37.9885, 'longitude': -85.7159, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '42201', 'place_name': 'Aberdeen', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Butler', 'locality_code': '31', 'latitude': 37.2539, 'longitude': -86.6817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42219', 'place_name': 'Dunbar', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Butler', 'locality_code': '31', 'latitude': 37.1709, 'longitude': -86.7678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42252', 'place_name': 'Jetson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Butler', 'locality_code': '31', 'latitude': 37.2483, 'longitude': -86.5093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42261', 'place_name': 'Morgantown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Butler', 'locality_code': '31', 'latitude': 37.2002, 'longitude': -86.6859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42273', 'place_name': 'Rochester', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Butler', 'locality_code': '31', 'latitude': 37.2048, 'longitude': -86.8592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42288', 'place_name': 'Woodbury', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Butler', 'locality_code': '31', 'latitude': 37.1834, 'longitude': -86.6339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42411', 'place_name': 'Fredonia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Caldwell', 'locality_code': '33', 'latitude': 37.213, 'longitude': -88.0112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42445', 'place_name': 'Princeton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Caldwell', 'locality_code': '33', 'latitude': 37.1151, 'longitude': -87.8632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42020', 'place_name': 'Almo', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Calloway', 'locality_code': '35', 'latitude': 36.6923, 'longitude': -88.2929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42036', 'place_name': 'Dexter', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Calloway', 'locality_code': '35', 'latitude': 36.7155, 'longitude': -88.236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42049', 'place_name': 'Hazel', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Calloway', 'locality_code': '35', 'latitude': 36.5422, 'longitude': -88.3319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42054', 'place_name': 'Kirksey', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Calloway', 'locality_code': '35', 'latitude': 36.6731, 'longitude': -88.4238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42071', 'place_name': 'Murray', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Calloway', 'locality_code': '35', 'latitude': 36.6099, 'longitude': -88.3032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42076', 'place_name': 'New Concord', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Calloway', 'locality_code': '35', 'latitude': 36.55, 'longitude': -88.0955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41001', 'place_name': 'Alexandria', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 38.9406, 'longitude': -84.3943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41007', 'place_name': 'California', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 38.9056, 'longitude': -84.3171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41059', 'place_name': 'Melbourne', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 39.0067, 'longitude': -84.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41071', 'place_name': 'Newport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 39.0563, 'longitude': -84.4787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41072', 'place_name': 'Newport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 38.9638, 'longitude': -84.3689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41073', 'place_name': 'Bellevue', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 39.1024, 'longitude': -84.4787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41074', 'place_name': 'Dayton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 39.1114, 'longitude': -84.4712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41075', 'place_name': 'Fort Thomas', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 39.0786, 'longitude': -84.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41076', 'place_name': 'Newport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 39.0262, 'longitude': -84.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41085', 'place_name': 'Silver Grove', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 39.0343, 'longitude': -84.3908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41099', 'place_name': 'Newport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Campbell', 'locality_code': '37', 'latitude': 38.9638, 'longitude': -84.3689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42021', 'place_name': 'Arlington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carlisle', 'locality_code': '39', 'latitude': 36.7903, 'longitude': -89.0128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42023', 'place_name': 'Bardwell', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carlisle', 'locality_code': '39', 'latitude': 36.8634, 'longitude': -89.0209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42035', 'place_name': 'Cunningham', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carlisle', 'locality_code': '39', 'latitude': 36.8963, 'longitude': -88.8728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42070', 'place_name': 'Milburn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carlisle', 'locality_code': '39', 'latitude': 36.7987, 'longitude': -88.8998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41008', 'place_name': 'Carrollton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carroll', 'locality_code': '41', 'latitude': 38.6696, 'longitude': -85.173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41045', 'place_name': 'Ghent', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carroll', 'locality_code': '41', 'latitude': 38.7188, 'longitude': -85.0557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41083', 'place_name': 'Sanders', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carroll', 'locality_code': '41', 'latitude': 38.661, 'longitude': -84.9732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41098', 'place_name': 'Worthville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carroll', 'locality_code': '41', 'latitude': 38.6179, 'longitude': -85.0663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41128', 'place_name': 'Carter', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.4339, 'longitude': -83.1336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41132', 'place_name': 'Denton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.2597, 'longitude': -82.8562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41142', 'place_name': 'Grahn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.2897, 'longitude': -83.0811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41143', 'place_name': 'Grayson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.3326, 'longitude': -82.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41146', 'place_name': 'Hitchins', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.2766, 'longitude': -82.8982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41164', 'place_name': 'Olive Hill', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.3001, 'longitude': -83.1741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41173', 'place_name': 'Soldier', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.262, 'longitude': -83.2847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41181', 'place_name': 'Willard', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Carter', 'locality_code': '43', 'latitude': 38.2045, 'longitude': -82.9076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42516', 'place_name': 'Bethelridge', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Casey', 'locality_code': '45', 'latitude': 37.2337, 'longitude': -84.7583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42528', 'place_name': 'Dunnville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Casey', 'locality_code': '45', 'latitude': 37.1906, 'longitude': -84.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42539', 'place_name': 'Liberty', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Casey', 'locality_code': '45', 'latitude': 37.3146, 'longitude': -84.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42541', 'place_name': 'Middleburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Casey', 'locality_code': '45', 'latitude': 37.3591, 'longitude': -84.8321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42565', 'place_name': 'Windsor', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Casey', 'locality_code': '45', 'latitude': 37.1568, 'longitude': -84.8799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42566', 'place_name': 'Yosemite', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Casey', 'locality_code': '45', 'latitude': 37.3074, 'longitude': -84.8124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42217', 'place_name': 'Crofton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 37.0344, 'longitude': -87.4891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42221', 'place_name': 'Fairview', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.8434, 'longitude': -87.3039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42223', 'place_name': 'Fort Campbell', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.6543, 'longitude': -87.4606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42232', 'place_name': 'Gracey', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.8564, 'longitude': -87.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42236', 'place_name': 'Herndon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.7085, 'longitude': -87.6082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42240', 'place_name': 'Hopkinsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.8621, 'longitude': -87.4851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42241', 'place_name': 'Hopkinsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.8656, 'longitude': -87.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42254', 'place_name': 'La Fayette', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.6582, 'longitude': -87.6563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42262', 'place_name': 'Oak Grove', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.6652, 'longitude': -87.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42266', 'place_name': 'Pembroke', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Christian', 'locality_code': '47', 'latitude': 36.7759, 'longitude': -87.3556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40391', 'place_name': 'Winchester', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clark', 'locality_code': '49', 'latitude': 37.9872, 'longitude': -84.1789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40392', 'place_name': 'Winchester', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clark', 'locality_code': '49', 'latitude': 37.9901, 'longitude': -84.1797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40914', 'place_name': 'Big Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.1623, 'longitude': -83.5688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40932', 'place_name': 'Fall Rock', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.2198, 'longitude': -83.7883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40941', 'place_name': 'Garrard', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.1237, 'longitude': -83.7463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40944', 'place_name': 'Goose Rock', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.0904, 'longitude': -83.6944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40951', 'place_name': 'Hima', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.1206, 'longitude': -83.7783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40962', 'place_name': 'Manchester', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.1511, 'longitude': -83.7793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40972', 'place_name': 'Oneida', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.2695, 'longitude': -83.6491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40983', 'place_name': 'Sextons Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clay', 'locality_code': '51', 'latitude': 37.333, 'longitude': -83.7666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42602', 'place_name': 'Albany', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clinton', 'locality_code': '53', 'latitude': 36.6857, 'longitude': -85.1407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42603', 'place_name': 'Alpha', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Clinton', 'locality_code': '53', 'latitude': 36.7824, 'longitude': -85.0275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42033', 'place_name': 'Crayne', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Crittenden', 'locality_code': '55', 'latitude': 37.2706, 'longitude': -88.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42037', 'place_name': 'Dycusburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Crittenden', 'locality_code': '55', 'latitude': 37.1595, 'longitude': -88.1845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42064', 'place_name': 'Marion', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Crittenden', 'locality_code': '55', 'latitude': 37.3254, 'longitude': -88.1005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42717', 'place_name': 'Burkesville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Cumberland', 'locality_code': '57', 'latitude': 36.8068, 'longitude': -85.397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42759', 'place_name': 'Marrowbone', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Cumberland', 'locality_code': '57', 'latitude': 36.8306, 'longitude': -85.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42301', 'place_name': 'Owensboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.7513, 'longitude': -87.1554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42302', 'place_name': 'Owensboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.7455, 'longitude': -87.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42303', 'place_name': 'Owensboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.7559, 'longitude': -87.0803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42304', 'place_name': 'Owensboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.7455, 'longitude': -87.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42334', 'place_name': 'Curdsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.735, 'longitude': -87.3317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42355', 'place_name': 'Maceo', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.8436, 'longitude': -86.9999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42356', 'place_name': 'Maple Mount', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.6932, 'longitude': -87.3238, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '42366', 'place_name': 'Philpot', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.7183, 'longitude': -86.9372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42376', 'place_name': 'Utica', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.6206, 'longitude': -87.0591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42377', 'place_name': 'West Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.6967, 'longitude': -87.2869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42378', 'place_name': 'Whitesville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Daviess', 'locality_code': '59', 'latitude': 37.6834, 'longitude': -86.8699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42163', 'place_name': 'Rocky Hill', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Edmonson', 'locality_code': '61', 'latitude': 37.0689, 'longitude': -86.1364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42207', 'place_name': 'Bee Spring', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Edmonson', 'locality_code': '61', 'latitude': 37.2975, 'longitude': -86.2794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42210', 'place_name': 'Brownsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Edmonson', 'locality_code': '61', 'latitude': 37.2229, 'longitude': -86.2923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42259', 'place_name': 'Mammoth Cave', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Edmonson', 'locality_code': '61', 'latitude': 37.2802, 'longitude': -86.1688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42275', 'place_name': 'Roundhill', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Edmonson', 'locality_code': '61', 'latitude': 37.256, 'longitude': -86.407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42285', 'place_name': 'Sweeden', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Edmonson', 'locality_code': '61', 'latitude': 37.2641, 'longitude': -86.2978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41149', 'place_name': 'Isonville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Elliott', 'locality_code': '63', 'latitude': 38.0462, 'longitude': -83.0506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41171', 'place_name': 'Sandy Hook', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Elliott', 'locality_code': '63', 'latitude': 38.1316, 'longitude': -83.0797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40336', 'place_name': 'Irvine', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Estill', 'locality_code': '65', 'latitude': 37.6858, 'longitude': -83.9862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40472', 'place_name': 'Ravenna', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Estill', 'locality_code': '65', 'latitude': 37.6867, 'longitude': -83.9387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40502', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0174, 'longitude': -84.4854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40503', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.001, 'longitude': -84.5282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40504', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0406, 'longitude': -84.5433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40505', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0612, 'longitude': -84.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40506', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0287, 'longitude': -84.5075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40507', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0464, 'longitude': -84.4953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40508', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0513, 'longitude': -84.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40509', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0102, 'longitude': -84.4274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40510', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0702, 'longitude': -84.591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40511', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0932, 'longitude': -84.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40512', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40513', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0139, 'longitude': -84.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40514', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 37.9833, 'longitude': -84.5767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40515', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 37.9651, 'longitude': -84.4708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40516', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0544, 'longitude': -84.3548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40517', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 37.9849, 'longitude': -84.4816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40522', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40523', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40524', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40526', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40533', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40536', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0321, 'longitude': -84.5084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40544', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40546', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40550', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40555', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40574', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40575', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40576', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40577', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40578', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40579', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40580', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40581', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40582', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40583', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40588', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40591', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0283, 'longitude': -84.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40598', 'place_name': 'Lexington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fayette', 'locality_code': '67', 'latitude': 38.0771, 'longitude': -84.5296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41037', 'place_name': 'Elizaville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fleming', 'locality_code': '69', 'latitude': 38.4195, 'longitude': -83.8255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41039', 'place_name': 'Ewing', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fleming', 'locality_code': '69', 'latitude': 38.4157, 'longitude': -83.8733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41041', 'place_name': 'Flemingsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fleming', 'locality_code': '69', 'latitude': 38.428, 'longitude': -83.708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41049', 'place_name': 'Hillsboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fleming', 'locality_code': '69', 'latitude': 38.2929, 'longitude': -83.6697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41065', 'place_name': 'Muses Mills', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fleming', 'locality_code': '69', 'latitude': 38.3501, 'longitude': -83.5271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41081', 'place_name': 'Plummers Landing', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fleming', 'locality_code': '69', 'latitude': 38.3481, 'longitude': -83.7186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41093', 'place_name': 'Wallingford', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fleming', 'locality_code': '69', 'latitude': 38.3374, 'longitude': -83.5625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41601', 'place_name': 'Allen', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.6074, 'longitude': -82.7225, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41602', 'place_name': 'Auxier', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.737, 'longitude': -82.7582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41603', 'place_name': 'Banner', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5707, 'longitude': -82.6806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41604', 'place_name': 'Beaver', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.3774, 'longitude': -82.6869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41605', 'place_name': 'Betsy Layne', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5555, 'longitude': -82.6267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41606', 'place_name': 'Bevinsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.3465, 'longitude': -82.7403, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41607', 'place_name': 'Blue River', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.6253, 'longitude': -82.8418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41612', 'place_name': 'Bypro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.3465, 'longitude': -82.7165, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41615', 'place_name': 'Dana', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5467, 'longitude': -82.6705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41616', 'place_name': 'David', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5767, 'longitude': -82.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41619', 'place_name': 'Drift', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.4933, 'longitude': -82.7575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41621', 'place_name': 'Dwale', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.6246, 'longitude': -82.7227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41622', 'place_name': 'Eastern', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.517, 'longitude': -82.806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41630', 'place_name': 'Garrett', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.4798, 'longitude': -82.8316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41631', 'place_name': 'Grethel', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.4576, 'longitude': -82.6645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41635', 'place_name': 'Harold', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5368, 'longitude': -82.6332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41636', 'place_name': 'Hi Hat', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.3994, 'longitude': -82.7292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41640', 'place_name': 'Hueysville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5087, 'longitude': -82.8518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41642', 'place_name': 'Ivel', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5956, 'longitude': -82.6463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41643', 'place_name': 'Lackey', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.471, 'longitude': -82.8294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41645', 'place_name': 'Langley', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5381, 'longitude': -82.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41647', 'place_name': 'Mc Dowell', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.4355, 'longitude': -82.7203, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41649', 'place_name': 'Martin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5708, 'longitude': -82.7819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41650', 'place_name': 'Melvin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.3536, 'longitude': -82.6763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41651', 'place_name': 'Minnie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.4548, 'longitude': -82.7646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41653', 'place_name': 'Prestonsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.661, 'longitude': -82.7636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41655', 'place_name': 'Printer', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5055, 'longitude': -82.706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41659', 'place_name': 'Stanville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5741, 'longitude': -82.6271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41660', 'place_name': 'Teaberry', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.422, 'longitude': -82.6405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41663', 'place_name': 'Tram', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.5725, 'longitude': -82.6452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41666', 'place_name': 'Wayland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.4367, 'longitude': -82.801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41667', 'place_name': 'Weeksbury', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.317, 'longitude': -82.7041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41669', 'place_name': 'Wheelwright', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Floyd', 'locality_code': '71', 'latitude': 37.3314, 'longitude': -82.7156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40601', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2281, 'longitude': -84.8697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40602', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2341, 'longitude': -84.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40603', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2341, 'longitude': -84.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40604', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2341, 'longitude': -84.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40618', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2341, 'longitude': -84.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40619', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2341, 'longitude': -84.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40620', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2341, 'longitude': -84.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40621', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2009, 'longitude': -84.8733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40622', 'place_name': 'Frankfort', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Franklin', 'locality_code': '73', 'latitude': 38.2009, 'longitude': -84.8733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42041', 'place_name': 'Fulton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fulton', 'locality_code': '75', 'latitude': 36.5475, 'longitude': -88.8749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42050', 'place_name': 'Hickman', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Fulton', 'locality_code': '75', 'latitude': 36.5593, 'longitude': -89.1947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41046', 'place_name': 'Glencoe', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Gallatin', 'locality_code': '77', 'latitude': 38.7229, 'longitude': -84.8116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41086', 'place_name': 'Sparta', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Gallatin', 'locality_code': '77', 'latitude': 38.7256, 'longitude': -84.8813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41095', 'place_name': 'Warsaw', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Gallatin', 'locality_code': '77', 'latitude': 38.7807, 'longitude': -84.8496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40410', 'place_name': 'Bryantsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Garrard', 'locality_code': '79', 'latitude': 37.7145, 'longitude': -84.6491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40444', 'place_name': 'Lancaster', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Garrard', 'locality_code': '79', 'latitude': 37.6584, 'longitude': -84.5969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40461', 'place_name': 'Paint Lick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Garrard', 'locality_code': '79', 'latitude': 37.6092, 'longitude': -84.4269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41010', 'place_name': 'Corinth', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grant', 'locality_code': '81', 'latitude': 38.5302, 'longitude': -84.5846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41030', 'place_name': 'Crittenden', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grant', 'locality_code': '81', 'latitude': 38.7741, 'longitude': -84.5982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41035', 'place_name': 'Dry Ridge', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grant', 'locality_code': '81', 'latitude': 38.7049, 'longitude': -84.6237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41052', 'place_name': 'Jonesville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grant', 'locality_code': '81', 'latitude': 38.6398, 'longitude': -84.7755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41054', 'place_name': 'Mason', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grant', 'locality_code': '81', 'latitude': 38.5932, 'longitude': -84.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41097', 'place_name': 'Williamstown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grant', 'locality_code': '81', 'latitude': 38.6292, 'longitude': -84.5744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42027', 'place_name': 'Boaz', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.93, 'longitude': -88.6223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42039', 'place_name': 'Fancy Farm', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.7767, 'longitude': -88.7918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42040', 'place_name': 'Farmington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.6, 'longitude': -88.5186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42051', 'place_name': 'Hickory', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.8478, 'longitude': -88.6788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42061', 'place_name': 'Lowes', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.8862, 'longitude': -88.7728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42063', 'place_name': 'Lynnville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.5603, 'longitude': -88.5692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42066', 'place_name': 'Mayfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.7327, 'longitude': -88.6506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42069', 'place_name': 'Melber', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.9197, 'longitude': -88.752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42079', 'place_name': 'Sedalia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.5748, 'longitude': -88.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42082', 'place_name': 'Symsonia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.9044, 'longitude': -88.5153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42085', 'place_name': 'Water Valley', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.5694, 'longitude': -88.8084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42088', 'place_name': 'Wingo', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Graves', 'locality_code': '83', 'latitude': 36.6253, 'longitude': -88.7394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40119', 'place_name': 'Falls Of Rough', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grayson', 'locality_code': '85', 'latitude': 37.5522, 'longitude': -86.4836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42712', 'place_name': 'Big Clifty', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grayson', 'locality_code': '85', 'latitude': 37.5278, 'longitude': -86.1395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42721', 'place_name': 'Caneyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grayson', 'locality_code': '85', 'latitude': 37.4222, 'longitude': -86.4702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42726', 'place_name': 'Clarkson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grayson', 'locality_code': '85', 'latitude': 37.4336, 'longitude': -86.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42754', 'place_name': 'Leitchfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grayson', 'locality_code': '85', 'latitude': 37.4603, 'longitude': -86.3249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42755', 'place_name': 'Leitchfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grayson', 'locality_code': '85', 'latitude': 37.4801, 'longitude': -86.2939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42762', 'place_name': 'Millwood', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Grayson', 'locality_code': '85', 'latitude': 37.4446, 'longitude': -86.4008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42743', 'place_name': 'Greensburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Green', 'locality_code': '87', 'latitude': 37.243, 'longitude': -85.5236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42782', 'place_name': 'Summersville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Green', 'locality_code': '87', 'latitude': 37.3419, 'longitude': -85.6194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41121', 'place_name': 'Argillite', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Greenup', 'locality_code': '89', 'latitude': 38.4322, 'longitude': -82.8094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41139', 'place_name': 'Flatwoods', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Greenup', 'locality_code': '89', 'latitude': 38.5188, 'longitude': -82.7212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41144', 'place_name': 'Greenup', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Greenup', 'locality_code': '89', 'latitude': 38.5368, 'longitude': -82.9191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41169', 'place_name': 'Russell', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Greenup', 'locality_code': '89', 'latitude': 38.5173, 'longitude': -82.6977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41174', 'place_name': 'South Portsmouth', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Greenup', 'locality_code': '89', 'latitude': 38.7087, 'longitude': -83.0162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41175', 'place_name': 'South Shore', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Greenup', 'locality_code': '89', 'latitude': 38.7148, 'longitude': -82.9366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41183', 'place_name': 'Worthington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Greenup', 'locality_code': '89', 'latitude': 38.5511, 'longitude': -82.7396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42348', 'place_name': 'Hawesville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hancock', 'locality_code': '91', 'latitude': 37.8503, 'longitude': -86.7638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42351', 'place_name': 'Lewisport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hancock', 'locality_code': '91', 'latitude': 37.909, 'longitude': -86.8957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42364', 'place_name': 'Pellville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hancock', 'locality_code': '91', 'latitude': 37.7523, 'longitude': -86.8136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42368', 'place_name': 'Reynolds Station', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hancock', 'locality_code': '91', 'latitude': 37.7403, 'longitude': -86.7414, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40121', 'place_name': 'Fort Knox', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.8928, 'longitude': -85.9489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40122', 'place_name': 'Fort Knox', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.8911, 'longitude': -85.9636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40159', 'place_name': 'Radcliff', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.7235, 'longitude': -85.9769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40160', 'place_name': 'Radcliff', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.8267, 'longitude': -85.9404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40162', 'place_name': 'Rineyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.7525, 'longitude': -85.9954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40175', 'place_name': 'Vine Grove', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.8589, 'longitude': -86.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40177', 'place_name': 'West Point', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.9954, 'longitude': -85.9545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42701', 'place_name': 'Elizabethtown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.6848, 'longitude': -85.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42702', 'place_name': 'Elizabethtown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.694, 'longitude': -85.8591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42724', 'place_name': 'Cecilia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.669, 'longitude': -86.0545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42732', 'place_name': 'Eastview', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.6061, 'longitude': -86.0906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42740', 'place_name': 'Glendale', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.6034, 'longitude': -85.8921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42776', 'place_name': 'Sonora', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.5221, 'longitude': -85.923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42784', 'place_name': 'Upton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.4568, 'longitude': -85.9086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42788', 'place_name': 'White Mills', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hardin', 'locality_code': '93', 'latitude': 37.5438, 'longitude': -86.0395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40801', 'place_name': 'Ages Brookside', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8654, 'longitude': -83.2879, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40806', 'place_name': 'Baxter', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8749, 'longitude': -83.3141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40807', 'place_name': 'Benham', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.9648, 'longitude': -82.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40808', 'place_name': 'Big Laurel', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.9798, 'longitude': -83.2171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40810', 'place_name': 'Bledsoe', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.934, 'longitude': -83.3242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40815', 'place_name': 'Cawood', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.7812, 'longitude': -83.2914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40818', 'place_name': 'Coalgood', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8202, 'longitude': -83.2445, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40819', 'place_name': 'Coldiron', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8201, 'longitude': -83.4707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40820', 'place_name': 'Cranks', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.7558, 'longitude': -83.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40823', 'place_name': 'Cumberland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.9711, 'longitude': -82.9771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40824', 'place_name': 'Dayhoit', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8356, 'longitude': -83.3753, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40828', 'place_name': 'Evarts', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8398, 'longitude': -83.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40829', 'place_name': 'Grays Knob', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.7974, 'longitude': -83.2645, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40830', 'place_name': 'Gulston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.7656, 'longitude': -83.3262, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40831', 'place_name': 'Harlan', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.7596, 'longitude': -83.3499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40843', 'place_name': 'Holmes Mill', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8757, 'longitude': -82.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40847', 'place_name': 'Kenvir', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8537, 'longitude': -83.1571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40849', 'place_name': 'Lejunior', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8899, 'longitude': -83.1433, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40854', 'place_name': 'Loyall', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8481, 'longitude': -83.353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40855', 'place_name': 'Lynch', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.9603, 'longitude': -82.9198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40863', 'place_name': 'Pathfork', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.7521, 'longitude': -83.4629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40865', 'place_name': 'Putney', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.9039, 'longitude': -83.2381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40870', 'place_name': 'Totz', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.9448, 'longitude': -83.1177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40873', 'place_name': 'Wallins Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8165, 'longitude': -83.419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40927', 'place_name': 'Closplint', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.8713, 'longitude': -83.0414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40964', 'place_name': 'Mary Alice', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harlan', 'locality_code': '95', 'latitude': 36.7843, 'longitude': -83.3299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41003', 'place_name': 'Berry', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harrison', 'locality_code': '97', 'latitude': 38.516, 'longitude': -84.3611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41031', 'place_name': 'Cynthiana', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Harrison', 'locality_code': '97', 'latitude': 38.3964, 'longitude': -84.2949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42713', 'place_name': 'Bonnieville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hart', 'locality_code': '99', 'latitude': 37.3741, 'longitude': -85.896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42722', 'place_name': 'Canmer', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hart', 'locality_code': '99', 'latitude': 37.2696, 'longitude': -85.7203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42729', 'place_name': 'Cub Run', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hart', 'locality_code': '99', 'latitude': 37.3149, 'longitude': -86.0813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42746', 'place_name': 'Hardyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hart', 'locality_code': '99', 'latitude': 37.2249, 'longitude': -85.7542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42749', 'place_name': 'Horse Cave', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hart', 'locality_code': '99', 'latitude': 37.1849, 'longitude': -85.8785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42765', 'place_name': 'Munfordville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hart', 'locality_code': '99', 'latitude': 37.2898, 'longitude': -85.9201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42402', 'place_name': 'Baskett', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.8709, 'longitude': -87.4625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42406', 'place_name': 'Corydon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.7443, 'longitude': -87.7, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42419', 'place_name': 'Henderson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.8072, 'longitude': -87.5991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42420', 'place_name': 'Henderson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.8274, 'longitude': -87.5632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42451', 'place_name': 'Reed', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.8588, 'longitude': -87.3704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42452', 'place_name': 'Robards', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.6758, 'longitude': -87.5266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42457', 'place_name': 'Smith Mills', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.8323, 'longitude': -87.7889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42458', 'place_name': 'Spottsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henderson', 'locality_code': '101', 'latitude': 37.8399, 'longitude': -87.4247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40007', 'place_name': 'Bethlehem', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.4529, 'longitude': -85.0169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40011', 'place_name': 'Campbellsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.5231, 'longitude': -85.1611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40019', 'place_name': 'Eminence', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.3696, 'longitude': -85.1782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40036', 'place_name': 'Lockport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.4219, 'longitude': -84.9586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40050', 'place_name': 'New Castle', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.4374, 'longitude': -85.1756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40055', 'place_name': 'Pendleton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.4809, 'longitude': -85.317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40057', 'place_name': 'Pleasureville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.3598, 'longitude': -85.1072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40058', 'place_name': 'Port Royal', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.4941, 'longitude': -85.1242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40068', 'place_name': 'Smithfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.3933, 'longitude': -85.2656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40070', 'place_name': 'Sulphur', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.4921, 'longitude': -85.252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40075', 'place_name': 'Turners Station', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Henry', 'locality_code': '103', 'latitude': 38.5521, 'longitude': -85.1019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42031', 'place_name': 'Clinton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hickman', 'locality_code': '105', 'latitude': 36.6675, 'longitude': -88.9676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42032', 'place_name': 'Columbus', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hickman', 'locality_code': '105', 'latitude': 36.7598, 'longitude': -89.1034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42408', 'place_name': 'Dawson Springs', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.1964, 'longitude': -87.6821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42410', 'place_name': 'Earlington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.2742, 'longitude': -87.5119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42413', 'place_name': 'Hanson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.4382, 'longitude': -87.4751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42431', 'place_name': 'Madisonville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.3256, 'longitude': -87.4953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42436', 'place_name': 'Manitou', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.4067, 'longitude': -87.5639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42440', 'place_name': 'Mortons Gap', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.249, 'longitude': -87.4615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42441', 'place_name': 'Nebo', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.3683, 'longitude': -87.6865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42442', 'place_name': 'Nortonville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.1834, 'longitude': -87.4605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42453', 'place_name': 'Saint Charles', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.1604, 'longitude': -87.5697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42464', 'place_name': 'White Plains', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Hopkins', 'locality_code': '107', 'latitude': 37.1788, 'longitude': -87.3644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40402', 'place_name': 'Annville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jackson', 'locality_code': '109', 'latitude': 37.3052, 'longitude': -83.9711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40434', 'place_name': 'Gray Hawk', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jackson', 'locality_code': '109', 'latitude': 37.3951, 'longitude': -83.9402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40447', 'place_name': 'Mc Kee', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jackson', 'locality_code': '109', 'latitude': 37.4338, 'longitude': -84.0251, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40481', 'place_name': 'Sandgap', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jackson', 'locality_code': '109', 'latitude': 37.4862, 'longitude': -84.0905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40486', 'place_name': 'Tyner', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jackson', 'locality_code': '109', 'latitude': 37.3693, 'longitude': -83.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40488', 'place_name': 'Waneta', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jackson', 'locality_code': '109', 'latitude': 37.4748, 'longitude': -84.0427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40018', 'place_name': 'Eastwood', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2331, 'longitude': -85.4558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40023', 'place_name': 'Fisherville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1652, 'longitude': -85.4282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40025', 'place_name': 'Glenview', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2997, 'longitude': -85.6487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40027', 'place_name': 'Harrods Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.3297, 'longitude': -85.633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40041', 'place_name': 'Masonic Home', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2536, 'longitude': -85.6622, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40059', 'place_name': 'Prospect', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.356, 'longitude': -85.6083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40118', 'place_name': 'Fairdale', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1087, 'longitude': -85.7549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40201', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40202', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2507, 'longitude': -85.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40203', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2493, 'longitude': -85.7694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40204', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2369, 'longitude': -85.7249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40205', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2222, 'longitude': -85.6885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40206', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2503, 'longitude': -85.7034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40207', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2628, 'longitude': -85.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40208', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.22, 'longitude': -85.7648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40209', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1901, 'longitude': -85.7519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40210', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2306, 'longitude': -85.7905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40211', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.242, 'longitude': -85.8127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40212', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2651, 'longitude': -85.8045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40213', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1839, 'longitude': -85.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40214', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1593, 'longitude': -85.778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40215', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1913, 'longitude': -85.7847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40216', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1865, 'longitude': -85.8335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40217', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2174, 'longitude': -85.7404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40218', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40219', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1381, 'longitude': -85.6953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40220', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2149, 'longitude': -85.6245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40221', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40222', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2674, 'longitude': -85.6237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40223', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2651, 'longitude': -85.5582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40224', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40225', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40228', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1442, 'longitude': -85.6265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40229', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.0891, 'longitude': -85.6548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40231', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40232', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40233', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40241', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.3045, 'longitude': -85.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40242', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2785, 'longitude': -85.594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40243', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2422, 'longitude': -85.5353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40245', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2683, 'longitude': -85.4845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40250', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40251', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40252', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40253', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40255', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40256', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40257', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40258', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1457, 'longitude': -85.8641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40259', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40261', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40266', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40268', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40269', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40270', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40272', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.0846, 'longitude': -85.851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40280', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2467, 'longitude': -85.6853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40281', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40282', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40283', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40285', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40287', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40289', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40290', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40291', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1313, 'longitude': -85.5754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40292', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.189, 'longitude': -85.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40293', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40294', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40295', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40296', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40297', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40298', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.2542, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40299', 'place_name': 'Louisville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jefferson', 'locality_code': '111', 'latitude': 38.1768, 'longitude': -85.5218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40339', 'place_name': 'Keene', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jessamine', 'locality_code': '113', 'latitude': 37.9434, 'longitude': -84.6419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40340', 'place_name': 'Nicholasville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jessamine', 'locality_code': '113', 'latitude': 37.8662, 'longitude': -84.5795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40356', 'place_name': 'Nicholasville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jessamine', 'locality_code': '113', 'latitude': 37.8808, 'longitude': -84.5646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40390', 'place_name': 'Wilmore', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Jessamine', 'locality_code': '113', 'latitude': 37.8602, 'longitude': -84.6714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41204', 'place_name': 'Boons Camp', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8216, 'longitude': -82.6704, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41216', 'place_name': 'East Point', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.7579, 'longitude': -82.8182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41219', 'place_name': 'Flatgap', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.9231, 'longitude': -82.9221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41222', 'place_name': 'Hagerhill', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.7805, 'longitude': -82.8416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41226', 'place_name': 'Keaton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.9856, 'longitude': -82.9602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41234', 'place_name': 'Meally', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8078, 'longitude': -82.7415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41238', 'place_name': 'Oil Springs', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8101, 'longitude': -82.9424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41240', 'place_name': 'Paintsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8242, 'longitude': -82.7945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41254', 'place_name': 'River', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8795, 'longitude': -82.7251, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41255', 'place_name': 'Sitka', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8922, 'longitude': -82.8446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41256', 'place_name': 'Staffordsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8253, 'longitude': -82.8823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41257', 'place_name': 'Stambaugh', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.9166, 'longitude': -82.8034, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41260', 'place_name': 'Thelma', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.822, 'longitude': -82.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41263', 'place_name': 'Tutor Key', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8507, 'longitude': -82.7602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41265', 'place_name': 'Van Lear', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.7481, 'longitude': -82.7054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41268', 'place_name': 'West Van Lear', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.7862, 'longitude': -82.7807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41271', 'place_name': 'Williamsport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8313, 'longitude': -82.7264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41274', 'place_name': 'Wittensville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Johnson', 'locality_code': '115', 'latitude': 37.8703, 'longitude': -82.81, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41011', 'place_name': 'Covington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 39.0708, 'longitude': -84.5212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41012', 'place_name': 'Covington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 38.9447, 'longitude': -84.5205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41014', 'place_name': 'Covington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 39.0642, 'longitude': -84.5118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41015', 'place_name': 'Latonia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 39.0217, 'longitude': -84.4989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41016', 'place_name': 'Covington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 39.0873, 'longitude': -84.549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41017', 'place_name': 'Ft Mitchell', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 39.03, 'longitude': -84.559, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41018', 'place_name': 'Erlanger', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 39.0082, 'longitude': -84.5977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41019', 'place_name': 'Covington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 38.9447, 'longitude': -84.5205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41025', 'place_name': 'Erlanger', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 39.0603, 'longitude': -84.6309, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41051', 'place_name': 'Independence', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 38.9354, 'longitude': -84.5479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41053', 'place_name': 'Kenton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 38.8684, 'longitude': -84.4561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41063', 'place_name': 'Morning View', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Kenton', 'locality_code': '117', 'latitude': 38.8394, 'longitude': -84.5069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41725', 'place_name': 'Carrie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3318, 'longitude': -83.0327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41740', 'place_name': 'Emmalena', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3499, 'longitude': -83.0471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41743', 'place_name': 'Fisty', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3064, 'longitude': -83.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41759', 'place_name': 'Sassafras', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.2207, 'longitude': -83.0552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41772', 'place_name': 'Vest', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.4073, 'longitude': -83.0153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41817', 'place_name': 'Garner', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3582, 'longitude': -82.9252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41822', 'place_name': 'Hindman', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3359, 'longitude': -82.9804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41828', 'place_name': 'Kite', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3136, 'longitude': -82.7975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41831', 'place_name': 'Leburn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3794, 'longitude': -82.9523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41834', 'place_name': 'Littcarr', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.2409, 'longitude': -82.9488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41836', 'place_name': 'Mallie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.2692, 'longitude': -82.9161, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41839', 'place_name': 'Mousie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.4331, 'longitude': -82.9018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41843', 'place_name': 'Pine Top', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.2868, 'longitude': -82.8741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41844', 'place_name': 'Pippa Passes', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3491, 'longitude': -82.8742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41847', 'place_name': 'Redfox', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.2172, 'longitude': -82.9424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41859', 'place_name': 'Dema', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3976, 'longitude': -82.7836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41861', 'place_name': 'Raven', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.4043, 'longitude': -82.8261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41862', 'place_name': 'Topmost', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knott', 'locality_code': '119', 'latitude': 37.3485, 'longitude': -82.7926, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40734', 'place_name': 'Gray', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.9467, 'longitude': -83.9828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40771', 'place_name': 'Woodbine', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.8586, 'longitude': -84.0347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40903', 'place_name': 'Artemus', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.8388, 'longitude': -83.8329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40906', 'place_name': 'Barbourville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.8665, 'longitude': -83.8888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40915', 'place_name': 'Bimble', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.8868, 'longitude': -83.8282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40921', 'place_name': 'Bryants Store', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.7708, 'longitude': -83.9009, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40923', 'place_name': 'Cannon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.9195, 'longitude': -83.851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40930', 'place_name': 'Dewitt', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.877, 'longitude': -83.7377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40935', 'place_name': 'Flat Lick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.829, 'longitude': -83.7702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40939', 'place_name': 'Fourmile', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.7934, 'longitude': -83.7419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40943', 'place_name': 'Girdler', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.9691, 'longitude': -83.8539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40946', 'place_name': 'Green Road', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.8713, 'longitude': -83.83, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40949', 'place_name': 'Heidrick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.8904, 'longitude': -83.8716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40953', 'place_name': 'Hinkle', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.9362, 'longitude': -83.8045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40982', 'place_name': 'Scalf', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.9327, 'longitude': -83.6901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40995', 'place_name': 'Trosper', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.761, 'longitude': -83.8155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40997', 'place_name': 'Walker', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Knox', 'locality_code': '121', 'latitude': 36.8911, 'longitude': -83.6616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42716', 'place_name': 'Buffalo', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Larue', 'locality_code': '123', 'latitude': 37.512, 'longitude': -85.6986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42748', 'place_name': 'Hodgenville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Larue', 'locality_code': '123', 'latitude': 37.5746, 'longitude': -85.7232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42757', 'place_name': 'Magnolia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Larue', 'locality_code': '123', 'latitude': 37.4165, 'longitude': -85.7308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42764', 'place_name': 'Mount Sherman', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Larue', 'locality_code': '123', 'latitude': 37.426, 'longitude': -85.6191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40724', 'place_name': 'Bush', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.0926, 'longitude': -83.8702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40729', 'place_name': 'East Bernstadt', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.2488, 'longitude': -84.138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40737', 'place_name': 'Keavy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.0156, 'longitude': -84.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40740', 'place_name': 'Lily', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.0256, 'longitude': -84.0282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40741', 'place_name': 'London', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.1549, 'longitude': -84.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40742', 'place_name': 'London', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.1376, 'longitude': -84.1156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40743', 'place_name': 'London', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.1345, 'longitude': -84.0457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40744', 'place_name': 'London', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.0995, 'longitude': -84.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40745', 'place_name': 'London', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.1376, 'longitude': -84.1156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40750', 'place_name': 'London', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.1289, 'longitude': -84.0833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40755', 'place_name': 'Pittsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Laurel', 'locality_code': '125', 'latitude': 37.1678, 'longitude': -84.1166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41124', 'place_name': 'Blaine', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 38.027, 'longitude': -82.8513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41159', 'place_name': 'Martha', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 38.0152, 'longitude': -82.9558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41160', 'place_name': 'Mazie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 38.027, 'longitude': -82.9724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41180', 'place_name': 'Webbville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 38.1634, 'longitude': -82.7897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41201', 'place_name': 'Adams', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 38.0741, 'longitude': -82.7447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41230', 'place_name': 'Louisa', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 38.1043, 'longitude': -82.6056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41232', 'place_name': 'Lowmansville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 37.9315, 'longitude': -82.7349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41264', 'place_name': 'Ulysses', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lawrence', 'locality_code': '127', 'latitude': 37.9416, 'longitude': -82.6739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41311', 'place_name': 'Beattyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lee', 'locality_code': '129', 'latitude': 37.5999, 'longitude': -83.714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41347', 'place_name': 'Lone', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lee', 'locality_code': '129', 'latitude': 37.5442, 'longitude': -83.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41368', 'place_name': 'Saint Helens', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lee', 'locality_code': '129', 'latitude': 37.5829, 'longitude': -83.6471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41397', 'place_name': 'Zoe', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lee', 'locality_code': '129', 'latitude': 37.6867, 'longitude': -83.6702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40803', 'place_name': 'Asher', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0114, 'longitude': -83.4553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40816', 'place_name': 'Chappell', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0098, 'longitude': -83.3494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40827', 'place_name': 'Essie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0547, 'longitude': -83.4561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40840', 'place_name': 'Helton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 36.954, 'longitude': -83.3907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40844', 'place_name': 'Hoskinston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0773, 'longitude': -83.3916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40858', 'place_name': 'Mozelle', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0037, 'longitude': -83.4135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40868', 'place_name': 'Stinnett', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0883, 'longitude': -83.3907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40874', 'place_name': 'Warbranch', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 36.984, 'longitude': -83.4667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40979', 'place_name': 'Roark', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0226, 'longitude': -83.5152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41714', 'place_name': 'Bear Branch', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.1939, 'longitude': -83.5035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41749', 'place_name': 'Hyden', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.1877, 'longitude': -83.4169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41762', 'place_name': 'Sizerock', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.2187, 'longitude': -83.4974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41764', 'place_name': 'Smilax', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.1214, 'longitude': -83.2539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41766', 'place_name': 'Thousandsticks', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.1851, 'longitude': -83.4288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41775', 'place_name': 'Wendover', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.1079, 'longitude': -83.3563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41776', 'place_name': 'Wooton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.1671, 'longitude': -83.2913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41777', 'place_name': 'Yeaddiss', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Leslie', 'locality_code': '131', 'latitude': 37.0565, 'longitude': -83.2361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40826', 'place_name': 'Eolia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.0618, 'longitude': -82.7706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40862', 'place_name': 'Partridge', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.0129, 'longitude': -82.8795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41517', 'place_name': 'Burdine', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1893, 'longitude': -82.599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41537', 'place_name': 'Jenkins', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1911, 'longitude': -82.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41804', 'place_name': 'Blackey', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1551, 'longitude': -82.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41810', 'place_name': 'Cromona', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1865, 'longitude': -82.6971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41812', 'place_name': 'Deane', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.2409, 'longitude': -82.7696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41815', 'place_name': 'Ermine', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1615, 'longitude': -82.7974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41819', 'place_name': 'Gordon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 36.9891, 'longitude': -83.0655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41821', 'place_name': 'Hallie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.0837, 'longitude': -83.0027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41824', 'place_name': 'Isom', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1932, 'longitude': -82.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41825', 'place_name': 'Jackhorn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.2246, 'longitude': -82.7228, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41826', 'place_name': 'Jeremiah', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1699, 'longitude': -82.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41832', 'place_name': 'Letcher', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1531, 'longitude': -82.9548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41833', 'place_name': 'Linefork', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.0233, 'longitude': -82.9878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41835', 'place_name': 'Mc Roberts', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.2137, 'longitude': -82.6734, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41837', 'place_name': 'Mayking', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1302, 'longitude': -82.7427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41838', 'place_name': 'Millstone', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1766, 'longitude': -82.7517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41840', 'place_name': 'Neon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1876, 'longitude': -82.711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41845', 'place_name': 'Premium', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1252, 'longitude': -82.9035, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41848', 'place_name': 'Roxana', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1102, 'longitude': -82.9407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41849', 'place_name': 'Seco', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1765, 'longitude': -82.7358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41855', 'place_name': 'Thornton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1906, 'longitude': -82.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41858', 'place_name': 'Whitesburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Letcher', 'locality_code': '133', 'latitude': 37.1388, 'longitude': -82.855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41135', 'place_name': 'Emerson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lewis', 'locality_code': '135', 'latitude': 38.3563, 'longitude': -83.2877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41141', 'place_name': 'Garrison', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lewis', 'locality_code': '135', 'latitude': 38.5869, 'longitude': -83.2, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41166', 'place_name': 'Quincy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lewis', 'locality_code': '135', 'latitude': 38.6271, 'longitude': -83.1056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41179', 'place_name': 'Vanceburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lewis', 'locality_code': '135', 'latitude': 38.4699, 'longitude': -83.2702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41189', 'place_name': 'Tollesboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lewis', 'locality_code': '135', 'latitude': 38.5723, 'longitude': -83.5605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40419', 'place_name': 'Crab Orchard', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lincoln', 'locality_code': '137', 'latitude': 37.4465, 'longitude': -84.4939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40437', 'place_name': 'Hustonville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lincoln', 'locality_code': '137', 'latitude': 37.4595, 'longitude': -84.8528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40442', 'place_name': 'Kings Mountain', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lincoln', 'locality_code': '137', 'latitude': 37.3818, 'longitude': -84.7148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40448', 'place_name': 'Mc Kinney', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lincoln', 'locality_code': '137', 'latitude': 37.446, 'longitude': -84.6998, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '40484', 'place_name': 'Stanford', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lincoln', 'locality_code': '137', 'latitude': 37.5245, 'longitude': -84.6912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40489', 'place_name': 'Waynesburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lincoln', 'locality_code': '137', 'latitude': 37.3499, 'longitude': -84.6655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42028', 'place_name': 'Burna', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Livingston', 'locality_code': '139', 'latitude': 37.2392, 'longitude': -88.3379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42045', 'place_name': 'Grand Rivers', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Livingston', 'locality_code': '139', 'latitude': 37.0762, 'longitude': -88.2647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42047', 'place_name': 'Hampton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Livingston', 'locality_code': '139', 'latitude': 37.2831, 'longitude': -88.3714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42058', 'place_name': 'Ledbetter', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Livingston', 'locality_code': '139', 'latitude': 37.0611, 'longitude': -88.4665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42078', 'place_name': 'Salem', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Livingston', 'locality_code': '139', 'latitude': 37.2553, 'longitude': -88.2711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42081', 'place_name': 'Smithland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Livingston', 'locality_code': '139', 'latitude': 37.2387, 'longitude': -88.3757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42083', 'place_name': 'Tiline', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Livingston', 'locality_code': '139', 'latitude': 37.1457, 'longitude': -88.285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42202', 'place_name': 'Adairville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Logan', 'locality_code': '141', 'latitude': 36.6914, 'longitude': -86.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42206', 'place_name': 'Auburn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Logan', 'locality_code': '141', 'latitude': 36.8818, 'longitude': -86.7198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42256', 'place_name': 'Lewisburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Logan', 'locality_code': '141', 'latitude': 37.0037, 'longitude': -86.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42265', 'place_name': 'Olmstead', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Logan', 'locality_code': '141', 'latitude': 36.7595, 'longitude': -86.9804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42276', 'place_name': 'Russellville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Logan', 'locality_code': '141', 'latitude': 36.8453, 'longitude': -86.8823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42038', 'place_name': 'Eddyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lyon', 'locality_code': '143', 'latitude': 37.0664, 'longitude': -88.0494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42055', 'place_name': 'Kuttawa', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Lyon', 'locality_code': '143', 'latitude': 37.0619, 'longitude': -88.1498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42001', 'place_name': 'Paducah', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCracken', 'locality_code': '145', 'latitude': 37.0634, 'longitude': -88.6632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42002', 'place_name': 'Paducah', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCracken', 'locality_code': '145', 'latitude': 37.0855, 'longitude': -88.7125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42003', 'place_name': 'Paducah', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCracken', 'locality_code': '145', 'latitude': 37.0368, 'longitude': -88.5934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42053', 'place_name': 'Kevil', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCracken', 'locality_code': '145', 'latitude': 37.0872, 'longitude': -88.8764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42086', 'place_name': 'West Paducah', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCracken', 'locality_code': '145', 'latitude': 37.0922, 'longitude': -88.7611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42631', 'place_name': 'Marshes Siding', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCreary', 'locality_code': '147', 'latitude': 36.7437, 'longitude': -84.4808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42634', 'place_name': 'Parkers Lake', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCreary', 'locality_code': '147', 'latitude': 36.8347, 'longitude': -84.4436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42635', 'place_name': 'Pine Knot', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCreary', 'locality_code': '147', 'latitude': 36.6807, 'longitude': -84.3984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42638', 'place_name': 'Revelo', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCreary', 'locality_code': '147', 'latitude': 36.6734, 'longitude': -84.4722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42647', 'place_name': 'Stearns', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCreary', 'locality_code': '147', 'latitude': 36.7082, 'longitude': -84.5165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42649', 'place_name': 'Strunk', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCreary', 'locality_code': '147', 'latitude': 36.6191, 'longitude': -84.4308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42653', 'place_name': 'Whitley City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McCreary', 'locality_code': '147', 'latitude': 36.7217, 'longitude': -84.4676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42322', 'place_name': 'Beech Grove', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McLean', 'locality_code': '149', 'latitude': 37.6162, 'longitude': -87.3964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42327', 'place_name': 'Calhoun', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McLean', 'locality_code': '149', 'latitude': 37.575, 'longitude': -87.2773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42350', 'place_name': 'Island', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McLean', 'locality_code': '149', 'latitude': 37.4471, 'longitude': -87.1692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42352', 'place_name': 'Livermore', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McLean', 'locality_code': '149', 'latitude': 37.5045, 'longitude': -87.1239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42371', 'place_name': 'Rumsey', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McLean', 'locality_code': '149', 'latitude': 37.5076, 'longitude': -87.2806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42372', 'place_name': 'Sacramento', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'McLean', 'locality_code': '149', 'latitude': 37.4177, 'longitude': -87.2736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40385', 'place_name': 'Waco', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Madison', 'locality_code': '151', 'latitude': 37.7426, 'longitude': -84.1441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40403', 'place_name': 'Berea', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Madison', 'locality_code': '151', 'latitude': 37.5799, 'longitude': -84.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40404', 'place_name': 'Berea', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Madison', 'locality_code': '151', 'latitude': 37.5687, 'longitude': -84.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40405', 'place_name': 'Bighill', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Madison', 'locality_code': '151', 'latitude': 37.5545, 'longitude': -84.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40475', 'place_name': 'Richmond', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Madison', 'locality_code': '151', 'latitude': 37.7546, 'longitude': -84.2955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40476', 'place_name': 'Richmond', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Madison', 'locality_code': '151', 'latitude': 37.7479, 'longitude': -84.2947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41426', 'place_name': 'Falcon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Magoffin', 'locality_code': '153', 'latitude': 37.7843, 'longitude': -83.0109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41464', 'place_name': 'Royalton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Magoffin', 'locality_code': '153', 'latitude': 37.6751, 'longitude': -83.0218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41465', 'place_name': 'Salyersville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Magoffin', 'locality_code': '153', 'latitude': 37.7325, 'longitude': -83.0298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41632', 'place_name': 'Gunlock', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Magoffin', 'locality_code': '153', 'latitude': 37.5892, 'longitude': -82.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40009', 'place_name': 'Bradfordsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.4662, 'longitude': -85.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40033', 'place_name': 'Lebanon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.5658, 'longitude': -85.2668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40037', 'place_name': 'Loretto', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.6421, 'longitude': -85.4113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40049', 'place_name': 'Nerinx', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.6603, 'longitude': -85.3932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40060', 'place_name': 'Raywick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.538, 'longitude': -85.43, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40062', 'place_name': 'Saint Francis', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.6047, 'longitude': -85.4251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40063', 'place_name': 'Saint Mary', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.5795, 'longitude': -85.3551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40328', 'place_name': 'Gravel Switch', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marion', 'locality_code': '155', 'latitude': 37.5758, 'longitude': -85.0824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42025', 'place_name': 'Benton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marshall', 'locality_code': '157', 'latitude': 36.8806, 'longitude': -88.3548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42029', 'place_name': 'Calvert City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marshall', 'locality_code': '157', 'latitude': 37.0147, 'longitude': -88.3811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42044', 'place_name': 'Gilbertsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marshall', 'locality_code': '157', 'latitude': 36.9655, 'longitude': -88.2667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42048', 'place_name': 'Hardin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Marshall', 'locality_code': '157', 'latitude': 36.7762, 'longitude': -88.2622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41203', 'place_name': 'Beauty', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Martin', 'locality_code': '159', 'latitude': 37.8401, 'longitude': -82.439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41214', 'place_name': 'Debord', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Martin', 'locality_code': '159', 'latitude': 37.8265, 'longitude': -82.5513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41224', 'place_name': 'Inez', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Martin', 'locality_code': '159', 'latitude': 37.8754, 'longitude': -82.5337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41231', 'place_name': 'Lovely', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Martin', 'locality_code': '159', 'latitude': 37.8259, 'longitude': -82.4013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41250', 'place_name': 'Pilgrim', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Martin', 'locality_code': '159', 'latitude': 37.7379, 'longitude': -82.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41262', 'place_name': 'Tomahawk', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Martin', 'locality_code': '159', 'latitude': 37.8687, 'longitude': -82.5971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41267', 'place_name': 'Warfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Martin', 'locality_code': '159', 'latitude': 37.875, 'longitude': -82.4386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41034', 'place_name': 'Dover', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mason', 'locality_code': '161', 'latitude': 38.691, 'longitude': -83.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41055', 'place_name': 'Mayslick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mason', 'locality_code': '161', 'latitude': 38.522, 'longitude': -83.861, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41056', 'place_name': 'Maysville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mason', 'locality_code': '161', 'latitude': 38.6207, 'longitude': -83.8067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41062', 'place_name': 'Minerva', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mason', 'locality_code': '161', 'latitude': 38.7054, 'longitude': -83.9191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41096', 'place_name': 'Washington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mason', 'locality_code': '161', 'latitude': 38.6123, 'longitude': -83.808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40104', 'place_name': 'Battletown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Meade', 'locality_code': '163', 'latitude': 38.0393, 'longitude': -86.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40108', 'place_name': 'Brandenburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Meade', 'locality_code': '163', 'latitude': 37.9662, 'longitude': -86.1084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40117', 'place_name': 'Ekron', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Meade', 'locality_code': '163', 'latitude': 37.9113, 'longitude': -86.1542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40142', 'place_name': 'Guston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Meade', 'locality_code': '163', 'latitude': 37.8951, 'longitude': -86.2155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40155', 'place_name': 'Muldraugh', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Meade', 'locality_code': '163', 'latitude': 37.9371, 'longitude': -85.9918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40157', 'place_name': 'Payneville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Meade', 'locality_code': '163', 'latitude': 38.0301, 'longitude': -86.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40161', 'place_name': 'Rhodelia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Meade', 'locality_code': '163', 'latitude': 38.006, 'longitude': -86.3984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40316', 'place_name': 'Denniston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Menifee', 'locality_code': '165', 'latitude': 37.9159, 'longitude': -83.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40322', 'place_name': 'Frenchburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Menifee', 'locality_code': '165', 'latitude': 37.947, 'longitude': -83.6084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40346', 'place_name': 'Means', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Menifee', 'locality_code': '165', 'latitude': 37.9807, 'longitude': -83.7447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40387', 'place_name': 'Wellington', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Menifee', 'locality_code': '165', 'latitude': 37.978, 'longitude': -83.4675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40310', 'place_name': 'Burgin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mercer', 'locality_code': '167', 'latitude': 37.7534, 'longitude': -84.7666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40330', 'place_name': 'Harrodsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mercer', 'locality_code': '167', 'latitude': 37.8033, 'longitude': -84.8607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40372', 'place_name': 'Salvisa', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Mercer', 'locality_code': '167', 'latitude': 37.9167, 'longitude': -84.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42124', 'place_name': 'Beaumont', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Metcalfe', 'locality_code': '169', 'latitude': 36.8705, 'longitude': -85.644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42129', 'place_name': 'Edmonton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Metcalfe', 'locality_code': '169', 'latitude': 37.0008, 'longitude': -85.6095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42154', 'place_name': 'Knob Lick', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Metcalfe', 'locality_code': '169', 'latitude': 37.0556, 'longitude': -85.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42166', 'place_name': 'Summer Shade', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Metcalfe', 'locality_code': '169', 'latitude': 36.8883, 'longitude': -85.7083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42214', 'place_name': 'Center', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Metcalfe', 'locality_code': '169', 'latitude': 37.1177, 'longitude': -85.7038, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '42133', 'place_name': 'Fountain Run', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Monroe', 'locality_code': '171', 'latitude': 36.72, 'longitude': -85.952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42140', 'place_name': 'Gamaliel', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Monroe', 'locality_code': '171', 'latitude': 36.654, 'longitude': -85.8134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42151', 'place_name': 'Hestand', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Monroe', 'locality_code': '171', 'latitude': 36.6535, 'longitude': -85.5698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42157', 'place_name': 'Mount Hermon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Monroe', 'locality_code': '171', 'latitude': 36.7723, 'longitude': -85.8195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42167', 'place_name': 'Tompkinsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Monroe', 'locality_code': '171', 'latitude': 36.7236, 'longitude': -85.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40334', 'place_name': 'Hope', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Montgomery', 'locality_code': '173', 'latitude': 38.0161, 'longitude': -83.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40337', 'place_name': 'Jeffersonville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Montgomery', 'locality_code': '173', 'latitude': 37.964, 'longitude': -83.8558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40353', 'place_name': 'Mount Sterling', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Montgomery', 'locality_code': '173', 'latitude': 38.0548, 'longitude': -83.9388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41352', 'place_name': 'Mize', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.8235, 'longitude': -83.3335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41408', 'place_name': 'Cannel City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.7901, 'longitude': -83.2741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41413', 'place_name': 'Crockett', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.9856, 'longitude': -83.0907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41421', 'place_name': 'Elkfork', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.9708, 'longitude': -83.1193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41425', 'place_name': 'Ezel', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.8912, 'longitude': -83.4444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41451', 'place_name': 'Malone', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.872, 'longitude': -83.2582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41472', 'place_name': 'West Liberty', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.9215, 'longitude': -83.2596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41477', 'place_name': 'Wrigley', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Morgan', 'locality_code': '175', 'latitude': 37.914, 'longitude': -83.2338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42321', 'place_name': 'Beech Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.1716, 'longitude': -87.0559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42323', 'place_name': 'Beechmont', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.1737, 'longitude': -87.0349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42324', 'place_name': 'Belton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.1511, 'longitude': -86.9774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42325', 'place_name': 'Bremen', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.343, 'longitude': -87.233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42326', 'place_name': 'Browder', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.1999, 'longitude': -87.0001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42330', 'place_name': 'Central City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.3007, 'longitude': -87.1202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42332', 'place_name': 'Cleaton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.2533, 'longitude': -87.0897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42337', 'place_name': 'Drakesboro', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.2136, 'longitude': -87.048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42339', 'place_name': 'Dunmor', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.084, 'longitude': -87.0079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42344', 'place_name': 'Graham', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.2467, 'longitude': -87.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42345', 'place_name': 'Greenville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.2076, 'longitude': -87.1806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42367', 'place_name': 'Powderly', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.2429, 'longitude': -87.1549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42374', 'place_name': 'South Carrollton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Muhlenberg', 'locality_code': '177', 'latitude': 37.3375, 'longitude': -87.1419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40004', 'place_name': 'Bardstown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.8083, 'longitude': -85.4613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40008', 'place_name': 'Bloomfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.908, 'longitude': -85.2862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40012', 'place_name': 'Chaplin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.9025, 'longitude': -85.2015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40013', 'place_name': 'Coxs Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.9125, 'longitude': -85.4658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40020', 'place_name': 'Fairfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.934, 'longitude': -85.3862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40048', 'place_name': 'Nazareth', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.8472, 'longitude': -85.4694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40051', 'place_name': 'New Haven', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.6438, 'longitude': -85.547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40052', 'place_name': 'New Hope', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.632, 'longitude': -85.5083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40107', 'place_name': 'Boston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nelson', 'locality_code': '179', 'latitude': 37.7408, 'longitude': -85.5948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40311', 'place_name': 'Carlisle', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nicholas', 'locality_code': '181', 'latitude': 38.3212, 'longitude': -84.0279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40350', 'place_name': 'Moorefield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Nicholas', 'locality_code': '181', 'latitude': 38.2926, 'longitude': -83.8929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42320', 'place_name': 'Beaver Dam', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.387, 'longitude': -86.8729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42328', 'place_name': 'Centertown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.4079, 'longitude': -87.009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42333', 'place_name': 'Cromwell', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.3418, 'longitude': -86.77, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42338', 'place_name': 'Dundee', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.552, 'longitude': -86.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42343', 'place_name': 'Fordsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.6297, 'longitude': -86.7263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42347', 'place_name': 'Hartford', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.4785, 'longitude': -86.918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42349', 'place_name': 'Horse Branch', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.4234, 'longitude': -86.6987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42354', 'place_name': 'Mc Henry', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.3778, 'longitude': -86.9298, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '42361', 'place_name': 'Olaton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.5259, 'longitude': -86.6875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42369', 'place_name': 'Rockport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.3554, 'longitude': -87.0065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42370', 'place_name': 'Rosine', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Ohio', 'locality_code': '183', 'latitude': 37.449, 'longitude': -86.7389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40010', 'place_name': 'Buckner', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Oldham', 'locality_code': '185', 'latitude': 38.3735, 'longitude': -85.4507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40014', 'place_name': 'Crestwood', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Oldham', 'locality_code': '185', 'latitude': 38.3326, 'longitude': -85.461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40026', 'place_name': 'Goshen', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Oldham', 'locality_code': '185', 'latitude': 38.4113, 'longitude': -85.5708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40031', 'place_name': 'La Grange', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Oldham', 'locality_code': '185', 'latitude': 38.4029, 'longitude': -85.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40032', 'place_name': 'La Grange', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Oldham', 'locality_code': '185', 'latitude': 38.4046, 'longitude': -85.4605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40056', 'place_name': 'Pewee Valley', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Oldham', 'locality_code': '185', 'latitude': 38.3039, 'longitude': -85.4834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40077', 'place_name': 'Westport', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Oldham', 'locality_code': '185', 'latitude': 38.4921, 'longitude': -85.4524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40355', 'place_name': 'New Liberty', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Owen', 'locality_code': '187', 'latitude': 38.6277, 'longitude': -84.8756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40359', 'place_name': 'Owenton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Owen', 'locality_code': '187', 'latitude': 38.4986, 'longitude': -84.8086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40363', 'place_name': 'Perry Park', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Owen', 'locality_code': '187', 'latitude': 38.5218, 'longitude': -85.0139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41314', 'place_name': 'Booneville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Owsley', 'locality_code': '189', 'latitude': 37.4965, 'longitude': -83.6574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41351', 'place_name': 'Mistletoe', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Owsley', 'locality_code': '189', 'latitude': 37.3126, 'longitude': -83.5916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41364', 'place_name': 'Ricetown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Owsley', 'locality_code': '189', 'latitude': 37.3871, 'longitude': -83.6752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41386', 'place_name': 'Vincent', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Owsley', 'locality_code': '189', 'latitude': 37.3986, 'longitude': -83.7049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41006', 'place_name': 'Butler', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pendleton', 'locality_code': '191', 'latitude': 38.8013, 'longitude': -84.3446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41033', 'place_name': 'De Mossville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pendleton', 'locality_code': '191', 'latitude': 38.7623, 'longitude': -84.4859, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41040', 'place_name': 'Falmouth', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pendleton', 'locality_code': '191', 'latitude': 38.6643, 'longitude': -84.3451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40981', 'place_name': 'Saul', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.3313, 'longitude': -83.387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41367', 'place_name': 'Rowdy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.397, 'longitude': -83.227, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41701', 'place_name': 'Hazard', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2983, 'longitude': -83.1912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41702', 'place_name': 'Hazard', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2495, 'longitude': -83.1932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41712', 'place_name': 'Ary', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.3638, 'longitude': -83.1546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41713', 'place_name': 'Avawam', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2254, 'longitude': -83.2736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41719', 'place_name': 'Bonnyman', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2983, 'longitude': -83.2544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41721', 'place_name': 'Buckhorn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.301, 'longitude': -83.4936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41722', 'place_name': 'Bulan', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.315, 'longitude': -83.1561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41723', 'place_name': 'Busy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2632, 'longitude': -83.3007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41727', 'place_name': 'Chavies', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.3479, 'longitude': -83.3563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41729', 'place_name': 'Combs', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2649, 'longitude': -83.2174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41731', 'place_name': 'Cornettsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.134, 'longitude': -83.0768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41735', 'place_name': 'Delphia', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.0233, 'longitude': -83.0956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41736', 'place_name': 'Dice', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.3758, 'longitude': -83.2419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41739', 'place_name': 'Dwarf', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.3394, 'longitude': -83.1303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41745', 'place_name': 'Gays Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.3353, 'longitude': -83.4347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41746', 'place_name': 'Happy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2101, 'longitude': -83.0917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41751', 'place_name': 'Jeff', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.2184, 'longitude': -83.1427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41754', 'place_name': 'Krypton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.3003, 'longitude': -83.3219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41760', 'place_name': 'Scuddy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.1971, 'longitude': -83.0817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41763', 'place_name': 'Slemp', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.0705, 'longitude': -83.1136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41773', 'place_name': 'Vicco', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.202, 'longitude': -83.0658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41774', 'place_name': 'Viper', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.1585, 'longitude': -83.1405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41778', 'place_name': 'Yerkes', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Perry', 'locality_code': '193', 'latitude': 37.283, 'longitude': -83.3212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41501', 'place_name': 'Pikeville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5161, 'longitude': -82.5173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41502', 'place_name': 'Pikeville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4793, 'longitude': -82.5188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41503', 'place_name': 'South Williamson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.667, 'longitude': -82.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41512', 'place_name': 'Ashcamp', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.2589, 'longitude': -82.4613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41513', 'place_name': 'Belcher', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3478, 'longitude': -82.3406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41514', 'place_name': 'Belfry', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.6401, 'longitude': -82.2573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41519', 'place_name': 'Canada', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5899, 'longitude': -82.3308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41520', 'place_name': 'Dorton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.279, 'longitude': -82.5773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41522', 'place_name': 'Elkhorn City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3109, 'longitude': -82.4091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41524', 'place_name': 'Fedscreek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4266, 'longitude': -82.2562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41526', 'place_name': 'Fords Branch', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4332, 'longitude': -82.511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41527', 'place_name': 'Forest Hills', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.6432, 'longitude': -82.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41528', 'place_name': 'Freeburn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5512, 'longitude': -82.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41531', 'place_name': 'Hardy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5928, 'longitude': -82.2328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41534', 'place_name': 'Hellier', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.2876, 'longitude': -82.4713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41535', 'place_name': 'Huddy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5964, 'longitude': -82.2797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41538', 'place_name': 'Jonancy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3165, 'longitude': -82.5829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41539', 'place_name': 'Kimper', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5068, 'longitude': -82.3271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41540', 'place_name': 'Lick Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3592, 'longitude': -82.3092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41542', 'place_name': 'Lookout', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3148, 'longitude': -82.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41543', 'place_name': 'Mc Andrews', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5624, 'longitude': -82.2803, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41544', 'place_name': 'Mc Carr', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5969, 'longitude': -82.1674, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41547', 'place_name': 'Majestic', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5311, 'longitude': -82.0916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41548', 'place_name': 'Mouthcard', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3815, 'longitude': -82.2727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41549', 'place_name': 'Myra', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.2898, 'longitude': -82.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41553', 'place_name': 'Phelps', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4987, 'longitude': -82.1584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41554', 'place_name': 'Phyllis', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4484, 'longitude': -82.2985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41555', 'place_name': 'Pinsonfork', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5466, 'longitude': -82.2621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41557', 'place_name': 'Raccoon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4935, 'longitude': -82.4221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41558', 'place_name': 'Ransom', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5426, 'longitude': -82.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41559', 'place_name': 'Regina', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3744, 'longitude': -82.3831, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41560', 'place_name': 'Robinson Creek', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3799, 'longitude': -82.5616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41561', 'place_name': 'Rockhouse', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3316, 'longitude': -82.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41562', 'place_name': 'Shelbiana', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4063, 'longitude': -82.4673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41563', 'place_name': 'Shelby Gap', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.2311, 'longitude': -82.5286, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41564', 'place_name': 'Sidney', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.6076, 'longitude': -82.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41566', 'place_name': 'Steele', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.4029, 'longitude': -82.2071, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '41567', 'place_name': 'Stone', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5859, 'longitude': -82.271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41568', 'place_name': 'Stopover', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.5093, 'longitude': -82.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41571', 'place_name': 'Varney', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.6275, 'longitude': -82.4356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41572', 'place_name': 'Virgie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pike', 'locality_code': '195', 'latitude': 37.3197, 'longitude': -82.6114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40312', 'place_name': 'Clay City', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Powell', 'locality_code': '197', 'latitude': 37.8524, 'longitude': -83.9309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40376', 'place_name': 'Slade', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Powell', 'locality_code': '197', 'latitude': 37.7951, 'longitude': -83.7041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40380', 'place_name': 'Stanton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Powell', 'locality_code': '197', 'latitude': 37.8223, 'longitude': -83.7853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42501', 'place_name': 'Somerset', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.1029, 'longitude': -84.5443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42502', 'place_name': 'Somerset', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.092, 'longitude': -84.6041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42503', 'place_name': 'Somerset', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.1566, 'longitude': -84.5248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42518', 'place_name': 'Bronston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 36.9525, 'longitude': -84.6314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42519', 'place_name': 'Burnside', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 36.9393, 'longitude': -84.5357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42533', 'place_name': 'Ferguson', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.0677, 'longitude': -84.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42544', 'place_name': 'Nancy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.0631, 'longitude': -84.7192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42553', 'place_name': 'Science Hill', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.1683, 'longitude': -84.6487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42558', 'place_name': 'Tateville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 36.9492, 'longitude': -84.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42564', 'place_name': 'West Somerset', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.1114, 'longitude': -84.5929, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '42567', 'place_name': 'Eubank', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Pulaski', 'locality_code': '199', 'latitude': 37.2642, 'longitude': -84.6066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41064', 'place_name': 'Mount Olivet', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Robertson', 'locality_code': '201', 'latitude': 38.5218, 'longitude': -84.048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40409', 'place_name': 'Brodhead', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rockcastle', 'locality_code': '203', 'latitude': 37.3815, 'longitude': -84.4336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40445', 'place_name': 'Livingston', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rockcastle', 'locality_code': '203', 'latitude': 37.3074, 'longitude': -84.2318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40456', 'place_name': 'Mount Vernon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rockcastle', 'locality_code': '203', 'latitude': 37.3983, 'longitude': -84.3379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40460', 'place_name': 'Orlando', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rockcastle', 'locality_code': '203', 'latitude': 37.3734, 'longitude': -84.2528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40473', 'place_name': 'Renfro Valley', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rockcastle', 'locality_code': '203', 'latitude': 37.3879, 'longitude': -84.3316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40492', 'place_name': 'Wildie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rockcastle', 'locality_code': '203', 'latitude': 37.4234, 'longitude': -84.3022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40313', 'place_name': 'Clearfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rowan', 'locality_code': '205', 'latitude': 38.1287, 'longitude': -83.4425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40317', 'place_name': 'Elliottville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rowan', 'locality_code': '205', 'latitude': 38.1765, 'longitude': -83.2682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40319', 'place_name': 'Farmers', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rowan', 'locality_code': '205', 'latitude': 38.1403, 'longitude': -83.5337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40351', 'place_name': 'Morehead', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Rowan', 'locality_code': '205', 'latitude': 38.199, 'longitude': -83.4436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42629', 'place_name': 'Jamestown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Russell', 'locality_code': '207', 'latitude': 36.968, 'longitude': -85.0968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42642', 'place_name': 'Russell Springs', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Russell', 'locality_code': '207', 'latitude': 37.0551, 'longitude': -85.0375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40324', 'place_name': 'Georgetown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Scott', 'locality_code': '209', 'latitude': 38.2117, 'longitude': -84.5562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40370', 'place_name': 'Sadieville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Scott', 'locality_code': '209', 'latitude': 38.3908, 'longitude': -84.5384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40379', 'place_name': 'Stamping Ground', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Scott', 'locality_code': '209', 'latitude': 38.2888, 'longitude': -84.6818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40003', 'place_name': 'Bagdad', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Shelby', 'locality_code': '211', 'latitude': 38.2608, 'longitude': -85.0651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40022', 'place_name': 'Finchville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Shelby', 'locality_code': '211', 'latitude': 38.1561, 'longitude': -85.3476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40065', 'place_name': 'Shelbyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Shelby', 'locality_code': '211', 'latitude': 38.2162, 'longitude': -85.2243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40066', 'place_name': 'Shelbyville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Shelby', 'locality_code': '211', 'latitude': 38.1973, 'longitude': -85.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40067', 'place_name': 'Simpsonville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Shelby', 'locality_code': '211', 'latitude': 38.2312, 'longitude': -85.3548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40076', 'place_name': 'Waddy', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Shelby', 'locality_code': '211', 'latitude': 38.1054, 'longitude': -85.1288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42134', 'place_name': 'Franklin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Simpson', 'locality_code': '213', 'latitude': 36.7254, 'longitude': -86.57, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42135', 'place_name': 'Franklin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Simpson', 'locality_code': '213', 'latitude': 36.7223, 'longitude': -86.5772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40046', 'place_name': 'Mount Eden', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Spencer', 'locality_code': '215', 'latitude': 38.0352, 'longitude': -85.1641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40071', 'place_name': 'Taylorsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Spencer', 'locality_code': '215', 'latitude': 38.0471, 'longitude': -85.3829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42718', 'place_name': 'Campbellsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Taylor', 'locality_code': '217', 'latitude': 37.3466, 'longitude': -85.3508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42719', 'place_name': 'Campbellsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Taylor', 'locality_code': '217', 'latitude': 37.3379, 'longitude': -85.3304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42733', 'place_name': 'Elk Horn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Taylor', 'locality_code': '217', 'latitude': 37.3393, 'longitude': -85.1918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42758', 'place_name': 'Mannsville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Taylor', 'locality_code': '217', 'latitude': 37.3726, 'longitude': -85.1966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42204', 'place_name': 'Allensville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Todd', 'locality_code': '219', 'latitude': 36.7167, 'longitude': -87.0661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42216', 'place_name': 'Clifty', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Todd', 'locality_code': '219', 'latitude': 37.0045, 'longitude': -87.1521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42220', 'place_name': 'Elkton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Todd', 'locality_code': '219', 'latitude': 36.9094, 'longitude': -87.1678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42234', 'place_name': 'Guthrie', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Todd', 'locality_code': '219', 'latitude': 36.7149, 'longitude': -87.1502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42280', 'place_name': 'Sharon Grove', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Todd', 'locality_code': '219', 'latitude': 36.9278, 'longitude': -87.1003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42286', 'place_name': 'Trenton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Todd', 'locality_code': '219', 'latitude': 36.7314, 'longitude': -87.2611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42211', 'place_name': 'Cadiz', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Trigg', 'locality_code': '221', 'latitude': 36.802, 'longitude': -87.8286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42215', 'place_name': 'Cerulean', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Trigg', 'locality_code': '221', 'latitude': 36.9496, 'longitude': -87.6648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40006', 'place_name': 'Bedford', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Trimble', 'locality_code': '223', 'latitude': 38.5864, 'longitude': -85.3133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40045', 'place_name': 'Milton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Trimble', 'locality_code': '223', 'latitude': 38.6925, 'longitude': -85.3659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42437', 'place_name': 'Morganfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Union', 'locality_code': '225', 'latitude': 37.6869, 'longitude': -87.9439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42459', 'place_name': 'Sturgis', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Union', 'locality_code': '225', 'latitude': 37.5487, 'longitude': -87.9965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42460', 'place_name': 'Sullivan', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Union', 'locality_code': '225', 'latitude': 37.494, 'longitude': -87.9328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42461', 'place_name': 'Uniontown', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Union', 'locality_code': '225', 'latitude': 37.7677, 'longitude': -87.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42462', 'place_name': 'Waverly', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Union', 'locality_code': '225', 'latitude': 37.743, 'longitude': -87.8067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42101', 'place_name': 'Bowling Green', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 37.0174, 'longitude': -86.4518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42102', 'place_name': 'Bowling Green', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.9223, 'longitude': -86.387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42103', 'place_name': 'Bowling Green', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.9663, 'longitude': -86.3933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42104', 'place_name': 'Bowling Green', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.9375, 'longitude': -86.4481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42122', 'place_name': 'Alvaton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.863, 'longitude': -86.3632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42128', 'place_name': 'Drake', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.9834, 'longitude': -86.394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42159', 'place_name': 'Oakland', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.9985, 'longitude': -86.2501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42170', 'place_name': 'Woodburn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.8557, 'longitude': -86.5623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42171', 'place_name': 'Smiths Grove', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 37.0581, 'longitude': -86.1938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42274', 'place_name': 'Rockfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Warren', 'locality_code': '227', 'latitude': 36.9241, 'longitude': -86.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40040', 'place_name': 'Mackville', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Washington', 'locality_code': '229', 'latitude': 37.7568, 'longitude': -85.059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40061', 'place_name': 'Saint Catharine', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Washington', 'locality_code': '229', 'latitude': 37.774, 'longitude': -85.2011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40069', 'place_name': 'Springfield', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Washington', 'locality_code': '229', 'latitude': 37.7342, 'longitude': -85.2107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40078', 'place_name': 'Willisburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Washington', 'locality_code': '229', 'latitude': 37.8373, 'longitude': -85.1362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42633', 'place_name': 'Monticello', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Wayne', 'locality_code': '231', 'latitude': 36.8674, 'longitude': -84.8254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42404', 'place_name': 'Clay', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Webster', 'locality_code': '233', 'latitude': 37.4756, 'longitude': -87.8368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42409', 'place_name': 'Dixon', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Webster', 'locality_code': '233', 'latitude': 37.5106, 'longitude': -87.7019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42444', 'place_name': 'Poole', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Webster', 'locality_code': '233', 'latitude': 37.641, 'longitude': -87.6439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42450', 'place_name': 'Providence', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Webster', 'locality_code': '233', 'latitude': 37.405, 'longitude': -87.7505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42455', 'place_name': 'Sebree', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Webster', 'locality_code': '233', 'latitude': 37.5889, 'longitude': -87.5255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42456', 'place_name': 'Slaughters', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Webster', 'locality_code': '233', 'latitude': 37.5054, 'longitude': -87.5053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '42463', 'place_name': 'Wheatcroft', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Webster', 'locality_code': '233', 'latitude': 37.488, 'longitude': -87.8661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40701', 'place_name': 'Corbin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Whitley', 'locality_code': '235', 'latitude': 36.9344, 'longitude': -84.1021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40702', 'place_name': 'Corbin', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Whitley', 'locality_code': '235', 'latitude': 36.9374, 'longitude': -84.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40730', 'place_name': 'Emlyn', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Whitley', 'locality_code': '235', 'latitude': 36.7039, 'longitude': -84.1415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40759', 'place_name': 'Rockholds', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Whitley', 'locality_code': '235', 'latitude': 36.8242, 'longitude': -84.104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40763', 'place_name': 'Siler', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Whitley', 'locality_code': '235', 'latitude': 36.7025, 'longitude': -83.955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40769', 'place_name': 'Williamsburg', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Whitley', 'locality_code': '235', 'latitude': 36.747, 'longitude': -84.1394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41301', 'place_name': 'Campton', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Wolfe', 'locality_code': '237', 'latitude': 37.7287, 'longitude': -83.494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41332', 'place_name': 'Hazel Green', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Wolfe', 'locality_code': '237', 'latitude': 37.7981, 'longitude': -83.421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41360', 'place_name': 'Pine Ridge', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Wolfe', 'locality_code': '237', 'latitude': 37.7749, 'longitude': -83.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '41365', 'place_name': 'Rogers', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Wolfe', 'locality_code': '237', 'latitude': 37.7093, 'longitude': -83.6314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40347', 'place_name': 'Midway', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Woodford', 'locality_code': '239', 'latitude': 38.1487, 'longitude': -84.6928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40383', 'place_name': 'Versailles', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Woodford', 'locality_code': '239', 'latitude': 38.0413, 'longitude': -84.7287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '40384', 'place_name': 'Versailles', 'state': 'Kentucky', 'state_ab': 'KY', 'county': 'Woodford', 'locality_code': '239', 'latitude': 38.0526, 'longitude': -84.7299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70516', 'place_name': 'Branch', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.3446, 'longitude': -92.3459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70525', 'place_name': 'Church Point', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.4013, 'longitude': -92.224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70526', 'place_name': 'Crowley', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.2148, 'longitude': -92.3777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70527', 'place_name': 'Crowley', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.2284, 'longitude': -92.3018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70531', 'place_name': 'Egan', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.251, 'longitude': -92.5002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70534', 'place_name': 'Estherwood', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.1808, 'longitude': -92.4643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70537', 'place_name': 'Evangeline', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.2683, 'longitude': -92.5532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70543', 'place_name': 'Iota', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.3313, 'longitude': -92.4957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70556', 'place_name': 'Mermentau', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.1861, 'longitude': -92.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70559', 'place_name': 'Morse', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.1298, 'longitude': -92.4767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70578', 'place_name': 'Rayne', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Acadia', 'locality_code': '1', 'latitude': 30.2349, 'longitude': -92.2685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70638', 'place_name': 'Elizabeth', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.8547, 'longitude': -92.7815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70644', 'place_name': 'Grant', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.7962, 'longitude': -92.9517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70648', 'place_name': 'Kinder', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.4607, 'longitude': -92.8693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70651', 'place_name': 'Leblanc', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.5648, 'longitude': -92.9583, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '70654', 'place_name': 'Mittie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.7144, 'longitude': -92.9068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70655', 'place_name': 'Oberlin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.6162, 'longitude': -92.7527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70658', 'place_name': 'Reeves', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.521, 'longitude': -93.0477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71463', 'place_name': 'Oakdale', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Allen', 'locality_code': '3', 'latitude': 30.8172, 'longitude': -92.664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70346', 'place_name': 'Donaldsonville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.1018, 'longitude': -90.997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70707', 'place_name': 'Gonzales', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.2047, 'longitude': -90.8695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70718', 'place_name': 'Brittany', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.201, 'longitude': -90.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70725', 'place_name': 'Darrow', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.13, 'longitude': -90.9651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70728', 'place_name': 'Duplessis', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.2954, 'longitude': -90.9458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70734', 'place_name': 'Geismar', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.2196, 'longitude': -91.0079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70737', 'place_name': 'Gonzales', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.2473, 'longitude': -90.918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70738', 'place_name': 'Burnside', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.1388, 'longitude': -90.924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70769', 'place_name': 'Prairieville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.3073, 'longitude': -90.9405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70774', 'place_name': 'Saint Amant', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.2385, 'longitude': -90.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70778', 'place_name': 'Sorrento', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ascension', 'locality_code': '5', 'latitude': 30.1854, 'longitude': -90.8631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70339', 'place_name': 'Pierre Part', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Assumption', 'locality_code': '7', 'latitude': 29.9476, 'longitude': -91.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70341', 'place_name': 'Belle Rose', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Assumption', 'locality_code': '7', 'latitude': 30.026, 'longitude': -91.0444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70372', 'place_name': 'Labadieville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Assumption', 'locality_code': '7', 'latitude': 29.8345, 'longitude': -90.9613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70390', 'place_name': 'Napoleonville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Assumption', 'locality_code': '7', 'latitude': 29.9288, 'longitude': -91.0266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70391', 'place_name': 'Paincourtville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Assumption', 'locality_code': '7', 'latitude': 29.9902, 'longitude': -91.0588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70393', 'place_name': 'Plattenville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Assumption', 'locality_code': '7', 'latitude': 29.9974, 'longitude': -91.0232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71320', 'place_name': 'Bordelonville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.1055, 'longitude': -91.9073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71322', 'place_name': 'Bunkie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 30.8641, 'longitude': -92.1466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71323', 'place_name': 'Center Point', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.2482, 'longitude': -92.2099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71327', 'place_name': 'Cottonport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 30.9862, 'longitude': -92.0581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71329', 'place_name': 'Dupont', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 30.9294, 'longitude': -91.9479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71331', 'place_name': 'Effie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.2275, 'longitude': -92.0967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71333', 'place_name': 'Evergreen', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 30.9161, 'longitude': -92.067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71339', 'place_name': 'Hamburg', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.0307, 'longitude': -91.9315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71341', 'place_name': 'Hessmer', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.0534, 'longitude': -92.1399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71350', 'place_name': 'Mansura', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.0615, 'longitude': -92.0543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71351', 'place_name': 'Marksville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.1396, 'longitude': -92.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71355', 'place_name': 'Moreauville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 31.0988, 'longitude': -91.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71362', 'place_name': 'Plaucheville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 30.9365, 'longitude': -91.9847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71369', 'place_name': 'Simmesport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Avoyelles', 'locality_code': '9', 'latitude': 30.9771, 'longitude': -91.8259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70634', 'place_name': 'Deridder', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Beauregard', 'locality_code': '11', 'latitude': 30.8287, 'longitude': -93.2685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70637', 'place_name': 'Dry Creek', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Beauregard', 'locality_code': '11', 'latitude': 30.6859, 'longitude': -92.9843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70652', 'place_name': 'Longville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Beauregard', 'locality_code': '11', 'latitude': 30.58, 'longitude': -93.2548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70653', 'place_name': 'Merryville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Beauregard', 'locality_code': '11', 'latitude': 30.6716, 'longitude': -93.5613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70657', 'place_name': 'Ragley', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Beauregard', 'locality_code': '11', 'latitude': 30.4703, 'longitude': -93.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70660', 'place_name': 'Singer', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Beauregard', 'locality_code': '11', 'latitude': 30.5329, 'longitude': -93.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70662', 'place_name': 'Sugartown', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Beauregard', 'locality_code': '11', 'latitude': 30.8277, 'longitude': -93.017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71001', 'place_name': 'Arcadia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.5556, 'longitude': -92.9245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71008', 'place_name': 'Bienville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.2523, 'longitude': -92.9084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71016', 'place_name': 'Castor', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.2452, 'longitude': -93.0936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71028', 'place_name': 'Gibsland', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.5299, 'longitude': -93.0706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71045', 'place_name': 'Jamestown', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.3613, 'longitude': -93.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71068', 'place_name': 'Ringgold', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.3263, 'longitude': -93.2982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71070', 'place_name': 'Saline', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.197, 'longitude': -92.917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71080', 'place_name': 'Taylor', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bienville', 'locality_code': '13', 'latitude': 32.366, 'longitude': -93.1011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71006', 'place_name': 'Benton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.6976, 'longitude': -93.691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71037', 'place_name': 'Haughton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.5507, 'longitude': -93.5657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71051', 'place_name': 'Elm Grove', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.3886, 'longitude': -93.5026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71064', 'place_name': 'Plain Dealing', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.9074, 'longitude': -93.6905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71067', 'place_name': 'Princeton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.5791, 'longitude': -93.5226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71110', 'place_name': 'Barksdale Afb', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.5137, 'longitude': -93.6404, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '71111', 'place_name': 'Bossier City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.5449, 'longitude': -93.7038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71112', 'place_name': 'Bossier City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.486, 'longitude': -93.6767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71113', 'place_name': 'Bossier City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.6276, 'longitude': -93.609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71171', 'place_name': 'Bossier City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.516, 'longitude': -93.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71172', 'place_name': 'Bossier City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Bossier', 'locality_code': '15', 'latitude': 32.6276, 'longitude': -93.609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71004', 'place_name': 'Belcher', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.7544, 'longitude': -93.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71007', 'place_name': 'Bethany', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.3662, 'longitude': -94.0034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71009', 'place_name': 'Blanchard', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.5719, 'longitude': -93.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71029', 'place_name': 'Gilliam', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.8251, 'longitude': -93.8293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71033', 'place_name': 'Greenwood', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.4429, 'longitude': -93.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71043', 'place_name': 'Hosston', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.8967, 'longitude': -93.8834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71044', 'place_name': 'Ida', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.9934, 'longitude': -93.9022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71047', 'place_name': 'Keithville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.3161, 'longitude': -93.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71060', 'place_name': 'Mooringsport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6626, 'longitude': -93.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71061', 'place_name': 'Oil City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.7451, 'longitude': -93.9838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71069', 'place_name': 'Rodessa', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.9701, 'longitude': -93.9885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71082', 'place_name': 'Vivian', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.8423, 'longitude': -93.9504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71101', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.5037, 'longitude': -93.7487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71102', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71103', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.4945, 'longitude': -93.7727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71104', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.483, 'longitude': -93.7349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71105', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.4589, 'longitude': -93.7143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71106', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.3912, 'longitude': -93.7116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71107', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6016, 'longitude': -93.8738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71108', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.4486, 'longitude': -93.7814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71109', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.474, 'longitude': -93.8013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71115', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.3401, 'longitude': -93.6092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71118', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.3977, 'longitude': -93.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71119', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.4771, 'longitude': -93.8726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71120', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71129', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.4141, 'longitude': -93.8742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71130', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71133', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71134', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71135', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71136', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71137', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71138', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71148', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71149', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71150', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.5056, 'longitude': -93.7434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71151', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71152', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71153', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71154', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71156', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71161', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71162', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71163', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71164', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71165', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71166', 'place_name': 'Shreveport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caddo Parish', 'locality_code': '17', 'latitude': 32.6076, 'longitude': -93.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70601', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2285, 'longitude': -93.188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70602', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2642, 'longitude': -93.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70605', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.1693, 'longitude': -93.2218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70606', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2642, 'longitude': -93.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70607', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.1244, 'longitude': -93.1835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70609', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2642, 'longitude': -93.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70611', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.322, 'longitude': -93.2111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70612', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2642, 'longitude': -93.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70615', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2585, 'longitude': -93.1146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70616', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2642, 'longitude': -93.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70629', 'place_name': 'Lake Charles', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2642, 'longitude': -93.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70630', 'place_name': 'Bell City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.1054, 'longitude': -93.0372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70633', 'place_name': 'Dequincy', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.4211, 'longitude': -93.4151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70646', 'place_name': 'Hayes', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.097, 'longitude': -92.9146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70647', 'place_name': 'Iowa', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2219, 'longitude': -93.0259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70661', 'place_name': 'Starks', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.3085, 'longitude': -93.6615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70663', 'place_name': 'Sulphur', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.219, 'longitude': -93.3639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70664', 'place_name': 'Sulphur', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2642, 'longitude': -93.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70665', 'place_name': 'Sulphur', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2009, 'longitude': -93.4437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70668', 'place_name': 'Vinton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2015, 'longitude': -93.5728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70669', 'place_name': 'Westlake', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Calcasieu', 'locality_code': '19', 'latitude': 30.2613, 'longitude': -93.2688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71415', 'place_name': 'Clarks', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caldwell', 'locality_code': '21', 'latitude': 32.0344, 'longitude': -92.1381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71418', 'place_name': 'Columbia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caldwell', 'locality_code': '21', 'latitude': 32.1022, 'longitude': -92.1177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71435', 'place_name': 'Grayson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caldwell', 'locality_code': '21', 'latitude': 32.067, 'longitude': -92.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71441', 'place_name': 'Kelly', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Caldwell', 'locality_code': '21', 'latitude': 31.9648, 'longitude': -92.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70631', 'place_name': 'Cameron', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Cameron', 'locality_code': '23', 'latitude': 29.7911, 'longitude': -93.438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70632', 'place_name': 'Creole', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Cameron', 'locality_code': '23', 'latitude': 29.8646, 'longitude': -93.0033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70643', 'place_name': 'Grand Chenier', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Cameron', 'locality_code': '23', 'latitude': 29.7644, 'longitude': -92.9261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70645', 'place_name': 'Hackberry', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Cameron', 'locality_code': '23', 'latitude': 29.9822, 'longitude': -93.375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71340', 'place_name': 'Harrisonburg', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Catahoula', 'locality_code': '25', 'latitude': 31.7779, 'longitude': -91.8133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71343', 'place_name': 'Jonesville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Catahoula', 'locality_code': '25', 'latitude': 31.6862, 'longitude': -91.8678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71363', 'place_name': 'Rhinehart', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Catahoula', 'locality_code': '25', 'latitude': 31.6377, 'longitude': -92.0068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71368', 'place_name': 'Sicily Island', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Catahoula', 'locality_code': '25', 'latitude': 31.8507, 'longitude': -91.6807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71401', 'place_name': 'Aimwell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Catahoula', 'locality_code': '25', 'latitude': 31.7835, 'longitude': -91.9935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71425', 'place_name': 'Enterprise', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Catahoula', 'locality_code': '25', 'latitude': 31.9064, 'longitude': -91.8751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71003', 'place_name': 'Athens', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Claiborne', 'locality_code': '27', 'latitude': 32.6451, 'longitude': -93.0239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71038', 'place_name': 'Haynesville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Claiborne', 'locality_code': '27', 'latitude': 32.9278, 'longitude': -93.0691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71040', 'place_name': 'Homer', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Claiborne', 'locality_code': '27', 'latitude': 32.7749, 'longitude': -93.0288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71048', 'place_name': 'Lisbon', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Claiborne', 'locality_code': '27', 'latitude': 32.8452, 'longitude': -92.8878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71079', 'place_name': 'Summerfield', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Claiborne', 'locality_code': '27', 'latitude': 32.9238, 'longitude': -92.8215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71316', 'place_name': 'Acme', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Concordia', 'locality_code': '29', 'latitude': 31.3016, 'longitude': -91.8216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71326', 'place_name': 'Clayton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Concordia', 'locality_code': '29', 'latitude': 31.7158, 'longitude': -91.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71334', 'place_name': 'Ferriday', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Concordia', 'locality_code': '29', 'latitude': 31.6602, 'longitude': -91.5502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71354', 'place_name': 'Monterey', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Concordia', 'locality_code': '29', 'latitude': 31.4499, 'longitude': -91.7182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71373', 'place_name': 'Vidalia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Concordia', 'locality_code': '29', 'latitude': 31.5782, 'longitude': -91.4695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71377', 'place_name': 'Wildsville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Concordia', 'locality_code': '29', 'latitude': 31.6094, 'longitude': -91.7808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71027', 'place_name': 'Frierson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 32.245, 'longitude': -93.6915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71030', 'place_name': 'Gloster', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 32.1858, 'longitude': -93.801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71032', 'place_name': 'Grand Cane', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 32.105, 'longitude': -93.7941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71046', 'place_name': 'Keatchie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 32.1622, 'longitude': -93.951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71049', 'place_name': 'Logansport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 31.9943, 'longitude': -93.9627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71050', 'place_name': 'Longstreet', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 32.0977, 'longitude': -93.9521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71052', 'place_name': 'Mansfield', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 32.0239, 'longitude': -93.698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71063', 'place_name': 'Pelican', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 31.8966, 'longitude': -93.5634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71078', 'place_name': 'Stonewall', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'De Soto', 'locality_code': '31', 'latitude': 32.2848, 'longitude': -93.8003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70704', 'place_name': 'Baker', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70714', 'place_name': 'Baker', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5814, 'longitude': -91.1429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70739', 'place_name': 'Greenwell Springs', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5984, 'longitude': -90.9705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70770', 'place_name': 'Pride', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.6133, 'longitude': -90.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70791', 'place_name': 'Zachary', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.6561, 'longitude': -91.1358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70801', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4492, 'longitude': -91.1856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70802', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4438, 'longitude': -91.1775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70803', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.405, 'longitude': -91.1868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70804', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.3863, 'longitude': -91.1339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70805', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.486, 'longitude': -91.1481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70806', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4485, 'longitude': -91.13, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70807', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5768, 'longitude': -91.2246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70808', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4066, 'longitude': -91.1468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70809', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4089, 'longitude': -91.0842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70810', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.3633, 'longitude': -91.0919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70811', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5317, 'longitude': -91.1167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70812', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5052, 'longitude': -91.1181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70813', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5201, 'longitude': -91.1949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70814', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4848, 'longitude': -91.0689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70815', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4558, 'longitude': -91.0596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70816', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4273, 'longitude': -91.0356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70817', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.3904, 'longitude': -91.0021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70818', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5408, 'longitude': -91.05, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70819', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4668, 'longitude': -91.0156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70820', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.3795, 'longitude': -91.1671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70821', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4613, 'longitude': -91.0447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70822', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70823', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70825', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70826', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70827', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4338, 'longitude': -91.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70831', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70833', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70835', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70836', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.392, 'longitude': -91.0892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70837', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70873', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5305, 'longitude': -91.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70874', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5902, 'longitude': -91.2054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70879', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70884', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70891', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4492, 'longitude': -91.1547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70892', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.4507, 'longitude': -91.1546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70893', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.413, 'longitude': -91.1715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70894', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70895', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70896', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70898', 'place_name': 'Baton Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Baton Rouge Parish', 'locality_code': '33', 'latitude': 30.5159, 'longitude': -91.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71254', 'place_name': 'Lake Providence', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Carroll', 'locality_code': '35', 'latitude': 32.8071, 'longitude': -91.1906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71276', 'place_name': 'Sondheimer', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Carroll', 'locality_code': '35', 'latitude': 32.5756, 'longitude': -91.1496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71286', 'place_name': 'Transylvania', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Carroll', 'locality_code': '35', 'latitude': 32.6705, 'longitude': -91.2288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70722', 'place_name': 'Clinton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Feliciana', 'locality_code': '37', 'latitude': 30.8249, 'longitude': -90.9331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70730', 'place_name': 'Ethel', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Feliciana', 'locality_code': '37', 'latitude': 30.8131, 'longitude': -91.11, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70748', 'place_name': 'Jackson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Feliciana', 'locality_code': '37', 'latitude': 30.8087, 'longitude': -91.1987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70761', 'place_name': 'Norwood', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Feliciana', 'locality_code': '37', 'latitude': 30.9518, 'longitude': -91.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70777', 'place_name': 'Slaughter', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Feliciana', 'locality_code': '37', 'latitude': 30.7383, 'longitude': -91.07, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70789', 'place_name': 'Wilson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'East Feliciana', 'locality_code': '37', 'latitude': 30.9473, 'longitude': -91.0655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70515', 'place_name': 'Basile', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.4978, 'longitude': -92.5736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70524', 'place_name': 'Chataignier', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.5709, 'longitude': -92.3202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70554', 'place_name': 'Mamou', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.6496, 'longitude': -92.4196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70576', 'place_name': 'Pine Prairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.7831, 'longitude': -92.4163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70580', 'place_name': 'Reddell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.675, 'longitude': -92.4265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70585', 'place_name': 'Turkey Creek', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.8707, 'longitude': -92.404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70586', 'place_name': 'Ville Platte', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.6924, 'longitude': -92.2737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71367', 'place_name': 'Saint Landry', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Evangeline', 'locality_code': '39', 'latitude': 30.8998, 'longitude': -92.2964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71219', 'place_name': 'Baskin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 32.2897, 'longitude': -91.7132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71230', 'place_name': 'Crowville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 32.2407, 'longitude': -91.5901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71243', 'place_name': 'Fort Necessity', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 32.0434, 'longitude': -91.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71249', 'place_name': 'Jigger', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 32.0349, 'longitude': -91.7468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71295', 'place_name': 'Winnsboro', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 32.1592, 'longitude': -91.7108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71324', 'place_name': 'Chase', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 32.0971, 'longitude': -91.699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71336', 'place_name': 'Gilbert', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 32.0349, 'longitude': -91.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71378', 'place_name': 'Wisner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Franklin', 'locality_code': '41', 'latitude': 31.9913, 'longitude': -91.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71407', 'place_name': 'Bentley', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Grant', 'locality_code': '43', 'latitude': 31.5157, 'longitude': -92.4882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71417', 'place_name': 'Colfax', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Grant', 'locality_code': '43', 'latitude': 31.5079, 'longitude': -92.6568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71423', 'place_name': 'Dry Prong', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Grant', 'locality_code': '43', 'latitude': 31.5979, 'longitude': -92.5665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71432', 'place_name': 'Georgetown', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Grant', 'locality_code': '43', 'latitude': 31.745, 'longitude': -92.3952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71454', 'place_name': 'Montgomery', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Grant', 'locality_code': '43', 'latitude': 31.6674, 'longitude': -92.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71467', 'place_name': 'Pollock', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Grant', 'locality_code': '43', 'latitude': 31.5, 'longitude': -92.4005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70513', 'place_name': 'Avery Island', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberia', 'locality_code': '45', 'latitude': 29.8981, 'longitude': -91.9062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70544', 'place_name': 'Jeanerette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberia', 'locality_code': '45', 'latitude': 29.9032, 'longitude': -91.6544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70552', 'place_name': 'Loreauville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberia', 'locality_code': '45', 'latitude': 30.0683, 'longitude': -91.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70560', 'place_name': 'New Iberia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberia', 'locality_code': '45', 'latitude': 30.001, 'longitude': -91.82, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70562', 'place_name': 'New Iberia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberia', 'locality_code': '45', 'latitude': 30.0035, 'longitude': -91.8187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70563', 'place_name': 'New Iberia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberia', 'locality_code': '45', 'latitude': 30.0245, 'longitude': -91.7496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70569', 'place_name': 'Lydia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberia', 'locality_code': '45', 'latitude': 29.9239, 'longitude': -91.7831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70721', 'place_name': 'Carville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.2184, 'longitude': -91.0925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70740', 'place_name': 'Grosse Tete', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.3879, 'longitude': -91.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70757', 'place_name': 'Maringouin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.4626, 'longitude': -91.5099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70764', 'place_name': 'Plaquemine', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.2684, 'longitude': -91.2524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70765', 'place_name': 'Plaquemine', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.2891, 'longitude': -91.2343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70772', 'place_name': 'Rosedale', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.4408, 'longitude': -91.4562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70776', 'place_name': 'Saint Gabriel', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.2528, 'longitude': -91.0857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70780', 'place_name': 'Sunshine', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.2982, 'longitude': -91.1799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70788', 'place_name': 'White Castle', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Iberville', 'locality_code': '47', 'latitude': 30.1545, 'longitude': -91.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71226', 'place_name': 'Chatham', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jackson', 'locality_code': '49', 'latitude': 32.2922, 'longitude': -92.4374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71238', 'place_name': 'Eros', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jackson', 'locality_code': '49', 'latitude': 32.3988, 'longitude': -92.3479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71247', 'place_name': 'Hodge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jackson', 'locality_code': '49', 'latitude': 32.2768, 'longitude': -92.7235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71251', 'place_name': 'Jonesboro', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jackson', 'locality_code': '49', 'latitude': 32.2483, 'longitude': -92.6944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71268', 'place_name': 'Quitman', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jackson', 'locality_code': '49', 'latitude': 32.3564, 'longitude': -92.7085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70001', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9871, 'longitude': -90.1695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70002', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 30.0098, 'longitude': -90.163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70003', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9975, 'longitude': -90.2146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70004', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9841, 'longitude': -90.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70005', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 30.0005, 'longitude': -90.1331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70006', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 30.0129, 'longitude': -90.1915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70009', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9841, 'longitude': -90.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70010', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9841, 'longitude': -90.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70011', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9841, 'longitude': -90.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70033', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9841, 'longitude': -90.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70036', 'place_name': 'Barataria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.6964, 'longitude': -90.1122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70053', 'place_name': 'Gretna', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9108, 'longitude': -90.0531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70054', 'place_name': 'Gretna', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9146, 'longitude': -90.054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70055', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9841, 'longitude': -90.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70056', 'place_name': 'Gretna', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.8872, 'longitude': -90.0331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70058', 'place_name': 'Harvey', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.8725, 'longitude': -90.0673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70059', 'place_name': 'Harvey', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9035, 'longitude': -90.0773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70060', 'place_name': 'Metairie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9841, 'longitude': -90.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70062', 'place_name': 'Kenner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9912, 'longitude': -90.2479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70063', 'place_name': 'Kenner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9941, 'longitude': -90.2417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70064', 'place_name': 'Kenner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9941, 'longitude': -90.2417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70065', 'place_name': 'Kenner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 30.0252, 'longitude': -90.2522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70067', 'place_name': 'Lafitte', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.7143, 'longitude': -90.1052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70072', 'place_name': 'Marrero', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.8598, 'longitude': -90.1105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70073', 'place_name': 'Marrero', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.8994, 'longitude': -90.1004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70094', 'place_name': 'Westwego', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.8973, 'longitude': -90.2033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70096', 'place_name': 'Westwego', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.906, 'longitude': -90.1423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70097', 'place_name': 'Kenner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9565, 'longitude': -90.2635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70121', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9614, 'longitude': -90.1577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70123', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9511, 'longitude': -90.206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70141', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70181', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.6779, 'longitude': -90.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70183', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70358', 'place_name': 'Grand Isle', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Parish', 'locality_code': '51', 'latitude': 29.2297, 'longitude': -90.0088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70532', 'place_name': 'Elton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Davis', 'locality_code': '53', 'latitude': 30.4715, 'longitude': -92.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70546', 'place_name': 'Jennings', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Davis', 'locality_code': '53', 'latitude': 30.2201, 'longitude': -92.6574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70549', 'place_name': 'Lake Arthur', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Davis', 'locality_code': '53', 'latitude': 30.091, 'longitude': -92.6825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70581', 'place_name': 'Roanoke', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Davis', 'locality_code': '53', 'latitude': 30.2464, 'longitude': -92.7421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70591', 'place_name': 'Welsh', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Davis', 'locality_code': '53', 'latitude': 30.2363, 'longitude': -92.819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70640', 'place_name': 'Fenton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Davis', 'locality_code': '53', 'latitude': 30.3655, 'longitude': -92.9122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70650', 'place_name': 'Lacassine', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Jefferson Davis', 'locality_code': '53', 'latitude': 30.2374, 'longitude': -92.9232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70501', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2361, 'longitude': -92.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70502', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2241, 'longitude': -92.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70503', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.1843, 'longitude': -92.0497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70504', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2139, 'longitude': -92.0187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70505', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2023, 'longitude': -92.0188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70506', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2077, 'longitude': -92.0656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70507', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2813, 'longitude': -92.016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70508', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.1582, 'longitude': -92.0236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70509', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.1565, 'longitude': -92, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70518', 'place_name': 'Broussard', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.1219, 'longitude': -91.9502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70520', 'place_name': 'Carencro', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.3244, 'longitude': -92.0423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70529', 'place_name': 'Duson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.1912, 'longitude': -92.1525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70558', 'place_name': 'Milton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.1038, 'longitude': -92.0765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70583', 'place_name': 'Scott', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2504, 'longitude': -92.0981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70592', 'place_name': 'Youngsville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.0975, 'longitude': -92.0096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70593', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2081, 'longitude': -92.0951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70596', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2241, 'longitude': -92.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70598', 'place_name': 'Lafayette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafayette', 'locality_code': '55', 'latitude': 30.2081, 'longitude': -92.0951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70301', 'place_name': 'Thibodaux', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.7992, 'longitude': -90.8096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70302', 'place_name': 'Thibodaux', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.7958, 'longitude': -90.8229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70310', 'place_name': 'Thibodaux', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.8033, 'longitude': -90.8169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70345', 'place_name': 'Cut Off', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.5232, 'longitude': -90.3393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70354', 'place_name': 'Galliano', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.4311, 'longitude': -90.2981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70355', 'place_name': 'Gheens', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.7076, 'longitude': -90.4849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70357', 'place_name': 'Golden Meadow', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.3821, 'longitude': -90.2639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70371', 'place_name': 'Kraemer', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.8652, 'longitude': -90.5962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70373', 'place_name': 'Larose', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.5724, 'longitude': -90.3817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70374', 'place_name': 'Lockport', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.6155, 'longitude': -90.4442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70375', 'place_name': 'Mathews', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.6938, 'longitude': -90.5496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70394', 'place_name': 'Raceland', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lafourche', 'locality_code': '57', 'latitude': 29.7178, 'longitude': -90.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71342', 'place_name': 'Jena', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'La Salle', 'locality_code': '59', 'latitude': 31.6748, 'longitude': -92.1137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71371', 'place_name': 'Trout', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'La Salle', 'locality_code': '59', 'latitude': 31.6531, 'longitude': -92.1993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71465', 'place_name': 'Olla', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'La Salle', 'locality_code': '59', 'latitude': 31.8734, 'longitude': -92.2214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71479', 'place_name': 'Tullos', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'La Salle', 'locality_code': '59', 'latitude': 31.8569, 'longitude': -92.374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71480', 'place_name': 'Urania', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'La Salle', 'locality_code': '59', 'latitude': 31.865, 'longitude': -92.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71227', 'place_name': 'Choudrant', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lincoln', 'locality_code': '61', 'latitude': 32.5556, 'longitude': -92.5224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71235', 'place_name': 'Dubach', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lincoln', 'locality_code': '61', 'latitude': 32.6949, 'longitude': -92.6785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71245', 'place_name': 'Grambling', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lincoln', 'locality_code': '61', 'latitude': 32.5244, 'longitude': -92.7158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71270', 'place_name': 'Ruston', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lincoln', 'locality_code': '61', 'latitude': 32.5308, 'longitude': -92.6439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71272', 'place_name': 'Ruston', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lincoln', 'locality_code': '61', 'latitude': 32.5258, 'longitude': -92.6493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71273', 'place_name': 'Ruston', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lincoln', 'locality_code': '61', 'latitude': 32.6065, 'longitude': -92.6484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71275', 'place_name': 'Simsboro', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Lincoln', 'locality_code': '61', 'latitude': 32.5384, 'longitude': -92.7995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70449', 'place_name': 'Maurepas', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.2716, 'longitude': -90.7043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70462', 'place_name': 'Springfield', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.4157, 'longitude': -90.5775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70706', 'place_name': 'Denham Springs', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.6085, 'longitude': -90.9038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70711', 'place_name': 'Albany', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.5149, 'longitude': -90.5964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70726', 'place_name': 'Denham Springs', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.459, 'longitude': -90.9027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70727', 'place_name': 'Denham Springs', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.3375, 'longitude': -90.8434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70733', 'place_name': 'French Settlement', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.2952, 'longitude': -90.7951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70744', 'place_name': 'Holden', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.5556, 'longitude': -90.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70754', 'place_name': 'Livingston', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.4741, 'longitude': -90.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70785', 'place_name': 'Walker', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.5247, 'longitude': -90.8557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70786', 'place_name': 'Watson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Livingston', 'locality_code': '63', 'latitude': 30.5502, 'longitude': -90.9582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71233', 'place_name': 'Delta', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Madison', 'locality_code': '65', 'latitude': 32.3257, 'longitude': -90.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71282', 'place_name': 'Tallulah', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Madison', 'locality_code': '65', 'latitude': 32.4326, 'longitude': -91.0645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71284', 'place_name': 'Tallulah', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Madison', 'locality_code': '65', 'latitude': 32.4085, 'longitude': -91.1868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71220', 'place_name': 'Bastrop', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Morehouse', 'locality_code': '67', 'latitude': 32.7894, 'longitude': -91.9078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71221', 'place_name': 'Bastrop', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Morehouse', 'locality_code': '67', 'latitude': 32.7562, 'longitude': -91.8723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71223', 'place_name': 'Bonita', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Morehouse', 'locality_code': '67', 'latitude': 32.9123, 'longitude': -91.6822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71229', 'place_name': 'Collinston', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Morehouse', 'locality_code': '67', 'latitude': 32.6971, 'longitude': -91.8634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71250', 'place_name': 'Jones', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Morehouse', 'locality_code': '67', 'latitude': 32.9663, 'longitude': -91.5965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71261', 'place_name': 'Mer Rouge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Morehouse', 'locality_code': '67', 'latitude': 32.7718, 'longitude': -91.7716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71264', 'place_name': 'Oak Ridge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Morehouse', 'locality_code': '67', 'latitude': 32.6243, 'longitude': -91.7618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71002', 'place_name': 'Ashland', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 32.1378, 'longitude': -93.0906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71031', 'place_name': 'Goldonna', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 32, 'longitude': -92.9611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71066', 'place_name': 'Powhatan', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.8741, 'longitude': -93.1966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71411', 'place_name': 'Campti', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.8959, 'longitude': -93.0936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71414', 'place_name': 'Clarence', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.8216, 'longitude': -93.0296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71416', 'place_name': 'Cloutierville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.5432, 'longitude': -92.9182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71428', 'place_name': 'Flora', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.6124, 'longitude': -93.098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71434', 'place_name': 'Gorum', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.433, 'longitude': -92.9435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71450', 'place_name': 'Marthaville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.7726, 'longitude': -93.3954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71452', 'place_name': 'Melrose', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.6104, 'longitude': -92.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71455', 'place_name': 'Mora', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.4016, 'longitude': -92.974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71456', 'place_name': 'Natchez', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.6615, 'longitude': -93.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71457', 'place_name': 'Natchitoches', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.7617, 'longitude': -93.0916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71458', 'place_name': 'Natchitoches', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.7476, 'longitude': -93.0791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71468', 'place_name': 'Provencal', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.5157, 'longitude': -93.1488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71469', 'place_name': 'Robeline', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.7715, 'longitude': -93.321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71497', 'place_name': 'Natchitoches', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Natchitoches', 'locality_code': '69', 'latitude': 31.7476, 'longitude': -93.0791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70112', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9605, 'longitude': -90.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70113', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9405, 'longitude': -90.0848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70114', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9379, 'longitude': -90.0331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70115', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9289, 'longitude': -90.1005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70116', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9686, 'longitude': -90.0646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70117', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9703, 'longitude': -90.0312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70118', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9504, 'longitude': -90.1236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70119', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9746, 'longitude': -90.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70122', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 30.0056, 'longitude': -90.0644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70124', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 30.0071, 'longitude': -90.1094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70125', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9512, 'longitude': -90.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70126', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9987, 'longitude': -90.0446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70127', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 30.0313, 'longitude': -89.9758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70128', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 30.0487, 'longitude': -89.9585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70129', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 30.0877, 'longitude': -89.8462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70130', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9324, 'longitude': -90.0739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70131', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9168, 'longitude': -89.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70139', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70142', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70143', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70145', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70146', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70148', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 30.0309, 'longitude': -90.068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70150', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70151', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70152', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70153', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70154', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70156', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70157', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70158', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9229, 'longitude': -90.0709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70159', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70160', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70161', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70162', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70163', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.95, 'longitude': -90.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70164', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70165', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70166', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70167', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70170', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70172', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70174', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70175', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70176', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70177', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70178', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70179', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70182', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70184', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70185', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70186', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70187', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70189', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70190', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70195', 'place_name': 'New Orleans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Orleans', 'locality_code': '71', 'latitude': 29.9546, 'longitude': -90.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71201', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.5286, 'longitude': -92.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71202', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.3868, 'longitude': -92.0722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71203', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.553, 'longitude': -92.0422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71207', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.5093, 'longitude': -92.1193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71209', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.5277, 'longitude': -92.0756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71210', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.4908, 'longitude': -92.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71211', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.4908, 'longitude': -92.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71212', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.5093, 'longitude': -92.1193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71213', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.4908, 'longitude': -92.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71217', 'place_name': 'Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.5116, 'longitude': -92.0849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71225', 'place_name': 'Calhoun', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.5248, 'longitude': -92.3299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71240', 'place_name': 'Fairbanks', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.6443, 'longitude': -92.0365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71280', 'place_name': 'Sterlington', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.7119, 'longitude': -92.0981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71281', 'place_name': 'Swartz', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.4908, 'longitude': -92.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71291', 'place_name': 'West Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.5317, 'longitude': -92.176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71292', 'place_name': 'West Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.4566, 'longitude': -92.1854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71294', 'place_name': 'West Monroe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Ouachita Parish', 'locality_code': '73', 'latitude': 32.4908, 'longitude': -92.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70037', 'place_name': 'Belle Chasse', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.8345, 'longitude': -90.0042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70038', 'place_name': 'Boothville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.3079, 'longitude': -89.3814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70040', 'place_name': 'Braithwaite', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.7361, 'longitude': -89.9197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70041', 'place_name': 'Buras', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.3519, 'longitude': -89.5242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70050', 'place_name': 'Empire', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.3814, 'longitude': -89.5926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70081', 'place_name': 'Pilottown', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.1816, 'longitude': -89.2576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70082', 'place_name': 'Pointe A La Hache', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.542, 'longitude': -89.7512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70083', 'place_name': 'Port Sulphur', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.47, 'longitude': -89.6847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70091', 'place_name': 'Venice', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.2659, 'longitude': -89.3761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70093', 'place_name': 'Belle Chasse', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Plaquemines Parish', 'locality_code': '75', 'latitude': 29.8549, 'longitude': -89.9906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70715', 'place_name': 'Batchelor', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.8298, 'longitude': -91.6944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70732', 'place_name': 'Fordoche', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.596, 'longitude': -91.6165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70736', 'place_name': 'Glynn', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.6376, 'longitude': -91.3423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70747', 'place_name': 'Innis', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.8736, 'longitude': -91.6766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70749', 'place_name': 'Jarreau', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.6326, 'longitude': -91.4332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70752', 'place_name': 'Lakeland', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.5799, 'longitude': -91.4217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70753', 'place_name': 'Lettsworth', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.9324, 'longitude': -91.7403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70755', 'place_name': 'Livonia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.5524, 'longitude': -91.5332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70756', 'place_name': 'Lottie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.5563, 'longitude': -91.6418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70759', 'place_name': 'Morganza', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.7245, 'longitude': -91.5959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70760', 'place_name': 'New Roads', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.7014, 'longitude': -91.4421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70762', 'place_name': 'Oscar', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.5983, 'longitude': -91.4577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70773', 'place_name': 'Rougon', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.6035, 'longitude': -91.3813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70783', 'place_name': 'Ventress', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Pointe Coupee', 'locality_code': '77', 'latitude': 30.6814, 'longitude': -91.4033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71301', 'place_name': 'Alexandria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.2885, 'longitude': -92.4633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71302', 'place_name': 'Alexandria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.2683, 'longitude': -92.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71303', 'place_name': 'Alexandria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3048, 'longitude': -92.5089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71306', 'place_name': 'Alexandria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3113, 'longitude': -92.4451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71307', 'place_name': 'Alexandria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.2034, 'longitude': -92.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71309', 'place_name': 'Alexandria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3047, 'longitude': -92.6196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71315', 'place_name': 'Alexandria', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.1397, 'longitude': -92.3984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71325', 'place_name': 'Cheneyville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.0201, 'longitude': -92.2951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71328', 'place_name': 'Deville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3574, 'longitude': -92.1654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71330', 'place_name': 'Echo', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.1093, 'longitude': -92.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71346', 'place_name': 'Lecompte', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.106, 'longitude': -92.389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71348', 'place_name': 'Libuse', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3541, 'longitude': -92.3335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71359', 'place_name': 'Pineville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3224, 'longitude': -92.4343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71360', 'place_name': 'Pineville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.2232, 'longitude': -92.3203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71361', 'place_name': 'Pineville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3692, 'longitude': -92.4198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71365', 'place_name': 'Ruby', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.1894, 'longitude': -92.2487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71405', 'place_name': 'Ball', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.4151, 'longitude': -92.3945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71409', 'place_name': 'Boyce', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3216, 'longitude': -92.6867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71424', 'place_name': 'Elmer', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.1465, 'longitude': -92.7171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71427', 'place_name': 'Flatwoods', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3849, 'longitude': -92.8812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71430', 'place_name': 'Forest Hill', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.0243, 'longitude': -92.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71431', 'place_name': 'Gardner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.2587, 'longitude': -92.6775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71433', 'place_name': 'Glenmora', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.0262, 'longitude': -92.616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71438', 'place_name': 'Hineston', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.1669, 'longitude': -92.7375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71447', 'place_name': 'Lena', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.4207, 'longitude': -92.8312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71448', 'place_name': 'Longleaf', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.0066, 'longitude': -92.5526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71466', 'place_name': 'Otis', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.2077, 'longitude': -92.7392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71472', 'place_name': 'Sieper', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.1976, 'longitude': -92.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71477', 'place_name': 'Tioga', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.3999, 'longitude': -92.6042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71485', 'place_name': 'Woodworth', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Rapides', 'locality_code': '79', 'latitude': 31.1635, 'longitude': -92.5322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71019', 'place_name': 'Coushatta', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Red River', 'locality_code': '81', 'latitude': 32.0231, 'longitude': -93.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71034', 'place_name': 'Hall Summit', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Red River', 'locality_code': '81', 'latitude': 32.1752, 'longitude': -93.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71218', 'place_name': 'Archibald', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Richland', 'locality_code': '83', 'latitude': 32.3632, 'longitude': -91.7693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71232', 'place_name': 'Delhi', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Richland', 'locality_code': '83', 'latitude': 32.3929, 'longitude': -91.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71259', 'place_name': 'Mangham', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Richland', 'locality_code': '83', 'latitude': 32.3331, 'longitude': -91.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71269', 'place_name': 'Rayville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Richland', 'locality_code': '83', 'latitude': 32.4456, 'longitude': -91.7433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71279', 'place_name': 'Start', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Richland', 'locality_code': '83', 'latitude': 32.4865, 'longitude': -91.8593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71065', 'place_name': 'Pleasant Hill', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.8086, 'longitude': -93.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71406', 'place_name': 'Belmont', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.71, 'longitude': -93.4959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71419', 'place_name': 'Converse', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.7339, 'longitude': -93.6902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71426', 'place_name': 'Fisher', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.4937, 'longitude': -93.4602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71429', 'place_name': 'Florien', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.4275, 'longitude': -93.5179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71449', 'place_name': 'Many', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.5851, 'longitude': -93.4641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71460', 'place_name': 'Negreet', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.4693, 'longitude': -93.5749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71462', 'place_name': 'Noble', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.6938, 'longitude': -93.7167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71486', 'place_name': 'Zwolle', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Sabine', 'locality_code': '85', 'latitude': 31.6138, 'longitude': -93.6636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70032', 'place_name': 'Arabi', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Bernard', 'locality_code': '87', 'latitude': 29.9612, 'longitude': -89.9965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70043', 'place_name': 'Chalmette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Bernard', 'locality_code': '87', 'latitude': 29.9466, 'longitude': -89.9611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70044', 'place_name': 'Chalmette', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Bernard', 'locality_code': '87', 'latitude': 29.9676, 'longitude': -89.9514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70075', 'place_name': 'Meraux', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Bernard', 'locality_code': '87', 'latitude': 29.9335, 'longitude': -89.9214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70085', 'place_name': 'Saint Bernard', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Bernard', 'locality_code': '87', 'latitude': 29.8611, 'longitude': -89.8364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70092', 'place_name': 'Violet', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Bernard', 'locality_code': '87', 'latitude': 29.9043, 'longitude': -89.896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70030', 'place_name': 'Des Allemands', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.8134, 'longitude': -90.4407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70031', 'place_name': 'Ama', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.9435, 'longitude': -90.2925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70039', 'place_name': 'Boutte', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.8973, 'longitude': -90.3934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70047', 'place_name': 'Destrehan', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.9642, 'longitude': -90.3682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70057', 'place_name': 'Hahnville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.9668, 'longitude': -90.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70070', 'place_name': 'Luling', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.9251, 'longitude': -90.3693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70078', 'place_name': 'New Sarpy', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.9817, 'longitude': -90.3859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70079', 'place_name': 'Norco', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 30.0057, 'longitude': -90.4198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70080', 'place_name': 'Paradis', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.877, 'longitude': -90.4352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70087', 'place_name': 'Saint Rose', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Charles', 'locality_code': '89', 'latitude': 29.9581, 'longitude': -90.3124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70441', 'place_name': 'Greensburg', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Helena', 'locality_code': '91', 'latitude': 30.8647, 'longitude': -90.7256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70453', 'place_name': 'Pine Grove', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Helena', 'locality_code': '91', 'latitude': 30.7032, 'longitude': -90.7672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70052', 'place_name': 'Gramercy', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 30.0527, 'longitude': -90.6902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70071', 'place_name': 'Lutcher', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 30.0447, 'longitude': -90.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70086', 'place_name': 'Saint James', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 30.0276, 'longitude': -90.8605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70090', 'place_name': 'Vacherie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 29.9694, 'longitude': -90.7097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70723', 'place_name': 'Convent', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 30.0208, 'longitude': -90.8298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70743', 'place_name': 'Hester', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 30.0206, 'longitude': -90.7814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70763', 'place_name': 'Paulina', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 30.0352, 'longitude': -90.7374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70792', 'place_name': 'Uncle Sam', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. James', 'locality_code': '93', 'latitude': 30.0279, 'longitude': -90.8028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70049', 'place_name': 'Edgard', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. John the Baptist', 'locality_code': '95', 'latitude': 30.0319, 'longitude': -90.5817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70051', 'place_name': 'Garyville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. John the Baptist', 'locality_code': '95', 'latitude': 30.0535, 'longitude': -90.6201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70068', 'place_name': 'La Place', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. John the Baptist', 'locality_code': '95', 'latitude': 30.0777, 'longitude': -90.4895, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '70069', 'place_name': 'La Place', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. John the Baptist', 'locality_code': '95', 'latitude': 30.0912, 'longitude': -90.4832, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '70076', 'place_name': 'Mount Airy', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. John the Baptist', 'locality_code': '95', 'latitude': 30.0575, 'longitude': -90.6369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70084', 'place_name': 'Reserve', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. John the Baptist', 'locality_code': '95', 'latitude': 30.0603, 'longitude': -90.5518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70512', 'place_name': 'Arnaudville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.3981, 'longitude': -91.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70535', 'place_name': 'Eunice', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.5116, 'longitude': -92.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70541', 'place_name': 'Grand Coteau', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.4201, 'longitude': -92.0462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70550', 'place_name': 'Lawtell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.5165, 'longitude': -92.1841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70551', 'place_name': 'Leonville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.4752, 'longitude': -91.9737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70570', 'place_name': 'Opelousas', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.5144, 'longitude': -92.0897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70571', 'place_name': 'Opelousas', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.5335, 'longitude': -92.0815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70577', 'place_name': 'Port Barre', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.5478, 'longitude': -91.9286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70584', 'place_name': 'Sunset', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.3884, 'longitude': -92.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70589', 'place_name': 'Washington', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.6839, 'longitude': -92.0252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70750', 'place_name': 'Krotz Springs', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.5379, 'longitude': -91.7563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71345', 'place_name': 'Lebeau', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.7292, 'longitude': -91.9755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71353', 'place_name': 'Melville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.6626, 'longitude': -91.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71356', 'place_name': 'Morrow', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.8299, 'longitude': -92.0426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71358', 'place_name': 'Palmetto', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Landry', 'locality_code': '97', 'latitude': 30.7065, 'longitude': -91.9114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70517', 'place_name': 'Breaux Bridge', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Martin', 'locality_code': '99', 'latitude': 30.2948, 'longitude': -91.8296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70519', 'place_name': 'Cade', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Martin', 'locality_code': '99', 'latitude': 30.0797, 'longitude': -91.9114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70521', 'place_name': 'Cecilia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Martin', 'locality_code': '99', 'latitude': 30.3364, 'longitude': -91.8492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70582', 'place_name': 'Saint Martinville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Martin', 'locality_code': '99', 'latitude': 30.2237, 'longitude': -91.7794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70340', 'place_name': 'Amelia', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.6663, 'longitude': -91.102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70342', 'place_name': 'Berwick', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.6929, 'longitude': -91.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70380', 'place_name': 'Morgan City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.6977, 'longitude': -91.2654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70381', 'place_name': 'Morgan City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.6946, 'longitude': -91.2593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70392', 'place_name': 'Patterson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.6967, 'longitude': -91.2812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70514', 'place_name': 'Baldwin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.8488, 'longitude': -91.5458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70522', 'place_name': 'Centerville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.7523, 'longitude': -91.4397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70523', 'place_name': 'Charenton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.8796, 'longitude': -91.5337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70538', 'place_name': 'Franklin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.7857, 'longitude': -91.5026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70540', 'place_name': 'Garden City', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Mary', 'locality_code': '101', 'latitude': 29.7633, 'longitude': -91.467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70420', 'place_name': 'Abita Springs', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.4837, 'longitude': -90.0041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70431', 'place_name': 'Bush', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.6134, 'longitude': -89.9557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70433', 'place_name': 'Covington', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.4876, 'longitude': -90.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70434', 'place_name': 'Covington', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.4755, 'longitude': -90.1004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70435', 'place_name': 'Covington', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.5661, 'longitude': -90.1098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70437', 'place_name': 'Folsom', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.6145, 'longitude': -90.1879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70445', 'place_name': 'Lacombe', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.322, 'longitude': -89.9297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70447', 'place_name': 'Madisonville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.4287, 'longitude': -90.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70448', 'place_name': 'Mandeville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.3666, 'longitude': -90.0487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70452', 'place_name': 'Pearl River', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.3944, 'longitude': -89.7732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70457', 'place_name': 'Saint Benedict', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.5269, 'longitude': -90.1126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70458', 'place_name': 'Slidell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.2784, 'longitude': -89.7712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70459', 'place_name': 'Slidell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.4255, 'longitude': -89.8813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70460', 'place_name': 'Slidell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.2916, 'longitude': -89.8129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70461', 'place_name': 'Slidell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.2726, 'longitude': -89.729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70463', 'place_name': 'Sun', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.6491, 'longitude': -89.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70464', 'place_name': 'Talisheek', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.5347, 'longitude': -89.8859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70469', 'place_name': 'Slidell', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.2752, 'longitude': -89.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70470', 'place_name': 'Mandeville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.4255, 'longitude': -89.8813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70471', 'place_name': 'Mandeville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'St. Tammany', 'locality_code': '103', 'latitude': 30.4207, 'longitude': -90.0589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70401', 'place_name': 'Hammond', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.5191, 'longitude': -90.4879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70402', 'place_name': 'Hammond', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.514, 'longitude': -90.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70403', 'place_name': 'Hammond', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.4911, 'longitude': -90.4697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70404', 'place_name': 'Hammond', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.5046, 'longitude': -90.4629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70421', 'place_name': 'Akers', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.2902, 'longitude': -90.4018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70422', 'place_name': 'Amite', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.7266, 'longitude': -90.509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70436', 'place_name': 'Fluker', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.8128, 'longitude': -90.5207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70442', 'place_name': 'Husser', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.692, 'longitude': -90.339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70443', 'place_name': 'Independence', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.6351, 'longitude': -90.5277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70444', 'place_name': 'Kentwood', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.8892, 'longitude': -90.4728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70446', 'place_name': 'Loranger', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.5884, 'longitude': -90.3567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70451', 'place_name': 'Natalbany', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.5519, 'longitude': -90.4859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70454', 'place_name': 'Ponchatoula', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.4406, 'longitude': -90.4422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70455', 'place_name': 'Robert', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.5063, 'longitude': -90.3352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70456', 'place_name': 'Roseland', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.7717, 'longitude': -90.5243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70465', 'place_name': 'Tangipahoa', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.8764, 'longitude': -90.5089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70466', 'place_name': 'Tickfaw', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tangipahoa', 'locality_code': '105', 'latitude': 30.5668, 'longitude': -90.482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71357', 'place_name': 'Newellton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tensas', 'locality_code': '107', 'latitude': 32.0656, 'longitude': -91.2578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71366', 'place_name': 'Saint Joseph', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tensas', 'locality_code': '107', 'latitude': 31.9248, 'longitude': -91.2784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71375', 'place_name': 'Waterproof', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Tensas', 'locality_code': '107', 'latitude': 31.8076, 'longitude': -91.3872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70343', 'place_name': 'Bourg', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.5485, 'longitude': -90.6087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70344', 'place_name': 'Chauvin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.4634, 'longitude': -90.598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70352', 'place_name': 'Donner', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.6964, 'longitude': -90.9444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70353', 'place_name': 'Dulac', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.3695, 'longitude': -90.697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70356', 'place_name': 'Gibson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.6625, 'longitude': -90.9776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70359', 'place_name': 'Gray', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.6903, 'longitude': -90.7807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70360', 'place_name': 'Houma', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.5943, 'longitude': -90.7548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70361', 'place_name': 'Houma', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.5958, 'longitude': -90.7195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70363', 'place_name': 'Houma', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.5601, 'longitude': -90.6917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70364', 'place_name': 'Houma', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.6299, 'longitude': -90.7268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70377', 'place_name': 'Montegut', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.4744, 'longitude': -90.544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70395', 'place_name': 'Schriever', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.7123, 'longitude': -90.8513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70397', 'place_name': 'Theriot', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Terrebonne', 'locality_code': '109', 'latitude': 29.4516, 'longitude': -90.7651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71222', 'place_name': 'Bernice', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Union', 'locality_code': '111', 'latitude': 32.8221, 'longitude': -92.6579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71234', 'place_name': 'Downsville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Union', 'locality_code': '111', 'latitude': 32.6525, 'longitude': -92.3745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71241', 'place_name': 'Farmerville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Union', 'locality_code': '111', 'latitude': 32.7534, 'longitude': -92.318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71256', 'place_name': 'Lillie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Union', 'locality_code': '111', 'latitude': 32.9529, 'longitude': -92.6858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71260', 'place_name': 'Marion', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Union', 'locality_code': '111', 'latitude': 32.8716, 'longitude': -92.2862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71277', 'place_name': 'Spearsville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Union', 'locality_code': '111', 'latitude': 32.955, 'longitude': -92.587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70510', 'place_name': 'Abbeville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 29.9466, 'longitude': -92.2416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70511', 'place_name': 'Abbeville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 29.9747, 'longitude': -92.1343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70528', 'place_name': 'Delcambre', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 29.9474, 'longitude': -91.9889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70533', 'place_name': 'Erath', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 29.9522, 'longitude': -92.0343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70542', 'place_name': 'Gueydan', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 30.0255, 'longitude': -92.5338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70548', 'place_name': 'Kaplan', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 29.9771, 'longitude': -92.3025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70555', 'place_name': 'Maurice', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 30.0722, 'longitude': -92.107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70575', 'place_name': 'Perry', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vermilion', 'locality_code': '113', 'latitude': 29.9485, 'longitude': -92.1571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70639', 'place_name': 'Evans', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 30.9684, 'longitude': -93.5203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70656', 'place_name': 'Pitkin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 30.933, 'longitude': -92.9548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70659', 'place_name': 'Rosepine', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 30.9243, 'longitude': -93.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71403', 'place_name': 'Anacoco', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.2149, 'longitude': -93.3829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71439', 'place_name': 'Hornbeck', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.3226, 'longitude': -93.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71443', 'place_name': 'Kurthwood', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.3374, 'longitude': -93.1657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71446', 'place_name': 'Leesville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.1256, 'longitude': -93.1736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71459', 'place_name': 'Fort Polk', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.0466, 'longitude': -93.2054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71461', 'place_name': 'New Llano', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.1149, 'longitude': -93.2716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71474', 'place_name': 'Simpson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.257, 'longitude': -93.017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71475', 'place_name': 'Slagle', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.2024, 'longitude': -93.1274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71496', 'place_name': 'Leesville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Vernon', 'locality_code': '115', 'latitude': 31.1435, 'longitude': -93.261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70426', 'place_name': 'Angie', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Washington', 'locality_code': '117', 'latitude': 30.9224, 'longitude': -89.8567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70427', 'place_name': 'Bogalusa', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Washington', 'locality_code': '117', 'latitude': 30.7733, 'longitude': -89.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70429', 'place_name': 'Bogalusa', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Washington', 'locality_code': '117', 'latitude': 30.791, 'longitude': -89.8487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70438', 'place_name': 'Franklinton', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Washington', 'locality_code': '117', 'latitude': 30.8577, 'longitude': -90.1155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70450', 'place_name': 'Mount Hermon', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Washington', 'locality_code': '117', 'latitude': 30.9536, 'longitude': -90.2769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70467', 'place_name': 'Varnado', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Washington', 'locality_code': '117', 'latitude': 30.8938, 'longitude': -89.8295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71018', 'place_name': 'Cotton Valley', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.819, 'longitude': -93.4259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71021', 'place_name': 'Cullen', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.9721, 'longitude': -93.4492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71023', 'place_name': 'Doyline', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.49, 'longitude': -93.3996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71024', 'place_name': 'Dubberly', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.5192, 'longitude': -93.2142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71039', 'place_name': 'Heflin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.447, 'longitude': -93.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71055', 'place_name': 'Minden', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.6323, 'longitude': -93.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71058', 'place_name': 'Minden', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.6154, 'longitude': -93.2868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71071', 'place_name': 'Sarepta', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.9434, 'longitude': -93.4404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71072', 'place_name': 'Shongaloo', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.9713, 'longitude': -93.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71073', 'place_name': 'Sibley', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 32.5095, 'longitude': -93.3009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71075', 'place_name': 'Springhill', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Webster', 'locality_code': '119', 'latitude': 33.0005, 'longitude': -93.4596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70710', 'place_name': 'Addis', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Baton Rouge', 'locality_code': '121', 'latitude': 30.3557, 'longitude': -91.2613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70719', 'place_name': 'Brusly', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Baton Rouge', 'locality_code': '121', 'latitude': 30.3877, 'longitude': -91.2526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70729', 'place_name': 'Erwinville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Baton Rouge', 'locality_code': '121', 'latitude': 30.548, 'longitude': -91.4187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70767', 'place_name': 'Port Allen', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Baton Rouge', 'locality_code': '121', 'latitude': 30.472, 'longitude': -91.2541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71237', 'place_name': 'Epps', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Carroll', 'locality_code': '123', 'latitude': 32.6161, 'longitude': -91.4913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71242', 'place_name': 'Forest', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Carroll', 'locality_code': '123', 'latitude': 32.8239, 'longitude': -91.3989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71253', 'place_name': 'Kilbourne', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Carroll', 'locality_code': '123', 'latitude': 32.9946, 'longitude': -91.3162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71263', 'place_name': 'Oak Grove', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Carroll', 'locality_code': '123', 'latitude': 32.8731, 'longitude': -91.4302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71266', 'place_name': 'Pioneer', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Carroll', 'locality_code': '123', 'latitude': 32.7154, 'longitude': -91.4648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70712', 'place_name': 'Angola', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Feliciana', 'locality_code': '125', 'latitude': 30.9656, 'longitude': -91.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70775', 'place_name': 'Saint Francisville', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Feliciana', 'locality_code': '125', 'latitude': 30.8694, 'longitude': -91.4186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70782', 'place_name': 'Tunica', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Feliciana', 'locality_code': '125', 'latitude': 30.9601, 'longitude': -91.5396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70784', 'place_name': 'Wakefield', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Feliciana', 'locality_code': '125', 'latitude': 30.9175, 'longitude': -91.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '70787', 'place_name': 'Weyanoke', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'West Feliciana', 'locality_code': '125', 'latitude': 30.9468, 'longitude': -91.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71404', 'place_name': 'Atlanta', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Winn', 'locality_code': '127', 'latitude': 31.776, 'longitude': -92.7958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71410', 'place_name': 'Calvin', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Winn', 'locality_code': '127', 'latitude': 31.9657, 'longitude': -92.7757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71422', 'place_name': 'Dodson', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Winn', 'locality_code': '127', 'latitude': 32.0701, 'longitude': -92.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71440', 'place_name': 'Joyce', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Winn', 'locality_code': '127', 'latitude': 31.9393, 'longitude': -92.5988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71471', 'place_name': 'Saint Maurice', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Winn', 'locality_code': '127', 'latitude': 31.7596, 'longitude': -92.959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71473', 'place_name': 'Sikes', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Winn', 'locality_code': '127', 'latitude': 32.0686, 'longitude': -92.4429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '71483', 'place_name': 'Winnfield', 'state': 'Louisiana', 'state_ab': 'LA', 'county': 'Winn', 'locality_code': '127', 'latitude': 31.9214, 'longitude': -92.6366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2532', 'place_name': 'Buzzards Bay', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7455, 'longitude': -70.5905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2534', 'place_name': 'Cataumet', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6694, 'longitude': -70.6234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2536', 'place_name': 'East Falmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.5968, 'longitude': -70.5671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2537', 'place_name': 'East Sandwich', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7283, 'longitude': -70.44, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2540', 'place_name': 'Falmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.5648, 'longitude': -70.6217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2541', 'place_name': 'Falmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.5515, 'longitude': -70.6148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2542', 'place_name': 'Buzzards Bay', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6531, 'longitude': -70.5537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2543', 'place_name': 'Woods Hole', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.5263, 'longitude': -70.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2553', 'place_name': 'Monument Beach', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7196, 'longitude': -70.612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2556', 'place_name': 'North Falmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6417, 'longitude': -70.623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2559', 'place_name': 'Pocasset', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6881, 'longitude': -70.6105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2561', 'place_name': 'Sagamore', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7703, 'longitude': -70.5337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2562', 'place_name': 'Sagamore Beach', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7933, 'longitude': -70.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2563', 'place_name': 'Sandwich', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7113, 'longitude': -70.4775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2574', 'place_name': 'West Falmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6039, 'longitude': -70.6382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2601', 'place_name': 'Hyannis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6601, 'longitude': -70.2967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2630', 'place_name': 'Barnstable', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6983, 'longitude': -70.3001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2631', 'place_name': 'Brewster', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7492, 'longitude': -70.0699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2632', 'place_name': 'Centerville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6606, 'longitude': -70.3532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2633', 'place_name': 'Chatham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6889, 'longitude': -69.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2634', 'place_name': 'Centerville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6487, 'longitude': -70.3481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2635', 'place_name': 'Cotuit', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6243, 'longitude': -70.4364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2637', 'place_name': 'Cummaquid', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7014, 'longitude': -70.2772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2638', 'place_name': 'Dennis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7322, 'longitude': -70.1911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2639', 'place_name': 'Dennis Port', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6649, 'longitude': -70.1327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2641', 'place_name': 'East Dennis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7426, 'longitude': -70.162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2642', 'place_name': 'Eastham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.8408, 'longitude': -69.9849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2643', 'place_name': 'East Orleans', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7843, 'longitude': -69.962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2644', 'place_name': 'Forestdale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6827, 'longitude': -70.5143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2645', 'place_name': 'Harwich', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7008, 'longitude': -70.0579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2646', 'place_name': 'Harwich Port', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6703, 'longitude': -70.0722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2647', 'place_name': 'Hyannis Port', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.635, 'longitude': -70.3063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2648', 'place_name': 'Marstons Mills', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6703, 'longitude': -70.4163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2649', 'place_name': 'Mashpee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6181, 'longitude': -70.4854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2650', 'place_name': 'North Chatham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.703, 'longitude': -69.9666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2651', 'place_name': 'North Eastham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.8243, 'longitude': -69.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2652', 'place_name': 'North Truro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 42.0338, 'longitude': -70.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2653', 'place_name': 'Orleans', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7792, 'longitude': -69.9822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2655', 'place_name': 'Osterville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.63, 'longitude': -70.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2657', 'place_name': 'Provincetown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 42.0534, 'longitude': -70.1865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2659', 'place_name': 'South Chatham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6801, 'longitude': -70.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2660', 'place_name': 'South Dennis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7097, 'longitude': -70.1585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2661', 'place_name': 'South Harwich', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6862, 'longitude': -70.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2662', 'place_name': 'South Orleans', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7567, 'longitude': -69.9841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2663', 'place_name': 'South Wellfleet', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.9182, 'longitude': -69.9953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2664', 'place_name': 'South Yarmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6739, 'longitude': -70.1949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2666', 'place_name': 'Truro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.9988, 'longitude': -70.0564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2667', 'place_name': 'Wellfleet', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.9289, 'longitude': -70.0186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2668', 'place_name': 'West Barnstable', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7002, 'longitude': -70.372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2669', 'place_name': 'West Chatham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6812, 'longitude': -69.9911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2670', 'place_name': 'West Dennis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6626, 'longitude': -70.1681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2671', 'place_name': 'West Harwich', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6694, 'longitude': -70.1135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2672', 'place_name': 'West Hyannisport', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6356, 'longitude': -70.3233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2673', 'place_name': 'West Yarmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.6614, 'longitude': -70.2363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2675', 'place_name': 'Yarmouth Port', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Barnstable', 'locality_code': '1', 'latitude': 41.7051, 'longitude': -70.227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1029', 'place_name': 'East Otis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1909, 'longitude': -73.0517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1201', 'place_name': 'Pittsfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.4531, 'longitude': -73.2471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1202', 'place_name': 'Pittsfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3929, 'longitude': -73.2285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1203', 'place_name': 'Pittsfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3929, 'longitude': -73.2285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1220', 'place_name': 'Adams', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.6223, 'longitude': -73.1172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1222', 'place_name': 'Ashley Falls', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.0596, 'longitude': -73.3202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1223', 'place_name': 'Becket', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3594, 'longitude': -73.1203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1224', 'place_name': 'Berkshire', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.5126, 'longitude': -73.1929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1225', 'place_name': 'Cheshire', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.5611, 'longitude': -73.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1226', 'place_name': 'Dalton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.475, 'longitude': -73.1603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1227', 'place_name': 'Dalton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.4737, 'longitude': -73.1662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1229', 'place_name': 'Glendale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.2793, 'longitude': -73.3435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1230', 'place_name': 'Great Barrington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1959, 'longitude': -73.3607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1235', 'place_name': 'Hinsdale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.4298, 'longitude': -73.0724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1236', 'place_name': 'Housatonic', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.2653, 'longitude': -73.3745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1237', 'place_name': 'Lanesborough', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.5173, 'longitude': -73.2282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1238', 'place_name': 'Lee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.299, 'longitude': -73.2317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1240', 'place_name': 'Lenox', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3642, 'longitude': -73.2713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1242', 'place_name': 'Lenox Dale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3386, 'longitude': -73.2509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1244', 'place_name': 'Mill River', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1228, 'longitude': -73.254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1245', 'place_name': 'Monterey', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1867, 'longitude': -73.2065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1247', 'place_name': 'North Adams', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.6955, 'longitude': -73.08, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1252', 'place_name': 'North Egremont', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1986, 'longitude': -73.4462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1253', 'place_name': 'Otis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1931, 'longitude': -73.0918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1254', 'place_name': 'Richmond', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3784, 'longitude': -73.3645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1255', 'place_name': 'Sandisfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1094, 'longitude': -73.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1256', 'place_name': 'Savoy', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.577, 'longitude': -73.0233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1257', 'place_name': 'Sheffield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1001, 'longitude': -73.3611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1258', 'place_name': 'South Egremont', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.1012, 'longitude': -73.4566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1259', 'place_name': 'Southfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.078, 'longitude': -73.2609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1260', 'place_name': 'South Lee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.2779, 'longitude': -73.2773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1262', 'place_name': 'Stockbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.301, 'longitude': -73.3223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1263', 'place_name': 'Stockbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3929, 'longitude': -73.2285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1264', 'place_name': 'Tyringham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.22, 'longitude': -73.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1266', 'place_name': 'West Stockbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.3348, 'longitude': -73.3825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1267', 'place_name': 'Williamstown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.7089, 'longitude': -73.2036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1270', 'place_name': 'Windsor', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.515, 'longitude': -73.0412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1343', 'place_name': 'Drury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Berkshire', 'locality_code': '3', 'latitude': 42.6427, 'longitude': -72.9862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2048', 'place_name': 'Mansfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 42.0212, 'longitude': -71.2178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2334', 'place_name': 'Easton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 42.0235, 'longitude': -71.1324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2356', 'place_name': 'North Easton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 42.059, 'longitude': -71.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2357', 'place_name': 'North Easton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 42.0645, 'longitude': -71.0871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2375', 'place_name': 'South Easton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 42.0257, 'longitude': -71.0988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2702', 'place_name': 'Assonet', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7975, 'longitude': -71.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2703', 'place_name': 'Attleboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.9296, 'longitude': -71.3009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2712', 'place_name': 'Chartley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.9487, 'longitude': -71.2259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2714', 'place_name': 'Dartmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7562, 'longitude': -71.0671, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '2715', 'place_name': 'Dighton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.8125, 'longitude': -71.1427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2717', 'place_name': 'East Freetown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7635, 'longitude': -70.9677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2718', 'place_name': 'East Taunton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.8736, 'longitude': -71.0192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2719', 'place_name': 'Fairhaven', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6409, 'longitude': -70.8896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2720', 'place_name': 'Fall River', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7182, 'longitude': -71.14, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2721', 'place_name': 'Fall River', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6883, 'longitude': -71.1574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2722', 'place_name': 'Fall River', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7015, 'longitude': -71.155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2723', 'place_name': 'Fall River', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6926, 'longitude': -71.1332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2724', 'place_name': 'Fall River', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.685, 'longitude': -71.1748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2725', 'place_name': 'Somerset', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7223, 'longitude': -71.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2726', 'place_name': 'Somerset', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.756, 'longitude': -71.1492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2740', 'place_name': 'New Bedford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6347, 'longitude': -70.9372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2741', 'place_name': 'New Bedford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6362, 'longitude': -70.9342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2742', 'place_name': 'New Bedford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6362, 'longitude': -70.9342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2743', 'place_name': 'Acushnet', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6997, 'longitude': -70.9087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2744', 'place_name': 'New Bedford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6127, 'longitude': -70.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2745', 'place_name': 'New Bedford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6913, 'longitude': -70.9355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2746', 'place_name': 'New Bedford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.66, 'longitude': -70.9324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2747', 'place_name': 'North Dartmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6338, 'longitude': -70.9958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2748', 'place_name': 'South Dartmouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.5665, 'longitude': -70.9843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2760', 'place_name': 'North Attleboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.9775, 'longitude': -71.3298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2761', 'place_name': 'North Attleboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.9834, 'longitude': -71.3328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2763', 'place_name': 'Attleboro Falls', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.9726, 'longitude': -71.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2764', 'place_name': 'North Dighton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.8529, 'longitude': -71.1485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2766', 'place_name': 'Norton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.9718, 'longitude': -71.1894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2767', 'place_name': 'Raynham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.9324, 'longitude': -71.0469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2768', 'place_name': 'Raynham Center', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7562, 'longitude': -71.0671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2769', 'place_name': 'Rehoboth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.8515, 'longitude': -71.2545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2771', 'place_name': 'Seekonk', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.8378, 'longitude': -71.3224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2777', 'place_name': 'Swansea', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7473, 'longitude': -71.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2779', 'place_name': 'Berkley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.8353, 'longitude': -71.0765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2780', 'place_name': 'Taunton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.905, 'longitude': -71.1026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2783', 'place_name': 'Taunton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.7562, 'longitude': -71.0671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2790', 'place_name': 'Westport', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.6211, 'longitude': -71.089, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '2791', 'place_name': 'Westport Point', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Bristol', 'locality_code': '5', 'latitude': 41.5223, 'longitude': -71.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2535', 'place_name': 'Chilmark', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Dukes', 'locality_code': '7', 'latitude': 41.3575, 'longitude': -70.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2539', 'place_name': 'Edgartown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Dukes', 'locality_code': '7', 'latitude': 41.3889, 'longitude': -70.5339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2552', 'place_name': 'Menemsha', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Dukes', 'locality_code': '7', 'latitude': 41.3798, 'longitude': -70.6431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2557', 'place_name': 'Oak Bluffs', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Dukes', 'locality_code': '7', 'latitude': 41.4543, 'longitude': -70.562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2568', 'place_name': 'Vineyard Haven', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Dukes', 'locality_code': '7', 'latitude': 41.45, 'longitude': -70.5937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2575', 'place_name': 'West Tisbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Dukes', 'locality_code': '7', 'latitude': 41.4213, 'longitude': -70.6428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2713', 'place_name': 'Cuttyhunk', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Dukes', 'locality_code': '7', 'latitude': 41.4218, 'longitude': -70.9313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1810', 'place_name': 'Andover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6496, 'longitude': -71.1565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1812', 'place_name': 'Andover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6472, 'longitude': -71.1842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1830', 'place_name': 'Haverhill', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7856, 'longitude': -71.0721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1831', 'place_name': 'Haverhill', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7711, 'longitude': -71.1221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1832', 'place_name': 'Haverhill', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7792, 'longitude': -71.1095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1833', 'place_name': 'Georgetown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7281, 'longitude': -70.9822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1834', 'place_name': 'Groveland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.753, 'longitude': -71.027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1835', 'place_name': 'Haverhill', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7528, 'longitude': -71.0843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1840', 'place_name': 'Lawrence', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.708, 'longitude': -71.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1841', 'place_name': 'Lawrence', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7115, 'longitude': -71.167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1842', 'place_name': 'Lawrence', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.707, 'longitude': -71.1631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1843', 'place_name': 'Lawrence', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6911, 'longitude': -71.1605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1844', 'place_name': 'Methuen', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.728, 'longitude': -71.181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1845', 'place_name': 'North Andover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6826, 'longitude': -71.109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1860', 'place_name': 'Merrimac', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.8346, 'longitude': -71.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1885', 'place_name': 'West Boxford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.707, 'longitude': -71.0639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1899', 'place_name': 'Andover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6584, 'longitude': -71.137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1901', 'place_name': 'Lynn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4612, 'longitude': -70.9467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1902', 'place_name': 'Lynn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4698, 'longitude': -70.942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1903', 'place_name': 'Lynn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4668, 'longitude': -70.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1904', 'place_name': 'Lynn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4889, 'longitude': -70.9647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1905', 'place_name': 'Lynn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4694, 'longitude': -70.9728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1906', 'place_name': 'Saugus', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4633, 'longitude': -71.0111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1907', 'place_name': 'Swampscott', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4746, 'longitude': -70.9098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1908', 'place_name': 'Nahant', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4261, 'longitude': -70.9277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1910', 'place_name': 'Lynn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4548, 'longitude': -70.9747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1913', 'place_name': 'Amesbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.8559, 'longitude': -70.9367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1915', 'place_name': 'Beverly', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5608, 'longitude': -70.8759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1921', 'place_name': 'Boxford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6797, 'longitude': -71.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1922', 'place_name': 'Byfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7568, 'longitude': -70.9351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1923', 'place_name': 'Danvers', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5694, 'longitude': -70.9425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1929', 'place_name': 'Essex', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6286, 'longitude': -70.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1930', 'place_name': 'Gloucester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6208, 'longitude': -70.6721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1931', 'place_name': 'Gloucester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6159, 'longitude': -70.662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1936', 'place_name': 'Hamilton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6354, 'longitude': -70.8791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1937', 'place_name': 'Hathorne', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5862, 'longitude': -70.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1938', 'place_name': 'Ipswich', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6809, 'longitude': -70.8494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1940', 'place_name': 'Lynnfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5327, 'longitude': -71.0339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1944', 'place_name': 'Manchester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5796, 'longitude': -70.7674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1945', 'place_name': 'Marblehead', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.4984, 'longitude': -70.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1949', 'place_name': 'Middleton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5942, 'longitude': -71.013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1950', 'place_name': 'Newburyport', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.813, 'longitude': -70.8847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1951', 'place_name': 'Newbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7835, 'longitude': -70.8474, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '1952', 'place_name': 'Salisbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.8507, 'longitude': -70.8588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1960', 'place_name': 'Peabody', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5326, 'longitude': -70.9612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1961', 'place_name': 'Peabody', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6354, 'longitude': -70.8791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1965', 'place_name': 'Prides Crossing', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5581, 'longitude': -70.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1966', 'place_name': 'Rockport', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.658, 'longitude': -70.6194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1969', 'place_name': 'Rowley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7138, 'longitude': -70.907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1970', 'place_name': 'Salem', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.5151, 'longitude': -70.9003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1971', 'place_name': 'Salem', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6354, 'longitude': -70.8791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1982', 'place_name': 'South Hamilton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6185, 'longitude': -70.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1983', 'place_name': 'Topsfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6415, 'longitude': -70.9488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1984', 'place_name': 'Wenham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6017, 'longitude': -70.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1985', 'place_name': 'West Newbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.7949, 'longitude': -70.9778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5501', 'place_name': 'Andover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6472, 'longitude': -71.1842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5544', 'place_name': 'Andover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Essex', 'locality_code': '9', 'latitude': 42.6472, 'longitude': -71.1842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1054', 'place_name': 'Leverett', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.4682, 'longitude': -72.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1072', 'place_name': 'Shutesbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.482, 'longitude': -72.4213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1093', 'place_name': 'Whately', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.4427, 'longitude': -72.6525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1301', 'place_name': 'Greenfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6013, 'longitude': -72.6236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1302', 'place_name': 'Greenfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5222, 'longitude': -72.6242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1330', 'place_name': 'Ashfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5232, 'longitude': -72.811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1337', 'place_name': 'Bernardston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6952, 'longitude': -72.5772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1338', 'place_name': 'Buckland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5736, 'longitude': -72.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1339', 'place_name': 'Charlemont', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.608, 'longitude': -72.8901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1340', 'place_name': 'Colrain', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.679, 'longitude': -72.7265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1341', 'place_name': 'Conway', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5138, 'longitude': -72.7025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1342', 'place_name': 'Deerfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5406, 'longitude': -72.6072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1344', 'place_name': 'Erving', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6076, 'longitude': -72.4292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1346', 'place_name': 'Heath', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6853, 'longitude': -72.8391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1347', 'place_name': 'Lake Pleasant', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5566, 'longitude': -72.5181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1349', 'place_name': 'Millers Falls', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.582, 'longitude': -72.4926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1350', 'place_name': 'Monroe Bridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.7215, 'longitude': -72.9762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1351', 'place_name': 'Montague', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5429, 'longitude': -72.5328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1354', 'place_name': 'Gill', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6404, 'longitude': -72.4995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1355', 'place_name': 'New Salem', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5146, 'longitude': -72.3062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1360', 'place_name': 'Northfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6887, 'longitude': -72.451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1364', 'place_name': 'Orange', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6129, 'longitude': -72.2924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1367', 'place_name': 'Rowe', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6953, 'longitude': -72.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1370', 'place_name': 'Shelburne Falls', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6022, 'longitude': -72.7391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1373', 'place_name': 'South Deerfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.4756, 'longitude': -72.6153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1375', 'place_name': 'Sunderland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.4539, 'longitude': -72.5676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1376', 'place_name': 'Turners Falls', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5954, 'longitude': -72.5557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1378', 'place_name': 'Warwick', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.6671, 'longitude': -72.3397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1379', 'place_name': 'Wendell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5656, 'longitude': -72.4009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1380', 'place_name': 'Wendell Depot', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Franklin', 'locality_code': '11', 'latitude': 42.5534, 'longitude': -72.3927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1001', 'place_name': 'Agawam', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0702, 'longitude': -72.6227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1008', 'place_name': 'Blandford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1829, 'longitude': -72.9361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1009', 'place_name': 'Bondsville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.2061, 'longitude': -72.3405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1010', 'place_name': 'Brimfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1165, 'longitude': -72.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1011', 'place_name': 'Chester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.2794, 'longitude': -72.9888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1013', 'place_name': 'Chicopee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1487, 'longitude': -72.6079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1014', 'place_name': 'Chicopee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1020', 'place_name': 'Chicopee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1764, 'longitude': -72.5761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1021', 'place_name': 'Chicopee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1022', 'place_name': 'Chicopee', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1934, 'longitude': -72.5544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1028', 'place_name': 'East Longmeadow', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0672, 'longitude': -72.5056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1030', 'place_name': 'Feeding Hills', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0718, 'longitude': -72.6751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1034', 'place_name': 'Granville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1127, 'longitude': -72.952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1036', 'place_name': 'Hampden', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0648, 'longitude': -72.4318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1040', 'place_name': 'Holyoke', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.202, 'longitude': -72.6262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1041', 'place_name': 'Holyoke', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.2043, 'longitude': -72.6162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1056', 'place_name': 'Ludlow', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1728, 'longitude': -72.471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1057', 'place_name': 'Monson', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.101, 'longitude': -72.3196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1069', 'place_name': 'Palmer', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1762, 'longitude': -72.3288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1071', 'place_name': 'Russell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1471, 'longitude': -72.8403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1077', 'place_name': 'Southwick', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0511, 'longitude': -72.7706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1079', 'place_name': 'Thorndike', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1929, 'longitude': -72.3296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1080', 'place_name': 'Three Rivers', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1819, 'longitude': -72.3624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1081', 'place_name': 'Wales', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0627, 'longitude': -72.2046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1085', 'place_name': 'Westfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1251, 'longitude': -72.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1086', 'place_name': 'Westfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1734, 'longitude': -72.848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1089', 'place_name': 'West Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1151, 'longitude': -72.6411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1090', 'place_name': 'West Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1095', 'place_name': 'Wilbraham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1245, 'longitude': -72.4464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1097', 'place_name': 'Woronoco', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.164, 'longitude': -72.8295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1101', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1015, 'longitude': -72.5898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1102', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1103', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1029, 'longitude': -72.5887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1104', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1288, 'longitude': -72.5778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1105', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0999, 'longitude': -72.5783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1106', 'place_name': 'Longmeadow', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0507, 'longitude': -72.5676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1107', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1179, 'longitude': -72.6065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1108', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0853, 'longitude': -72.5584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1109', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1145, 'longitude': -72.5543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1111', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1115', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1029, 'longitude': -72.5916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1116', 'place_name': 'Longmeadow', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1118', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0929, 'longitude': -72.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1119', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1247, 'longitude': -72.5121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1128', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0944, 'longitude': -72.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1129', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1223, 'longitude': -72.4876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1138', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1139', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1144', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1018, 'longitude': -72.5915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1151', 'place_name': 'Indian Orchard', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1532, 'longitude': -72.505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1152', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1707, 'longitude': -72.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1199', 'place_name': 'Springfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.1199, 'longitude': -72.605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1521', 'place_name': 'Holland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampden', 'locality_code': '13', 'latitude': 42.0403, 'longitude': -72.1544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1002', 'place_name': 'Amherst', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3671, 'longitude': -72.4646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1003', 'place_name': 'Amherst', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3919, 'longitude': -72.5248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1004', 'place_name': 'Amherst', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3845, 'longitude': -72.5132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1007', 'place_name': 'Belchertown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.2751, 'longitude': -72.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1012', 'place_name': 'Chesterfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3923, 'longitude': -72.8256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1026', 'place_name': 'Cummington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.4633, 'longitude': -72.9202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1027', 'place_name': 'Easthampton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.2668, 'longitude': -72.669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1032', 'place_name': 'Goshen', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.4404, 'longitude': -72.7995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1033', 'place_name': 'Granby', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.2557, 'longitude': -72.52, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1035', 'place_name': 'Hadley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3606, 'longitude': -72.5715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1038', 'place_name': 'Hatfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3844, 'longitude': -72.6167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1039', 'place_name': 'Haydenville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3818, 'longitude': -72.7032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1050', 'place_name': 'Huntington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.2653, 'longitude': -72.8733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1053', 'place_name': 'Leeds', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3543, 'longitude': -72.7034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1059', 'place_name': 'North Amherst', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.4104, 'longitude': -72.5309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1060', 'place_name': 'Northampton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3223, 'longitude': -72.6313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1061', 'place_name': 'Northampton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3696, 'longitude': -72.636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1062', 'place_name': 'Florence', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3219, 'longitude': -72.6928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1063', 'place_name': 'Northampton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3179, 'longitude': -72.6402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1066', 'place_name': 'North Hatfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.4112, 'longitude': -72.6223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1070', 'place_name': 'Plainfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.5144, 'longitude': -72.9183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1073', 'place_name': 'Southampton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.2247, 'longitude': -72.7194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1075', 'place_name': 'South Hadley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.2375, 'longitude': -72.5811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1082', 'place_name': 'Ware', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.2618, 'longitude': -72.2583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1084', 'place_name': 'West Chesterfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3903, 'longitude': -72.8709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1088', 'place_name': 'West Hatfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3906, 'longitude': -72.6469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1096', 'place_name': 'Williamsburg', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.4085, 'longitude': -72.778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1098', 'place_name': 'Worthington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3843, 'longitude': -72.9314, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '1243', 'place_name': 'Middlefield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Hampshire', 'locality_code': '15', 'latitude': 42.3561, 'longitude': -73.0104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1431', 'place_name': 'Ashby', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6745, 'longitude': -71.8174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1432', 'place_name': 'Ayer', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5591, 'longitude': -71.5788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1450', 'place_name': 'Groton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6124, 'longitude': -71.5584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1460', 'place_name': 'Littleton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5401, 'longitude': -71.4877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1463', 'place_name': 'Pepperell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6689, 'longitude': -71.5934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1464', 'place_name': 'Shirley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5734, 'longitude': -71.6483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1469', 'place_name': 'Townsend', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6525, 'longitude': -71.6896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1470', 'place_name': 'Groton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6112, 'longitude': -71.5745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1471', 'place_name': 'Groton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6112, 'longitude': -71.5745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1472', 'place_name': 'West Groton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6043, 'longitude': -71.6273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1474', 'place_name': 'West Townsend', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6678, 'longitude': -71.7522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1701', 'place_name': 'Framingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3007, 'longitude': -71.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1702', 'place_name': 'Framingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.2822, 'longitude': -71.4339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1703', 'place_name': 'Framingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4464, 'longitude': -71.4594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1704', 'place_name': 'Framingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4464, 'longitude': -71.4594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1705', 'place_name': 'Framingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4464, 'longitude': -71.4594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1718', 'place_name': 'Acton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4851, 'longitude': -71.4328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1719', 'place_name': 'Boxborough', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4884, 'longitude': -71.5178, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '1720', 'place_name': 'Acton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4751, 'longitude': -71.4483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1721', 'place_name': 'Ashland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.2539, 'longitude': -71.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1730', 'place_name': 'Bedford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4843, 'longitude': -71.2768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1731', 'place_name': 'Hanscom Afb', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4567, 'longitude': -71.2795, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '1741', 'place_name': 'Carlisle', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5286, 'longitude': -71.3519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1742', 'place_name': 'Concord', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4567, 'longitude': -71.3747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1746', 'place_name': 'Holliston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.2026, 'longitude': -71.4361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1748', 'place_name': 'Hopkinton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.219, 'longitude': -71.5302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1749', 'place_name': 'Hudson', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3918, 'longitude': -71.5609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1752', 'place_name': 'Marlborough', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3509, 'longitude': -71.5434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1754', 'place_name': 'Maynard', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4321, 'longitude': -71.455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1760', 'place_name': 'Natick', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.2875, 'longitude': -71.3574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1770', 'place_name': 'Sherborn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.2331, 'longitude': -71.3787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1773', 'place_name': 'Lincoln', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4217, 'longitude': -71.3137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1775', 'place_name': 'Stow', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4308, 'longitude': -71.515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1776', 'place_name': 'Sudbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3837, 'longitude': -71.4282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1778', 'place_name': 'Wayland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3486, 'longitude': -71.3588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1784', 'place_name': 'Woodville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.2376, 'longitude': -71.562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1801', 'place_name': 'Woburn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4829, 'longitude': -71.1574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1803', 'place_name': 'Burlington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5089, 'longitude': -71.2004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1805', 'place_name': 'Burlington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5048, 'longitude': -71.1956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1813', 'place_name': 'Woburn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4793, 'longitude': -71.1523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1815', 'place_name': 'Woburn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4793, 'longitude': -71.1523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1821', 'place_name': 'Billerica', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5519, 'longitude': -71.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1822', 'place_name': 'Billerica', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5584, 'longitude': -71.2689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1824', 'place_name': 'Chelmsford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5911, 'longitude': -71.3556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1826', 'place_name': 'Dracut', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6764, 'longitude': -71.3186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1827', 'place_name': 'Dunstable', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6739, 'longitude': -71.4952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1850', 'place_name': 'Lowell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.656, 'longitude': -71.3051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1851', 'place_name': 'Lowell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6315, 'longitude': -71.3329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1852', 'place_name': 'Lowell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6344, 'longitude': -71.2983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1853', 'place_name': 'Lowell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6334, 'longitude': -71.3162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1854', 'place_name': 'Lowell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6493, 'longitude': -71.3355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1862', 'place_name': 'North Billerica', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5757, 'longitude': -71.2902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1863', 'place_name': 'North Chelmsford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6347, 'longitude': -71.3908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1864', 'place_name': 'North Reading', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5819, 'longitude': -71.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1865', 'place_name': 'Nutting Lake', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5379, 'longitude': -71.2689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1866', 'place_name': 'Pinehurst', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5293, 'longitude': -71.2281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1867', 'place_name': 'Reading', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.528, 'longitude': -71.109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1876', 'place_name': 'Tewksbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6028, 'longitude': -71.2232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1879', 'place_name': 'Tyngsboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.6724, 'longitude': -71.4158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1880', 'place_name': 'Wakefield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5009, 'longitude': -71.0685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1886', 'place_name': 'Westford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5864, 'longitude': -71.4401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1887', 'place_name': 'Wilmington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5581, 'longitude': -71.1723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1888', 'place_name': 'Woburn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4793, 'longitude': -71.1523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1889', 'place_name': 'North Reading', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.5716, 'longitude': -71.1096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1890', 'place_name': 'Winchester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.453, 'longitude': -71.1441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2138', 'place_name': 'Cambridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.377, 'longitude': -71.1256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2139', 'place_name': 'Cambridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3647, 'longitude': -71.1042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2140', 'place_name': 'Cambridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3932, 'longitude': -71.1338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2141', 'place_name': 'Cambridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3687, 'longitude': -71.0836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2142', 'place_name': 'Cambridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.362, 'longitude': -71.083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2143', 'place_name': 'Somerville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3829, 'longitude': -71.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2144', 'place_name': 'Somerville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4003, 'longitude': -71.1221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2145', 'place_name': 'Somerville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3907, 'longitude': -71.0929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2148', 'place_name': 'Malden', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4291, 'longitude': -71.0605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2149', 'place_name': 'Everett', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4112, 'longitude': -71.0514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2153', 'place_name': 'Medford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4184, 'longitude': -71.1062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2155', 'place_name': 'Medford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4173, 'longitude': -71.1087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2156', 'place_name': 'West Medford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4223, 'longitude': -71.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2176', 'place_name': 'Melrose', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4581, 'longitude': -71.0632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2180', 'place_name': 'Stoneham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4828, 'longitude': -71.0978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2212', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2238', 'place_name': 'Cambridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3751, 'longitude': -71.1056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2420', 'place_name': 'Lexington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4563, 'longitude': -71.2167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2421', 'place_name': 'Lexington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4426, 'longitude': -71.2265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2451', 'place_name': 'Waltham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3986, 'longitude': -71.2451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2452', 'place_name': 'Waltham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3943, 'longitude': -71.218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2453', 'place_name': 'Waltham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3654, 'longitude': -71.2317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2454', 'place_name': 'Waltham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3567, 'longitude': -71.2505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2455', 'place_name': 'North Waltham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3621, 'longitude': -71.2055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2456', 'place_name': 'New Town', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4464, 'longitude': -71.4594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2458', 'place_name': 'Newton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3528, 'longitude': -71.1875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2459', 'place_name': 'Newton Center', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3341, 'longitude': -71.1833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2460', 'place_name': 'Newtonville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.352, 'longitude': -71.2084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2461', 'place_name': 'Newton Highlands', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3168, 'longitude': -71.2084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2462', 'place_name': 'Newton Lower Falls', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3299, 'longitude': -71.2562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2464', 'place_name': 'Newton Upper Falls', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3129, 'longitude': -71.2195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2465', 'place_name': 'West Newton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3492, 'longitude': -71.2267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2466', 'place_name': 'Auburndale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3441, 'longitude': -71.248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2467', 'place_name': 'Chestnut Hill', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3164, 'longitude': -71.1612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2468', 'place_name': 'Waban', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3271, 'longitude': -71.2315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2471', 'place_name': 'Watertown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3709, 'longitude': -71.1828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2472', 'place_name': 'Watertown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.37, 'longitude': -71.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2474', 'place_name': 'Arlington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4202, 'longitude': -71.1565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2475', 'place_name': 'Arlington Heights', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4204, 'longitude': -71.1801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2476', 'place_name': 'Arlington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.4162, 'longitude': -71.1752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2477', 'place_name': 'Watertown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3709, 'longitude': -71.1828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2478', 'place_name': 'Belmont', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3959, 'longitude': -71.1787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2479', 'place_name': 'Waverley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3876, 'longitude': -71.1828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2493', 'place_name': 'Weston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3589, 'longitude': -71.3001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2495', 'place_name': 'Nonantum', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Middlesex', 'locality_code': '17', 'latitude': 42.3626, 'longitude': -71.2023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2554', 'place_name': 'Nantucket', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Nantucket', 'locality_code': '19', 'latitude': 41.2725, 'longitude': -70.0932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2564', 'place_name': 'Siasconset', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Nantucket', 'locality_code': '19', 'latitude': 41.2639, 'longitude': -69.9626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2584', 'place_name': 'Nantucket', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Nantucket', 'locality_code': '19', 'latitude': 41.2778, 'longitude': -70.046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2019', 'place_name': 'Bellingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.0746, 'longitude': -71.4768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2021', 'place_name': 'Canton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1645, 'longitude': -71.1355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2025', 'place_name': 'Cohasset', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2395, 'longitude': -70.8128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2026', 'place_name': 'Dedham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2437, 'longitude': -71.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2027', 'place_name': 'Dedham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.18, 'longitude': -71.0892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2030', 'place_name': 'Dover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2362, 'longitude': -71.2854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2032', 'place_name': 'East Walpole', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1532, 'longitude': -71.2179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2035', 'place_name': 'Foxboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.0649, 'longitude': -71.2441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2038', 'place_name': 'Franklin', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.0935, 'longitude': -71.4058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2052', 'place_name': 'Medfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1845, 'longitude': -71.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2053', 'place_name': 'Medway', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1514, 'longitude': -71.4217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2054', 'place_name': 'Millis', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1669, 'longitude': -71.3607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2056', 'place_name': 'Norfolk', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1177, 'longitude': -71.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2062', 'place_name': 'Norwood', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1868, 'longitude': -71.2033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2067', 'place_name': 'Sharon', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1094, 'longitude': -71.1759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2070', 'place_name': 'Sheldonville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.0348, 'longitude': -71.387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2071', 'place_name': 'South Walpole', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.0992, 'longitude': -71.2752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2072', 'place_name': 'Stoughton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1253, 'longitude': -71.1074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2081', 'place_name': 'Walpole', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1444, 'longitude': -71.2544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2090', 'place_name': 'Westwood', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2148, 'longitude': -71.2104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2093', 'place_name': 'Wrentham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.0617, 'longitude': -71.3396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2169', 'place_name': 'Quincy', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2491, 'longitude': -70.9978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2170', 'place_name': 'Quincy', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2671, 'longitude': -71.0186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2171', 'place_name': 'Quincy', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2825, 'longitude': -71.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2184', 'place_name': 'Braintree', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2093, 'longitude': -70.9963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2185', 'place_name': 'Braintree', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.18, 'longitude': -71.0892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2186', 'place_name': 'Milton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2537, 'longitude': -71.0771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2187', 'place_name': 'Milton Village', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2668, 'longitude': -71.0717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2188', 'place_name': 'Weymouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2113, 'longitude': -70.9582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2189', 'place_name': 'East Weymouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.214, 'longitude': -70.9203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2190', 'place_name': 'South Weymouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1751, 'longitude': -70.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2191', 'place_name': 'North Weymouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2459, 'longitude': -70.9467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2269', 'place_name': 'Quincy', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2529, 'longitude': -71.0023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2322', 'place_name': 'Avon', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1258, 'longitude': -71.0437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2343', 'place_name': 'Holbrook', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1464, 'longitude': -71.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2368', 'place_name': 'Randolph', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.1736, 'longitude': -71.0514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2445', 'place_name': 'Brookline', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.3259, 'longitude': -71.1341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2446', 'place_name': 'Brookline', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.3431, 'longitude': -71.123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2447', 'place_name': 'Brookline Village', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.3329, 'longitude': -71.1162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2457', 'place_name': 'Babson Park', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2987, 'longitude': -71.2595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2481', 'place_name': 'Wellesley Hills', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.3106, 'longitude': -71.2747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2482', 'place_name': 'Wellesley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2945, 'longitude': -71.2992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2492', 'place_name': 'Needham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2798, 'longitude': -71.2501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2494', 'place_name': 'Needham Heights', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.2945, 'longitude': -71.2328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2762', 'place_name': 'Plainville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Norfolk', 'locality_code': '21', 'latitude': 42.0124, 'longitude': -71.3275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2018', 'place_name': 'Accord', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1745, 'longitude': -70.8837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2020', 'place_name': 'Brant Rock', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0818, 'longitude': -70.6439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2040', 'place_name': 'Greenbush', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1793, 'longitude': -70.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2041', 'place_name': 'Green Harbor', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0696, 'longitude': -70.6491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2043', 'place_name': 'Hingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.2245, 'longitude': -70.8911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2044', 'place_name': 'Hingham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.2418, 'longitude': -70.8898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2045', 'place_name': 'Hull', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.2853, 'longitude': -70.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2047', 'place_name': 'Humarock', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1428, 'longitude': -70.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2050', 'place_name': 'Marshfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1062, 'longitude': -70.6993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2051', 'place_name': 'Marshfield Hills', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1512, 'longitude': -70.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2055', 'place_name': 'Minot', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.2404, 'longitude': -70.762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2059', 'place_name': 'North Marshfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1432, 'longitude': -70.7703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2060', 'place_name': 'North Scituate', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.219, 'longitude': -70.7856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2061', 'place_name': 'Norwell', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1596, 'longitude': -70.8217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2065', 'place_name': 'Ocean Bluff', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0972, 'longitude': -70.6516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2066', 'place_name': 'Scituate', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.2032, 'longitude': -70.7525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2301', 'place_name': 'Brockton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0794, 'longitude': -71.04, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2302', 'place_name': 'Brockton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0847, 'longitude': -71.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2303', 'place_name': 'Brockton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0834, 'longitude': -71.0184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2304', 'place_name': 'Brockton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0834, 'longitude': -71.0184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2305', 'place_name': 'Brockton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0834, 'longitude': -71.0184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2324', 'place_name': 'Bridgewater', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9773, 'longitude': -70.9723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2325', 'place_name': 'Bridgewater', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9873, 'longitude': -70.9728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2327', 'place_name': 'Bryantville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0407, 'longitude': -70.8272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2330', 'place_name': 'Carver', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8883, 'longitude': -70.7678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2331', 'place_name': 'Duxbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9705, 'longitude': -70.7014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2332', 'place_name': 'Duxbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0399, 'longitude': -70.7163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2333', 'place_name': 'East Bridgewater', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0315, 'longitude': -70.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2337', 'place_name': 'Elmwood', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0098, 'longitude': -70.962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2338', 'place_name': 'Halifax', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0002, 'longitude': -70.8448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2339', 'place_name': 'Hanover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1214, 'longitude': -70.857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2340', 'place_name': 'Hanover', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1137, 'longitude': -70.8161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2341', 'place_name': 'Hanson', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0616, 'longitude': -70.8651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2344', 'place_name': 'Middleboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8932, 'longitude': -70.9112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2345', 'place_name': 'Manomet', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8882, 'longitude': -70.581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2346', 'place_name': 'Middleboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8884, 'longitude': -70.893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2347', 'place_name': 'Lakeville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8374, 'longitude': -70.9582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2348', 'place_name': 'Lakeville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8459, 'longitude': -70.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2349', 'place_name': 'Middleboro', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8932, 'longitude': -70.9112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2350', 'place_name': 'Monponsett', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0185, 'longitude': -70.8475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2351', 'place_name': 'Abington', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1167, 'longitude': -70.9543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2355', 'place_name': 'North Carver', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9169, 'longitude': -70.8013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2358', 'place_name': 'North Pembroke', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0932, 'longitude': -70.7925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2359', 'place_name': 'Pembroke', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0621, 'longitude': -70.8044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2360', 'place_name': 'Plymouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9104, 'longitude': -70.642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2361', 'place_name': 'Plymouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9705, 'longitude': -70.7014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2362', 'place_name': 'Plymouth', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9584, 'longitude': -70.6673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2364', 'place_name': 'Kingston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.995, 'longitude': -70.741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2366', 'place_name': 'South Carver', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.8501, 'longitude': -70.7044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2367', 'place_name': 'Plympton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9655, 'longitude': -70.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2370', 'place_name': 'Rockland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.1293, 'longitude': -70.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2379', 'place_name': 'West Bridgewater', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0255, 'longitude': -71.0161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2381', 'place_name': 'White Horse Beach', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.9316, 'longitude': -70.5611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2382', 'place_name': 'Whitman', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 42.0816, 'longitude': -70.9381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2538', 'place_name': 'East Wareham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.7682, 'longitude': -70.6532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2558', 'place_name': 'Onset', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.7476, 'longitude': -70.6582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2571', 'place_name': 'Wareham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.7541, 'longitude': -70.7116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2576', 'place_name': 'West Wareham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.7796, 'longitude': -70.7642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2738', 'place_name': 'Marion', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.7095, 'longitude': -70.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2739', 'place_name': 'Mattapoisett', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.6618, 'longitude': -70.8164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2770', 'place_name': 'Rochester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Plymouth', 'locality_code': '23', 'latitude': 41.7591, 'longitude': -70.8523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2108', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3576, 'longitude': -71.0684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2109', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.36, 'longitude': -71.0545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2110', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3576, 'longitude': -71.0514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2111', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3503, 'longitude': -71.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2112', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2113', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3657, 'longitude': -71.056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2114', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3611, 'longitude': -71.0682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2115', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3427, 'longitude': -71.0922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2116', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3492, 'longitude': -71.0768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2117', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3585, 'longitude': -71.058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2118', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3362, 'longitude': -71.0729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2119', 'place_name': 'Roxbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3251, 'longitude': -71.0953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2120', 'place_name': 'Roxbury Crossing', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3307, 'longitude': -71.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2121', 'place_name': 'Dorchester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2973, 'longitude': -71.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2122', 'place_name': 'Dorchester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2973, 'longitude': -71.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2123', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3389, 'longitude': -70.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2124', 'place_name': 'Dorchester Center', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2918, 'longitude': -71.0717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2125', 'place_name': 'Dorchester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2973, 'longitude': -71.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2126', 'place_name': 'Mattapan', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2739, 'longitude': -71.0939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2127', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3347, 'longitude': -71.0375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2128', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3642, 'longitude': -71.0257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2129', 'place_name': 'Charlestown', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3778, 'longitude': -71.0627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2130', 'place_name': 'Jamaica Plain', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3126, 'longitude': -71.1115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2131', 'place_name': 'Roslindale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2836, 'longitude': -71.1295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2132', 'place_name': 'West Roxbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2787, 'longitude': -71.1589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2133', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2134', 'place_name': 'Allston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3535, 'longitude': -71.1329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2135', 'place_name': 'Brighton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3478, 'longitude': -71.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2136', 'place_name': 'Hyde Park', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.254, 'longitude': -71.1261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2137', 'place_name': 'Readville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.2404, 'longitude': -71.137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2150', 'place_name': 'Chelsea', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3963, 'longitude': -71.0325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2151', 'place_name': 'Revere', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.4138, 'longitude': -71.0052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2152', 'place_name': 'Winthrop', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3763, 'longitude': -70.98, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2163', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3253, 'longitude': -71.1122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2196', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2199', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3479, 'longitude': -71.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2201', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2203', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3615, 'longitude': -71.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2204', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3389, 'longitude': -70.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2205', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3503, 'longitude': -71.0539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2206', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3389, 'longitude': -70.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2210', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3489, 'longitude': -71.0465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2211', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2215', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3471, 'longitude': -71.1027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2217', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3389, 'longitude': -70.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2222', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3644, 'longitude': -71.0633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2241', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2266', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2283', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3389, 'longitude': -70.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2284', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3389, 'longitude': -70.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2293', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2297', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3584, 'longitude': -71.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2298', 'place_name': 'Boston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Suffolk', 'locality_code': '25', 'latitude': 42.3823, 'longitude': -71.0323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1005', 'place_name': 'Barre', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4097, 'longitude': -72.1084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1031', 'place_name': 'Gilbertville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3322, 'longitude': -72.1986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1037', 'place_name': 'Hardwick', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3479, 'longitude': -72.2253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1068', 'place_name': 'Oakham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.348, 'longitude': -72.0513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1074', 'place_name': 'South Barre', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3854, 'longitude': -72.0954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1083', 'place_name': 'Warren', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.204, 'longitude': -72.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1092', 'place_name': 'West Warren', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2029, 'longitude': -72.229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1094', 'place_name': 'Wheelwright', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3582, 'longitude': -72.1408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1331', 'place_name': 'Athol', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5959, 'longitude': -72.2267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1366', 'place_name': 'Petersham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4898, 'longitude': -72.1893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1368', 'place_name': 'Royalston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.6722, 'longitude': -72.1964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1420', 'place_name': 'Fitchburg', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5796, 'longitude': -71.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1430', 'place_name': 'Ashburnham', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.6496, 'longitude': -71.9267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1434', 'place_name': 'Devens', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5385, 'longitude': -71.6115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1436', 'place_name': 'Baldwinville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5936, 'longitude': -72.0646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1438', 'place_name': 'East Templeton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5631, 'longitude': -72.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1440', 'place_name': 'Gardner', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.574, 'longitude': -71.9898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1441', 'place_name': 'Westminster', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5459, 'longitude': -71.9106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1451', 'place_name': 'Harvard', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4986, 'longitude': -71.5753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1452', 'place_name': 'Hubbardston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4865, 'longitude': -72.0012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1453', 'place_name': 'Leominster', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5274, 'longitude': -71.7563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1462', 'place_name': 'Lunenburg', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5884, 'longitude': -71.7266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1467', 'place_name': 'Still River', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4871, 'longitude': -71.6131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1468', 'place_name': 'Templeton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.546, 'longitude': -72.065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1473', 'place_name': 'Westminster', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.5483, 'longitude': -71.9096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1475', 'place_name': 'Winchendon', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.6789, 'longitude': -72.0475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1501', 'place_name': 'Auburn', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2055, 'longitude': -71.8391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1503', 'place_name': 'Berlin', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3844, 'longitude': -71.6356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1504', 'place_name': 'Blackstone', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0287, 'longitude': -71.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1505', 'place_name': 'Boylston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3377, 'longitude': -71.731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1506', 'place_name': 'Brookfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1991, 'longitude': -72.0989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1507', 'place_name': 'Charlton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1379, 'longitude': -71.9664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1508', 'place_name': 'Charlton City', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1459, 'longitude': -71.9884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1509', 'place_name': 'Charlton Depot', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1731, 'longitude': -71.9787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1510', 'place_name': 'Clinton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4181, 'longitude': -71.6828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1515', 'place_name': 'East Brookfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2193, 'longitude': -72.0481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1516', 'place_name': 'Douglas', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0528, 'longitude': -71.7509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1518', 'place_name': 'Fiskdale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1228, 'longitude': -72.1178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1519', 'place_name': 'Grafton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2004, 'longitude': -71.6868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1520', 'place_name': 'Holden', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.342, 'longitude': -71.8414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1522', 'place_name': 'Jefferson', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3755, 'longitude': -71.8706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1523', 'place_name': 'Lancaster', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.451, 'longitude': -71.6868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1524', 'place_name': 'Leicester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.237, 'longitude': -71.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1525', 'place_name': 'Linwood', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0973, 'longitude': -71.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1526', 'place_name': 'Manchaug', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0945, 'longitude': -71.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1527', 'place_name': 'Millbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1968, 'longitude': -71.7644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1529', 'place_name': 'Millville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0331, 'longitude': -71.5798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1531', 'place_name': 'New Braintree', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3198, 'longitude': -72.1306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1532', 'place_name': 'Northborough', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3182, 'longitude': -71.6464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1534', 'place_name': 'Northbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1494, 'longitude': -71.6564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1535', 'place_name': 'North Brookfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2665, 'longitude': -72.0821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1536', 'place_name': 'North Grafton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2297, 'longitude': -71.7037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1537', 'place_name': 'North Oxford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1655, 'longitude': -71.886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1538', 'place_name': 'North Uxbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0876, 'longitude': -71.6412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1540', 'place_name': 'Oxford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1129, 'longitude': -71.8687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1541', 'place_name': 'Princeton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4508, 'longitude': -71.8762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1542', 'place_name': 'Rochdale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1997, 'longitude': -71.9069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1543', 'place_name': 'Rutland', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3762, 'longitude': -71.949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1545', 'place_name': 'Shrewsbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2848, 'longitude': -71.7205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1546', 'place_name': 'Shrewsbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3648, 'longitude': -71.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1550', 'place_name': 'Southbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.075, 'longitude': -72.0353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1560', 'place_name': 'South Grafton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.176, 'longitude': -71.6927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1561', 'place_name': 'South Lancaster', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4435, 'longitude': -71.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1562', 'place_name': 'Spencer', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2441, 'longitude': -71.9906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1564', 'place_name': 'Sterling', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4354, 'longitude': -71.7752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1566', 'place_name': 'Sturbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1126, 'longitude': -72.0842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1568', 'place_name': 'Upton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1756, 'longitude': -71.6032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1569', 'place_name': 'Uxbridge', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0744, 'longitude': -71.6329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1570', 'place_name': 'Webster', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0521, 'longitude': -71.8486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1571', 'place_name': 'Dudley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0489, 'longitude': -71.8932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1581', 'place_name': 'Westborough', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2679, 'longitude': -71.6176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1583', 'place_name': 'West Boylston', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3584, 'longitude': -71.7838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1585', 'place_name': 'West Brookfield', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2441, 'longitude': -72.1511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1586', 'place_name': 'West Millbury', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1712, 'longitude': -71.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1588', 'place_name': 'Whitinsville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1153, 'longitude': -71.6644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1590', 'place_name': 'Sutton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1266, 'longitude': -71.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1601', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2626, 'longitude': -71.8023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1602', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2703, 'longitude': -71.8417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1603', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.245, 'longitude': -71.838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1604', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2541, 'longitude': -71.7746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1605', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2894, 'longitude': -71.7888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1606', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.311, 'longitude': -71.7958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1607', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2303, 'longitude': -71.7938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1608', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2624, 'longitude': -71.8003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1609', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2826, 'longitude': -71.8277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1610', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2492, 'longitude': -71.8108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1611', 'place_name': 'Cherry Valley', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2373, 'longitude': -71.875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1612', 'place_name': 'Paxton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3066, 'longitude': -71.9202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1613', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2933, 'longitude': -71.802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1614', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2626, 'longitude': -71.8023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1615', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2626, 'longitude': -71.8023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1653', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3648, 'longitude': -71.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1655', 'place_name': 'Worcester', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.3648, 'longitude': -71.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1740', 'place_name': 'Bolton', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.4365, 'longitude': -71.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1745', 'place_name': 'Fayville', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2934, 'longitude': -71.5028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1747', 'place_name': 'Hopedale', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1268, 'longitude': -71.5376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1756', 'place_name': 'Mendon', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.0967, 'longitude': -71.5499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1757', 'place_name': 'Milford', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.1511, 'longitude': -71.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '1772', 'place_name': 'Southborough', 'state': 'Massachusetts', 'state_ab': 'MA', 'county': 'Worcester', 'locality_code': '27', 'latitude': 42.2939, 'longitude': -71.532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21501', 'place_name': 'Cumberland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6529, 'longitude': -78.7625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21502', 'place_name': 'Cumberland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5992, 'longitude': -78.8444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21503', 'place_name': 'Cumberland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6529, 'longitude': -78.7625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21504', 'place_name': 'Cumberland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5807, 'longitude': -78.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21505', 'place_name': 'Cumberland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.594, 'longitude': -78.8434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21521', 'place_name': 'Barton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5331, 'longitude': -79.0281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21524', 'place_name': 'Corriganville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6967, 'longitude': -78.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21528', 'place_name': 'Eckhart Mines', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6528, 'longitude': -78.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21529', 'place_name': 'Ellerslie', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.7083, 'longitude': -78.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21530', 'place_name': 'Flintstone', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6993, 'longitude': -78.5739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21532', 'place_name': 'Frostburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6494, 'longitude': -78.9306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21539', 'place_name': 'Lonaconing', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5757, 'longitude': -78.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21540', 'place_name': 'Luke', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.4774, 'longitude': -79.0594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21542', 'place_name': 'Midland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5901, 'longitude': -78.9497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21543', 'place_name': 'Midlothian', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6343, 'longitude': -78.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21545', 'place_name': 'Mount Savage', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6991, 'longitude': -78.8739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21555', 'place_name': 'Oldtown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5846, 'longitude': -78.6044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21556', 'place_name': 'Pinto', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5725, 'longitude': -78.844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21557', 'place_name': 'Rawlings', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5214, 'longitude': -78.9062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21560', 'place_name': 'Spring Gap', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.5654, 'longitude': -78.7164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21562', 'place_name': 'Westernport', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.4905, 'longitude': -79.014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21766', 'place_name': 'Little Orleans', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Allegany', 'locality_code': '1', 'latitude': 39.6876, 'longitude': -78.3781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20711', 'place_name': 'Lothian', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.8029, 'longitude': -76.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20724', 'place_name': 'Laurel', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0958, 'longitude': -76.8155, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20733', 'place_name': 'Churchton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.8018, 'longitude': -76.5248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20751', 'place_name': 'Deale', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.7829, 'longitude': -76.5515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20755', 'place_name': 'Fort George G Meade', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1059, 'longitude': -76.7467, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20758', 'place_name': 'Friendship', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.7361, 'longitude': -76.5835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20764', 'place_name': 'Shady Side', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.8368, 'longitude': -76.5109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20765', 'place_name': 'Galesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.8446, 'longitude': -76.5456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20776', 'place_name': 'Harwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.8582, 'longitude': -76.6145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20778', 'place_name': 'West River', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.8252, 'longitude': -76.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20779', 'place_name': 'Tracys Landing', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.7671, 'longitude': -76.5752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21012', 'place_name': 'Arnold', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0476, 'longitude': -76.4941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21032', 'place_name': 'Crownsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0489, 'longitude': -76.5935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21035', 'place_name': 'Davidsonville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9374, 'longitude': -76.6375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21037', 'place_name': 'Edgewater', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9149, 'longitude': -76.5424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21054', 'place_name': 'Gambrills', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0407, 'longitude': -76.6819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21056', 'place_name': 'Gibson Island', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0751, 'longitude': -76.4324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21060', 'place_name': 'Glen Burnie', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1702, 'longitude': -76.5798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21061', 'place_name': 'Glen Burnie', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1618, 'longitude': -76.6297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21062', 'place_name': 'Glen Burnie', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9742, 'longitude': -76.5949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21076', 'place_name': 'Hanover', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1551, 'longitude': -76.7215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21077', 'place_name': 'Harmans', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1561, 'longitude': -76.6977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21090', 'place_name': 'Linthicum Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.2092, 'longitude': -76.6681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21106', 'place_name': 'Mayo', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.8876, 'longitude': -76.5119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21108', 'place_name': 'Millersville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1041, 'longitude': -76.619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21113', 'place_name': 'Odenton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0762, 'longitude': -76.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21114', 'place_name': 'Crofton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0112, 'longitude': -76.6802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21122', 'place_name': 'Pasadena', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1206, 'longitude': -76.495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21123', 'place_name': 'Pasadena', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9742, 'longitude': -76.5949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21140', 'place_name': 'Riva', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9504, 'longitude': -76.5854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21144', 'place_name': 'Severn', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1275, 'longitude': -76.698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21146', 'place_name': 'Severna Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0811, 'longitude': -76.5577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21225', 'place_name': 'Brooklyn', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.2259, 'longitude': -76.6153, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '21226', 'place_name': 'Curtis Bay', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.2109, 'longitude': -76.5597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21240', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.1753, 'longitude': -76.6732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21401', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9898, 'longitude': -76.5501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21402', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9871, 'longitude': -76.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21403', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9524, 'longitude': -76.491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21404', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9784, 'longitude': -76.4922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21405', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0305, 'longitude': -76.5515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21409', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 39.0416, 'longitude': -76.4377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21411', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9742, 'longitude': -76.5949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21412', 'place_name': 'Annapolis', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Anne Arundel', 'locality_code': '3', 'latitude': 38.9742, 'longitude': -76.5949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21013', 'place_name': 'Baldwin', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.5194, 'longitude': -76.4927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21020', 'place_name': 'Boring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.5213, 'longitude': -76.8047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21022', 'place_name': 'Brooklandville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3979, 'longitude': -76.6717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21023', 'place_name': 'Butler', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.533, 'longitude': -76.7432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21027', 'place_name': 'Chase', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3634, 'longitude': -76.3711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21030', 'place_name': 'Cockeysville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4919, 'longitude': -76.6677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21031', 'place_name': 'Hunt Valley', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4805, 'longitude': -76.6553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21051', 'place_name': 'Fork', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4731, 'longitude': -76.4484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21052', 'place_name': 'Fort Howard', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.207, 'longitude': -76.4456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21053', 'place_name': 'Freeland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.694, 'longitude': -76.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21057', 'place_name': 'Glen Arm', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4575, 'longitude': -76.5153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21065', 'place_name': 'Hunt Valley', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4883, 'longitude': -76.6538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21071', 'place_name': 'Glyndon', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.477, 'longitude': -76.815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21082', 'place_name': 'Hydes', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.474, 'longitude': -76.4695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21087', 'place_name': 'Kingsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4558, 'longitude': -76.4147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21092', 'place_name': 'Long Green', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4729, 'longitude': -76.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21093', 'place_name': 'Lutherville Timonium', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4332, 'longitude': -76.6546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21094', 'place_name': 'Lutherville Timonium', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.439, 'longitude': -76.5921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21105', 'place_name': 'Maryland Line', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.7114, 'longitude': -76.6595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21111', 'place_name': 'Monkton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.5662, 'longitude': -76.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21117', 'place_name': 'Owings Mills', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4269, 'longitude': -76.7769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21120', 'place_name': 'Parkton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.6422, 'longitude': -76.6737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21128', 'place_name': 'Perry Hall', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.401, 'longitude': -76.451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21131', 'place_name': 'Phoenix', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4833, 'longitude': -76.5776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21133', 'place_name': 'Randallstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3746, 'longitude': -76.8002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21136', 'place_name': 'Reisterstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.46, 'longitude': -76.8135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21139', 'place_name': 'Riderwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4093, 'longitude': -76.6486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21152', 'place_name': 'Sparks Glencoe', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.5483, 'longitude': -76.6819, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '21153', 'place_name': 'Stevenson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4104, 'longitude': -76.713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21155', 'place_name': 'Upperco', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.5676, 'longitude': -76.7972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21156', 'place_name': 'Upper Falls', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4372, 'longitude': -76.3966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21162', 'place_name': 'White Marsh', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3923, 'longitude': -76.4132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21163', 'place_name': 'Woodstock', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3498, 'longitude': -76.8456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21204', 'place_name': 'Towson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4072, 'longitude': -76.6038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21207', 'place_name': 'Gwynn Oak', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3296, 'longitude': -76.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21208', 'place_name': 'Pikesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3764, 'longitude': -76.729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21219', 'place_name': 'Sparrows Point', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.2296, 'longitude': -76.4455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21220', 'place_name': 'Middle River', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3401, 'longitude': -76.4153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21221', 'place_name': 'Essex', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3086, 'longitude': -76.4533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21222', 'place_name': 'Dundalk', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.2655, 'longitude': -76.4935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21227', 'place_name': 'Halethorpe', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.2309, 'longitude': -76.6969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21228', 'place_name': 'Catonsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.2782, 'longitude': -76.7401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21234', 'place_name': 'Parkville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3876, 'longitude': -76.5418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21236', 'place_name': 'Nottingham', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3914, 'longitude': -76.4871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21237', 'place_name': 'Rosedale', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3361, 'longitude': -76.5014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21244', 'place_name': 'Windsor Mill', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3331, 'longitude': -76.7849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21250', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.2582, 'longitude': -76.7131, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '21251', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.439, 'longitude': -76.5921, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '21252', 'place_name': 'Towson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4015, 'longitude': -76.6019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21282', 'place_name': 'Pikesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.3743, 'longitude': -76.7225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21284', 'place_name': 'Towson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4015, 'longitude': -76.6019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21285', 'place_name': 'Towson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4015, 'longitude': -76.6019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21286', 'place_name': 'Towson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore', 'locality_code': '5', 'latitude': 39.4143, 'longitude': -76.5761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20610', 'place_name': 'Barstow', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.5254, 'longitude': -76.6161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20615', 'place_name': 'Broomes Island', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.418, 'longitude': -76.5478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20629', 'place_name': 'Dowell', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.3364, 'longitude': -76.4524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20639', 'place_name': 'Huntingtown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.6095, 'longitude': -76.6003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20657', 'place_name': 'Lusby', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.3661, 'longitude': -76.4346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20676', 'place_name': 'Port Republic', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.4952, 'longitude': -76.5349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20678', 'place_name': 'Prince Frederick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.5336, 'longitude': -76.5955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20685', 'place_name': 'Saint Leonard', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.4501, 'longitude': -76.511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20688', 'place_name': 'Solomons', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.3293, 'longitude': -76.4651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20689', 'place_name': 'Sunderland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.649, 'longitude': -76.5767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20714', 'place_name': 'North Beach', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.7119, 'longitude': -76.5367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20732', 'place_name': 'Chesapeake Beach', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.6698, 'longitude': -76.5376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20736', 'place_name': 'Owings', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.6955, 'longitude': -76.6061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20754', 'place_name': 'Dunkirk', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Calvert', 'locality_code': '9', 'latitude': 38.7408, 'longitude': -76.6427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21609', 'place_name': 'Bethlehem', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 38.7406, 'longitude': -75.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21629', 'place_name': 'Denton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 38.8595, 'longitude': -75.8357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21632', 'place_name': 'Federalsburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 38.7147, 'longitude': -75.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21636', 'place_name': 'Goldsboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 39.023, 'longitude': -75.7926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21639', 'place_name': 'Greensboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 38.9616, 'longitude': -75.8059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21640', 'place_name': 'Henderson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 39.0672, 'longitude': -75.7948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21641', 'place_name': 'Hillsboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 38.9206, 'longitude': -75.9388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21649', 'place_name': 'Marydel', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 39.1082, 'longitude': -75.7622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21655', 'place_name': 'Preston', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 38.7465, 'longitude': -75.9163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21660', 'place_name': 'Ridgely', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 38.9568, 'longitude': -75.8848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21670', 'place_name': 'Templeville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Caroline', 'locality_code': '11', 'latitude': 39.1362, 'longitude': -75.766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21048', 'place_name': 'Finksburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.4991, 'longitude': -76.9101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21074', 'place_name': 'Hampstead', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.6146, 'longitude': -76.8644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21088', 'place_name': 'Lineboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.7187, 'longitude': -76.8439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21102', 'place_name': 'Manchester', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.6747, 'longitude': -76.8941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21104', 'place_name': 'Marriottsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.3342, 'longitude': -76.9132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21157', 'place_name': 'Westminster', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.5642, 'longitude': -76.9807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21158', 'place_name': 'Westminster', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.607, 'longitude': -77.0294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21757', 'place_name': 'Keymar', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.5656, 'longitude': -77.2817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21776', 'place_name': 'New Windsor', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.5162, 'longitude': -77.1034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21784', 'place_name': 'Sykesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.4567, 'longitude': -76.9696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21787', 'place_name': 'Taneytown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.6658, 'longitude': -77.1691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21791', 'place_name': 'Union Bridge', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.5799, 'longitude': -77.1319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21797', 'place_name': 'Woodbine', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Carroll', 'locality_code': '13', 'latitude': 39.3464, 'longitude': -77.0647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21901', 'place_name': 'North East', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6045, 'longitude': -75.9538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21902', 'place_name': 'Perry Point', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.553, 'longitude': -76.0725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21903', 'place_name': 'Perryville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.5649, 'longitude': -76.0592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21904', 'place_name': 'Port Deposit', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6151, 'longitude': -76.0633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21911', 'place_name': 'Rising Sun', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6882, 'longitude': -76.0492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21912', 'place_name': 'Warwick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.4283, 'longitude': -75.7996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21913', 'place_name': 'Cecilton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.4015, 'longitude': -75.8654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21914', 'place_name': 'Charlestown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.5729, 'longitude': -75.9795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21915', 'place_name': 'Chesapeake City', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.5133, 'longitude': -75.8406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21916', 'place_name': 'Childs', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6462, 'longitude': -75.8716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21917', 'place_name': 'Colora', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6695, 'longitude': -76.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21918', 'place_name': 'Conowingo', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6778, 'longitude': -76.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21919', 'place_name': 'Earleville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.4271, 'longitude': -75.9403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21920', 'place_name': 'Elk Mills', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.658, 'longitude': -75.8282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21921', 'place_name': 'Elkton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6264, 'longitude': -75.8458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21922', 'place_name': 'Elkton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.6068, 'longitude': -75.8333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21930', 'place_name': 'Georgetown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Cecil', 'locality_code': '15', 'latitude': 39.3662, 'longitude': -75.8845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20601', 'place_name': 'Waldorf', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.6371, 'longitude': -76.8778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20602', 'place_name': 'Waldorf', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.584, 'longitude': -76.8942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20603', 'place_name': 'Waldorf', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.6294, 'longitude': -76.9769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20604', 'place_name': 'Waldorf', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5095, 'longitude': -76.9817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20611', 'place_name': 'Bel Alton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.4731, 'longitude': -76.9789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20612', 'place_name': 'Benedict', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5093, 'longitude': -76.6797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20616', 'place_name': 'Bryans Road', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.6415, 'longitude': -77.0766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20617', 'place_name': 'Bryantown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5426, 'longitude': -76.8465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20625', 'place_name': 'Cobb Island', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.262, 'longitude': -76.8502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20632', 'place_name': 'Faulkner', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.4382, 'longitude': -76.9729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20637', 'place_name': 'Hughesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5207, 'longitude': -76.7817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20640', 'place_name': 'Indian Head', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.6001, 'longitude': -77.1622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20643', 'place_name': 'Ironsides', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5039, 'longitude': -77.1483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20645', 'place_name': 'Issue', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.2926, 'longitude': -76.9059, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20646', 'place_name': 'La Plata', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5257, 'longitude': -76.9865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20658', 'place_name': 'Marbury', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5633, 'longitude': -77.1596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20661', 'place_name': 'Mount Victoria', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.3436, 'longitude': -76.8846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20662', 'place_name': 'Nanjemoy', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.4462, 'longitude': -77.1983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20664', 'place_name': 'Newburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.3298, 'longitude': -76.9175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20675', 'place_name': 'Pomfret', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5855, 'longitude': -77.0093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20677', 'place_name': 'Port Tobacco', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.4994, 'longitude': -77.0419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20682', 'place_name': 'Rock Point', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.2836, 'longitude': -76.8481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20693', 'place_name': 'Welcome', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.4672, 'longitude': -77.095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20695', 'place_name': 'White Plains', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Charles', 'locality_code': '17', 'latitude': 38.5974, 'longitude': -76.9903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21613', 'place_name': 'Cambridge', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.5643, 'longitude': -76.0874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21622', 'place_name': 'Church Creek', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.4278, 'longitude': -76.1696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21626', 'place_name': 'Crapo', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.3295, 'longitude': -76.1142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21627', 'place_name': 'Crocheron', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.2426, 'longitude': -76.0531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21631', 'place_name': 'East New Market', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.5921, 'longitude': -75.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21634', 'place_name': 'Fishing Creek', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.3223, 'longitude': -76.2244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21643', 'place_name': 'Hurlock', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.6438, 'longitude': -75.863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21648', 'place_name': 'Madison', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.4782, 'longitude': -76.2412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21659', 'place_name': 'Rhodesdale', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.603, 'longitude': -75.7749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21664', 'place_name': 'Secretary', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.6093, 'longitude': -75.9474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21669', 'place_name': 'Taylors Island', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.4631, 'longitude': -76.2964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21672', 'place_name': 'Toddville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.2726, 'longitude': -76.0596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21675', 'place_name': 'Wingate', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.2899, 'longitude': -76.0863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21677', 'place_name': 'Woolford', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.5026, 'longitude': -76.1833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21835', 'place_name': 'Linkwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.5403, 'longitude': -75.963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21869', 'place_name': 'Vienna', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Dorchester', 'locality_code': '19', 'latitude': 38.4774, 'longitude': -75.8729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21701', 'place_name': 'Frederick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4461, 'longitude': -77.335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21702', 'place_name': 'Frederick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4926, 'longitude': -77.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21703', 'place_name': 'Frederick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3647, 'longitude': -77.4636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21704', 'place_name': 'Frederick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3455, 'longitude': -77.3832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21705', 'place_name': 'Frederick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4143, 'longitude': -77.4105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21709', 'place_name': 'Frederick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.47, 'longitude': -77.3921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21710', 'place_name': 'Adamstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.291, 'longitude': -77.4552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21714', 'place_name': 'Braddock Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4203, 'longitude': -77.5051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21716', 'place_name': 'Brunswick', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3164, 'longitude': -77.623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21717', 'place_name': 'Buckeystown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3309, 'longitude': -77.4274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21718', 'place_name': 'Burkittsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3923, 'longitude': -77.6275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21727', 'place_name': 'Emmitsburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.694, 'longitude': -77.3357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21754', 'place_name': 'Ijamsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3267, 'longitude': -77.2964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21755', 'place_name': 'Jefferson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3653, 'longitude': -77.5441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21758', 'place_name': 'Knoxville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3479, 'longitude': -77.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21759', 'place_name': 'Ladiesburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.5694, 'longitude': -77.2905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21762', 'place_name': 'Libertytown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4822, 'longitude': -77.2468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21769', 'place_name': 'Middletown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4416, 'longitude': -77.5502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21770', 'place_name': 'Monrovia', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3512, 'longitude': -77.2494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21771', 'place_name': 'Mount Airy', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.3881, 'longitude': -77.1723, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '21773', 'place_name': 'Myersville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.5282, 'longitude': -77.5513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21774', 'place_name': 'New Market', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4096, 'longitude': -77.2759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21775', 'place_name': 'New Midway', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.5645, 'longitude': -77.2947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21777', 'place_name': 'Point Of Rocks', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.2791, 'longitude': -77.5328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21778', 'place_name': 'Rocky Ridge', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.6057, 'longitude': -77.3296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21780', 'place_name': 'Sabillasville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.6828, 'longitude': -77.4693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21788', 'place_name': 'Thurmont', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.6109, 'longitude': -77.3989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21790', 'place_name': 'Tuscarora', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.2667, 'longitude': -77.5101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21792', 'place_name': 'Unionville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4748, 'longitude': -77.1855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21793', 'place_name': 'Walkersville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.4787, 'longitude': -77.3484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21798', 'place_name': 'Woodsboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Frederick', 'locality_code': '21', 'latitude': 39.5311, 'longitude': -77.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21520', 'place_name': 'Accident', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.6355, 'longitude': -79.3085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21522', 'place_name': 'Bittinger', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.6023, 'longitude': -79.2234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21523', 'place_name': 'Bloomington', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.4861, 'longitude': -79.083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21531', 'place_name': 'Friendsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.6665, 'longitude': -79.4219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21536', 'place_name': 'Grantsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.6551, 'longitude': -79.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21538', 'place_name': 'Kitzmiller', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.4169, 'longitude': -79.2222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21541', 'place_name': 'Mc Henry', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.5656, 'longitude': -79.3823, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '21550', 'place_name': 'Oakland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.4339, 'longitude': -79.3167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21561', 'place_name': 'Swanton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Garrett', 'locality_code': '23', 'latitude': 39.4764, 'longitude': -79.2402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21001', 'place_name': 'Aberdeen', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.5109, 'longitude': -76.1805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21005', 'place_name': 'Aberdeen Proving Ground', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.4771, 'longitude': -76.1208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21009', 'place_name': 'Abingdon', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.4744, 'longitude': -76.2997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21010', 'place_name': 'Gunpowder', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.3982, 'longitude': -76.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21014', 'place_name': 'Bel Air', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.5394, 'longitude': -76.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21015', 'place_name': 'Bel Air', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.5303, 'longitude': -76.3153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21017', 'place_name': 'Belcamp', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.4756, 'longitude': -76.242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21018', 'place_name': 'Benson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.5093, 'longitude': -76.3851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21028', 'place_name': 'Churchville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.5648, 'longitude': -76.249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21034', 'place_name': 'Darlington', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.654, 'longitude': -76.2278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21040', 'place_name': 'Edgewood', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.4277, 'longitude': -76.3055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21047', 'place_name': 'Fallston', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.527, 'longitude': -76.4328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21050', 'place_name': 'Forest Hill', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.5755, 'longitude': -76.4008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21078', 'place_name': 'Havre De Grace', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.5523, 'longitude': -76.1171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21084', 'place_name': 'Jarrettsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.6162, 'longitude': -76.4684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21085', 'place_name': 'Joppa', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.4242, 'longitude': -76.3541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21130', 'place_name': 'Perryman', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.4716, 'longitude': -76.2117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21132', 'place_name': 'Pylesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.6959, 'longitude': -76.4113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21154', 'place_name': 'Street', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.6574, 'longitude': -76.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21160', 'place_name': 'Whiteford', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.7077, 'longitude': -76.316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21161', 'place_name': 'White Hall', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Harford', 'locality_code': '25', 'latitude': 39.6618, 'longitude': -76.5666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20588', 'place_name': 'Dhs', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 38.7504, 'longitude': -76.8544, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20701', 'place_name': 'Annapolis Junction', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.1332, 'longitude': -76.7988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20723', 'place_name': 'Laurel', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.1208, 'longitude': -76.8435, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20759', 'place_name': 'Fulton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.1502, 'longitude': -76.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20763', 'place_name': 'Savage', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.138, 'longitude': -76.8218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20777', 'place_name': 'Highland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.1843, 'longitude': -76.9686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20794', 'place_name': 'Jessup', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.1484, 'longitude': -76.7922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21029', 'place_name': 'Clarksville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2125, 'longitude': -76.9515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21036', 'place_name': 'Dayton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2339, 'longitude': -76.9968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21041', 'place_name': 'Ellicott City', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2364, 'longitude': -76.9419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21042', 'place_name': 'Ellicott City', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2726, 'longitude': -76.8614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21043', 'place_name': 'Ellicott City', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2548, 'longitude': -76.8001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21044', 'place_name': 'Columbia', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2141, 'longitude': -76.8788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21045', 'place_name': 'Columbia', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2051, 'longitude': -76.8322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21046', 'place_name': 'Columbia', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.1702, 'longitude': -76.8538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21075', 'place_name': 'Elkridge', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2058, 'longitude': -76.7531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21150', 'place_name': 'Simpsonville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2364, 'longitude': -76.9419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21723', 'place_name': 'Cooksville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.3211, 'longitude': -77.0051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21737', 'place_name': 'Glenelg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2546, 'longitude': -77.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21738', 'place_name': 'Glenwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2795, 'longitude': -77.0148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21765', 'place_name': 'Lisbon', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.3378, 'longitude': -77.072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21794', 'place_name': 'West Friendship', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Howard', 'locality_code': '27', 'latitude': 39.2934, 'longitude': -76.966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21610', 'place_name': 'Betterton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.3655, 'longitude': -76.0639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21620', 'place_name': 'Chestertown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.2125, 'longitude': -76.0802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21635', 'place_name': 'Galena', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.3374, 'longitude': -75.8717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21645', 'place_name': 'Kennedyville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.2978, 'longitude': -75.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21650', 'place_name': 'Massey', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.3126, 'longitude': -75.8215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21651', 'place_name': 'Millington', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.2743, 'longitude': -75.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21661', 'place_name': 'Rock Hall', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.1344, 'longitude': -76.2305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21667', 'place_name': 'Still Pond', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.3293, 'longitude': -76.0455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21678', 'place_name': 'Worton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Kent', 'locality_code': '29', 'latitude': 39.2963, 'longitude': -76.1008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20810', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9806, 'longitude': -77.1008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20811', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9806, 'longitude': -77.1008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20812', 'place_name': 'Glen Echo', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9693, 'longitude': -77.1435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20813', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20814', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0003, 'longitude': -77.1022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20815', 'place_name': 'Chevy Chase', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.978, 'longitude': -77.082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20816', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9585, 'longitude': -77.1153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20817', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9896, 'longitude': -77.1538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20818', 'place_name': 'Cabin John', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9743, 'longitude': -77.1591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20824', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9807, 'longitude': -77.1003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20825', 'place_name': 'Chevy Chase', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0029, 'longitude': -77.0712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20827', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20830', 'place_name': 'Olney', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1552, 'longitude': -77.0667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20832', 'place_name': 'Olney', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1526, 'longitude': -77.0749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20833', 'place_name': 'Brookeville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1871, 'longitude': -77.0603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20837', 'place_name': 'Poolesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1386, 'longitude': -77.4067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20838', 'place_name': 'Barnesville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.2233, 'longitude': -77.3764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20839', 'place_name': 'Beallsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.179, 'longitude': -77.4128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20841', 'place_name': 'Boyds', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.21, 'longitude': -77.3167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20842', 'place_name': 'Dickerson', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.2126, 'longitude': -77.4199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20847', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.084, 'longitude': -77.1528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20848', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20849', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.084, 'longitude': -77.1528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20850', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.087, 'longitude': -77.168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20851', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0763, 'longitude': -77.1234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20852', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0496, 'longitude': -77.1204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20853', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0887, 'longitude': -77.095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20854', 'place_name': 'Potomac', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0388, 'longitude': -77.1922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20855', 'place_name': 'Derwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1345, 'longitude': -77.1477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20857', 'place_name': 'Rockville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.084, 'longitude': -77.1528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20859', 'place_name': 'Potomac', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20860', 'place_name': 'Sandy Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1503, 'longitude': -77.0291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20861', 'place_name': 'Ashton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.151, 'longitude': -76.9924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20862', 'place_name': 'Brinklow', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1838, 'longitude': -77.0163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20866', 'place_name': 'Burtonsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0922, 'longitude': -76.9339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20868', 'place_name': 'Spencerville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1223, 'longitude': -76.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20871', 'place_name': 'Clarksburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.2387, 'longitude': -77.2794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20872', 'place_name': 'Damascus', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.2761, 'longitude': -77.2131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20874', 'place_name': 'Germantown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1355, 'longitude': -77.2822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20875', 'place_name': 'Germantown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20876', 'place_name': 'Germantown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.188, 'longitude': -77.2358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20877', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1419, 'longitude': -77.189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20878', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1125, 'longitude': -77.2515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20879', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.173, 'longitude': -77.1855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20880', 'place_name': 'Washington Grove', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1388, 'longitude': -77.1726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20882', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.2335, 'longitude': -77.1458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20883', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0883, 'longitude': -77.1568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20884', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20885', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1874, 'longitude': -77.2028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20886', 'place_name': 'Montgomery Village', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1757, 'longitude': -77.1873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20889', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20891', 'place_name': 'Kensington', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0257, 'longitude': -77.0764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20892', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0024, 'longitude': -77.1034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20894', 'place_name': 'Bethesda', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20895', 'place_name': 'Kensington', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0298, 'longitude': -77.0793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20896', 'place_name': 'Garrett Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0365, 'longitude': -77.0931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20897', 'place_name': 'Suburb Maryland Fac', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20898', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.144, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20899', 'place_name': 'Gaithersburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1403, 'longitude': -77.222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20901', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0191, 'longitude': -77.0076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20902', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.04, 'longitude': -77.0444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20903', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0095, 'longitude': -76.9846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20904', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0668, 'longitude': -76.9969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20905', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.1148, 'longitude': -77.0059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20906', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.084, 'longitude': -77.0613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20907', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20908', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20910', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9982, 'longitude': -77.0338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20911', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20912', 'place_name': 'Takoma Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9832, 'longitude': -77.0007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20914', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20915', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20916', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20918', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20993', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 39.0336, 'longitude': -76.9861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20997', 'place_name': 'Silver Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Montgomery', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -77.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20607', 'place_name': 'Accokeek', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.672, 'longitude': -77.0162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20608', 'place_name': 'Aquasco', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.5825, 'longitude': -76.7149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20613', 'place_name': 'Brandywine', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.6922, 'longitude': -76.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20623', 'place_name': 'Cheltenham', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.7531, 'longitude': -76.8369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20697', 'place_name': 'Southern Md Facility', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20703', 'place_name': 'Lanham', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20704', 'place_name': 'Beltsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0348, 'longitude': -76.9075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20705', 'place_name': 'Beltsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0455, 'longitude': -76.9242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20706', 'place_name': 'Lanham', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9675, 'longitude': -76.8551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20707', 'place_name': 'Laurel', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.1077, 'longitude': -76.872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20708', 'place_name': 'Laurel', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0499, 'longitude': -76.8345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20709', 'place_name': 'Laurel', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0993, 'longitude': -76.8483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20710', 'place_name': 'Bladensburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9421, 'longitude': -76.9261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20712', 'place_name': 'Mount Rainier', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9431, 'longitude': -76.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20715', 'place_name': 'Bowie', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9797, 'longitude': -76.7435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20716', 'place_name': 'Bowie', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9263, 'longitude': -76.7098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20717', 'place_name': 'Bowie', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20718', 'place_name': 'Bowie', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20719', 'place_name': 'Bowie', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20720', 'place_name': 'Bowie', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9885, 'longitude': -76.791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20721', 'place_name': 'Bowie', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9194, 'longitude': -76.7871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20722', 'place_name': 'Brentwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9407, 'longitude': -76.9531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20725', 'place_name': 'Laurel', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0993, 'longitude': -76.8483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20726', 'place_name': 'Laurel', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0993, 'longitude': -76.8483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20731', 'place_name': 'Capitol Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8851, 'longitude': -76.9158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20735', 'place_name': 'Clinton', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.7549, 'longitude': -76.9026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20737', 'place_name': 'Riverdale', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9601, 'longitude': -76.9147, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20738', 'place_name': 'Riverdale', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20740', 'place_name': 'College Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9963, 'longitude': -76.9299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20741', 'place_name': 'College Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20742', 'place_name': 'College Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9896, 'longitude': -76.9457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20743', 'place_name': 'Capitol Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8897, 'longitude': -76.8925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20744', 'place_name': 'Fort Washington', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.7587, 'longitude': -76.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20745', 'place_name': 'Oxon Hill', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8108, 'longitude': -76.9898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20746', 'place_name': 'Suitland', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8425, 'longitude': -76.9222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20747', 'place_name': 'District Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8539, 'longitude': -76.8891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20748', 'place_name': 'Temple Hills', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8222, 'longitude': -76.9478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20749', 'place_name': 'Fort Washington', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20750', 'place_name': 'Oxon Hill', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8034, 'longitude': -76.9897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20752', 'place_name': 'Suitland', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8487, 'longitude': -76.9239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20753', 'place_name': 'District Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20757', 'place_name': 'Temple Hills', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.814, 'longitude': -76.9455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20762', 'place_name': 'Andrews Air Force Base', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8062, 'longitude': -76.8756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20768', 'place_name': 'Greenbelt', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0046, 'longitude': -76.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20769', 'place_name': 'Glenn Dale', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9766, 'longitude': -76.8053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20770', 'place_name': 'Greenbelt', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9996, 'longitude': -76.884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20771', 'place_name': 'Greenbelt', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0046, 'longitude': -76.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20772', 'place_name': 'Upper Marlboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8377, 'longitude': -76.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20773', 'place_name': 'Upper Marlboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8159, 'longitude': -76.7497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20774', 'place_name': 'Upper Marlboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8682, 'longitude': -76.8156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20775', 'place_name': 'Upper Marlboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20781', 'place_name': 'Hyattsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9506, 'longitude': -76.9347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20782', 'place_name': 'Hyattsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9647, 'longitude': -76.9649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20783', 'place_name': 'Hyattsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 39.0005, 'longitude': -76.9723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20784', 'place_name': 'Hyattsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9513, 'longitude': -76.8958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20785', 'place_name': 'Hyattsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9223, 'longitude': -76.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20787', 'place_name': 'Hyattsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9871, 'longitude': -76.9824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20788', 'place_name': 'Hyattsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9694, 'longitude': -76.9509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20790', 'place_name': 'Capitol Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20791', 'place_name': 'Capitol Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20792', 'place_name': 'Upper Marlboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8158, 'longitude': -76.75, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20797', 'place_name': 'Southern Md Facility', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '20799', 'place_name': 'Capitol Heights', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.8336, 'longitude': -76.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20913', 'place_name': 'Takoma Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Prince George's", 'locality_code': '33', 'latitude': 38.9779, 'longitude': -77.0075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21607', 'place_name': 'Barclay', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.1299, 'longitude': -75.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21617', 'place_name': 'Centreville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.0564, 'longitude': -76.045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21619', 'place_name': 'Chester', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 38.9583, 'longitude': -76.2842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21623', 'place_name': 'Church Hill', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.146, 'longitude': -75.988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21628', 'place_name': 'Crumpton', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.233, 'longitude': -75.9195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21638', 'place_name': 'Grasonville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 38.9456, 'longitude': -76.1997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21644', 'place_name': 'Ingleside', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.1182, 'longitude': -75.8769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21656', 'place_name': 'Price', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.0346, 'longitude': -76.0921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21657', 'place_name': 'Queen Anne', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 38.9456, 'longitude': -75.9777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21658', 'place_name': 'Queenstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.0025, 'longitude': -76.1424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21666', 'place_name': 'Stevensville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 38.9394, 'longitude': -76.3371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21668', 'place_name': 'Sudlersville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.1823, 'longitude': -75.85, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21690', 'place_name': 'Chestertown', 'state': 'Maryland', 'state_ab': 'MD', 'county': "Queen Anne's", 'locality_code': '35', 'latitude': 39.0346, 'longitude': -76.0921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20606', 'place_name': 'Abell', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2471, 'longitude': -76.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20609', 'place_name': 'Avenue', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2826, 'longitude': -76.7466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20618', 'place_name': 'Bushwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2844, 'longitude': -76.7929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20619', 'place_name': 'California', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.3006, 'longitude': -76.5312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20620', 'place_name': 'Callaway', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2275, 'longitude': -76.521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20621', 'place_name': 'Chaptico', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.351, 'longitude': -76.7833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20622', 'place_name': 'Charlotte Hall', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.475, 'longitude': -76.8038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20624', 'place_name': 'Clements', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.3407, 'longitude': -76.7264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20626', 'place_name': 'Coltons Point', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.237, 'longitude': -76.7646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20627', 'place_name': 'Compton', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2768, 'longitude': -76.704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20628', 'place_name': 'Dameron', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1533, 'longitude': -76.3575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20630', 'place_name': 'Drayden', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1719, 'longitude': -76.4731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20634', 'place_name': 'Great Mills', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2674, 'longitude': -76.4954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20635', 'place_name': 'Helen', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.3121, 'longitude': -76.6077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20636', 'place_name': 'Hollywood', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.3524, 'longitude': -76.5626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20650', 'place_name': 'Leonardtown', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2774, 'longitude': -76.638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20653', 'place_name': 'Lexington Park', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2495, 'longitude': -76.4529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20656', 'place_name': 'Loveville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.3593, 'longitude': -76.6833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20659', 'place_name': 'Mechanicsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.4293, 'longitude': -76.7254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20660', 'place_name': 'Morganza', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.3754, 'longitude': -76.6955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20667', 'place_name': 'Park Hall', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2177, 'longitude': -76.4429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20670', 'place_name': 'Patuxent River', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.2791, 'longitude': -76.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20674', 'place_name': 'Piney Point', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1397, 'longitude': -76.5047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20680', 'place_name': 'Ridge', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1169, 'longitude': -76.3711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20684', 'place_name': 'Saint Inigoes', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1441, 'longitude': -76.4083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20686', 'place_name': 'Saint Marys City', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1871, 'longitude': -76.4344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20687', 'place_name': 'Scotland', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.0828, 'longitude': -76.3477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20690', 'place_name': 'Tall Timbers', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1653, 'longitude': -76.5399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20692', 'place_name': 'Valley Lee', 'state': 'Maryland', 'state_ab': 'MD', 'county': "St. Mary's", 'locality_code': '37', 'latitude': 38.1899, 'longitude': -76.5087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21817', 'place_name': 'Crisfield', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 37.9845, 'longitude': -75.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21821', 'place_name': 'Deal Island', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.1533, 'longitude': -75.9496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21824', 'place_name': 'Ewell', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 37.9938, 'longitude': -76.0351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21836', 'place_name': 'Manokin', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.1154, 'longitude': -75.7558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21838', 'place_name': 'Marion Station', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.0266, 'longitude': -75.7579, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '21853', 'place_name': 'Princess Anne', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.1919, 'longitude': -75.7072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21857', 'place_name': 'Rehobeth', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.039, 'longitude': -75.663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21866', 'place_name': 'Tylerton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 37.9666, 'longitude': -76.0235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21867', 'place_name': 'Upper Fairmount', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.104, 'longitude': -75.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21871', 'place_name': 'Westover', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.101, 'longitude': -75.7406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21890', 'place_name': 'Westover', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Somerset', 'locality_code': '39', 'latitude': 38.0927, 'longitude': -75.8882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21601', 'place_name': 'Easton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.7768, 'longitude': -76.0758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21612', 'place_name': 'Bozman', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.7515, 'longitude': -76.2764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21624', 'place_name': 'Claiborne', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.8368, 'longitude': -76.2714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21625', 'place_name': 'Cordova', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.8704, 'longitude': -76.0029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21647', 'place_name': 'Mcdaniel', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.8192, 'longitude': -76.2806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21652', 'place_name': 'Neavitt', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.7246, 'longitude': -76.2824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21653', 'place_name': 'Newcomb', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.7518, 'longitude': -76.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21654', 'place_name': 'Oxford', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.6864, 'longitude': -76.1538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21662', 'place_name': 'Royal Oak', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.714, 'longitude': -76.2097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21663', 'place_name': 'Saint Michaels', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.783, 'longitude': -76.2215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21665', 'place_name': 'Sherwood', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.7374, 'longitude': -76.3278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21671', 'place_name': 'Tilghman', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.7063, 'longitude': -76.3377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21673', 'place_name': 'Trappe', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.6647, 'longitude': -76.0507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21676', 'place_name': 'Wittman', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.7846, 'longitude': -76.3001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21679', 'place_name': 'Wye Mills', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Talbot', 'locality_code': '41', 'latitude': 38.9281, 'longitude': -76.0814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21711', 'place_name': 'Big Pool', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6457, 'longitude': -78.0104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21713', 'place_name': 'Boonsboro', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.552, 'longitude': -77.6957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21715', 'place_name': 'Brownsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.3869, 'longitude': -77.658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21719', 'place_name': 'Cascade', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6958, 'longitude': -77.4955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21720', 'place_name': 'Cavetown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6473, 'longitude': -77.5842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21721', 'place_name': 'Chewsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6425, 'longitude': -77.6372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21722', 'place_name': 'Clear Spring', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6658, 'longitude': -77.9064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21733', 'place_name': 'Fairplay', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.5594, 'longitude': -77.7604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21734', 'place_name': 'Funkstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.609, 'longitude': -77.7044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21740', 'place_name': 'Hagerstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.632, 'longitude': -77.7372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21741', 'place_name': 'Hagerstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6418, 'longitude': -77.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21742', 'place_name': 'Hagerstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6573, 'longitude': -77.6921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21746', 'place_name': 'Hagerstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.5638, 'longitude': -77.7206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21747', 'place_name': 'Hagerstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6418, 'longitude': -77.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21749', 'place_name': 'Hagerstown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6418, 'longitude': -77.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21750', 'place_name': 'Hancock', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6991, 'longitude': -78.1762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21756', 'place_name': 'Keedysville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.4563, 'longitude': -77.6944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21767', 'place_name': 'Maugansville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.6996, 'longitude': -77.7499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21779', 'place_name': 'Rohrersville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.4431, 'longitude': -77.658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21781', 'place_name': 'Saint James', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.5699, 'longitude': -77.7607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21782', 'place_name': 'Sharpsburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.4424, 'longitude': -77.7511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21783', 'place_name': 'Smithsburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.647, 'longitude': -77.5706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21795', 'place_name': 'Williamsport', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Washington', 'locality_code': '43', 'latitude': 39.593, 'longitude': -77.8087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21801', 'place_name': 'Salisbury', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3824, 'longitude': -75.6336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21802', 'place_name': 'Salisbury', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3884, 'longitude': -75.6276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21803', 'place_name': 'Salisbury', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3884, 'longitude': -75.6276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21804', 'place_name': 'Salisbury', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3508, 'longitude': -75.5338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21810', 'place_name': 'Allen', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.2873, 'longitude': -75.688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21814', 'place_name': 'Bivalve', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.2953, 'longitude': -75.8914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21826', 'place_name': 'Fruitland', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3225, 'longitude': -75.6228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21830', 'place_name': 'Hebron', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.4026, 'longitude': -75.6963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21837', 'place_name': 'Mardela Springs', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.4864, 'longitude': -75.7414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21840', 'place_name': 'Nanticoke', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.2672, 'longitude': -75.9021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21849', 'place_name': 'Parsonsburg', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3914, 'longitude': -75.4737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21850', 'place_name': 'Pittsville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3755, 'longitude': -75.4076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21852', 'place_name': 'Powellville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3287, 'longitude': -75.3755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21856', 'place_name': 'Quantico', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3339, 'longitude': -75.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21861', 'place_name': 'Sharptown', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.5389, 'longitude': -75.7192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21865', 'place_name': 'Tyaskin', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.2833, 'longitude': -75.8465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21874', 'place_name': 'Willards', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.3939, 'longitude': -75.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21875', 'place_name': 'Delmar', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Wicomico', 'locality_code': '45', 'latitude': 38.4445, 'longitude': -75.5583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21811', 'place_name': 'Berlin', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.3475, 'longitude': -75.1866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21813', 'place_name': 'Bishopville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.4296, 'longitude': -75.1855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21822', 'place_name': 'Eden', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.2807, 'longitude': -75.651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21829', 'place_name': 'Girdletree', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.0958, 'longitude': -75.3902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21841', 'place_name': 'Newark', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.2489, 'longitude': -75.2893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21842', 'place_name': 'Ocean City', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.3365, 'longitude': -75.0849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21843', 'place_name': 'Ocean City', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.3365, 'longitude': -75.0849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21851', 'place_name': 'Pocomoke City', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.0714, 'longitude': -75.555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21862', 'place_name': 'Showell', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.4003, 'longitude': -75.2166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21863', 'place_name': 'Snow Hill', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.1868, 'longitude': -75.405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21864', 'place_name': 'Stockton', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.0452, 'longitude': -75.4108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21872', 'place_name': 'Whaleyville', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Worcester', 'locality_code': '47', 'latitude': 38.4121, 'longitude': -75.2811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21201', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2946, 'longitude': -76.6252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21202', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2998, 'longitude': -76.6075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21203', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21205', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3009, 'longitude': -76.5799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21206', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3365, 'longitude': -76.5411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21209', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3716, 'longitude': -76.6744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21210', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3507, 'longitude': -76.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21211', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3316, 'longitude': -76.6336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21212', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3626, 'longitude': -76.61, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21213', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3127, 'longitude': -76.581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21214', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3521, 'longitude': -76.5644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21215', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3446, 'longitude': -76.6794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21216', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3093, 'longitude': -76.6699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21217', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3064, 'longitude': -76.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21218', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.3265, 'longitude': -76.6048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21223', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.287, 'longitude': -76.6476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21224', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2876, 'longitude': -76.5568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21229', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2856, 'longitude': -76.6899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21230', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2645, 'longitude': -76.6224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21231', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2892, 'longitude': -76.59, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21233', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21235', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21239', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.361, 'longitude': -76.5891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21241', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21263', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21264', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21270', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21273', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21275', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21278', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21279', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21280', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21281', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21287', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2975, 'longitude': -76.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21288', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21289', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21290', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2933, 'longitude': -76.6238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21297', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '21298', 'place_name': 'Baltimore', 'state': 'Maryland', 'state_ab': 'MD', 'county': 'Baltimore (city)', 'locality_code': '510', 'latitude': 39.2847, 'longitude': -76.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4210', 'place_name': 'Auburn', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.0948, 'longitude': -70.239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4211', 'place_name': 'Auburn', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.197, 'longitude': -70.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4212', 'place_name': 'Auburn', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.197, 'longitude': -70.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4222', 'place_name': 'Durham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 43.9684, 'longitude': -70.1846, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4223', 'place_name': 'Danville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.0239, 'longitude': -70.2857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4228', 'place_name': 'East Livermore', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.3994, 'longitude': -70.1303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4230', 'place_name': 'East Poland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.0627, 'longitude': -70.327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4236', 'place_name': 'Greene', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.1891, 'longitude': -70.1455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4240', 'place_name': 'Lewiston', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.0985, 'longitude': -70.1916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4241', 'place_name': 'Lewiston', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.197, 'longitude': -70.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4243', 'place_name': 'Lewiston', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.197, 'longitude': -70.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4250', 'place_name': 'Lisbon', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.0255, 'longitude': -70.1139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4252', 'place_name': 'Lisbon Falls', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 43.9978, 'longitude': -70.0734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4253', 'place_name': 'Livermore', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.4079, 'longitude': -70.215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4254', 'place_name': 'Livermore Falls', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.4325, 'longitude': -70.1427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4256', 'place_name': 'Mechanic Falls', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.1117, 'longitude': -70.3917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4258', 'place_name': 'Minot', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.1461, 'longitude': -70.3399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4263', 'place_name': 'Leeds', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.2834, 'longitude': -70.1253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4266', 'place_name': 'North Turner', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.358, 'longitude': -70.2558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4274', 'place_name': 'Poland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.0474, 'longitude': -70.3899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4280', 'place_name': 'Sabattus', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.1133, 'longitude': -70.0748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4282', 'place_name': 'Turner', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.2557, 'longitude': -70.2494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4288', 'place_name': 'West Minot', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.1712, 'longitude': -70.3659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4291', 'place_name': 'West Poland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Androscoggin', 'locality_code': '1', 'latitude': 44.0409, 'longitude': -70.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4471', 'place_name': 'Orient', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 45.8911, 'longitude': -67.8471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4497', 'place_name': 'Wytopitlock', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 45.6645, 'longitude': -68.1055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4730', 'place_name': 'Houlton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.1189, 'longitude': -67.863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4732', 'place_name': 'Ashland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.6184, 'longitude': -68.3876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4733', 'place_name': 'Benedicta', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 45.8125, 'longitude': -68.4089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4734', 'place_name': 'Blaine', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.5048, 'longitude': -67.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4735', 'place_name': 'Bridgewater', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.4222, 'longitude': -67.8415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4736', 'place_name': 'Caribou', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.8706, 'longitude': -68.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4737', 'place_name': 'Clayton Lake', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.6109, 'longitude': -69.5223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4738', 'place_name': 'Crouseville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.755, 'longitude': -68.0964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4739', 'place_name': 'Eagle Lake', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.01, 'longitude': -68.691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4740', 'place_name': 'Easton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.6357, 'longitude': -67.9018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4741', 'place_name': 'Estcourt Station', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.4589, 'longitude': -69.2243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4742', 'place_name': 'Fort Fairfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.7623, 'longitude': -67.8402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4743', 'place_name': 'Fort Kent', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.2587, 'longitude': -68.5895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4744', 'place_name': 'Fort Kent Mills', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.2389, 'longitude': -68.5839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4745', 'place_name': 'Frenchville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.2826, 'longitude': -68.3917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4746', 'place_name': 'Grand Isle', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.3044, 'longitude': -68.1542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4747', 'place_name': 'Island Falls', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.0169, 'longitude': -68.2667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4750', 'place_name': 'Limestone', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.9248, 'longitude': -67.8451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4751', 'place_name': 'Limestone', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.8929, 'longitude': -67.9643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4756', 'place_name': 'Madawaska', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.3294, 'longitude': -68.3328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4757', 'place_name': 'Mapleton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.6746, 'longitude': -68.1536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4758', 'place_name': 'Mars Hill', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.5223, 'longitude': -67.863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4760', 'place_name': 'Monticello', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.3007, 'longitude': -67.8414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4761', 'place_name': 'New Limerick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.1004, 'longitude': -68.0034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4762', 'place_name': 'New Sweden', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.9559, 'longitude': -68.1154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4763', 'place_name': 'Oakfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.1088, 'longitude': -68.1298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4764', 'place_name': 'Oxbow', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.402, 'longitude': -68.5218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4766', 'place_name': 'Perham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.8816, 'longitude': -68.2391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4768', 'place_name': 'Portage', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.7753, 'longitude': -68.4877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4769', 'place_name': 'Presque Isle', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.6842, 'longitude': -68.0118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4772', 'place_name': 'Saint Agatha', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.2387, 'longitude': -68.3232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4773', 'place_name': 'Saint David', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.3343, 'longitude': -68.2314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4774', 'place_name': 'Saint Francis', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.1407, 'longitude': -68.9503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4775', 'place_name': 'Sheridan', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.6573, 'longitude': -68.405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4776', 'place_name': 'Sherman', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 45.8731, 'longitude': -68.3847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4779', 'place_name': 'Sinclair', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.1222, 'longitude': -68.323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4780', 'place_name': 'Smyrna Mills', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.1464, 'longitude': -68.2064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4781', 'place_name': 'Wallagrass', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.1295, 'longitude': -68.5973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4783', 'place_name': 'Stockholm', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.0423, 'longitude': -68.1395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4785', 'place_name': 'Van Buren', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 47.1589, 'longitude': -67.9459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4786', 'place_name': 'Washburn', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.7883, 'longitude': -68.1338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4787', 'place_name': 'Westfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Aroostook', 'locality_code': '3', 'latitude': 46.5945, 'longitude': -67.9302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4003', 'place_name': 'Bailey Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7341, 'longitude': -69.9952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4009', 'place_name': 'Bridgton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 44.052, 'longitude': -70.7241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4011', 'place_name': 'Brunswick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.8973, 'longitude': -69.9779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4013', 'place_name': 'Bustins Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.799, 'longitude': -70.0698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4015', 'place_name': 'Casco', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.9596, 'longitude': -70.526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4017', 'place_name': 'Chebeague Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7354, 'longitude': -70.1169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4019', 'place_name': 'Cliff Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6955, 'longitude': -70.1071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4021', 'place_name': 'Cumberland Center', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7974, 'longitude': -70.2649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4024', 'place_name': 'East Baldwin', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.8646, 'longitude': -70.6922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4029', 'place_name': 'Sebago', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.9017, 'longitude': -70.6878, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4032', 'place_name': 'Freeport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.857, 'longitude': -70.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4033', 'place_name': 'Freeport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.857, 'longitude': -70.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4034', 'place_name': 'Freeport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.857, 'longitude': -70.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4038', 'place_name': 'Gorham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6843, 'longitude': -70.468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4039', 'place_name': 'Gray', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.8942, 'longitude': -70.3429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4040', 'place_name': 'Harrison', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 44.1071, 'longitude': -70.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4050', 'place_name': 'Long Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.692, 'longitude': -70.1551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4055', 'place_name': 'Naples', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.9681, 'longitude': -70.5988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4057', 'place_name': 'North Bridgton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 44.0987, 'longitude': -70.6987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4062', 'place_name': 'Windham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7958, 'longitude': -70.4143, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4066', 'place_name': 'Orrs Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7727, 'longitude': -69.9668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4069', 'place_name': 'Pownal', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.89, 'longitude': -70.1955, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4070', 'place_name': 'Scarborough', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.577, 'longitude': -70.2736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4071', 'place_name': 'Raymond', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.9219, 'longitude': -70.4498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4074', 'place_name': 'Scarborough', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.5835, 'longitude': -70.3457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4077', 'place_name': 'South Casco', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.91, 'longitude': -70.5245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4078', 'place_name': 'South Freeport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.8208, 'longitude': -70.1208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4079', 'place_name': 'Harpswell', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7811, 'longitude': -69.9955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4082', 'place_name': 'South Windham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7362, 'longitude': -70.4237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4084', 'place_name': 'Standish', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.8142, 'longitude': -70.4807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4085', 'place_name': 'Steep Falls', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.7719, 'longitude': -70.6396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4091', 'place_name': 'West Baldwin', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.8299, 'longitude': -70.749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4092', 'place_name': 'Westbrook', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6843, 'longitude': -70.358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4096', 'place_name': 'Yarmouth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.8009, 'longitude': -70.175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4097', 'place_name': 'North Yarmouth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.838, 'longitude': -70.2001, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4098', 'place_name': 'Westbrook', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.677, 'longitude': -70.3712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4101', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6606, 'longitude': -70.2589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4102', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6602, 'longitude': -70.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4103', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6876, 'longitude': -70.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4104', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6615, 'longitude': -70.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4105', 'place_name': 'Falmouth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.734, 'longitude': -70.2625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4106', 'place_name': 'South Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6318, 'longitude': -70.2709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4107', 'place_name': 'Cape Elizabeth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6017, 'longitude': -70.2301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4108', 'place_name': 'Peaks Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6589, 'longitude': -70.194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4109', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6783, 'longitude': -70.1987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4110', 'place_name': 'Cumberland Foreside', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.759, 'longitude': -70.1993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4112', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6615, 'longitude': -70.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4116', 'place_name': 'South Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6415, 'longitude': -70.2409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4122', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6615, 'longitude': -70.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4123', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6615, 'longitude': -70.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4124', 'place_name': 'Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.6615, 'longitude': -70.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4260', 'place_name': 'New Gloucester', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Cumberland', 'locality_code': '5', 'latitude': 43.9608, 'longitude': -70.2974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4225', 'place_name': 'Dryden', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.6027, 'longitude': -70.2265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4227', 'place_name': 'East Dixfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.5734, 'longitude': -70.3037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4234', 'place_name': 'East Wilton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.6159, 'longitude': -70.1928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4239', 'place_name': 'Jay', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.516, 'longitude': -70.2099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4262', 'place_name': 'North Jay', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.5473, 'longitude': -70.2381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4285', 'place_name': 'Weld', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.7016, 'longitude': -70.4249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4294', 'place_name': 'Wilton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.5928, 'longitude': -70.2281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4936', 'place_name': 'Eustis', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 45.3356, 'longitude': -70.6283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4938', 'place_name': 'Farmington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.6653, 'longitude': -70.1329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4940', 'place_name': 'Farmington Falls', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.6226, 'longitude': -70.0752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4947', 'place_name': 'Kingfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.9854, 'longitude': -70.1832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4955', 'place_name': 'New Sharon', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.6458, 'longitude': -70.0139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4956', 'place_name': 'New Vineyard', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.7967, 'longitude': -70.122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4964', 'place_name': 'Oquossoc', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.9664, 'longitude': -70.7737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4966', 'place_name': 'Phillips', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.8375, 'longitude': -70.3601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4970', 'place_name': 'Rangeley', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.9631, 'longitude': -70.6658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4982', 'place_name': 'Stratton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 45.1116, 'longitude': -70.423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4983', 'place_name': 'Strong', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.8224, 'longitude': -70.2221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4984', 'place_name': 'Temple', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.6954, 'longitude': -70.2426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4992', 'place_name': 'West Farmington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Franklin', 'locality_code': '7', 'latitude': 44.6628, 'longitude': -70.153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4408', 'place_name': 'Aurora', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.8861, 'longitude': -68.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4416', 'place_name': 'Bucksport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.6015, 'longitude': -68.7768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4420', 'place_name': 'Castine', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.413, 'longitude': -68.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4421', 'place_name': 'Castine', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4156, 'longitude': -68.7929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4431', 'place_name': 'East Orland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.5612, 'longitude': -68.6647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4472', 'place_name': 'Orland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.5458, 'longitude': -68.7313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4476', 'place_name': 'Penobscot', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4645, 'longitude': -68.7111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4605', 'place_name': 'Ellsworth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.5548, 'longitude': -68.4121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4607', 'place_name': 'Gouldsboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4731, 'longitude': -68.0899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4609', 'place_name': 'Bar Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.3738, 'longitude': -68.2448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4612', 'place_name': 'Bernard', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2415, 'longitude': -68.358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4613', 'place_name': 'Birch Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.3842, 'longitude': -68.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4614', 'place_name': 'Blue Hill', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4343, 'longitude': -68.5885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4616', 'place_name': 'Brooklin', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2541, 'longitude': -68.5565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4617', 'place_name': 'Brooksville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.3756, 'longitude': -68.7313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4624', 'place_name': 'Corea', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4053, 'longitude': -67.985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4625', 'place_name': 'Cranberry Isles', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2484, 'longitude': -68.2603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4627', 'place_name': 'Deer Isle', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.234, 'longitude': -68.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4629', 'place_name': 'East Blue Hill', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4176, 'longitude': -68.5225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4634', 'place_name': 'Franklin', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.6087, 'longitude': -68.2417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4635', 'place_name': 'Frenchboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.1181, 'longitude': -68.3625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4640', 'place_name': 'Hancock', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.5046, 'longitude': -68.2402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4642', 'place_name': 'Harborside', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.334, 'longitude': -68.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4644', 'place_name': 'Hulls Cove', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4192, 'longitude': -68.2506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4646', 'place_name': 'Islesford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.262, 'longitude': -68.2339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4650', 'place_name': 'Little Deer Isle', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2847, 'longitude': -68.7058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4653', 'place_name': 'Bass Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2401, 'longitude': -68.3439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4660', 'place_name': 'Mount Desert', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.3347, 'longitude': -68.3087, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4662', 'place_name': 'Northeast Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2941, 'longitude': -68.2849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4664', 'place_name': 'Sullivan', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.5458, 'longitude': -68.1279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4669', 'place_name': 'Prospect Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.411, 'longitude': -68.0141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4672', 'place_name': 'Salsbury Cove', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4306, 'longitude': -68.2836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4673', 'place_name': 'Sargentville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.3136, 'longitude': -68.6863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4674', 'place_name': 'Seal Cove', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2859, 'longitude': -68.3986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4675', 'place_name': 'Seal Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.299, 'longitude': -68.2463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4676', 'place_name': 'Sedgwick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.3355, 'longitude': -68.6377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4677', 'place_name': 'Sorrento', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4907, 'longitude': -68.1787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4679', 'place_name': 'Southwest Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2823, 'longitude': -68.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4681', 'place_name': 'Stonington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.1752, 'longitude': -68.6746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4683', 'place_name': 'Sunset', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.2059, 'longitude': -68.7047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4684', 'place_name': 'Surry', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.4883, 'longitude': -68.5063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4685', 'place_name': 'Swans Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.1451, 'longitude': -68.4517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4693', 'place_name': 'Winter Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Hancock', 'locality_code': '9', 'latitude': 44.39, 'longitude': -68.0843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4259', 'place_name': 'Monmouth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.2208, 'longitude': -70.0263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4265', 'place_name': 'North Monmouth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.2753, 'longitude': -70.0367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4284', 'place_name': 'Wayne', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3493, 'longitude': -70.0712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4330', 'place_name': 'Augusta', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3232, 'longitude': -69.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4332', 'place_name': 'Augusta', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4141, 'longitude': -69.7519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4333', 'place_name': 'Augusta', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3106, 'longitude': -69.7795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4336', 'place_name': 'Augusta', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3157, 'longitude': -69.818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4338', 'place_name': 'Augusta', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3106, 'longitude': -69.7795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4343', 'place_name': 'East Winthrop', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3217, 'longitude': -69.8964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4344', 'place_name': 'Farmingdale', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.2523, 'longitude': -69.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4345', 'place_name': 'Gardiner', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.207, 'longitude': -69.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4346', 'place_name': 'Randolph', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.2347, 'longitude': -69.7506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4347', 'place_name': 'Hallowell', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.2864, 'longitude': -69.8057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4349', 'place_name': 'Kents Hill', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4383, 'longitude': -70.0748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4350', 'place_name': 'Litchfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.1634, 'longitude': -69.9581, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4351', 'place_name': 'Manchester', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.358, 'longitude': -69.867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4352', 'place_name': 'Mount Vernon', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4993, 'longitude': -69.9903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4355', 'place_name': 'Readfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4032, 'longitude': -69.9506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4358', 'place_name': 'South China', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3953, 'longitude': -69.5804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4359', 'place_name': 'South Gardiner', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.1801, 'longitude': -69.7567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4360', 'place_name': 'Vienna', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.5475, 'longitude': -70.003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4363', 'place_name': 'Windsor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3009, 'longitude': -69.5806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4364', 'place_name': 'Winthrop', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.3229, 'longitude': -69.9576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4901', 'place_name': 'Waterville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.5543, 'longitude': -69.6178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4903', 'place_name': 'Waterville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.5492, 'longitude': -69.7132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4910', 'place_name': 'Albion', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.5355, 'longitude': -69.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4917', 'place_name': 'Belgrade', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4688, 'longitude': -69.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4918', 'place_name': 'Belgrade Lakes', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.5265, 'longitude': -69.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4926', 'place_name': 'China Village', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.8526, 'longitude': -69.502, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4927', 'place_name': 'Clinton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.644, 'longitude': -69.5284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4935', 'place_name': 'East Vassalboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4478, 'longitude': -69.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4962', 'place_name': 'North Vassalboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4862, 'longitude': -69.6225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4963', 'place_name': 'Oakland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.5173, 'longitude': -69.7401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4989', 'place_name': 'Vassalboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Kennebec', 'locality_code': '11', 'latitude': 44.4405, 'longitude': -69.6519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4547', 'place_name': 'Friendship', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 43.9807, 'longitude': -69.3349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4563', 'place_name': 'Cushing', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 43.9867, 'longitude': -69.2721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4574', 'place_name': 'Washington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.2693, 'longitude': -69.3842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4645', 'place_name': 'Isle Au Haut', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.0561, 'longitude': -68.6206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4841', 'place_name': 'Rockland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.1123, 'longitude': -69.1139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4843', 'place_name': 'Camden', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.2137, 'longitude': -69.0767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4847', 'place_name': 'Hope', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.2589, 'longitude': -69.1467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4851', 'place_name': 'Matinicus', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 43.8651, 'longitude': -68.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4853', 'place_name': 'North Haven', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.1436, 'longitude': -68.8667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4854', 'place_name': 'Owls Head', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.0732, 'longitude': -69.0894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4855', 'place_name': 'Port Clyde', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 43.9273, 'longitude': -69.2528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4856', 'place_name': 'Rockport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.1888, 'longitude': -69.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4858', 'place_name': 'South Thomaston', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.0378, 'longitude': -69.1359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4859', 'place_name': 'Spruce Head', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.0104, 'longitude': -69.1707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4860', 'place_name': 'Tenants Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 43.9555, 'longitude': -69.2315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4861', 'place_name': 'Thomaston', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.0846, 'longitude': -69.1888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4862', 'place_name': 'Union', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.2619, 'longitude': -69.2771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4863', 'place_name': 'Vinalhaven', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.0397, 'longitude': -68.8368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4864', 'place_name': 'Warren', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.1271, 'longitude': -69.2479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4865', 'place_name': 'West Rockport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Knox', 'locality_code': '13', 'latitude': 44.1924, 'longitude': -69.1211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4341', 'place_name': 'Coopers Mills', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.2588, 'longitude': -69.551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4342', 'place_name': 'Dresden', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0785, 'longitude': -69.7457, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4348', 'place_name': 'Jefferson', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.2204, 'longitude': -69.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4353', 'place_name': 'Whitefield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.1884, 'longitude': -69.5751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4535', 'place_name': 'Alna', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0878, 'longitude': -69.6344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4537', 'place_name': 'Boothbay', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8945, 'longitude': -69.6273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4538', 'place_name': 'Boothbay Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8518, 'longitude': -69.6278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4539', 'place_name': 'Bristol', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.9519, 'longitude': -69.4954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4541', 'place_name': 'Chamberlain', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8843, 'longitude': -69.4792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4543', 'place_name': 'Damariscotta', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0293, 'longitude': -69.5042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4544', 'place_name': 'East Boothbay', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8262, 'longitude': -69.5939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4549', 'place_name': 'Isle Of Springs', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0213, 'longitude': -69.5233, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4551', 'place_name': 'Bremen', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0104, 'longitude': -69.4402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4553', 'place_name': 'Newcastle', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0499, 'longitude': -69.5331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4554', 'place_name': 'New Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8605, 'longitude': -69.5079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4555', 'place_name': 'Nobleboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0943, 'longitude': -69.4828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4556', 'place_name': 'Edgecomb', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.9792, 'longitude': -69.6197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4558', 'place_name': 'Pemaquid', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8924, 'longitude': -69.5289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4564', 'place_name': 'Round Pond', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.925, 'longitude': -69.4662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4568', 'place_name': 'South Bristol', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8677, 'longitude': -69.5614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4570', 'place_name': 'Squirrel Island', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0213, 'longitude': -69.5233, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4571', 'place_name': 'Trevett', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8826, 'longitude': -69.6801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4572', 'place_name': 'Waldoboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.1046, 'longitude': -69.3745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4573', 'place_name': 'Walpole', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.9462, 'longitude': -69.5516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4575', 'place_name': 'West Boothbay Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.849, 'longitude': -69.6434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4576', 'place_name': 'Southport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.8199, 'longitude': -69.6626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4578', 'place_name': 'Wiscasset', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 44.0074, 'longitude': -69.6826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4852', 'place_name': 'Monhegan', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Lincoln', 'locality_code': '15', 'latitude': 43.7642, 'longitude': -69.3164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4010', 'place_name': 'Brownfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 43.9381, 'longitude': -70.9087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4016', 'place_name': 'Center Lovell', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.181, 'longitude': -70.8917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4022', 'place_name': 'Denmark', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 43.9755, 'longitude': -70.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4037', 'place_name': 'Fryeburg', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.0313, 'longitude': -70.9668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4041', 'place_name': 'Hiram', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 43.8622, 'longitude': -70.8531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4051', 'place_name': 'Lovell', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.1614, 'longitude': -70.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4068', 'place_name': 'Porter', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 43.8262, 'longitude': -70.9243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4088', 'place_name': 'Waterford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.1931, 'longitude': -70.7163, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4216', 'place_name': 'Andover', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.6637, 'longitude': -70.7967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4217', 'place_name': 'Bethel', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.4162, 'longitude': -70.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4219', 'place_name': 'Bryant Pond', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.3957, 'longitude': -70.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4220', 'place_name': 'Buckfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.2877, 'longitude': -70.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4221', 'place_name': 'Canton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.4602, 'longitude': -70.2998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4224', 'place_name': 'Dixfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.5548, 'longitude': -70.4241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4226', 'place_name': 'East Andover', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.6084, 'longitude': -70.6993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4231', 'place_name': 'Stoneham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.2641, 'longitude': -70.8875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4237', 'place_name': 'Hanover', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.4959, 'longitude': -70.7167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4238', 'place_name': 'Hebron', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.2021, 'longitude': -70.3754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4255', 'place_name': 'Greenwood', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.3184, 'longitude': -70.6509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4257', 'place_name': 'Mexico', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.5628, 'longitude': -70.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4261', 'place_name': 'Newry', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.6895, 'longitude': -71.0112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4267', 'place_name': 'North Waterford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.2317, 'longitude': -70.7687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4268', 'place_name': 'Norway', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.2127, 'longitude': -70.5601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4270', 'place_name': 'Oxford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.1118, 'longitude': -70.5098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4271', 'place_name': 'Paris', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.2641, 'longitude': -70.4985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4275', 'place_name': 'Roxbury', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.6566, 'longitude': -70.6092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4276', 'place_name': 'Rumford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.5434, 'longitude': -70.5645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4281', 'place_name': 'South Paris', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.2167, 'longitude': -70.5012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4286', 'place_name': 'West Bethel', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.4021, 'longitude': -70.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4289', 'place_name': 'West Paris', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.3253, 'longitude': -70.5732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4290', 'place_name': 'Peru', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.4944, 'longitude': -70.4435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4292', 'place_name': 'Sumner', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Oxford', 'locality_code': '17', 'latitude': 44.374, 'longitude': -70.4469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4401', 'place_name': 'Bangor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8242, 'longitude': -68.7918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4402', 'place_name': 'Bangor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8012, 'longitude': -68.7778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4410', 'place_name': 'Bradford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.0855, 'longitude': -68.9235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4411', 'place_name': 'Bradley', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.9015, 'longitude': -68.6263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4412', 'place_name': 'Brewer', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.7874, 'longitude': -68.7539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4417', 'place_name': 'Burlington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.2349, 'longitude': -68.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4418', 'place_name': 'Greenbush', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.0803, 'longitude': -68.6509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4419', 'place_name': 'Carmel', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8053, 'longitude': -68.9942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4422', 'place_name': 'Charleston', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.067, 'longitude': -69.0869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4427', 'place_name': 'Corinth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.9805, 'longitude': -69.0109, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4428', 'place_name': 'Eddington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.7917, 'longitude': -68.5777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4429', 'place_name': 'Holden', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.7208, 'longitude': -68.6165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4430', 'place_name': 'East Millinocket', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.63, 'longitude': -68.5728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4434', 'place_name': 'Etna', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.7932, 'longitude': -69.1322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4435', 'place_name': 'Exeter', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.9679, 'longitude': -69.1079, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4444', 'place_name': 'Hampden', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.7411, 'longitude': -68.8731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4448', 'place_name': 'Howland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.2456, 'longitude': -68.6666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4449', 'place_name': 'Hudson', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.9914, 'longitude': -68.8878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4450', 'place_name': 'Kenduskeag', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.9183, 'longitude': -68.9342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4451', 'place_name': 'Kingman', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.5984, 'longitude': -68.2366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4453', 'place_name': 'Lagrange', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.1789, 'longitude': -68.8345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4455', 'place_name': 'Lee', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.3635, 'longitude': -68.2909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4456', 'place_name': 'Levant', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8843, 'longitude': -68.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4457', 'place_name': 'Lincoln', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.3508, 'longitude': -68.5077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4459', 'place_name': 'Mattawamkeag', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.5264, 'longitude': -68.352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4460', 'place_name': 'Medway', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.607, 'longitude': -68.5227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4461', 'place_name': 'Milford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.9393, 'longitude': -68.6296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4462', 'place_name': 'Millinocket', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.6596, 'longitude': -68.7101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4468', 'place_name': 'Old Town', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.943, 'longitude': -68.675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4469', 'place_name': 'Orono', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.0028, 'longitude': -68.6334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4473', 'place_name': 'Orono', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8865, 'longitude': -68.7172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4474', 'place_name': 'Orrington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.7263, 'longitude': -68.7876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4475', 'place_name': 'Passadumkeag', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.1815, 'longitude': -68.5871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4487', 'place_name': 'Springfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.4264, 'longitude': -68.1108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4488', 'place_name': 'Stetson', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8843, 'longitude': -69.1069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4489', 'place_name': 'Stillwater', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.9084, 'longitude': -68.6864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4493', 'place_name': 'West Enfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.2378, 'longitude': -68.5338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4495', 'place_name': 'Winn', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.4568, 'longitude': -68.3575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4765', 'place_name': 'Patten', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 46.0132, 'longitude': -68.4647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4777', 'place_name': 'Stacyville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.8637, 'longitude': -68.5053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4928', 'place_name': 'Corinna', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.926, 'longitude': -69.2323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4930', 'place_name': 'Dexter', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.0203, 'longitude': -69.2797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4932', 'place_name': 'Dixmont', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.6991, 'longitude': -69.1025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4933', 'place_name': 'East Newport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8209, 'longitude': -69.2225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4939', 'place_name': 'Garland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 45.0149, 'longitude': -69.157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4953', 'place_name': 'Newport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.8393, 'longitude': -69.2675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4969', 'place_name': 'Plymouth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Penobscot', 'locality_code': '19', 'latitude': 44.7699, 'longitude': -69.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4406', 'place_name': 'Abbot', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.2345, 'longitude': -69.5699, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4414', 'place_name': 'Brownville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.3412, 'longitude': -69.0423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4415', 'place_name': 'Brownville Junction', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.3512, 'longitude': -69.0581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4426', 'place_name': 'Dover Foxcroft', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.1877, 'longitude': -69.2045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4441', 'place_name': 'Greenville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.4716, 'longitude': -69.5844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4442', 'place_name': 'Greenville Junction', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.4796, 'longitude': -69.6939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4443', 'place_name': 'Guilford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.1735, 'longitude': -69.3975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4463', 'place_name': 'Milo', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.2446, 'longitude': -68.976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4464', 'place_name': 'Monson', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.2981, 'longitude': -69.488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4479', 'place_name': 'Sangerville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.1406, 'longitude': -69.3218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4481', 'place_name': 'Sebec', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.2465, 'longitude': -69.1021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4485', 'place_name': 'Shirley Mills', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Piscataquis', 'locality_code': '21', 'latitude': 45.3609, 'longitude': -69.6202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4008', 'place_name': 'Bowdoinham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 44.0101, 'longitude': -69.8984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4086', 'place_name': 'Topsham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 43.9814, 'longitude': -69.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4287', 'place_name': 'Bowdoin', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 44.0575, 'longitude': -69.9656, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '4357', 'place_name': 'Richmond', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 44.1042, 'longitude': -69.8211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4530', 'place_name': 'Bath', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 43.9062, 'longitude': -69.8266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4548', 'place_name': 'Georgetown', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 43.8054, 'longitude': -69.7453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4562', 'place_name': 'Phippsburg', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 43.7688, 'longitude': -69.815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4565', 'place_name': 'Sebasco Estates', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 43.7733, 'longitude': -69.8635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4579', 'place_name': 'Woolwich', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Sagadahoc', 'locality_code': '23', 'latitude': 43.9503, 'longitude': -69.7891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4478', 'place_name': 'Rockwood', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 45.8641, 'longitude': -69.8768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4911', 'place_name': 'Anson', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.7831, 'longitude': -69.9309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4912', 'place_name': 'Athens', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.9388, 'longitude': -69.6695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4920', 'place_name': 'Bingham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 45.0682, 'longitude': -69.8857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4923', 'place_name': 'Cambridge', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 45.0513, 'longitude': -69.4419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4924', 'place_name': 'Canaan', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.745, 'longitude': -69.5498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4925', 'place_name': 'Caratunk', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 45.241, 'longitude': -69.9386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4929', 'place_name': 'Detroit', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.7615, 'longitude': -69.3227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4937', 'place_name': 'Fairfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.6463, 'longitude': -69.6802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4942', 'place_name': 'Harmony', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.973, 'longitude': -69.5481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4943', 'place_name': 'Hartland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.8782, 'longitude': -69.4718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4944', 'place_name': 'Hinckley', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.6847, 'longitude': -69.6425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4945', 'place_name': 'Jackman', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 45.6351, 'longitude': -70.2492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4950', 'place_name': 'Madison', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.8096, 'longitude': -69.8449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4954', 'place_name': 'New Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.8842, 'longitude': -70.0967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4957', 'place_name': 'Norridgewock', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.6899, 'longitude': -69.8306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4958', 'place_name': 'North Anson', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.8797, 'longitude': -69.9119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4961', 'place_name': 'New Portland', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.9251, 'longitude': -70.0231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4965', 'place_name': 'Palmyra', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.8576, 'longitude': -69.3811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4967', 'place_name': 'Pittsfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.7871, 'longitude': -69.4022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4971', 'place_name': 'Saint Albans', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.9293, 'longitude': -69.3992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4975', 'place_name': 'Shawmut', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.6245, 'longitude': -69.5869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4976', 'place_name': 'Skowhegan', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.7772, 'longitude': -69.6976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4978', 'place_name': 'Smithfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.6301, 'longitude': -69.8075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4979', 'place_name': 'Solon', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 44.9676, 'longitude': -69.833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4985', 'place_name': 'West Forks', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Somerset', 'locality_code': '25', 'latitude': 45.3839, 'longitude': -69.9841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4354', 'place_name': 'Palermo', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.3843, 'longitude': -69.4334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4438', 'place_name': 'Frankfort', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.5979, 'longitude': -68.934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4496', 'place_name': 'Winterport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.6552, 'longitude': -68.8862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4848', 'place_name': 'Islesboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.3082, 'longitude': -68.9073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4849', 'place_name': 'Lincolnville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.3048, 'longitude': -69.0824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4850', 'place_name': 'Lincolnville Center', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.2979, 'longitude': -69.1075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4915', 'place_name': 'Belfast', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.4354, 'longitude': -69.0148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4921', 'place_name': 'Brooks', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.5678, 'longitude': -69.1404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4922', 'place_name': 'Burnham', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.6848, 'longitude': -69.38, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4941', 'place_name': 'Freedom', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.4633, 'longitude': -69.319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4949', 'place_name': 'Liberty', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.3741, 'longitude': -69.3306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4951', 'place_name': 'Monroe', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.5927, 'longitude': -69.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4952', 'place_name': 'Morrill', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.4107, 'longitude': -69.1471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4972', 'place_name': 'Sandy Point', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.5148, 'longitude': -68.8128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4973', 'place_name': 'Searsmont', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.377, 'longitude': -69.2196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4974', 'place_name': 'Searsport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.4877, 'longitude': -68.9311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4981', 'place_name': 'Stockton Springs', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.5141, 'longitude': -68.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4986', 'place_name': 'Thorndike', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.5744, 'longitude': -69.2487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4987', 'place_name': 'Troy', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.6757, 'longitude': -69.2549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4988', 'place_name': 'Unity', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Waldo', 'locality_code': '27', 'latitude': 44.6007, 'longitude': -69.3328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4413', 'place_name': 'Brookton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.5507, 'longitude': -67.7436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4424', 'place_name': 'Danforth', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.6687, 'longitude': -67.8688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4454', 'place_name': 'Lambert Lake', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.5459, 'longitude': -67.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4490', 'place_name': 'Topsfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.4304, 'longitude': -67.7473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4491', 'place_name': 'Vanceboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.5634, 'longitude': -67.4297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4492', 'place_name': 'Waite', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.3492, 'longitude': -67.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4606', 'place_name': 'Addison', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.583, 'longitude': -67.7146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4611', 'place_name': 'Beals', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.513, 'longitude': -67.6056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4619', 'place_name': 'Calais', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.1715, 'longitude': -67.2641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4622', 'place_name': 'Cherryfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.6228, 'longitude': -67.9436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4623', 'place_name': 'Columbia Falls', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.6699, 'longitude': -67.7534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4626', 'place_name': 'Cutler', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.6753, 'longitude': -67.2499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4628', 'place_name': 'Dennysville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.8961, 'longitude': -67.2244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4630', 'place_name': 'East Machias', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.7424, 'longitude': -67.3821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4631', 'place_name': 'Eastport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.92, 'longitude': -67.0074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4637', 'place_name': 'Grand Lake Stream', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.1795, 'longitude': -67.7744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4643', 'place_name': 'Harrington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.6122, 'longitude': -67.8147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4648', 'place_name': 'Jonesboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.6582, 'longitude': -67.5777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4649', 'place_name': 'Jonesport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.5509, 'longitude': -67.6044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4652', 'place_name': 'Lubec', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.9043, 'longitude': -67.0408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4654', 'place_name': 'Machias', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.7215, 'longitude': -67.482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4655', 'place_name': 'Machiasport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.682, 'longitude': -67.4073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4657', 'place_name': 'Meddybemps', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.0193, 'longitude': -67.3829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4658', 'place_name': 'Milbridge', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.5366, 'longitude': -67.8844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4666', 'place_name': 'Pembroke', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.9654, 'longitude': -67.2002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4667', 'place_name': 'Perry', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.9888, 'longitude': -67.0929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4668', 'place_name': 'Princeton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.2131, 'longitude': -67.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4671', 'place_name': 'Robbinston', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.067, 'longitude': -67.1433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4680', 'place_name': 'Steuben', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.4971, 'longitude': -67.9503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4686', 'place_name': 'Wesley', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.9854, 'longitude': -67.6991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4691', 'place_name': 'Whiting', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 44.7622, 'longitude': -67.2515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4694', 'place_name': 'Baileyville', 'state': 'Maine', 'state_ab': 'ME', 'county': 'Washington', 'locality_code': '29', 'latitude': 45.1035, 'longitude': -67.4722, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '3901', 'place_name': 'Berwick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.2899, 'longitude': -70.855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3902', 'place_name': 'Cape Neddick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.2133, 'longitude': -70.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3903', 'place_name': 'Eliot', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.1309, 'longitude': -70.7822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3904', 'place_name': 'Kittery', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.0921, 'longitude': -70.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3905', 'place_name': 'Kittery Point', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.0976, 'longitude': -70.7121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3906', 'place_name': 'North Berwick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.3254, 'longitude': -70.7212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3907', 'place_name': 'Ogunquit', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.2541, 'longitude': -70.6094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3908', 'place_name': 'South Berwick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.2292, 'longitude': -70.7859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3909', 'place_name': 'York', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.1544, 'longitude': -70.6578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3910', 'place_name': 'York Beach', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.1715, 'longitude': -70.6089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3911', 'place_name': 'York Harbor', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.1368, 'longitude': -70.6456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4001', 'place_name': 'Acton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5494, 'longitude': -70.9307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4002', 'place_name': 'Alfred', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4875, 'longitude': -70.6961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4004', 'place_name': 'Bar Mills', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.6131, 'longitude': -70.5498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4005', 'place_name': 'Biddeford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4935, 'longitude': -70.4883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4006', 'place_name': 'Biddeford Pool', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4448, 'longitude': -70.3414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4007', 'place_name': 'Biddeford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4581, 'longitude': -70.5053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4014', 'place_name': 'Cape Porpoise', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.3657, 'longitude': -70.6044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4020', 'place_name': 'Cornish', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.7796, 'longitude': -70.7784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4027', 'place_name': 'Lebanon', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4597, 'longitude': -70.9152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4028', 'place_name': 'East Parsonsfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.7334, 'longitude': -70.8434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4030', 'place_name': 'East Waterboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5995, 'longitude': -70.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4042', 'place_name': 'Hollis Center', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5946, 'longitude': -70.6051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4043', 'place_name': 'Kennebunk', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.3881, 'longitude': -70.5478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4046', 'place_name': 'Kennebunkport', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.3923, 'longitude': -70.4729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4047', 'place_name': 'Parsonsfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.745, 'longitude': -70.9092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4048', 'place_name': 'Limerick', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.6963, 'longitude': -70.7866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4049', 'place_name': 'Limington', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.726, 'longitude': -70.6752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4054', 'place_name': 'Moody', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.2763, 'longitude': -70.5978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4056', 'place_name': 'Newfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.6584, 'longitude': -70.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4061', 'place_name': 'North Waterboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.64, 'longitude': -70.7298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4063', 'place_name': 'Ocean Park', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5006, 'longitude': -70.3862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4064', 'place_name': 'Old Orchard Beach', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5254, 'longitude': -70.3883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4072', 'place_name': 'Saco', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5209, 'longitude': -70.4546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4073', 'place_name': 'Sanford', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4285, 'longitude': -70.7585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4076', 'place_name': 'Shapleigh', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5674, 'longitude': -70.8286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4083', 'place_name': 'Springvale', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4715, 'longitude': -70.8064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4087', 'place_name': 'Waterboro', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.5661, 'longitude': -70.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4090', 'place_name': 'Wells', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.3144, 'longitude': -70.5969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4093', 'place_name': 'Buxton', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.6379, 'longitude': -70.5189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4094', 'place_name': 'West Kennebunk', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.4061, 'longitude': -70.5733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '4095', 'place_name': 'West Newfield', 'state': 'Maine', 'state_ab': 'ME', 'county': 'York', 'locality_code': '31', 'latitude': 43.601, 'longitude': -70.9027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96960', 'place_name': 'Marshall Islands', 'state': 'Marshall Islands', 'state_ab': 'MH', 'county': 'Marshall Islands', 'locality_code': '20', 'latitude': 7.1128, 'longitude': 171.237, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96970', 'place_name': 'Ebeye', 'state': 'Marshall Islands', 'state_ab': 'MH', 'county': 'Marshall Islands', 'locality_code': '20', 'latitude': 8.786, 'longitude': 167.7365, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48705', 'place_name': 'Barton City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.702, 'longitude': -83.5994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48721', 'place_name': 'Black River', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.8138, 'longitude': -83.3407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48728', 'place_name': 'Curran', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.7336, 'longitude': -83.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48737', 'place_name': 'Glennie', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.5582, 'longitude': -83.6899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48738', 'place_name': 'Greenbush', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.548, 'longitude': -83.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48740', 'place_name': 'Harrisville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.6546, 'longitude': -83.3424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48742', 'place_name': 'Lincoln', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.7111, 'longitude': -83.3947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48745', 'place_name': 'Mikado', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.5833, 'longitude': -83.4355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48762', 'place_name': 'Spruce', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alcona', 'locality_code': '1', 'latitude': 44.8224, 'longitude': -83.5044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49806', 'place_name': 'Au Train', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.4446, 'longitude': -86.9115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49816', 'place_name': 'Chatham', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.3477, 'longitude': -86.929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49822', 'place_name': 'Deerton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.427, 'longitude': -87.0497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49825', 'place_name': 'Eben Junction', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.3549, 'longitude': -86.9701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49826', 'place_name': 'Rumely', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.3483, 'longitude': -87.0332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49839', 'place_name': 'Grand Marais', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.6529, 'longitude': -85.9836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49862', 'place_name': 'Munising', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.3994, 'longitude': -86.6983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49884', 'place_name': 'Shingleton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.3512, 'longitude': -86.4823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49891', 'place_name': 'Trenary', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.1947, 'longitude': -86.9502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49895', 'place_name': 'Wetmore', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alger', 'locality_code': '3', 'latitude': 46.3535, 'longitude': -86.6345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49010', 'place_name': 'Allegan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.5256, 'longitude': -85.8661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49070', 'place_name': 'Martin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.537, 'longitude': -85.6417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49078', 'place_name': 'Otsego', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.4723, 'longitude': -85.7035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49080', 'place_name': 'Plainwell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.4544, 'longitude': -85.5994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49311', 'place_name': 'Bradley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.633, 'longitude': -85.643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49314', 'place_name': 'Burnips', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.7312, 'longitude': -85.8404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49323', 'place_name': 'Dorr', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.7231, 'longitude': -85.7628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49328', 'place_name': 'Hopkins', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.6421, 'longitude': -85.7322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49335', 'place_name': 'Moline', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.737, 'longitude': -85.6635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49344', 'place_name': 'Shelbyville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.5936, 'longitude': -85.6282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49348', 'place_name': 'Wayland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.6643, 'longitude': -85.6191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49406', 'place_name': 'Douglas', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.6369, 'longitude': -86.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49408', 'place_name': 'Fennville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.5777, 'longitude': -86.1249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49416', 'place_name': 'Glenn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.5203, 'longitude': -86.2275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49419', 'place_name': 'Hamilton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.6881, 'longitude': -85.9747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49450', 'place_name': 'Pullman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.4651, 'longitude': -86.0799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49453', 'place_name': 'Saugatuck', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Allegan', 'locality_code': '5', 'latitude': 42.6456, 'longitude': -86.1655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49707', 'place_name': 'Alpena', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alpena', 'locality_code': '7', 'latitude': 45.079, 'longitude': -83.4602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49744', 'place_name': 'Herron', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alpena', 'locality_code': '7', 'latitude': 45.0124, 'longitude': -83.6535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49747', 'place_name': 'Hubbard Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alpena', 'locality_code': '7', 'latitude': 44.8947, 'longitude': -83.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49753', 'place_name': 'Lachine', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alpena', 'locality_code': '7', 'latitude': 45.0429, 'longitude': -83.7491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49766', 'place_name': 'Ossineke', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Alpena', 'locality_code': '7', 'latitude': 44.9104, 'longitude': -83.4592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49611', 'place_name': 'Alba', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 44.9737, 'longitude': -84.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49612', 'place_name': 'Alden', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 44.8779, 'longitude': -85.2241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49615', 'place_name': 'Bellaire', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 44.9765, 'longitude': -85.2265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49622', 'place_name': 'Central Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 45.0748, 'longitude': -85.2673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49627', 'place_name': 'Eastport', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 45.1072, 'longitude': -85.3501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49629', 'place_name': 'Elk Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 44.8955, 'longitude': -85.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49648', 'place_name': 'Kewadin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 45.0126, 'longitude': -85.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49659', 'place_name': 'Mancelona', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 44.9116, 'longitude': -85.0634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49729', 'place_name': 'Ellsworth', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Antrim', 'locality_code': '9', 'latitude': 45.1599, 'longitude': -85.2633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48658', 'place_name': 'Standish', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Arenac', 'locality_code': '11', 'latitude': 43.9733, 'longitude': -83.9433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48659', 'place_name': 'Sterling', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Arenac', 'locality_code': '11', 'latitude': 44.0669, 'longitude': -84.0505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48703', 'place_name': 'Au Gres', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Arenac', 'locality_code': '11', 'latitude': 44.0338, 'longitude': -83.702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48749', 'place_name': 'Omer', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Arenac', 'locality_code': '11', 'latitude': 44.0499, 'longitude': -83.843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48765', 'place_name': 'Turner', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Arenac', 'locality_code': '11', 'latitude': 44.1105, 'longitude': -83.7019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48766', 'place_name': 'Twining', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Arenac', 'locality_code': '11', 'latitude': 44.1293, 'longitude': -83.8491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49908', 'place_name': 'Baraga', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Baraga', 'locality_code': '13', 'latitude': 46.8048, 'longitude': -88.5758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49919', 'place_name': 'Covington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Baraga', 'locality_code': '13', 'latitude': 46.5413, 'longitude': -88.5371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49946', 'place_name': 'Lanse', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Baraga', 'locality_code': '13', 'latitude': 46.7704, 'longitude': -88.421, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49962', 'place_name': 'Skanee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Baraga', 'locality_code': '13', 'latitude': 46.8747, 'longitude': -88.1732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49970', 'place_name': 'Watton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Baraga', 'locality_code': '13', 'latitude': 46.5413, 'longitude': -88.6049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48897', 'place_name': 'Woodland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.7057, 'longitude': -85.1326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49035', 'place_name': 'Cloverdale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.5951, 'longitude': -85.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49046', 'place_name': 'Delton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.5141, 'longitude': -85.4067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49050', 'place_name': 'Dowling', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.5015, 'longitude': -85.2495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49058', 'place_name': 'Hastings', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.643, 'longitude': -85.2937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49060', 'place_name': 'Hickory Corners', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.4237, 'longitude': -85.3998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49073', 'place_name': 'Nashville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.5937, 'longitude': -85.122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49325', 'place_name': 'Freeport', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.7661, 'longitude': -85.3133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49333', 'place_name': 'Middleville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Barry', 'locality_code': '15', 'latitude': 42.6932, 'longitude': -85.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48611', 'place_name': 'Auburn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.608, 'longitude': -84.1027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48613', 'place_name': 'Bentley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.9267, 'longitude': -84.1053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48631', 'place_name': 'Kawkawlin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.6794, 'longitude': -83.9927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48634', 'place_name': 'Linwood', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.7714, 'longitude': -84.0513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48650', 'place_name': 'Pinconning', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.8491, 'longitude': -84.0082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48706', 'place_name': 'Bay City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.6088, 'longitude': -83.953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48707', 'place_name': 'Bay City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.7378, 'longitude': -83.9333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48708', 'place_name': 'Bay City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.5821, 'longitude': -83.8781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48710', 'place_name': 'University Center', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.5566, 'longitude': -83.9943, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48732', 'place_name': 'Essexville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.6069, 'longitude': -83.8217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48747', 'place_name': 'Munger', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Bay', 'locality_code': '17', 'latitude': 43.5286, 'longitude': -83.7672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49616', 'place_name': 'Benzonia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Benzie', 'locality_code': '19', 'latitude': 44.5955, 'longitude': -86.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49617', 'place_name': 'Beulah', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Benzie', 'locality_code': '19', 'latitude': 44.6306, 'longitude': -86.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49628', 'place_name': 'Elberta', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Benzie', 'locality_code': '19', 'latitude': 44.6194, 'longitude': -86.2265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49635', 'place_name': 'Frankfort', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Benzie', 'locality_code': '19', 'latitude': 44.6311, 'longitude': -86.2212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49640', 'place_name': 'Honor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Benzie', 'locality_code': '19', 'latitude': 44.6954, 'longitude': -86.0376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49650', 'place_name': 'Lake Ann', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Benzie', 'locality_code': '19', 'latitude': 44.7317, 'longitude': -85.8528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49683', 'place_name': 'Thompsonville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Benzie', 'locality_code': '19', 'latitude': 44.5198, 'longitude': -85.946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49022', 'place_name': 'Benton Harbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.1086, 'longitude': -86.4234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49023', 'place_name': 'Benton Harbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.1167, 'longitude': -86.4542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49038', 'place_name': 'Coloma', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.203, 'longitude': -86.3225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49039', 'place_name': 'Hagar Shores', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.2248, 'longitude': -86.3723, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49084', 'place_name': 'Riverside', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.1834, 'longitude': -86.3828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49085', 'place_name': 'Saint Joseph', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.064, 'longitude': -86.4783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49098', 'place_name': 'Watervliet', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.1938, 'longitude': -86.2604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49101', 'place_name': 'Baroda', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.9488, 'longitude': -86.4913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49102', 'place_name': 'Berrien Center', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.9484, 'longitude': -86.285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49103', 'place_name': 'Berrien Springs', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.948, 'longitude': -86.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49104', 'place_name': 'Berrien Springs', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.9464, 'longitude': -86.3389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49106', 'place_name': 'Bridgman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.9362, 'longitude': -86.5543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49107', 'place_name': 'Buchanan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8327, 'longitude': -86.3708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49111', 'place_name': 'Eau Claire', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.0151, 'longitude': -86.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49113', 'place_name': 'Galien', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8198, 'longitude': -86.5035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49115', 'place_name': 'Harbert', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8771, 'longitude': -86.6302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49116', 'place_name': 'Lakeside', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8485, 'longitude': -86.6694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49117', 'place_name': 'New Buffalo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.7927, 'longitude': -86.746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49119', 'place_name': 'New Troy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8744, 'longitude': -86.549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49120', 'place_name': 'Niles', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8202, 'longitude': -86.2368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49125', 'place_name': 'Sawyer', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8829, 'longitude': -86.5885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49126', 'place_name': 'Sodus', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.0521, 'longitude': -86.3921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49127', 'place_name': 'Stevensville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 42.022, 'longitude': -86.5119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49128', 'place_name': 'Three Oaks', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.815, 'longitude': -86.6154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49129', 'place_name': 'Union Pier', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Berrien', 'locality_code': '21', 'latitude': 41.8255, 'longitude': -86.6911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49028', 'place_name': 'Bronson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Branch', 'locality_code': '23', 'latitude': 41.8643, 'longitude': -85.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49036', 'place_name': 'Coldwater', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Branch', 'locality_code': '23', 'latitude': 41.9255, 'longitude': -85.0057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49082', 'place_name': 'Quincy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Branch', 'locality_code': '23', 'latitude': 41.9442, 'longitude': -84.8839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49089', 'place_name': 'Sherwood', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Branch', 'locality_code': '23', 'latitude': 42.0107, 'longitude': -85.2408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49094', 'place_name': 'Union City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Branch', 'locality_code': '23', 'latitude': 42.0551, 'longitude': -85.1356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49255', 'place_name': 'Montgomery', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Branch', 'locality_code': '23', 'latitude': 41.7928, 'longitude': -84.8496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49011', 'place_name': 'Athens', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.103, 'longitude': -85.2317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49014', 'place_name': 'Battle Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.303, 'longitude': -85.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49015', 'place_name': 'Battle Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.3028, 'longitude': -85.2128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49016', 'place_name': 'Battle Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.2464, 'longitude': -85.0045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49017', 'place_name': 'Battle Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.3173, 'longitude': -85.1782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49018', 'place_name': 'Battle Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.2464, 'longitude': -85.0045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49020', 'place_name': 'Bedford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.3953, 'longitude': -85.2322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49029', 'place_name': 'Burlington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.1239, 'longitude': -85.105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49033', 'place_name': 'Ceresco', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.2127, 'longitude': -85.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49037', 'place_name': 'Battle Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.3453, 'longitude': -85.2178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49051', 'place_name': 'East Leroy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.1961, 'longitude': -85.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49068', 'place_name': 'Marshall', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.272, 'longitude': -84.9583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49092', 'place_name': 'Tekonsha', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.0863, 'longitude': -84.9926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49224', 'place_name': 'Albion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.2581, 'longitude': -84.7561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49245', 'place_name': 'Homer', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Calhoun', 'locality_code': '25', 'latitude': 42.1416, 'longitude': -84.8157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49031', 'place_name': 'Cassopolis', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cass', 'locality_code': '27', 'latitude': 41.8968, 'longitude': -85.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49047', 'place_name': 'Dowagiac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cass', 'locality_code': '27', 'latitude': 41.991, 'longitude': -86.1168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49061', 'place_name': 'Jones', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cass', 'locality_code': '27', 'latitude': 41.9129, 'longitude': -85.8341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49067', 'place_name': 'Marcellus', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cass', 'locality_code': '27', 'latitude': 42.0275, 'longitude': -85.7988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49095', 'place_name': 'Vandalia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cass', 'locality_code': '27', 'latitude': 41.8955, 'longitude': -85.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49112', 'place_name': 'Edwardsburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cass', 'locality_code': '27', 'latitude': 41.7913, 'longitude': -86.0263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49130', 'place_name': 'Union', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cass', 'locality_code': '27', 'latitude': 41.7827, 'longitude': -85.8529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49711', 'place_name': 'Bay Shore', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Charlevoix', 'locality_code': '29', 'latitude': 45.3583, 'longitude': -85.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49712', 'place_name': 'Boyne City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Charlevoix', 'locality_code': '29', 'latitude': 45.2052, 'longitude': -85.0183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49713', 'place_name': 'Boyne Falls', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Charlevoix', 'locality_code': '29', 'latitude': 45.2116, 'longitude': -84.8916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49720', 'place_name': 'Charlevoix', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Charlevoix', 'locality_code': '29', 'latitude': 45.2654, 'longitude': -85.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49727', 'place_name': 'East Jordan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Charlevoix', 'locality_code': '29', 'latitude': 45.1539, 'longitude': -85.1387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49782', 'place_name': 'Beaver Island', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Charlevoix', 'locality_code': '29', 'latitude': 45.6684, 'longitude': -85.5473, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49796', 'place_name': 'Walloon Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Charlevoix', 'locality_code': '29', 'latitude': 45.2661, 'longitude': -84.9337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49701', 'place_name': 'Mackinaw City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.7777, 'longitude': -84.7298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49705', 'place_name': 'Afton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.3637, 'longitude': -84.4695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49716', 'place_name': 'Brutus', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.5068, 'longitude': -84.7467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49717', 'place_name': 'Burt Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.4408, 'longitude': -84.7112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49721', 'place_name': 'Cheboygan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.608, 'longitude': -84.4867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49749', 'place_name': 'Indian River', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.427, 'longitude': -84.5956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49761', 'place_name': 'Mullett Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.5595, 'longitude': -84.5221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49791', 'place_name': 'Topinabee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.4838, 'longitude': -84.5936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49792', 'place_name': 'Tower', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.3588, 'longitude': -84.2953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49799', 'place_name': 'Wolverine', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Cheboygan', 'locality_code': '31', 'latitude': 45.2861, 'longitude': -84.6065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49710', 'place_name': 'Barbeau', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.2848, 'longitude': -84.2173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49715', 'place_name': 'Brimley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.3891, 'longitude': -84.6981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49724', 'place_name': 'Dafter', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.327, 'longitude': -84.3878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49725', 'place_name': 'De Tour Village', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 45.9939, 'longitude': -83.9396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49726', 'place_name': 'Drummond Island', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.0055, 'longitude': -83.7367, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49728', 'place_name': 'Eckerman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.4088, 'longitude': -85.0136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49736', 'place_name': 'Goetzville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.079, 'longitude': -84.145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49748', 'place_name': 'Hulbert', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.3908, 'longitude': -85.1764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49752', 'place_name': 'Kinross', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.275, 'longitude': -84.5148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49768', 'place_name': 'Paradise', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.5951, 'longitude': -85.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49774', 'place_name': 'Pickford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.1559, 'longitude': -84.3663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49780', 'place_name': 'Rudyard', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.2585, 'longitude': -84.8004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49783', 'place_name': 'Sault Sainte Marie', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.4151, 'longitude': -84.2854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49784', 'place_name': 'Kincheloe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.4108, 'longitude': -84.3365, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49785', 'place_name': 'Kincheloe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.1815, 'longitude': -84.4054, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49786', 'place_name': 'Kincheloe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.4108, 'longitude': -84.3365, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49788', 'place_name': 'Kincheloe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.2627, 'longitude': -84.4626, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49793', 'place_name': 'Trout Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Chippewa', 'locality_code': '33', 'latitude': 46.1936, 'longitude': -85.019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48617', 'place_name': 'Clare', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clare', 'locality_code': '35', 'latitude': 43.8223, 'longitude': -84.7635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48622', 'place_name': 'Farwell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clare', 'locality_code': '35', 'latitude': 43.8342, 'longitude': -84.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48625', 'place_name': 'Harrison', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clare', 'locality_code': '35', 'latitude': 44.0285, 'longitude': -84.7729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48632', 'place_name': 'Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clare', 'locality_code': '35', 'latitude': 43.8575, 'longitude': -85.0219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48633', 'place_name': 'Lake George', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clare', 'locality_code': '35', 'latitude': 43.9634, 'longitude': -84.947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48808', 'place_name': 'Bath', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 42.8206, 'longitude': -84.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48820', 'place_name': 'Dewitt', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 42.8428, 'longitude': -84.5797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48822', 'place_name': 'Eagle', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 42.8263, 'longitude': -84.759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48831', 'place_name': 'Elsie', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 43.0886, 'longitude': -84.3869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48833', 'place_name': 'Eureka', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 43.1036, 'longitude': -84.5139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48835', 'place_name': 'Fowler', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 42.9941, 'longitude': -84.76, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48853', 'place_name': 'Maple Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 43.0992, 'longitude': -84.6898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48866', 'place_name': 'Ovid', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 42.9969, 'longitude': -84.3649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48879', 'place_name': 'Saint Johns', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 43.0059, 'longitude': -84.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48894', 'place_name': 'Westphalia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Clinton', 'locality_code': '37', 'latitude': 42.9328, 'longitude': -84.8083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49733', 'place_name': 'Frederic', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Crawford', 'locality_code': '39', 'latitude': 44.8382, 'longitude': -84.6824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49738', 'place_name': 'Grayling', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Crawford', 'locality_code': '39', 'latitude': 44.671, 'longitude': -84.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49739', 'place_name': 'Grayling', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Crawford', 'locality_code': '39', 'latitude': 44.683, 'longitude': -84.6104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49807', 'place_name': 'Bark River', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.6956, 'longitude': -87.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49818', 'place_name': 'Cornell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.9104, 'longitude': -87.2237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49829', 'place_name': 'Escanaba', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.7659, 'longitude': -87.089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49835', 'place_name': 'Garden', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.7549, 'longitude': -86.5776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49837', 'place_name': 'Gladstone', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.8813, 'longitude': -87.1152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49864', 'place_name': 'Nahma', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.8424, 'longitude': -86.6558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49872', 'place_name': 'Perkins', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.9925, 'longitude': -87.0792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49878', 'place_name': 'Rapid River', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.9107, 'longitude': -86.8845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49880', 'place_name': 'Rock', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 46.0503, 'longitude': -87.1331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49894', 'place_name': 'Wells', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Delta', 'locality_code': '41', 'latitude': 45.7849, 'longitude': -87.0734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49801', 'place_name': 'Iron Mountain', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.8219, 'longitude': -88.0683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49802', 'place_name': 'Kingsford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.8006, 'longitude': -88.0773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49815', 'place_name': 'Channing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 46.1546, 'longitude': -88.0772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49831', 'place_name': 'Felch', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.9972, 'longitude': -87.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49834', 'place_name': 'Foster City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.9438, 'longitude': -87.7584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49852', 'place_name': 'Loretto', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.7772, 'longitude': -87.8151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49870', 'place_name': 'Norway', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.7862, 'longitude': -87.9047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49876', 'place_name': 'Quinnesec', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.7999, 'longitude': -87.9922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49877', 'place_name': 'Ralph', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 46.1297, 'longitude': -87.7367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49881', 'place_name': 'Sagola', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 46.0813, 'longitude': -88.0676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49892', 'place_name': 'Vulcan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Dickinson', 'locality_code': '43', 'latitude': 45.7623, 'longitude': -87.8168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48813', 'place_name': 'Charlotte', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.5702, 'longitude': -84.8352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48821', 'place_name': 'Dimondale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.6501, 'longitude': -84.6486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48827', 'place_name': 'Eaton Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.5166, 'longitude': -84.6565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48837', 'place_name': 'Grand Ledge', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.7529, 'longitude': -84.7373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48861', 'place_name': 'Mulliken', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.7377, 'longitude': -84.8979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48876', 'place_name': 'Potterville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.6398, 'longitude': -84.7346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48890', 'place_name': 'Sunfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.7693, 'longitude': -84.9813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48908', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.5961, 'longitude': -84.8382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48917', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.7376, 'longitude': -84.6244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49021', 'place_name': 'Bellevue', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.4525, 'longitude': -85.0489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49076', 'place_name': 'Olivet', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.4459, 'longitude': -84.8973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49096', 'place_name': 'Vermontville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Eaton', 'locality_code': '45', 'latitude': 42.6392, 'longitude': -85.011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49706', 'place_name': 'Alanson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.4405, 'longitude': -84.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49718', 'place_name': 'Carp Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.7424, 'longitude': -84.7735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49722', 'place_name': 'Conway', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.4167, 'longitude': -84.867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49723', 'place_name': 'Cross Village', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.6254, 'longitude': -85.0419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49737', 'place_name': 'Good Hart', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.5802, 'longitude': -85.1137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49740', 'place_name': 'Harbor Springs', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.5251, 'longitude': -85.0062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49755', 'place_name': 'Levering', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.6377, 'longitude': -84.7986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49764', 'place_name': 'Oden', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.4236, 'longitude': -84.8281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49769', 'place_name': 'Pellston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.5703, 'longitude': -84.8425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49770', 'place_name': 'Petoskey', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Emmet', 'locality_code': '47', 'latitude': 45.3559, 'longitude': -84.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48411', 'place_name': 'Atlas', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.94, 'longitude': -83.5369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48420', 'place_name': 'Clio', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.1779, 'longitude': -83.7249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48423', 'place_name': 'Davison', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0348, 'longitude': -83.5268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48430', 'place_name': 'Fenton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.7851, 'longitude': -83.7294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48433', 'place_name': 'Flushing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.072, 'longitude': -83.8424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48436', 'place_name': 'Gaines', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.8813, 'longitude': -83.8855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48437', 'place_name': 'Genesee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.1123, 'longitude': -83.6154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48438', 'place_name': 'Goodrich', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9147, 'longitude': -83.4845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48439', 'place_name': 'Grand Blanc', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9282, 'longitude': -83.6264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48449', 'place_name': 'Lennon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9693, 'longitude': -83.9279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48451', 'place_name': 'Linden', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.8104, 'longitude': -83.7993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48457', 'place_name': 'Montrose', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.1754, 'longitude': -83.8824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48458', 'place_name': 'Mount Morris', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.116, 'longitude': -83.6895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48463', 'place_name': 'Otisville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.1706, 'longitude': -83.5172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48473', 'place_name': 'Swartz Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9468, 'longitude': -83.817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48480', 'place_name': 'Grand Blanc', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.918, 'longitude': -83.617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48501', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9659, 'longitude': -83.7808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48502', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0151, 'longitude': -83.6948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48503', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0128, 'longitude': -83.6914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48504', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0573, 'longitude': -83.7498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48505', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0634, 'longitude': -83.7001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48506', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0653, 'longitude': -83.631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48507', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9821, 'longitude': -83.734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48509', 'place_name': 'Burton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0259, 'longitude': -83.6041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48519', 'place_name': 'Burton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9859, 'longitude': -83.6135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48529', 'place_name': 'Burton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9744, 'longitude': -83.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48531', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.002, 'longitude': -83.6925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48532', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0111, 'longitude': -83.803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48550', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0349, 'longitude': -83.6887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48551', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.979, 'longitude': -83.7131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48552', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9779, 'longitude': -83.7131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48553', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9736, 'longitude': -83.7203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48554', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 42.9722, 'longitude': -83.7946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48555', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0113, 'longitude': -83.7108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48556', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0327, 'longitude': -83.6463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48557', 'place_name': 'Flint', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Genesee', 'locality_code': '49', 'latitude': 43.0806, 'longitude': -83.7837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48612', 'place_name': 'Beaverton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gladwin', 'locality_code': '51', 'latitude': 43.8866, 'longitude': -84.4241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48624', 'place_name': 'Gladwin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gladwin', 'locality_code': '51', 'latitude': 44.0296, 'longitude': -84.4968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48638', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gladwin', 'locality_code': '51', 'latitude': 43.4343, 'longitude': -84.0091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48652', 'place_name': 'Rhodes', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gladwin', 'locality_code': '51', 'latitude': 43.8517, 'longitude': -84.2134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49911', 'place_name': 'Bessemer', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gogebic', 'locality_code': '53', 'latitude': 46.4802, 'longitude': -90.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49938', 'place_name': 'Ironwood', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gogebic', 'locality_code': '53', 'latitude': 46.4638, 'longitude': -90.1588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49947', 'place_name': 'Marenisco', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gogebic', 'locality_code': '53', 'latitude': 46.3551, 'longitude': -89.6774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49959', 'place_name': 'Ramsay', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gogebic', 'locality_code': '53', 'latitude': 46.4727, 'longitude': -89.9976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49968', 'place_name': 'Wakefield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gogebic', 'locality_code': '53', 'latitude': 46.4752, 'longitude': -89.9424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49969', 'place_name': 'Watersmeet', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gogebic', 'locality_code': '53', 'latitude': 46.2542, 'longitude': -89.2108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49610', 'place_name': 'Acme', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.7894, 'longitude': -85.4884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49633', 'place_name': 'Fife Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.5721, 'longitude': -85.2531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49637', 'place_name': 'Grawn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.6428, 'longitude': -85.7113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49643', 'place_name': 'Interlochen', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.6518, 'longitude': -85.8022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49649', 'place_name': 'Kingsley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.5756, 'longitude': -85.5262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49666', 'place_name': 'Mayfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.6261, 'longitude': -85.5287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49673', 'place_name': 'Old Mission', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.9559, 'longitude': -85.49, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49684', 'place_name': 'Traverse City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.694, 'longitude': -85.6763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49685', 'place_name': 'Traverse City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.8162, 'longitude': -85.5751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49686', 'place_name': 'Traverse City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.7631, 'longitude': -85.6206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49690', 'place_name': 'Williamsburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.802, 'longitude': -85.4347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49696', 'place_name': 'Traverse City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Grand Traverse', 'locality_code': '55', 'latitude': 44.8162, 'longitude': -85.5751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48615', 'place_name': 'Breckenridge', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.3935, 'longitude': -84.5023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48662', 'place_name': 'Wheeler', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.3962, 'longitude': -84.4243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48801', 'place_name': 'Alma', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.3809, 'longitude': -84.6635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48806', 'place_name': 'Ashley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.1891, 'longitude': -84.488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48807', 'place_name': 'Bannister', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.1615, 'longitude': -84.3597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48830', 'place_name': 'Elm Hall', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.3639, 'longitude': -84.8362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48832', 'place_name': 'Elwell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.4106, 'longitude': -84.7631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48847', 'place_name': 'Ithaca', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.2828, 'longitude': -84.6088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48856', 'place_name': 'Middleton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.1689, 'longitude': -84.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48862', 'place_name': 'North Star', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.2484, 'longitude': -84.5433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48871', 'place_name': 'Perrinton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.1649, 'longitude': -84.666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48874', 'place_name': 'Pompeii', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.1863, 'longitude': -84.6017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48877', 'place_name': 'Riverdale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.4017, 'longitude': -84.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48880', 'place_name': 'Saint Louis', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.4278, 'longitude': -84.5952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48889', 'place_name': 'Sumner', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Gratiot', 'locality_code': '57', 'latitude': 43.3091, 'longitude': -84.7907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49227', 'place_name': 'Allen', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.957, 'longitude': -84.7677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49232', 'place_name': 'Camden', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.7361, 'longitude': -84.7245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49239', 'place_name': 'Frontier', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.7825, 'longitude': -84.6047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49242', 'place_name': 'Hillsdale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.924, 'longitude': -84.6208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49249', 'place_name': 'Jerome', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 42.0484, 'longitude': -84.4455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49250', 'place_name': 'Jonesville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.9798, 'longitude': -84.6451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49252', 'place_name': 'Litchfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 42.0369, 'longitude': -84.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49257', 'place_name': 'Moscow', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 42.0548, 'longitude': -84.5039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49258', 'place_name': 'Mosherville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 42.0603, 'longitude': -84.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49262', 'place_name': 'North Adams', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.9715, 'longitude': -84.5208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49266', 'place_name': 'Osseo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.8384, 'longitude': -84.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49271', 'place_name': 'Pittsford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.8963, 'longitude': -84.444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49274', 'place_name': 'Reading', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.8442, 'longitude': -84.7648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49281', 'place_name': 'Somerset', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 42.023, 'longitude': -84.3794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49282', 'place_name': 'Somerset Center', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 42.0388, 'longitude': -84.406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49288', 'place_name': 'Waldron', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Hillsdale', 'locality_code': '59', 'latitude': 41.7386, 'longitude': -84.4496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49905', 'place_name': 'Atlantic Mine', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.0937, 'longitude': -88.6613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49913', 'place_name': 'Calumet', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.2439, 'longitude': -88.4588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49916', 'place_name': 'Chassell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.002, 'longitude': -88.5546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49917', 'place_name': 'Copper City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.2842, 'longitude': -88.3875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49921', 'place_name': 'Dodgeville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.0914, 'longitude': -88.5809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49922', 'place_name': 'Dollar Bay', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.1196, 'longitude': -88.5115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49930', 'place_name': 'Hancock', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.1367, 'longitude': -88.5654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49931', 'place_name': 'Houghton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.1158, 'longitude': -88.558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49934', 'place_name': 'Hubbell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.1733, 'longitude': -88.4293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49942', 'place_name': 'Kearsarge', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.2694, 'longitude': -88.4184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49945', 'place_name': 'Lake Linden', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.1784, 'longitude': -88.2973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49952', 'place_name': 'Nisula', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 46.7748, 'longitude': -88.8799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49955', 'place_name': 'Painesdale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.0404, 'longitude': -88.6704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49958', 'place_name': 'Pelkie', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 46.7949, 'longitude': -88.6251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49961', 'place_name': 'Sidnaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 46.5047, 'longitude': -88.7085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49963', 'place_name': 'South Range', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 47.0719, 'longitude': -88.652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49965', 'place_name': 'Toivola', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Houghton', 'locality_code': '61', 'latitude': 46.9109, 'longitude': -88.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48413', 'place_name': 'Bad Axe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.8067, 'longitude': -83.0054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48432', 'place_name': 'Filion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.9014, 'longitude': -82.9825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48441', 'place_name': 'Harbor Beach', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.8312, 'longitude': -82.6886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48445', 'place_name': 'Kinde', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.948, 'longitude': -82.9755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48467', 'place_name': 'Port Austin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 44.0223, 'longitude': -82.9984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48468', 'place_name': 'Port Hope', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.928, 'longitude': -82.7529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48470', 'place_name': 'Ruth', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.7404, 'longitude': -82.7414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48475', 'place_name': 'Ubly', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.6896, 'longitude': -82.964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48720', 'place_name': 'Bay Port', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.8377, 'longitude': -83.3525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48725', 'place_name': 'Caseville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.9429, 'longitude': -83.2659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48731', 'place_name': 'Elkton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.8344, 'longitude': -83.1786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48754', 'place_name': 'Owendale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.7206, 'longitude': -83.2307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48755', 'place_name': 'Pigeon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.8179, 'longitude': -83.2755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48759', 'place_name': 'Sebewaing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Huron', 'locality_code': '63', 'latitude': 43.7289, 'longitude': -83.4366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48805', 'place_name': 'Okemos', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.5992, 'longitude': -84.372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48819', 'place_name': 'Dansville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.5505, 'longitude': -84.2939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48823', 'place_name': 'East Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7388, 'longitude': -84.4764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48824', 'place_name': 'East Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7283, 'longitude': -84.4882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48825', 'place_name': 'East Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7238, 'longitude': -84.4648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48826', 'place_name': 'East Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.737, 'longitude': -84.4839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48840', 'place_name': 'Haslett', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7531, 'longitude': -84.3989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48842', 'place_name': 'Holt', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.6394, 'longitude': -84.5242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48854', 'place_name': 'Mason', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.5796, 'longitude': -84.4561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48864', 'place_name': 'Okemos', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7053, 'longitude': -84.4187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48892', 'place_name': 'Webberville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.663, 'longitude': -84.1701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48895', 'place_name': 'Williamston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.6967, 'longitude': -84.2926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48901', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48906', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7635, 'longitude': -84.558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48909', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48910', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7008, 'longitude': -84.549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48911', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.6797, 'longitude': -84.5772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48912', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7371, 'longitude': -84.5244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48913', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48915', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7391, 'longitude': -84.5704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48916', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48918', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48919', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7286, 'longitude': -84.5517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48922', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48924', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48929', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48930', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48933', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7334, 'longitude': -84.5571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48937', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7487, 'longitude': -84.559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48951', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7035, 'longitude': -84.5365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48956', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48980', 'place_name': 'Lansing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.7325, 'longitude': -84.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49251', 'place_name': 'Leslie', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.4603, 'longitude': -84.4207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49264', 'place_name': 'Onondaga', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.4487, 'longitude': -84.5535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49285', 'place_name': 'Stockbridge', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ingham', 'locality_code': '65', 'latitude': 42.4604, 'longitude': -84.1752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48809', 'place_name': 'Belding', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 43.0885, 'longitude': -85.2313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48815', 'place_name': 'Clarksville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 42.8302, 'longitude': -85.2494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48845', 'place_name': 'Hubbardston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 43.0923, 'longitude': -84.8422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48846', 'place_name': 'Ionia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 42.9859, 'longitude': -85.071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48849', 'place_name': 'Lake Odessa', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 42.7863, 'longitude': -85.1357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48851', 'place_name': 'Lyons', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 42.9634, 'longitude': -84.9209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48860', 'place_name': 'Muir', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 43.0439, 'longitude': -84.9391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48865', 'place_name': 'Orleans', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 43.0895, 'longitude': -85.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48870', 'place_name': 'Palo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 43.1125, 'longitude': -84.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48873', 'place_name': 'Pewamo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 43.0007, 'longitude': -84.8492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48875', 'place_name': 'Portland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 42.8624, 'longitude': -84.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48881', 'place_name': 'Saranac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 42.9357, 'longitude': -85.203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48887', 'place_name': 'Smyrna', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ionia', 'locality_code': '67', 'latitude': 43.0595, 'longitude': -85.2628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48730', 'place_name': 'East Tawas', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.3008, 'longitude': -83.4776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48739', 'place_name': 'Hale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.3819, 'longitude': -83.8359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48743', 'place_name': 'Long Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.4197, 'longitude': -83.8719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48748', 'place_name': 'National City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.3137, 'longitude': -83.6839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48750', 'place_name': 'Oscoda', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.4465, 'longitude': -83.3619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48763', 'place_name': 'Tawas City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.2675, 'longitude': -83.5449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48764', 'place_name': 'Tawas City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.2665, 'longitude': -83.5192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48770', 'place_name': 'Whittemore', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iosco', 'locality_code': '69', 'latitude': 44.2325, 'longitude': -83.8068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49902', 'place_name': 'Alpha', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iron', 'locality_code': '71', 'latitude': 46.0438, 'longitude': -88.3771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49903', 'place_name': 'Amasa', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iron', 'locality_code': '71', 'latitude': 46.2321, 'longitude': -88.4508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49915', 'place_name': 'Caspian', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iron', 'locality_code': '71', 'latitude': 46.0643, 'longitude': -88.6329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49920', 'place_name': 'Crystal Falls', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iron', 'locality_code': '71', 'latitude': 46.1093, 'longitude': -88.3505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49927', 'place_name': 'Gaastra', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iron', 'locality_code': '71', 'latitude': 46.0526, 'longitude': -88.5917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49935', 'place_name': 'Iron River', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iron', 'locality_code': '71', 'latitude': 46.093, 'longitude': -88.646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49964', 'place_name': 'Stambaugh', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Iron', 'locality_code': '71', 'latitude': 46.0797, 'longitude': -88.629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48804', 'place_name': 'Mount Pleasant', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.6406, 'longitude': -84.8474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48858', 'place_name': 'Mount Pleasant', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.6013, 'longitude': -84.7736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48859', 'place_name': 'Mount Pleasant', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.5647, 'longitude': -84.8473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48878', 'place_name': 'Rosebush', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.6843, 'longitude': -84.7833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48883', 'place_name': 'Shepherd', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.5657, 'longitude': -84.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48893', 'place_name': 'Weidman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.6453, 'longitude': -85.0046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48896', 'place_name': 'Winn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.5234, 'longitude': -84.9017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49310', 'place_name': 'Blanchard', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Isabella', 'locality_code': '73', 'latitude': 43.5228, 'longitude': -85.0589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49201', 'place_name': 'Jackson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.2545, 'longitude': -84.3875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49202', 'place_name': 'Jackson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.2634, 'longitude': -84.4083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49203', 'place_name': 'Jackson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.229, 'longitude': -84.4132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49204', 'place_name': 'Jackson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.2459, 'longitude': -84.4013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49230', 'place_name': 'Brooklyn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.1044, 'longitude': -84.2414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49234', 'place_name': 'Clarklake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.1235, 'longitude': -84.3521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49237', 'place_name': 'Concord', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.1875, 'longitude': -84.6529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49240', 'place_name': 'Grass Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.2711, 'longitude': -84.194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49241', 'place_name': 'Hanover', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.1025, 'longitude': -84.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49246', 'place_name': 'Horton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.1191, 'longitude': -84.4976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49254', 'place_name': 'Michigan Center', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.2271, 'longitude': -84.3161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49259', 'place_name': 'Munith', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.3703, 'longitude': -84.2485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49261', 'place_name': 'Napoleon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.1643, 'longitude': -84.2458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49263', 'place_name': 'Norvell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.1582, 'longitude': -84.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49269', 'place_name': 'Parma', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.2739, 'longitude': -84.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49272', 'place_name': 'Pleasant Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.3903, 'longitude': -84.3428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49277', 'place_name': 'Rives Junction', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.3887, 'longitude': -84.4589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49283', 'place_name': 'Spring Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.2069, 'longitude': -84.5501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49284', 'place_name': 'Springport', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Jackson', 'locality_code': '75', 'latitude': 42.3805, 'longitude': -84.7039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49001', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2736, 'longitude': -85.5457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49002', 'place_name': 'Portage', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.1938, 'longitude': -85.5639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49003', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2454, 'longitude': -85.5299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49004', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.3518, 'longitude': -85.5621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49005', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2917, 'longitude': -85.5872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49006', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2922, 'longitude': -85.633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49007', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.3024, 'longitude': -85.5882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49008', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2624, 'longitude': -85.6096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49009', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2809, 'longitude': -85.6863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49012', 'place_name': 'Augusta', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.3563, 'longitude': -85.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49019', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2454, 'longitude': -85.5299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49024', 'place_name': 'Portage', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.1974, 'longitude': -85.6194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49034', 'place_name': 'Climax', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.234, 'longitude': -85.3238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49041', 'place_name': 'Comstock', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2867, 'longitude': -85.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49048', 'place_name': 'Kalamazoo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.3189, 'longitude': -85.5152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49052', 'place_name': 'Fulton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.1391, 'longitude': -85.3227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49053', 'place_name': 'Galesburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2948, 'longitude': -85.4237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49074', 'place_name': 'Nazareth', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2454, 'longitude': -85.5299, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49077', 'place_name': 'Oshtemo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.2589, 'longitude': -85.6775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49081', 'place_name': 'Portage', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.1718, 'longitude': -85.6178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49083', 'place_name': 'Richland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.3757, 'longitude': -85.4447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49087', 'place_name': 'Schoolcraft', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.1329, 'longitude': -85.6637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49088', 'place_name': 'Scotts', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.1819, 'longitude': -85.4685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49097', 'place_name': 'Vicksburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalamazoo', 'locality_code': '77', 'latitude': 42.1209, 'longitude': -85.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49646', 'place_name': 'Kalkaska', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalkaska', 'locality_code': '79', 'latitude': 44.7355, 'longitude': -85.1207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49676', 'place_name': 'Rapid City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalkaska', 'locality_code': '79', 'latitude': 44.8449, 'longitude': -85.2943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49680', 'place_name': 'South Boardman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kalkaska', 'locality_code': '79', 'latitude': 44.6401, 'longitude': -85.2472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49301', 'place_name': 'Ada', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9566, 'longitude': -85.481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49302', 'place_name': 'Alto', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8243, 'longitude': -85.4256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49306', 'place_name': 'Belmont', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.075, 'longitude': -85.5632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49315', 'place_name': 'Byron Center', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8016, 'longitude': -85.7136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49316', 'place_name': 'Caledonia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8187, 'longitude': -85.5244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49317', 'place_name': 'Cannonsburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0712, 'longitude': -85.4809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49319', 'place_name': 'Cedar Springs', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.2215, 'longitude': -85.5452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49321', 'place_name': 'Comstock Park', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0578, 'longitude': -85.6845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49330', 'place_name': 'Kent City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.2362, 'longitude': -85.7399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49331', 'place_name': 'Lowell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.955, 'longitude': -85.3653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49341', 'place_name': 'Rockford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.1152, 'longitude': -85.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49343', 'place_name': 'Sand Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.2981, 'longitude': -85.5367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49345', 'place_name': 'Sparta', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.1619, 'longitude': -85.6877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49351', 'place_name': 'Rockford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.12, 'longitude': -85.56, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49355', 'place_name': 'Ada', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9542, 'longitude': -85.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49356', 'place_name': 'Ada', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9542, 'longitude': -85.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49357', 'place_name': 'Ada', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9542, 'longitude': -85.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49418', 'place_name': 'Grandville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8939, 'longitude': -85.7619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49468', 'place_name': 'Grandville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9097, 'longitude': -85.7631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49501', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9842, 'longitude': -85.6291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49502', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9634, 'longitude': -85.6681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49503', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9659, 'longitude': -85.6527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49504', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9737, 'longitude': -85.7265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49505', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.012, 'longitude': -85.6309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49506', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.944, 'longitude': -85.6213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49507', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9318, 'longitude': -85.6542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49508', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8894, 'longitude': -85.6219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49509', 'place_name': 'Wyoming', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9134, 'longitude': -85.7053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49510', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49512', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8802, 'longitude': -85.5352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49514', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49515', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49516', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49518', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49519', 'place_name': 'Wyoming', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8977, 'longitude': -85.7186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49523', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9634, 'longitude': -85.6681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49525', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0135, 'longitude': -85.6027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49528', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8811, 'longitude': -85.6239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49530', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49544', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0073, 'longitude': -85.7255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49546', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.928, 'longitude': -85.5483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49548', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.8697, 'longitude': -85.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49555', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 42.9634, 'longitude': -85.6681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49560', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49588', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49599', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Kent', 'locality_code': '81', 'latitude': 43.0314, 'longitude': -85.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49805', 'place_name': 'Allouez', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Keweenaw', 'locality_code': '83', 'latitude': 47.2879, 'longitude': -88.4129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49901', 'place_name': 'Ahmeek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Keweenaw', 'locality_code': '83', 'latitude': 47.2933, 'longitude': -88.3897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49918', 'place_name': 'Copper Harbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Keweenaw', 'locality_code': '83', 'latitude': 47.4688, 'longitude': -87.8884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49950', 'place_name': 'Mohawk', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Keweenaw', 'locality_code': '83', 'latitude': 47.3526, 'longitude': -88.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49304', 'place_name': 'Baldwin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lake', 'locality_code': '85', 'latitude': 43.8894, 'longitude': -85.8819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49402', 'place_name': 'Branch', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lake', 'locality_code': '85', 'latitude': 43.9333, 'longitude': -86.0345, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49623', 'place_name': 'Chase', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lake', 'locality_code': '85', 'latitude': 43.8892, 'longitude': -85.6356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49642', 'place_name': 'Idlewild', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lake', 'locality_code': '85', 'latitude': 43.8872, 'longitude': -85.7759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49644', 'place_name': 'Irons', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lake', 'locality_code': '85', 'latitude': 44.0966, 'longitude': -85.939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49656', 'place_name': 'Luther', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lake', 'locality_code': '85', 'latitude': 44.0545, 'longitude': -85.6826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48003', 'place_name': 'Almont', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 42.926, 'longitude': -83.0362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48412', 'place_name': 'Attica', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.0547, 'longitude': -83.1668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48421', 'place_name': 'Columbiaville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.1503, 'longitude': -83.3811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48428', 'place_name': 'Dryden', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 42.9378, 'longitude': -83.1501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48440', 'place_name': 'Hadley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 42.9545, 'longitude': -83.4033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48444', 'place_name': 'Imlay City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.0425, 'longitude': -83.0708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48446', 'place_name': 'Lapeer', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.0579, 'longitude': -83.3332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48455', 'place_name': 'Metamora', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 42.9414, 'longitude': -83.2891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48461', 'place_name': 'North Branch', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.2069, 'longitude': -83.2267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48464', 'place_name': 'Otter Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.2183, 'longitude': -83.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48727', 'place_name': 'Clifford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.31, 'longitude': -83.1741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48760', 'place_name': 'Silverwood', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lapeer', 'locality_code': '87', 'latitude': 43.3141, 'longitude': -83.272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49621', 'place_name': 'Cedar', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 44.8605, 'longitude': -85.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49630', 'place_name': 'Empire', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 44.8144, 'longitude': -85.9999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49636', 'place_name': 'Glen Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 44.8734, 'longitude': -85.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49653', 'place_name': 'Lake Leelanau', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 44.9856, 'longitude': -85.7329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49654', 'place_name': 'Leland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 45.0793, 'longitude': -85.9896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49664', 'place_name': 'Maple City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 44.859, 'longitude': -85.8814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49670', 'place_name': 'Northport', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 45.1157, 'longitude': -85.6173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49674', 'place_name': 'Omena', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 45.0556, 'longitude': -85.589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49682', 'place_name': 'Suttons Bay', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Leelanau', 'locality_code': '89', 'latitude': 44.9656, 'longitude': -85.6423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49220', 'place_name': 'Addison', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 42.0036, 'longitude': -84.3122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49221', 'place_name': 'Adrian', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.9005, 'longitude': -84.0446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49228', 'place_name': 'Blissfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.8276, 'longitude': -83.8773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49229', 'place_name': 'Britton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.9887, 'longitude': -83.8377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49233', 'place_name': 'Cement City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 42.0604, 'longitude': -84.3254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49235', 'place_name': 'Clayton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.8636, 'longitude': -84.2147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49236', 'place_name': 'Clinton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 42.0639, 'longitude': -83.9442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49238', 'place_name': 'Deerfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.8909, 'longitude': -83.7847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49247', 'place_name': 'Hudson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.8581, 'longitude': -84.338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49248', 'place_name': 'Jasper', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.7704, 'longitude': -84.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49253', 'place_name': 'Manitou Beach', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.9671, 'longitude': -84.2767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49256', 'place_name': 'Morenci', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.7386, 'longitude': -84.2192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49265', 'place_name': 'Onsted', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 42.0295, 'longitude': -84.1839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49268', 'place_name': 'Palmyra', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.8729, 'longitude': -83.9263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49276', 'place_name': 'Riga', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.7953, 'longitude': -83.8011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49279', 'place_name': 'Sand Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.8259, 'longitude': -84.1016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49286', 'place_name': 'Tecumseh', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.9953, 'longitude': -83.9555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49287', 'place_name': 'Tipton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 42.0369, 'longitude': -84.0768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49289', 'place_name': 'Weston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Lenawee', 'locality_code': '91', 'latitude': 41.7683, 'longitude': -84.1076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48114', 'place_name': 'Brighton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.57, 'longitude': -83.7484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48116', 'place_name': 'Brighton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.5371, 'longitude': -83.7756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48137', 'place_name': 'Gregory', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.496, 'longitude': -84.0847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48139', 'place_name': 'Hamburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.4523, 'longitude': -83.8147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48143', 'place_name': 'Lakeland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.4573, 'longitude': -83.8366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48169', 'place_name': 'Pinckney', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.4596, 'longitude': -83.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48353', 'place_name': 'Hartland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.6356, 'longitude': -83.7147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48816', 'place_name': 'Cohoctah', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.7598, 'longitude': -83.9486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48836', 'place_name': 'Fowlerville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.6614, 'longitude': -84.0721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48843', 'place_name': 'Howell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.6159, 'longitude': -83.9248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48844', 'place_name': 'Howell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.6035, 'longitude': -83.9112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48855', 'place_name': 'Howell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Livingston', 'locality_code': '93', 'latitude': 42.6871, 'longitude': -83.914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49853', 'place_name': 'Mc Millan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Luce', 'locality_code': '95', 'latitude': 46.297, 'longitude': -85.7307, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49868', 'place_name': 'Newberry', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Luce', 'locality_code': '95', 'latitude': 46.3438, 'longitude': -85.515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49719', 'place_name': 'Cedarville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 46.0024, 'longitude': -84.3488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49745', 'place_name': 'Hessel', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 46.0217, 'longitude': -84.4284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49757', 'place_name': 'Mackinac Island', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 45.8578, 'longitude': -84.6245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49760', 'place_name': 'Moran', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 46.0441, 'longitude': -85.0078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49762', 'place_name': 'Naubinway', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 46.126, 'longitude': -85.4462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49775', 'place_name': 'Pointe Aux Pins', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 45.7549, 'longitude': -84.447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49781', 'place_name': 'Saint Ignace', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 45.9985, 'longitude': -84.6978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49820', 'place_name': 'Curtis', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 46.2048, 'longitude': -85.7865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49827', 'place_name': 'Engadine', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 46.204, 'longitude': -85.6005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49838', 'place_name': 'Gould City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mackinac', 'locality_code': '97', 'latitude': 46.0747, 'longitude': -85.7338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48005', 'place_name': 'Armada', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.8409, 'longitude': -82.8899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48015', 'place_name': 'Center Line', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4788, 'longitude': -83.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48021', 'place_name': 'Eastpointe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4658, 'longitude': -82.9459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48026', 'place_name': 'Fraser', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5423, 'longitude': -82.947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48035', 'place_name': 'Clinton Township', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5512, 'longitude': -82.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48036', 'place_name': 'Clinton Township', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5938, 'longitude': -82.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48038', 'place_name': 'Clinton Township', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6206, 'longitude': -82.9608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48042', 'place_name': 'Macomb', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6735, 'longitude': -82.9163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48043', 'place_name': 'Mount Clemens', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5978, 'longitude': -82.8823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48044', 'place_name': 'Macomb', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6442, 'longitude': -82.8985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48045', 'place_name': 'Harrison Township', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5877, 'longitude': -82.8215, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48046', 'place_name': 'Mount Clemens', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5973, 'longitude': -82.878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48047', 'place_name': 'New Baltimore', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.673, 'longitude': -82.7753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48048', 'place_name': 'New Haven', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.7443, 'longitude': -82.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48050', 'place_name': 'New Haven', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.7859, 'longitude': -82.7979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48051', 'place_name': 'New Baltimore', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6938, 'longitude': -82.8207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48062', 'place_name': 'Richmond', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.8389, 'longitude': -82.7996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48065', 'place_name': 'Romeo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.84, 'longitude': -83.0388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48066', 'place_name': 'Roseville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5034, 'longitude': -82.9387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48080', 'place_name': 'Saint Clair Shores', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4706, 'longitude': -82.9022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48081', 'place_name': 'Saint Clair Shores', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4941, 'longitude': -82.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48082', 'place_name': 'Saint Clair Shores', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5269, 'longitude': -82.8841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48088', 'place_name': 'Warren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5164, 'longitude': -82.9832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48089', 'place_name': 'Warren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4685, 'longitude': -82.9974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48090', 'place_name': 'Warren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4775, 'longitude': -83.0277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48091', 'place_name': 'Warren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4665, 'longitude': -83.0593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48092', 'place_name': 'Warren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5125, 'longitude': -83.0643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48093', 'place_name': 'Warren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5149, 'longitude': -82.9968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48094', 'place_name': 'Washington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.7262, 'longitude': -83.0268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48095', 'place_name': 'Washington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.7682, 'longitude': -83.0395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48096', 'place_name': 'Ray', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.754, 'longitude': -82.9163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48310', 'place_name': 'Sterling Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5648, 'longitude': -83.0701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48311', 'place_name': 'Sterling Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5803, 'longitude': -83.0302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48312', 'place_name': 'Sterling Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.5592, 'longitude': -83.0029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48313', 'place_name': 'Sterling Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6005, 'longitude': -82.9998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48314', 'place_name': 'Sterling Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6124, 'longitude': -83.0345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48315', 'place_name': 'Utica', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.671, 'longitude': -82.9988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48316', 'place_name': 'Utica', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6885, 'longitude': -83.0548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48317', 'place_name': 'Utica', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6413, 'longitude': -83.0504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48318', 'place_name': 'Utica', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.6261, 'longitude': -83.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48397', 'place_name': 'Warren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Macomb', 'locality_code': '99', 'latitude': 42.4917, 'longitude': -83.0402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49613', 'place_name': 'Arcadia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.5232, 'longitude': -86.2061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49614', 'place_name': 'Bear Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.4311, 'longitude': -86.1425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49619', 'place_name': 'Brethren', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.2966, 'longitude': -85.9964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49625', 'place_name': 'Copemish', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.4503, 'longitude': -85.8879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49626', 'place_name': 'Eastlake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.2413, 'longitude': -86.2913, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49634', 'place_name': 'Filer City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.2153, 'longitude': -86.2873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49645', 'place_name': 'Kaleva', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.3692, 'longitude': -86.0467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49660', 'place_name': 'Manistee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.2635, 'longitude': -86.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49675', 'place_name': 'Onekama', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.3646, 'longitude': -86.21, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49689', 'place_name': 'Wellston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Manistee', 'locality_code': '101', 'latitude': 44.2133, 'longitude': -85.9555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49808', 'place_name': 'Big Bay', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.8158, 'longitude': -87.7285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49814', 'place_name': 'Champion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.4685, 'longitude': -87.8306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49819', 'place_name': 'Arnold', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.0508, 'longitude': -87.4921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49833', 'place_name': 'Little Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.2888, 'longitude': -87.3418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49841', 'place_name': 'Gwinn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.3311, 'longitude': -87.4397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49849', 'place_name': 'Ishpeming', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.4387, 'longitude': -87.7091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49855', 'place_name': 'Marquette', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.5786, 'longitude': -87.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49861', 'place_name': 'Michigamme', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.5308, 'longitude': -88.0914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49865', 'place_name': 'National Mine', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.6041, 'longitude': -87.6148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49866', 'place_name': 'Negaunee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.5007, 'longitude': -87.5829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49871', 'place_name': 'Palmer', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.4416, 'longitude': -87.5764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49879', 'place_name': 'Republic', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.368, 'longitude': -87.9938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49885', 'place_name': 'Skandia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Marquette', 'locality_code': '103', 'latitude': 46.349, 'longitude': -87.2481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49405', 'place_name': 'Custer', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mason', 'locality_code': '105', 'latitude': 43.9324, 'longitude': -86.1777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49410', 'place_name': 'Fountain', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mason', 'locality_code': '105', 'latitude': 44.0363, 'longitude': -86.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49411', 'place_name': 'Free Soil', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mason', 'locality_code': '105', 'latitude': 44.112, 'longitude': -86.2652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49431', 'place_name': 'Ludington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mason', 'locality_code': '105', 'latitude': 43.9688, 'longitude': -86.4403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49454', 'place_name': 'Scottville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mason', 'locality_code': '105', 'latitude': 43.9547, 'longitude': -86.2801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49458', 'place_name': 'Walhalla', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mason', 'locality_code': '105', 'latitude': 43.9536, 'longitude': -86.1148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49305', 'place_name': 'Barryton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.7507, 'longitude': -85.1547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49307', 'place_name': 'Big Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.6897, 'longitude': -85.4797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49320', 'place_name': 'Chippewa Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.7553, 'longitude': -85.2783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49332', 'place_name': 'Mecosta', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.6813, 'longitude': -85.228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49336', 'place_name': 'Morley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.506, 'longitude': -85.4473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49338', 'place_name': 'Paris', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.7677, 'longitude': -85.5213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49340', 'place_name': 'Remus', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.6032, 'longitude': -85.1574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49342', 'place_name': 'Rodney', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.7379, 'longitude': -85.3219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49346', 'place_name': 'Stanwood', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Mecosta', 'locality_code': '107', 'latitude': 43.6017, 'longitude': -85.4446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49812', 'place_name': 'Carney', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.5917, 'longitude': -87.5439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49821', 'place_name': 'Daggett', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.4887, 'longitude': -87.6079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49845', 'place_name': 'Harris', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.6922, 'longitude': -87.3513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49847', 'place_name': 'Hermansville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.7149, 'longitude': -87.6227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49848', 'place_name': 'Ingalls', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.3748, 'longitude': -87.6206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49858', 'place_name': 'Menominee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.1343, 'longitude': -87.6215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49863', 'place_name': 'Nadeau', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.6089, 'longitude': -87.5529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49873', 'place_name': 'Perronville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.841, 'longitude': -87.4816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49874', 'place_name': 'Powers', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.6792, 'longitude': -87.5319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49886', 'place_name': 'Spalding', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.6958, 'longitude': -87.511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49887', 'place_name': 'Stephenson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.4166, 'longitude': -87.6258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49893', 'place_name': 'Wallace', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.3017, 'longitude': -87.5805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49896', 'place_name': 'Wilson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Menominee', 'locality_code': '109', 'latitude': 45.6649, 'longitude': -87.3997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48618', 'place_name': 'Coleman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.7494, 'longitude': -84.5911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48620', 'place_name': 'Edenville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.7774, 'longitude': -84.3813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48628', 'place_name': 'Hope', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.7882, 'longitude': -84.3296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48640', 'place_name': 'Midland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.6376, 'longitude': -84.268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48641', 'place_name': 'Midland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.5383, 'longitude': -84.3878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48642', 'place_name': 'Midland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.6375, 'longitude': -84.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48657', 'place_name': 'Sanford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.7204, 'longitude': -84.3954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48667', 'place_name': 'Midland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.6156, 'longitude': -84.2472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48670', 'place_name': 'Midland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.6375, 'longitude': -84.2568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48674', 'place_name': 'Midland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.6129, 'longitude': -84.1971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48686', 'place_name': 'Midland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Midland', 'locality_code': '111', 'latitude': 43.6473, 'longitude': -84.3873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49632', 'place_name': 'Falmouth', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Missaukee', 'locality_code': '113', 'latitude': 44.2529, 'longitude': -85.017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49651', 'place_name': 'Lake City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Missaukee', 'locality_code': '113', 'latitude': 44.3767, 'longitude': -85.0946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49657', 'place_name': 'Mc Bain', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Missaukee', 'locality_code': '113', 'latitude': 44.2172, 'longitude': -85.2283, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49667', 'place_name': 'Merritt', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Missaukee', 'locality_code': '113', 'latitude': 44.3433, 'longitude': -84.9446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48110', 'place_name': 'Azalia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 42.0082, 'longitude': -83.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48117', 'place_name': 'Carleton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 42.0529, 'longitude': -83.3755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48131', 'place_name': 'Dundee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.9514, 'longitude': -83.6522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48133', 'place_name': 'Erie', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.7829, 'longitude': -83.4958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48140', 'place_name': 'Ida', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.8549, 'longitude': -83.5916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48144', 'place_name': 'Lambertville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.7531, 'longitude': -83.6259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48145', 'place_name': 'La Salle', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.8585, 'longitude': -83.4715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48157', 'place_name': 'Luna Pier', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.8146, 'longitude': -83.4382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48159', 'place_name': 'Maybee', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 42.0288, 'longitude': -83.5179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48160', 'place_name': 'Milan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 42.0914, 'longitude': -83.6776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48161', 'place_name': 'Monroe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.908, 'longitude': -83.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48162', 'place_name': 'Monroe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.9293, 'longitude': -83.4448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48166', 'place_name': 'Newport', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.9766, 'longitude': -83.2804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48177', 'place_name': 'Samaria', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.8076, 'longitude': -83.5793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48179', 'place_name': 'South Rockwood', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 42.0624, 'longitude': -83.2663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48182', 'place_name': 'Temperance', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.7682, 'longitude': -83.5797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49267', 'place_name': 'Ottawa Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.7683, 'longitude': -83.6856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49270', 'place_name': 'Petersburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Monroe', 'locality_code': '115', 'latitude': 41.8757, 'longitude': -83.6877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48811', 'place_name': 'Carson City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.1695, 'longitude': -84.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48812', 'place_name': 'Cedar Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.4138, 'longitude': -84.9753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48818', 'place_name': 'Crystal', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.2624, 'longitude': -84.8993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48829', 'place_name': 'Edmore', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.4116, 'longitude': -85.028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48834', 'place_name': 'Fenwick', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.1497, 'longitude': -85.0666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48838', 'place_name': 'Greenville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.1793, 'longitude': -85.2497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48850', 'place_name': 'Lakeview', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.4269, 'longitude': -85.2924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48852', 'place_name': 'Mcbrides', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.3503, 'longitude': -85.0517, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48884', 'place_name': 'Sheridan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.2126, 'longitude': -85.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48885', 'place_name': 'Sidney', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.2358, 'longitude': -85.1207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48886', 'place_name': 'Six Lakes', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.4337, 'longitude': -85.1416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48888', 'place_name': 'Stanton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.3058, 'longitude': -85.0995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48891', 'place_name': 'Vestaburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.387, 'longitude': -84.9082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49322', 'place_name': 'Coral', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.3645, 'longitude': -85.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49326', 'place_name': 'Gowen', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.2239, 'longitude': -85.3159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49329', 'place_name': 'Howard City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.4083, 'longitude': -85.4856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49339', 'place_name': 'Pierson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.3355, 'longitude': -85.5134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49347', 'place_name': 'Trufant', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montcalm', 'locality_code': '117', 'latitude': 43.3156, 'longitude': -85.3685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49709', 'place_name': 'Atlanta', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montmorency', 'locality_code': '119', 'latitude': 44.9924, 'longitude': -84.148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49746', 'place_name': 'Hillman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montmorency', 'locality_code': '119', 'latitude': 45.0691, 'longitude': -83.9468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49756', 'place_name': 'Lewiston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Montmorency', 'locality_code': '119', 'latitude': 44.8538, 'longitude': -84.2973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49303', 'place_name': 'Bailey', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.2768, 'longitude': -85.8313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49318', 'place_name': 'Casnovia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.2381, 'longitude': -85.8254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49415', 'place_name': 'Fruitport', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.1443, 'longitude': -86.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49425', 'place_name': 'Holton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.4415, 'longitude': -86.1509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49437', 'place_name': 'Montague', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.4242, 'longitude': -86.374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49440', 'place_name': 'Muskegon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.2326, 'longitude': -86.2492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49441', 'place_name': 'Muskegon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.1962, 'longitude': -86.2738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49442', 'place_name': 'Muskegon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.2329, 'longitude': -86.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49443', 'place_name': 'Muskegon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.2342, 'longitude': -86.2484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49444', 'place_name': 'Muskegon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.1791, 'longitude': -86.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49445', 'place_name': 'Muskegon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.2952, 'longitude': -86.279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49451', 'place_name': 'Ravenna', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.2091, 'longitude': -85.9648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49457', 'place_name': 'Twin Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.3414, 'longitude': -86.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49461', 'place_name': 'Whitehall', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.3904, 'longitude': -86.3315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49463', 'place_name': 'Sylvan Beach', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Muskegon', 'locality_code': '121', 'latitude': 43.372, 'longitude': -86.4237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49309', 'place_name': 'Bitely', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Newaygo', 'locality_code': '123', 'latitude': 43.7321, 'longitude': -85.8778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49312', 'place_name': 'Brohman', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Newaygo', 'locality_code': '123', 'latitude': 43.6853, 'longitude': -85.8159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49327', 'place_name': 'Grant', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Newaygo', 'locality_code': '123', 'latitude': 43.3392, 'longitude': -85.8368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49337', 'place_name': 'Newaygo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Newaygo', 'locality_code': '123', 'latitude': 43.4198, 'longitude': -85.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49349', 'place_name': 'White Cloud', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Newaygo', 'locality_code': '123', 'latitude': 43.5398, 'longitude': -85.7586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49412', 'place_name': 'Fremont', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Newaygo', 'locality_code': '123', 'latitude': 43.4652, 'longitude': -85.9626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49413', 'place_name': 'Fremont', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Newaygo', 'locality_code': '123', 'latitude': 43.5543, 'longitude': -85.8009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48007', 'place_name': 'Troy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6061, 'longitude': -83.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48009', 'place_name': 'Birmingham', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5444, 'longitude': -83.2133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48012', 'place_name': 'Birmingham', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5467, 'longitude': -83.2113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48017', 'place_name': 'Clawson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5365, 'longitude': -83.1503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48025', 'place_name': 'Franklin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5219, 'longitude': -83.2519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48030', 'place_name': 'Hazel Park', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4608, 'longitude': -83.0982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48033', 'place_name': 'Southfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4723, 'longitude': -83.294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48034', 'place_name': 'Southfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4969, 'longitude': -83.2911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48037', 'place_name': 'Southfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5675, 'longitude': -83.15, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48067', 'place_name': 'Royal Oak', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4906, 'longitude': -83.1366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48068', 'place_name': 'Royal Oak', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4895, 'longitude': -83.1446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48069', 'place_name': 'Pleasant Ridge', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.471, 'longitude': -83.1438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48070', 'place_name': 'Huntington Woods', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4825, 'longitude': -83.1749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48071', 'place_name': 'Madison Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5016, 'longitude': -83.1027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48072', 'place_name': 'Berkley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5028, 'longitude': -83.1887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48073', 'place_name': 'Royal Oak', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.519, 'longitude': -83.157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48075', 'place_name': 'Southfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4638, 'longitude': -83.2255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48076', 'place_name': 'Southfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4981, 'longitude': -83.2058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48083', 'place_name': 'Troy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5597, 'longitude': -83.1138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48084', 'place_name': 'Troy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5627, 'longitude': -83.1799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48085', 'place_name': 'Troy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6006, 'longitude': -83.1198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48086', 'place_name': 'Southfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4734, 'longitude': -83.2219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48098', 'place_name': 'Troy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5991, 'longitude': -83.1789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48099', 'place_name': 'Troy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5876, 'longitude': -83.1737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48165', 'place_name': 'New Hudson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5076, 'longitude': -83.6342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48178', 'place_name': 'South Lyon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4567, 'longitude': -83.659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48220', 'place_name': 'Ferndale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4586, 'longitude': -83.1363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48237', 'place_name': 'Oak Park', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4662, 'longitude': -83.184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48301', 'place_name': 'Bloomfield Hills', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5445, 'longitude': -83.2792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48302', 'place_name': 'Bloomfield Hills', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5848, 'longitude': -83.2821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48303', 'place_name': 'Bloomfield Hills', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5836, 'longitude': -83.2455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48304', 'place_name': 'Bloomfield Hills', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.587, 'longitude': -83.2359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48306', 'place_name': 'Rochester', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7262, 'longitude': -83.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48307', 'place_name': 'Rochester', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6593, 'longitude': -83.1225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48308', 'place_name': 'Rochester', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6806, 'longitude': -83.1338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48309', 'place_name': 'Rochester', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6626, 'longitude': -83.1837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48320', 'place_name': 'Keego Harbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6114, 'longitude': -83.3356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48321', 'place_name': 'Auburn Hills', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6601, 'longitude': -83.3863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48322', 'place_name': 'West Bloomfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5424, 'longitude': -83.3793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48323', 'place_name': 'West Bloomfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5683, 'longitude': -83.3805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48324', 'place_name': 'West Bloomfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5961, 'longitude': -83.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48325', 'place_name': 'West Bloomfield', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6601, 'longitude': -83.3863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48326', 'place_name': 'Auburn Hills', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6583, 'longitude': -83.2375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48327', 'place_name': 'Waterford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6438, 'longitude': -83.4076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48328', 'place_name': 'Waterford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6429, 'longitude': -83.3546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48329', 'place_name': 'Waterford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6877, 'longitude': -83.3879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48330', 'place_name': 'Drayton Plains', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6754, 'longitude': -83.3637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48331', 'place_name': 'Farmington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5051, 'longitude': -83.4072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48332', 'place_name': 'Farmington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4645, 'longitude': -83.3763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48333', 'place_name': 'Farmington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4645, 'longitude': -83.3763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48334', 'place_name': 'Farmington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5065, 'longitude': -83.3484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48335', 'place_name': 'Farmington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4617, 'longitude': -83.4053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48336', 'place_name': 'Farmington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4656, 'longitude': -83.3638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48340', 'place_name': 'Pontiac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.668, 'longitude': -83.2893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48341', 'place_name': 'Pontiac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6294, 'longitude': -83.3041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48342', 'place_name': 'Pontiac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6439, 'longitude': -83.2792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48343', 'place_name': 'Pontiac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6389, 'longitude': -83.291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48346', 'place_name': 'Clarkston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7239, 'longitude': -83.4232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48347', 'place_name': 'Clarkston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6601, 'longitude': -83.3863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48348', 'place_name': 'Clarkston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7605, 'longitude': -83.404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48350', 'place_name': 'Davisburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7496, 'longitude': -83.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48356', 'place_name': 'Highland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6692, 'longitude': -83.5895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48357', 'place_name': 'Highland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6595, 'longitude': -83.637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48359', 'place_name': 'Lake Orion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7231, 'longitude': -83.2769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48360', 'place_name': 'Lake Orion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7429, 'longitude': -83.272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48361', 'place_name': 'Lake Orion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7845, 'longitude': -83.2397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48362', 'place_name': 'Lake Orion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7763, 'longitude': -83.2748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48363', 'place_name': 'Oakland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7732, 'longitude': -83.1711, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48366', 'place_name': 'Lakeville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.8214, 'longitude': -83.1502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48367', 'place_name': 'Leonard', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.8437, 'longitude': -83.1406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48370', 'place_name': 'Oxford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.8265, 'longitude': -83.2005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48371', 'place_name': 'Oxford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.8223, 'longitude': -83.2829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48374', 'place_name': 'Novi', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4735, 'longitude': -83.5224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48375', 'place_name': 'Novi', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4604, 'longitude': -83.4577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48376', 'place_name': 'Novi', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.471, 'longitude': -83.4748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48377', 'place_name': 'Novi', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.4992, 'longitude': -83.4773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48380', 'place_name': 'Milford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.602, 'longitude': -83.6508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48381', 'place_name': 'Milford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5758, 'longitude': -83.5924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48382', 'place_name': 'Commerce Township', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5834, 'longitude': -83.5009, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48383', 'place_name': 'White Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.658, 'longitude': -83.5398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48386', 'place_name': 'White Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.641, 'longitude': -83.4738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48387', 'place_name': 'Union Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.6148, 'longitude': -83.4469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48390', 'place_name': 'Walled Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5582, 'longitude': -83.4773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48391', 'place_name': 'Walled Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.5378, 'longitude': -83.481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48393', 'place_name': 'Wixom', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.534, 'longitude': -83.5285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48442', 'place_name': 'Holly', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.7905, 'longitude': -83.6127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48462', 'place_name': 'Ortonville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oakland', 'locality_code': '125', 'latitude': 42.8409, 'longitude': -83.4288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49420', 'place_name': 'Hart', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.7068, 'longitude': -86.3142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49421', 'place_name': 'Hesperia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.5965, 'longitude': -86.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49436', 'place_name': 'Mears', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.6825, 'longitude': -86.4533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49446', 'place_name': 'New Era', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.5556, 'longitude': -86.3448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49449', 'place_name': 'Pentwater', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.8237, 'longitude': -86.3868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49452', 'place_name': 'Rothbury', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.5116, 'longitude': -86.3446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49455', 'place_name': 'Shelby', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.6079, 'longitude': -86.3615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49459', 'place_name': 'Walkerville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oceana', 'locality_code': '127', 'latitude': 43.7626, 'longitude': -86.083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48610', 'place_name': 'Alger', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ogemaw', 'locality_code': '129', 'latitude': 44.1395, 'longitude': -84.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48635', 'place_name': 'Lupton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ogemaw', 'locality_code': '129', 'latitude': 44.3976, 'longitude': -83.9905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48654', 'place_name': 'Rose City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ogemaw', 'locality_code': '129', 'latitude': 44.4167, 'longitude': -84.1256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48661', 'place_name': 'West Branch', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ogemaw', 'locality_code': '129', 'latitude': 44.279, 'longitude': -84.2286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48756', 'place_name': 'Prescott', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ogemaw', 'locality_code': '129', 'latitude': 44.21, 'longitude': -84.0212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48761', 'place_name': 'South Branch', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ogemaw', 'locality_code': '129', 'latitude': 44.5014, 'longitude': -83.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49910', 'place_name': 'Bergland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.5881, 'longitude': -89.5973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49912', 'place_name': 'Bruce Crossing', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.528, 'longitude': -89.168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49925', 'place_name': 'Ewen', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.5404, 'longitude': -89.3145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49929', 'place_name': 'Greenland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.7809, 'longitude': -89.1146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49948', 'place_name': 'Mass City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.7474, 'longitude': -89.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49953', 'place_name': 'Ontonagon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.8275, 'longitude': -89.3485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49960', 'place_name': 'Rockland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.7537, 'longitude': -89.1958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49967', 'place_name': 'Trout Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.4864, 'longitude': -89.027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49971', 'place_name': 'White Pine', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ontonagon', 'locality_code': '131', 'latitude': 46.7538, 'longitude': -89.584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49631', 'place_name': 'Evart', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Osceola', 'locality_code': '133', 'latitude': 43.8888, 'longitude': -85.2649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49639', 'place_name': 'Hersey', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Osceola', 'locality_code': '133', 'latitude': 43.8481, 'longitude': -85.4059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49655', 'place_name': 'Leroy', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Osceola', 'locality_code': '133', 'latitude': 44.0457, 'longitude': -85.43, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '49665', 'place_name': 'Marion', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Osceola', 'locality_code': '133', 'latitude': 44.0463, 'longitude': -85.155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49677', 'place_name': 'Reed City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Osceola', 'locality_code': '133', 'latitude': 43.8868, 'longitude': -85.513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49679', 'place_name': 'Sears', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Osceola', 'locality_code': '133', 'latitude': 43.8776, 'longitude': -85.1465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49688', 'place_name': 'Tustin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Osceola', 'locality_code': '133', 'latitude': 44.1072, 'longitude': -85.4901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48619', 'place_name': 'Comins', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oscoda', 'locality_code': '135', 'latitude': 44.8264, 'longitude': -84.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48621', 'place_name': 'Fairview', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oscoda', 'locality_code': '135', 'latitude': 44.7205, 'longitude': -84.0525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48636', 'place_name': 'Luzerne', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oscoda', 'locality_code': '135', 'latitude': 44.6001, 'longitude': -84.2931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48647', 'place_name': 'Mio', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Oscoda', 'locality_code': '135', 'latitude': 44.6665, 'longitude': -84.1353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49730', 'place_name': 'Elmira', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Otsego', 'locality_code': '137', 'latitude': 45.0645, 'longitude': -84.8562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49734', 'place_name': 'Gaylord', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Otsego', 'locality_code': '137', 'latitude': 45.0275, 'longitude': -84.6748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49735', 'place_name': 'Gaylord', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Otsego', 'locality_code': '137', 'latitude': 45.0125, 'longitude': -84.6723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49751', 'place_name': 'Johannesburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Otsego', 'locality_code': '137', 'latitude': 45.0152, 'longitude': -84.3857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49795', 'place_name': 'Vanderbilt', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Otsego', 'locality_code': '137', 'latitude': 45.1532, 'longitude': -84.6511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49797', 'place_name': 'Waters', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Otsego', 'locality_code': '137', 'latitude': 44.8702, 'longitude': -84.6598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49401', 'place_name': 'Allendale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.9711, 'longitude': -85.9249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49403', 'place_name': 'Conklin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.1494, 'longitude': -85.8538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49404', 'place_name': 'Coopersville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0601, 'longitude': -85.9517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49409', 'place_name': 'Ferrysburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0809, 'longitude': -86.2154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49417', 'place_name': 'Grand Haven', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0378, 'longitude': -86.1912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49422', 'place_name': 'Holland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.7875, 'longitude': -86.1089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49423', 'place_name': 'Holland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.7692, 'longitude': -86.1164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49424', 'place_name': 'Holland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.8135, 'longitude': -86.1426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49426', 'place_name': 'Hudsonville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.8748, 'longitude': -85.8751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49427', 'place_name': 'Jamestown', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.8267, 'longitude': -85.8444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49428', 'place_name': 'Jenison', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.9104, 'longitude': -85.8276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49429', 'place_name': 'Jenison', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.9072, 'longitude': -85.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49430', 'place_name': 'Lamont', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0103, 'longitude': -85.8975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49434', 'place_name': 'Macatawa', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.7697, 'longitude': -86.2055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49435', 'place_name': 'Marne', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0532, 'longitude': -85.842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49448', 'place_name': 'Nunica', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0883, 'longitude': -86.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49456', 'place_name': 'Spring Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0887, 'longitude': -86.1915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49460', 'place_name': 'West Olive', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.9099, 'longitude': -86.1317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49464', 'place_name': 'Zeeland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 42.8256, 'longitude': -86.0104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49534', 'place_name': 'Grand Rapids', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Ottawa', 'locality_code': '139', 'latitude': 43.0141, 'longitude': -85.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49743', 'place_name': 'Hawks', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Presque Isle', 'locality_code': '141', 'latitude': 45.2975, 'longitude': -83.8542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49759', 'place_name': 'Millersburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Presque Isle', 'locality_code': '141', 'latitude': 45.4309, 'longitude': -84.0854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49765', 'place_name': 'Onaway', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Presque Isle', 'locality_code': '141', 'latitude': 45.3365, 'longitude': -84.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49776', 'place_name': 'Posen', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Presque Isle', 'locality_code': '141', 'latitude': 45.2233, 'longitude': -83.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49777', 'place_name': 'Presque Isle', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Presque Isle', 'locality_code': '141', 'latitude': 45.2969, 'longitude': -83.5023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49779', 'place_name': 'Rogers City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Presque Isle', 'locality_code': '141', 'latitude': 45.4123, 'longitude': -83.8355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48627', 'place_name': 'Higgins Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Roscommon', 'locality_code': '143', 'latitude': 44.3871, 'longitude': -84.7013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48629', 'place_name': 'Houghton Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Roscommon', 'locality_code': '143', 'latitude': 44.3147, 'longitude': -84.7647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48630', 'place_name': 'Houghton Lake Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Roscommon', 'locality_code': '143', 'latitude': 44.3275, 'longitude': -84.7745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48651', 'place_name': 'Prudenville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Roscommon', 'locality_code': '143', 'latitude': 44.2974, 'longitude': -84.6627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48653', 'place_name': 'Roscommon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Roscommon', 'locality_code': '143', 'latitude': 44.4839, 'longitude': -84.6601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48656', 'place_name': 'Saint Helen', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Roscommon', 'locality_code': '143', 'latitude': 44.3665, 'longitude': -84.4247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48415', 'place_name': 'Birch Run', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.2649, 'longitude': -83.7903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48417', 'place_name': 'Burt', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.2404, 'longitude': -83.9511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48601', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4047, 'longitude': -83.9156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48602', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4248, 'longitude': -83.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48603', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4631, 'longitude': -84.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48604', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4732, 'longitude': -83.9514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48605', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4588, 'longitude': -84.0518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48606', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.3485, 'longitude': -84.0326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48607', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4301, 'longitude': -83.9319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48608', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.3485, 'longitude': -84.0326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48609', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.3869, 'longitude': -84.0926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48614', 'place_name': 'Brant', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.2548, 'longitude': -84.2978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48616', 'place_name': 'Chesaning', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.1824, 'longitude': -84.1122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48623', 'place_name': 'Freeland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.5161, 'longitude': -84.1822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48626', 'place_name': 'Hemlock', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4099, 'longitude': -84.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48637', 'place_name': 'Merrill', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.3939, 'longitude': -84.3308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48649', 'place_name': 'Oakley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.1505, 'longitude': -84.2094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48655', 'place_name': 'Saint Charles', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.2863, 'longitude': -84.1598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48663', 'place_name': 'Saginaw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4195, 'longitude': -83.9508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48722', 'place_name': 'Bridgeport', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.3553, 'longitude': -83.8549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48724', 'place_name': 'Carrollton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.4586, 'longitude': -83.9303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48734', 'place_name': 'Frankenmuth', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.341, 'longitude': -83.7475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48787', 'place_name': 'Frankenmuth', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Saginaw', 'locality_code': '145', 'latitude': 43.335, 'longitude': -83.7494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48001', 'place_name': 'Algonac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.6367, 'longitude': -82.5866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48002', 'place_name': 'Allenton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.9388, 'longitude': -82.9198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48004', 'place_name': 'Anchorville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.8241, 'longitude': -82.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48006', 'place_name': 'Avoca', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 43.0752, 'longitude': -82.6955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48014', 'place_name': 'Capac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 43.0263, 'longitude': -82.9298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48022', 'place_name': 'Emmett', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.9872, 'longitude': -82.7854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48023', 'place_name': 'Fair Haven', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.7023, 'longitude': -82.6688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48027', 'place_name': 'Goodells', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.9443, 'longitude': -82.6916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48028', 'place_name': 'Harsens Island', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.585, 'longitude': -82.586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48032', 'place_name': 'Jeddo', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 43.1223, 'longitude': -82.5998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48039', 'place_name': 'Marine City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.6859, 'longitude': -82.5499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48040', 'place_name': 'Marysville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.9135, 'longitude': -82.4813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48041', 'place_name': 'Memphis', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.941, 'longitude': -82.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48049', 'place_name': 'North Street', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 43.0349, 'longitude': -82.5748, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48054', 'place_name': 'East China', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.7769, 'longitude': -82.5437, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48059', 'place_name': 'Fort Gratiot', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 43.0888, 'longitude': -82.4905, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '48060', 'place_name': 'Port Huron', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.9958, 'longitude': -82.4599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48061', 'place_name': 'Port Huron', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.9709, 'longitude': -82.4249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48063', 'place_name': 'Columbus', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.8892, 'longitude': -82.6675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48064', 'place_name': 'Casco', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.7674, 'longitude': -82.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48074', 'place_name': 'Smiths Creek', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.9051, 'longitude': -82.5679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48079', 'place_name': 'Saint Clair', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 42.8255, 'longitude': -82.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48097', 'place_name': 'Yale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Clair', 'locality_code': '147', 'latitude': 43.126, 'longitude': -82.8295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49030', 'place_name': 'Burr Oak', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.8459, 'longitude': -85.3345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49032', 'place_name': 'Centreville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.9217, 'longitude': -85.4963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49040', 'place_name': 'Colon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.9576, 'longitude': -85.3306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49042', 'place_name': 'Constantine', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.846, 'longitude': -85.6571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49066', 'place_name': 'Leonidas', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 42.0294, 'longitude': -85.3497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49072', 'place_name': 'Mendon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 42.0143, 'longitude': -85.4727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49075', 'place_name': 'Nottawa', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.9189, 'longitude': -85.4489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49091', 'place_name': 'Sturgis', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.8089, 'longitude': -85.4264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49093', 'place_name': 'Three Rivers', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.9596, 'longitude': -85.6371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49099', 'place_name': 'White Pigeon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'St. Joseph', 'locality_code': '149', 'latitude': 41.7929, 'longitude': -85.675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48401', 'place_name': 'Applegate', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.3619, 'longitude': -82.6479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48410', 'place_name': 'Argyle', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.5589, 'longitude': -82.9455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48416', 'place_name': 'Brown City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.2171, 'longitude': -82.9978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48419', 'place_name': 'Carsonville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.4258, 'longitude': -82.6022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48422', 'place_name': 'Croswell', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.2622, 'longitude': -82.6337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48426', 'place_name': 'Decker', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.4775, 'longitude': -83.0638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48427', 'place_name': 'Deckerville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.5151, 'longitude': -82.7191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48434', 'place_name': 'Forestville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.6632, 'longitude': -82.6133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48450', 'place_name': 'Lexington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.2435, 'longitude': -82.5301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48453', 'place_name': 'Marlette', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.3399, 'longitude': -83.0573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48454', 'place_name': 'Melvin', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.193, 'longitude': -82.8393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48456', 'place_name': 'Minden City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.6814, 'longitude': -82.7299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48465', 'place_name': 'Palms', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.6257, 'longitude': -82.7017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48466', 'place_name': 'Peck', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.2694, 'longitude': -82.8193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48469', 'place_name': 'Port Sanilac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.4329, 'longitude': -82.5468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48471', 'place_name': 'Sandusky', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.4055, 'longitude': -82.8409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48472', 'place_name': 'Snover', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Sanilac', 'locality_code': '151', 'latitude': 43.4886, 'longitude': -82.9301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49817', 'place_name': 'Cooks', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Schoolcraft', 'locality_code': '153', 'latitude': 45.8997, 'longitude': -86.5307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49836', 'place_name': 'Germfask', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Schoolcraft', 'locality_code': '153', 'latitude': 46.2363, 'longitude': -85.9159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49840', 'place_name': 'Gulliver', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Schoolcraft', 'locality_code': '153', 'latitude': 46.0115, 'longitude': -86.0214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49854', 'place_name': 'Manistique', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Schoolcraft', 'locality_code': '153', 'latitude': 46.0062, 'longitude': -86.2555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49883', 'place_name': 'Seney', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Schoolcraft', 'locality_code': '153', 'latitude': 46.388, 'longitude': -85.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48414', 'place_name': 'Bancroft', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.882, 'longitude': -84.1207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48418', 'place_name': 'Byron', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.8059, 'longitude': -83.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48429', 'place_name': 'Durand', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.9117, 'longitude': -83.9877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48460', 'place_name': 'New Lothrop', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 43.1388, 'longitude': -83.9851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48476', 'place_name': 'Vernon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.9406, 'longitude': -84.0328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48817', 'place_name': 'Corunna', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 43.0414, 'longitude': -84.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48841', 'place_name': 'Henderson', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 43.1143, 'longitude': -84.2369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48848', 'place_name': 'Laingsburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.8627, 'longitude': -84.353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48857', 'place_name': 'Morrice', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.8385, 'longitude': -84.1768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48867', 'place_name': 'Owosso', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.9934, 'longitude': -84.1595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48872', 'place_name': 'Perry', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.82, 'longitude': -84.2313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48882', 'place_name': 'Shaftsburg', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Shiawassee', 'locality_code': '155', 'latitude': 42.804, 'longitude': -84.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48435', 'place_name': 'Fostoria', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.2645, 'longitude': -83.3796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48701', 'place_name': 'Akron', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.5844, 'longitude': -83.5393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48723', 'place_name': 'Caro', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.4833, 'longitude': -83.3835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48726', 'place_name': 'Cass City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.5797, 'longitude': -83.1733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48729', 'place_name': 'Deford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.4735, 'longitude': -83.1702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48733', 'place_name': 'Fairgrove', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.5126, 'longitude': -83.5835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48735', 'place_name': 'Gagetown', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.6543, 'longitude': -83.2628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48741', 'place_name': 'Kingston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.3982, 'longitude': -83.1847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48744', 'place_name': 'Mayville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.3562, 'longitude': -83.3725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48746', 'place_name': 'Millington', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.2718, 'longitude': -83.5619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48757', 'place_name': 'Reese', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.4531, 'longitude': -83.7015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48758', 'place_name': 'Richville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.4073, 'longitude': -83.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48767', 'place_name': 'Unionville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.6473, 'longitude': -83.4699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48768', 'place_name': 'Vassar', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Tuscola', 'locality_code': '157', 'latitude': 43.3691, 'longitude': -83.5844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49013', 'place_name': 'Bangor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.3312, 'longitude': -86.1311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49026', 'place_name': 'Bloomingdale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.3842, 'longitude': -85.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49027', 'place_name': 'Breedsville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.3465, 'longitude': -86.0725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49043', 'place_name': 'Covert', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.2911, 'longitude': -86.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49045', 'place_name': 'Decatur', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.1012, 'longitude': -86.0338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49055', 'place_name': 'Gobles', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.3702, 'longitude': -85.8536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49056', 'place_name': 'Grand Junction', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.3761, 'longitude': -86.0541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49057', 'place_name': 'Hartford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.2088, 'longitude': -86.1687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49062', 'place_name': 'Kendall', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.3618, 'longitude': -85.8141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49063', 'place_name': 'Lacota', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.4136, 'longitude': -86.1298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49064', 'place_name': 'Lawrence', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.2076, 'longitude': -86.0525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49065', 'place_name': 'Lawton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.1545, 'longitude': -85.829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49071', 'place_name': 'Mattawan', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.2451, 'longitude': -85.7943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49079', 'place_name': 'Paw Paw', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.2349, 'longitude': -85.9005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49090', 'place_name': 'South Haven', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Van Buren', 'locality_code': '159', 'latitude': 42.4041, 'longitude': -86.2542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48103', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2794, 'longitude': -83.784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48104', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2694, 'longitude': -83.7282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48105', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.3042, 'longitude': -83.7068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48106', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2535, 'longitude': -83.8366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48107', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2535, 'longitude': -83.8366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48108', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2328, 'longitude': -83.7015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48109', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2776, 'longitude': -83.7409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48113', 'place_name': 'Ann Arbor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2535, 'longitude': -83.8366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48115', 'place_name': 'Bridgewater', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.1602, 'longitude': -83.9117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48118', 'place_name': 'Chelsea', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.3207, 'longitude': -84.0334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48130', 'place_name': 'Dexter', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.3583, 'longitude': -83.9, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48158', 'place_name': 'Manchester', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.1555, 'longitude': -84.0332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48175', 'place_name': 'Salem', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.4056, 'longitude': -83.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48176', 'place_name': 'Saline', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.1698, 'longitude': -83.7849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48189', 'place_name': 'Whitmore Lake', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.4289, 'longitude': -83.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48190', 'place_name': 'Whittaker', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.1244, 'longitude': -83.5946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48191', 'place_name': 'Willis', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.1292, 'longitude': -83.5687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48197', 'place_name': 'Ypsilanti', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2325, 'longitude': -83.6336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48198', 'place_name': 'Ypsilanti', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Washtenaw', 'locality_code': '161', 'latitude': 42.2439, 'longitude': -83.583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48101', 'place_name': 'Allen Park', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2522, 'longitude': -83.212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48111', 'place_name': 'Belleville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.1949, 'longitude': -83.4854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48112', 'place_name': 'Belleville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2048, 'longitude': -83.4852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48120', 'place_name': 'Dearborn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3223, 'longitude': -83.1763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48121', 'place_name': 'Dearborn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48122', 'place_name': 'Melvindale', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2812, 'longitude': -83.1826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48123', 'place_name': 'Dearborn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48124', 'place_name': 'Dearborn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2941, 'longitude': -83.2536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48125', 'place_name': 'Dearborn Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2768, 'longitude': -83.2606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48126', 'place_name': 'Dearborn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3349, 'longitude': -83.1801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48127', 'place_name': 'Dearborn Heights', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3353, 'longitude': -83.2864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48128', 'place_name': 'Dearborn', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.32, 'longitude': -83.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48134', 'place_name': 'Flat Rock', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.1055, 'longitude': -83.2795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48135', 'place_name': 'Garden City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3242, 'longitude': -83.3402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48136', 'place_name': 'Garden City', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48138', 'place_name': 'Grosse Ile', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.1352, 'longitude': -83.1561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48141', 'place_name': 'Inkster', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.294, 'longitude': -83.3146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48146', 'place_name': 'Lincoln Park', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2422, 'longitude': -83.1807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48150', 'place_name': 'Livonia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3615, 'longitude': -83.3649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48151', 'place_name': 'Livonia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3684, 'longitude': -83.3527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48152', 'place_name': 'Livonia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4258, 'longitude': -83.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48153', 'place_name': 'Livonia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3684, 'longitude': -83.3527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48154', 'place_name': 'Livonia', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3958, 'longitude': -83.3772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48164', 'place_name': 'New Boston', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.1449, 'longitude': -83.3589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48167', 'place_name': 'Northville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4262, 'longitude': -83.4794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48168', 'place_name': 'Northville', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4086, 'longitude': -83.4978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48170', 'place_name': 'Plymouth', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3688, 'longitude': -83.4799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48173', 'place_name': 'Rockwood', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.0731, 'longitude': -83.2127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48174', 'place_name': 'Romulus', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2223, 'longitude': -83.3966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48180', 'place_name': 'Taylor', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2317, 'longitude': -83.2673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48183', 'place_name': 'Trenton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.1382, 'longitude': -83.2179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48184', 'place_name': 'Wayne', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2768, 'longitude': -83.3758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48185', 'place_name': 'Westland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3358, 'longitude': -83.3846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48186', 'place_name': 'Westland', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.289, 'longitude': -83.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48187', 'place_name': 'Canton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.332, 'longitude': -83.4695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48188', 'place_name': 'Canton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.291, 'longitude': -83.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48192', 'place_name': 'Wyandotte', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2084, 'longitude': -83.1616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48193', 'place_name': 'Riverview', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.1782, 'longitude': -83.2461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48195', 'place_name': 'Southgate', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2044, 'longitude': -83.1999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48201', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3474, 'longitude': -83.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48202', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.377, 'longitude': -83.0796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48203', 'place_name': 'Highland Park', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4212, 'longitude': -83.1009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48204', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3661, 'longitude': -83.1422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48205', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4313, 'longitude': -82.9813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48206', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3749, 'longitude': -83.1087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48207', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3524, 'longitude': -83.0271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48208', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3495, 'longitude': -83.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48209', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3097, 'longitude': -83.1155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48210', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3376, 'longitude': -83.1303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48211', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3809, 'longitude': -83.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48212', 'place_name': 'Hamtramck', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4081, 'longitude': -83.0583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48213', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3982, 'longitude': -82.9925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48214', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3669, 'longitude': -82.9938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48215', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3773, 'longitude': -82.9513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48216', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3275, 'longitude': -83.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48217', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2719, 'longitude': -83.1545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48218', 'place_name': 'River Rouge', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2692, 'longitude': -83.1364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48219', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.426, 'longitude': -83.2495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48221', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.426, 'longitude': -83.15, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48222', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48223', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3945, 'longitude': -83.2454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48224', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4098, 'longitude': -82.9441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48225', 'place_name': 'Harper Woods', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4377, 'longitude': -82.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48226', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3333, 'longitude': -83.0484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48227', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3883, 'longitude': -83.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48228', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3547, 'longitude': -83.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48229', 'place_name': 'Ecorse', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2519, 'longitude': -83.1489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48230', 'place_name': 'Grosse Pointe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3847, 'longitude': -82.9244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48231', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48232', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48233', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48234', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4337, 'longitude': -83.0434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48235', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4261, 'longitude': -83.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48236', 'place_name': 'Grosse Pointe', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4274, 'longitude': -82.9002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48238', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3959, 'longitude': -83.1411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48239', 'place_name': 'Redford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3756, 'longitude': -83.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48240', 'place_name': 'Redford', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.4264, 'longitude': -83.3017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48242', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2166, 'longitude': -83.3532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48243', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48244', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48255', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48260', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48264', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48265', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48266', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48267', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48268', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48269', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48272', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48275', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48277', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48278', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48279', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.3314, 'longitude': -83.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '48288', 'place_name': 'Detroit', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wayne', 'locality_code': '163', 'latitude': 42.2399, 'longitude': -83.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49601', 'place_name': 'Cadillac', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wexford', 'locality_code': '165', 'latitude': 44.2504, 'longitude': -85.43, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49618', 'place_name': 'Boon', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wexford', 'locality_code': '165', 'latitude': 44.2916, 'longitude': -85.6144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49620', 'place_name': 'Buckley', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wexford', 'locality_code': '165', 'latitude': 44.5199, 'longitude': -85.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49638', 'place_name': 'Harrietta', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wexford', 'locality_code': '165', 'latitude': 44.2972, 'longitude': -85.7396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49663', 'place_name': 'Manton', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wexford', 'locality_code': '165', 'latitude': 44.4152, 'longitude': -85.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '49668', 'place_name': 'Mesick', 'state': 'Michigan', 'state_ab': 'MI', 'county': 'Wexford', 'locality_code': '165', 'latitude': 44.4075, 'longitude': -85.7061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55748', 'place_name': 'Hill City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.9968, 'longitude': -93.5994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55752', 'place_name': 'Jacobson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.9772, 'longitude': -93.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55760', 'place_name': 'Mcgregor', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.6072, 'longitude': -93.3076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55785', 'place_name': 'Swatara', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.9232, 'longitude': -93.7464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55787', 'place_name': 'Tamarack', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.6444, 'longitude': -93.1272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56350', 'place_name': 'Mc Grath', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.1957, 'longitude': -93.3774, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '56431', 'place_name': 'Aitkin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.4799, 'longitude': -93.6454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56469', 'place_name': 'Palisade', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Aitkin', 'locality_code': '1', 'latitude': 46.6895, 'longitude': -93.5627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55005', 'place_name': 'Bethel', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.3887, 'longitude': -93.2315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55011', 'place_name': 'Cedar', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.3414, 'longitude': -93.235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55014', 'place_name': 'Circle Pines', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.1528, 'longitude': -93.144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55070', 'place_name': 'Saint Francis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.3903, 'longitude': -93.3598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55303', 'place_name': 'Anoka', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.2825, 'longitude': -93.4186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55304', 'place_name': 'Andover', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.2377, 'longitude': -93.2724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55421', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.0523, 'longitude': -93.2541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55432', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.095, 'longitude': -93.2396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55433', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.1643, 'longitude': -93.3193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55434', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.1681, 'longitude': -93.2504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55448', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.1907, 'longitude': -93.3021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55449', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Anoka', 'locality_code': '3', 'latitude': 45.1697, 'longitude': -93.1889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56501', 'place_name': 'Detroit Lakes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.8172, 'longitude': -95.8453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56502', 'place_name': 'Detroit Lakes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.8172, 'longitude': -95.8453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56511', 'place_name': 'Audubon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.8719, 'longitude': -95.9881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56521', 'place_name': 'Callaway', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 47.0076, 'longitude': -95.944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56544', 'place_name': 'Frazee', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.7565, 'longitude': -95.5212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56554', 'place_name': 'Lake Park', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.8176, 'longitude': -96.067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56569', 'place_name': 'Ogema', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 47.1029, 'longitude': -95.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56570', 'place_name': 'Osage', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.9329, 'longitude': -95.2353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56575', 'place_name': 'Ponsford', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 47.0133, 'longitude': -95.3197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56577', 'place_name': 'Richwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.9747, 'longitude': -95.8228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56578', 'place_name': 'Rochert', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.8862, 'longitude': -95.7246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56591', 'place_name': 'White Earth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 47.0966, 'longitude': -95.8434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56593', 'place_name': 'Wolf Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Becker', 'locality_code': '5', 'latitude': 46.8035, 'longitude': -95.3535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56601', 'place_name': 'Bemidji', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.572, 'longitude': -94.8013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56619', 'place_name': 'Bemidji', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.4736, 'longitude': -94.8803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56630', 'place_name': 'Blackduck', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.7381, 'longitude': -94.4961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56647', 'place_name': 'Hines', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.7324, 'longitude': -94.6477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56650', 'place_name': 'Kelliher', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.9272, 'longitude': -94.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56663', 'place_name': 'Pennington', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.4651, 'longitude': -94.4834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56666', 'place_name': 'Ponemah', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 48.0372, 'longitude': -94.917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56667', 'place_name': 'Puposky', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.7436, 'longitude': -94.9803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56670', 'place_name': 'Redby', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.8689, 'longitude': -94.9404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56671', 'place_name': 'Redlake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.8654, 'longitude': -95.0643, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '56678', 'place_name': 'Solway', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.548, 'longitude': -95.1205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56683', 'place_name': 'Tenstrike', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.6566, 'longitude': -94.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56685', 'place_name': 'Waskish', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 48.177, 'longitude': -94.5037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56687', 'place_name': 'Wilton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Beltrami', 'locality_code': '7', 'latitude': 47.5036, 'longitude': -95.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56329', 'place_name': 'Foley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Benton', 'locality_code': '9', 'latitude': 45.6919, 'longitude': -93.9148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56333', 'place_name': 'Gilman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Benton', 'locality_code': '9', 'latitude': 45.6917, 'longitude': -94.0563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56357', 'place_name': 'Oak Park', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Benton', 'locality_code': '9', 'latitude': 45.7022, 'longitude': -93.8164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56367', 'place_name': 'Rice', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Benton', 'locality_code': '9', 'latitude': 45.7364, 'longitude': -94.1658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56379', 'place_name': 'Sauk Rapids', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Benton', 'locality_code': '9', 'latitude': 45.604, 'longitude': -94.1591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56210', 'place_name': 'Barry', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Big Stone', 'locality_code': '11', 'latitude': 45.5593, 'longitude': -96.5589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56211', 'place_name': 'Beardsley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Big Stone', 'locality_code': '11', 'latitude': 45.5539, 'longitude': -96.706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56225', 'place_name': 'Clinton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Big Stone', 'locality_code': '11', 'latitude': 45.4577, 'longitude': -96.4182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56227', 'place_name': 'Correll', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Big Stone', 'locality_code': '11', 'latitude': 45.2907, 'longitude': -96.1753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56240', 'place_name': 'Graceville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Big Stone', 'locality_code': '11', 'latitude': 45.5602, 'longitude': -96.4209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56276', 'place_name': 'Odessa', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Big Stone', 'locality_code': '11', 'latitude': 45.2597, 'longitude': -96.3289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56278', 'place_name': 'Ortonville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Big Stone', 'locality_code': '11', 'latitude': 45.3296, 'longitude': -96.4596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56001', 'place_name': 'Mankato', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.1538, 'longitude': -93.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56002', 'place_name': 'Mankato', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.1591, 'longitude': -94.0092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56010', 'place_name': 'Amboy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 43.8903, 'longitude': -94.1774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56024', 'place_name': 'Eagle Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.1546, 'longitude': -93.8719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56034', 'place_name': 'Garden City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.0467, 'longitude': -94.1791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56037', 'place_name': 'Good Thunder', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 43.9952, 'longitude': -94.0677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56055', 'place_name': 'Lake Crystal', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.1202, 'longitude': -94.2184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56063', 'place_name': 'Madison Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.2221, 'longitude': -93.8289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56065', 'place_name': 'Mapleton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 43.9331, 'longitude': -93.9542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56078', 'place_name': 'Pemberton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.0077, 'longitude': -93.7833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56080', 'place_name': 'Saint Clair', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 44.0817, 'longitude': -93.8571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56090', 'place_name': 'Vernon Center', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Blue Earth', 'locality_code': '13', 'latitude': 43.9706, 'longitude': -94.2142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56019', 'place_name': 'Comfrey', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Brown', 'locality_code': '15', 'latitude': 44.1111, 'longitude': -94.9134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56030', 'place_name': 'Essig', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Brown', 'locality_code': '15', 'latitude': 44.3258, 'longitude': -94.6052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56041', 'place_name': 'Hanska', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Brown', 'locality_code': '15', 'latitude': 44.1527, 'longitude': -94.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56073', 'place_name': 'New Ulm', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Brown', 'locality_code': '15', 'latitude': 44.3044, 'longitude': -94.4644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56084', 'place_name': 'Searles', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Brown', 'locality_code': '15', 'latitude': 44.2286, 'longitude': -94.4347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56085', 'place_name': 'Sleepy Eye', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Brown', 'locality_code': '15', 'latitude': 44.2821, 'longitude': -94.7273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56087', 'place_name': 'Springfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Brown', 'locality_code': '15', 'latitude': 44.2329, 'longitude': -94.9792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55707', 'place_name': 'Barnum', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.5196, 'longitude': -92.6292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55718', 'place_name': 'Carlton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.6484, 'longitude': -92.471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55720', 'place_name': 'Cloquet', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.7546, 'longitude': -92.5408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55726', 'place_name': 'Cromwell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.6718, 'longitude': -92.8739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55733', 'place_name': 'Esko', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.7126, 'longitude': -92.3569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55749', 'place_name': 'Holyoke', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.4664, 'longitude': -92.375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55757', 'place_name': 'Kettle River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.5029, 'longitude': -92.9047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55767', 'place_name': 'Moose Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.4472, 'longitude': -92.7466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55780', 'place_name': 'Sawyer', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.6831, 'longitude': -92.6927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55797', 'place_name': 'Wrenshall', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.5921, 'longitude': -92.3718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55798', 'place_name': 'Wright', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carlton', 'locality_code': '17', 'latitude': 46.6691, 'longitude': -93.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55315', 'place_name': 'Carver', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.7169, 'longitude': -93.6879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55317', 'place_name': 'Chanhassen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8679, 'longitude': -93.5359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55318', 'place_name': 'Chaska', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8061, 'longitude': -93.6083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55322', 'place_name': 'Cologne', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.7646, 'longitude': -93.7982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55339', 'place_name': 'Hamburg', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.7315, 'longitude': -93.9643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55360', 'place_name': 'Mayer', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.9022, 'longitude': -93.8859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55367', 'place_name': 'New Germany', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8994, 'longitude': -93.9701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55368', 'place_name': 'Norwood Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.7736, 'longitude': -93.9216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55383', 'place_name': 'Norwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.768, 'longitude': -93.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55386', 'place_name': 'Victoria', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8582, 'longitude': -93.6561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55387', 'place_name': 'Waconia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.851, 'longitude': -93.7784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55388', 'place_name': 'Watertown', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.9595, 'longitude': -93.8482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55397', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.7929, 'longitude': -93.918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55473', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55550', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55551', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55553', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55554', 'place_name': 'Norwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55558', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55568', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55583', 'place_name': 'Norwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55594', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Carver', 'locality_code': '19', 'latitude': 44.8055, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56430', 'place_name': 'Ah Gwah Ching', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 47.0741, 'longitude': -94.5628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56435', 'place_name': 'Backus', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 46.8699, 'longitude': -94.3959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56452', 'place_name': 'Hackensack', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 46.9884, 'longitude': -94.5033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56473', 'place_name': 'Pillager', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 46.3607, 'longitude': -94.4895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56474', 'place_name': 'Pine River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 46.6938, 'longitude': -94.4477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56484', 'place_name': 'Walker', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 47.0877, 'longitude': -94.5847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56626', 'place_name': 'Bena', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 47.3477, 'longitude': -94.2519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56633', 'place_name': 'Cass Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 47.3516, 'longitude': -94.6119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56641', 'place_name': 'Federal Dam', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 47.2069, 'longitude': -94.2575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56655', 'place_name': 'Longville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 47.0248, 'longitude': -94.1982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56662', 'place_name': 'Outing', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 46.8375, 'longitude': -93.9443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56672', 'place_name': 'Remer', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cass', 'locality_code': '21', 'latitude': 47.0874, 'longitude': -93.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56222', 'place_name': 'Clara City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chippewa', 'locality_code': '23', 'latitude': 44.9639, 'longitude': -95.3499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56260', 'place_name': 'Maynard', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chippewa', 'locality_code': '23', 'latitude': 44.9226, 'longitude': -95.4845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56262', 'place_name': 'Milan', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chippewa', 'locality_code': '23', 'latitude': 45.1143, 'longitude': -95.869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56265', 'place_name': 'Montevideo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chippewa', 'locality_code': '23', 'latitude': 44.9688, 'longitude': -95.6765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56295', 'place_name': 'Watson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chippewa', 'locality_code': '23', 'latitude': 45.0412, 'longitude': -95.834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55002', 'place_name': 'Almelund', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.5134, 'longitude': -92.8942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55012', 'place_name': 'Center City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.4482, 'longitude': -92.7894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55013', 'place_name': 'Chisago City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.3611, 'longitude': -92.8921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55032', 'place_name': 'Harris', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.5962, 'longitude': -93.0395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55045', 'place_name': 'Lindstrom', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.3873, 'longitude': -92.8421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55056', 'place_name': 'North Branch', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.5114, 'longitude': -92.9802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55069', 'place_name': 'Rush City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.6855, 'longitude': -92.9655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55074', 'place_name': 'Shafer', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.3576, 'longitude': -92.7609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55078', 'place_name': 'Stacy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.398, 'longitude': -92.9874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55079', 'place_name': 'Stacy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.3975, 'longitude': -93.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55084', 'place_name': 'Taylors Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.4576, 'longitude': -92.733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55092', 'place_name': 'Wyoming', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Chisago', 'locality_code': '25', 'latitude': 45.3364, 'longitude': -92.9675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56514', 'place_name': 'Barnesville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.6522, 'longitude': -96.4198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56525', 'place_name': 'Comstock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.6667, 'longitude': -96.7398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56529', 'place_name': 'Dilworth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.8782, 'longitude': -96.7022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56536', 'place_name': 'Felton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 47.0705, 'longitude': -96.5052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56546', 'place_name': 'Georgetown', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 47.0999, 'longitude': -96.727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56547', 'place_name': 'Glyndon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.882, 'longitude': -96.5583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56549', 'place_name': 'Hawley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.9777, 'longitude': -96.4092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56552', 'place_name': 'Hitterdal', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 47.0014, 'longitude': -96.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56560', 'place_name': 'Moorhead', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.8677, 'longitude': -96.7572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56561', 'place_name': 'Moorhead', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.8739, 'longitude': -96.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56562', 'place_name': 'Moorhead', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.8739, 'longitude': -96.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56563', 'place_name': 'Moorhead', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.8739, 'longitude': -96.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56580', 'place_name': 'Sabin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 46.7703, 'longitude': -96.5985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56585', 'place_name': 'Ulen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clay', 'locality_code': '27', 'latitude': 47.0903, 'longitude': -96.2824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56621', 'place_name': 'Bagley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clearwater', 'locality_code': '29', 'latitude': 47.487, 'longitude': -95.4133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56634', 'place_name': 'Clearbrook', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clearwater', 'locality_code': '29', 'latitude': 47.7146, 'longitude': -95.3752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56644', 'place_name': 'Gonvick', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clearwater', 'locality_code': '29', 'latitude': 47.749, 'longitude': -95.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56652', 'place_name': 'Leonard', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clearwater', 'locality_code': '29', 'latitude': 47.7334, 'longitude': -95.2481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56676', 'place_name': 'Shevlin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Clearwater', 'locality_code': '29', 'latitude': 47.5004, 'longitude': -95.245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55604', 'place_name': 'Grand Marais', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cook', 'locality_code': '31', 'latitude': 47.7758, 'longitude': -90.3391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55605', 'place_name': 'Grand Portage', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cook', 'locality_code': '31', 'latitude': 47.9591, 'longitude': -89.6989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55606', 'place_name': 'Hovland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cook', 'locality_code': '31', 'latitude': 47.8342, 'longitude': -90.0476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55612', 'place_name': 'Lutsen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cook', 'locality_code': '31', 'latitude': 47.6831, 'longitude': -90.6381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55613', 'place_name': 'Schroeder', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cook', 'locality_code': '31', 'latitude': 47.5422, 'longitude': -90.9338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55615', 'place_name': 'Tofte', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cook', 'locality_code': '31', 'latitude': 47.5738, 'longitude': -90.8363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56101', 'place_name': 'Windom', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cottonwood', 'locality_code': '33', 'latitude': 43.8831, 'longitude': -95.1373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56118', 'place_name': 'Bingham Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cottonwood', 'locality_code': '33', 'latitude': 43.8942, 'longitude': -95.0457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56145', 'place_name': 'Jeffers', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cottonwood', 'locality_code': '33', 'latitude': 44.0737, 'longitude': -95.1547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56159', 'place_name': 'Mountain Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cottonwood', 'locality_code': '33', 'latitude': 43.939, 'longitude': -94.9273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56174', 'place_name': 'Storden', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cottonwood', 'locality_code': '33', 'latitude': 44.0524, 'longitude': -95.3019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56183', 'place_name': 'Westbrook', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Cottonwood', 'locality_code': '33', 'latitude': 44.0654, 'longitude': -95.4232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56401', 'place_name': 'Brainerd', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.3502, 'longitude': -94.1, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56425', 'place_name': 'Baxter', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.3429, 'longitude': -94.2822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56441', 'place_name': 'Crosby', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.5091, 'longitude': -93.9874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56442', 'place_name': 'Crosslake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.6773, 'longitude': -94.1128, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '56444', 'place_name': 'Deerwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.4446, 'longitude': -93.8849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56447', 'place_name': 'Emily', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.7478, 'longitude': -93.9484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56448', 'place_name': 'Fifty Lakes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.747, 'longitude': -94.0656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56449', 'place_name': 'Fort Ripley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.2099, 'longitude': -94.2527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56450', 'place_name': 'Garrison', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.2314, 'longitude': -93.8341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56455', 'place_name': 'Ironton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.4778, 'longitude': -93.9789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56456', 'place_name': 'Jenkins', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.6461, 'longitude': -94.3347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56459', 'place_name': 'Lake Hubert', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.4987, 'longitude': -94.2519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56465', 'place_name': 'Merrifield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.5393, 'longitude': -94.1344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56468', 'place_name': 'Nisswa', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.4929, 'longitude': -94.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56472', 'place_name': 'Pequot Lakes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Crow Wing', 'locality_code': '35', 'latitude': 46.6257, 'longitude': -94.2684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55010', 'place_name': 'Castle Rock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.5472, 'longitude': -93.1531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55024', 'place_name': 'Farmington', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.6628, 'longitude': -93.1539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55031', 'place_name': 'Hampton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.6028, 'longitude': -92.9467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55033', 'place_name': 'Hastings', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.7129, 'longitude': -92.8637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55044', 'place_name': 'Lakeville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.6749, 'longitude': -93.2578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55065', 'place_name': 'Randolph', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.5274, 'longitude': -93.0196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55068', 'place_name': 'Rosemount', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.7394, 'longitude': -93.1258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55075', 'place_name': 'South Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.8881, 'longitude': -93.046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55076', 'place_name': 'Inver Grove Heights', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.8288, 'longitude': -93.0391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55077', 'place_name': 'Inver Grove Heights', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.8283, 'longitude': -93.094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55085', 'place_name': 'Vermillion', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.6748, 'longitude': -92.9683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55118', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.8965, 'longitude': -93.1034, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55120', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.8704, 'longitude': -93.1434, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55121', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.8471, 'longitude': -93.1543, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55122', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.786, 'longitude': -93.2202, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55123', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.806, 'longitude': -93.1409, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55124', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.7497, 'longitude': -93.2029, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55150', 'place_name': 'Mendota', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.8858, 'longitude': -93.1612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55306', 'place_name': 'Burnsville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.7307, 'longitude': -93.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55337', 'place_name': 'Burnsville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dakota', 'locality_code': '37', 'latitude': 44.7609, 'longitude': -93.2753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55924', 'place_name': 'Claremont', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dodge', 'locality_code': '39', 'latitude': 44.0522, 'longitude': -92.9888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55927', 'place_name': 'Dodge Center', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dodge', 'locality_code': '39', 'latitude': 44.0325, 'longitude': -92.8554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55940', 'place_name': 'Hayfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dodge', 'locality_code': '39', 'latitude': 43.8923, 'longitude': -92.8175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55944', 'place_name': 'Kasson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dodge', 'locality_code': '39', 'latitude': 44.024, 'longitude': -92.7464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55955', 'place_name': 'Mantorville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dodge', 'locality_code': '39', 'latitude': 44.0657, 'longitude': -92.76, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55985', 'place_name': 'West Concord', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Dodge', 'locality_code': '39', 'latitude': 44.152, 'longitude': -92.8825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56308', 'place_name': 'Alexandria', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.8817, 'longitude': -95.382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56315', 'place_name': 'Brandon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.9652, 'longitude': -95.5987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56319', 'place_name': 'Carlos', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.9726, 'longitude': -95.3105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56326', 'place_name': 'Evansville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 46.0153, 'longitude': -95.6951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56332', 'place_name': 'Garfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.9847, 'longitude': -95.5066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56341', 'place_name': 'Holmes City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.831, 'longitude': -95.5416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56343', 'place_name': 'Kensington', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.8176, 'longitude': -95.6945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56354', 'place_name': 'Miltona', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 46.0545, 'longitude': -95.3258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56355', 'place_name': 'Nelson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.9356, 'longitude': -95.2398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56360', 'place_name': 'Osakis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Douglas', 'locality_code': '41', 'latitude': 45.8768, 'longitude': -95.1332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56013', 'place_name': 'Blue Earth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.6394, 'longitude': -94.0924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56014', 'place_name': 'Bricelyn', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.5746, 'longitude': -93.8211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56023', 'place_name': 'Delavan', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.7719, 'longitude': -94.0225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56025', 'place_name': 'Easton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.7658, 'longitude': -93.9011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56027', 'place_name': 'Elmore', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.5201, 'longitude': -94.0984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56033', 'place_name': 'Frost', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.5638, 'longitude': -93.9361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56047', 'place_name': 'Huntley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.7316, 'longitude': -94.2375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56051', 'place_name': 'Kiester', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.5414, 'longitude': -93.7102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56068', 'place_name': 'Minnesota Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.8295, 'longitude': -93.8282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56097', 'place_name': 'Wells', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.7434, 'longitude': -93.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56098', 'place_name': 'Winnebago', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Faribault', 'locality_code': '43', 'latitude': 43.7755, 'longitude': -94.1632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55922', 'place_name': 'Canton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.5667, 'longitude': -91.913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55923', 'place_name': 'Chatfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.8362, 'longitude': -92.1574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55935', 'place_name': 'Fountain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.7284, 'longitude': -92.1423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55939', 'place_name': 'Harmony', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.5663, 'longitude': -92.0145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55949', 'place_name': 'Lanesboro', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.7174, 'longitude': -91.9877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55954', 'place_name': 'Mabel', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.5446, 'longitude': -91.7806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55961', 'place_name': 'Ostrander', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.5972, 'longitude': -92.4157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55962', 'place_name': 'Peterson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.7769, 'longitude': -91.8443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55965', 'place_name': 'Preston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.6641, 'longitude': -92.096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55971', 'place_name': 'Rushford', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.8216, 'longitude': -91.7536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55975', 'place_name': 'Spring Valley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.6823, 'longitude': -92.368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55990', 'place_name': 'Wykoff', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Fillmore', 'locality_code': '45', 'latitude': 43.7146, 'longitude': -92.2679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56007', 'place_name': 'Albert Lea', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.6537, 'longitude': -93.3707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56009', 'place_name': 'Alden', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.6466, 'longitude': -93.5823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56016', 'place_name': 'Clarks Grove', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.763, 'longitude': -93.3232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56020', 'place_name': 'Conger', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.615, 'longitude': -93.5283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56029', 'place_name': 'Emmons', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.5089, 'longitude': -93.4824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56032', 'place_name': 'Freeborn', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.7658, 'longitude': -93.5641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56035', 'place_name': 'Geneva', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.8235, 'longitude': -93.2671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56036', 'place_name': 'Glenville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.5577, 'longitude': -93.2618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56042', 'place_name': 'Hartland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.804, 'longitude': -93.477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56043', 'place_name': 'Hayward', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.6386, 'longitude': -93.2377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56045', 'place_name': 'Hollandale', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.7608, 'longitude': -93.2041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56089', 'place_name': 'Twin Lakes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Freeborn', 'locality_code': '47', 'latitude': 43.5593, 'longitude': -93.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55009', 'place_name': 'Cannon Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.496, 'longitude': -92.864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55018', 'place_name': 'Dennison', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.4265, 'longitude': -92.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55026', 'place_name': 'Frontenac', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.52, 'longitude': -92.3582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55027', 'place_name': 'Goodhue', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.4022, 'longitude': -92.5717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55066', 'place_name': 'Red Wing', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.5528, 'longitude': -92.5486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55089', 'place_name': 'Welch', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.603, 'longitude': -92.7263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55946', 'place_name': 'Kenyon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.2552, 'longitude': -93.0197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55963', 'place_name': 'Pine Island', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.211, 'longitude': -92.6613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55983', 'place_name': 'Wanamingo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.3121, 'longitude': -92.8103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55992', 'place_name': 'Zumbrota', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Goodhue', 'locality_code': '49', 'latitude': 44.3032, 'longitude': -92.6719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56248', 'place_name': 'Herman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.8086, 'longitude': -96.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56274', 'place_name': 'Norcross', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.8858, 'longitude': -96.1342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56309', 'place_name': 'Ashby', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Grant', 'locality_code': '51', 'latitude': 46.0781, 'longitude': -95.8214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56311', 'place_name': 'Barrett', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.8996, 'longitude': -95.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56339', 'place_name': 'Hoffman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.8233, 'longitude': -95.7955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56531', 'place_name': 'Elbow Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.9953, 'longitude': -95.9671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56590', 'place_name': 'Wendell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Grant', 'locality_code': '51', 'latitude': 46.0562, 'longitude': -96.1144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55111', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8828, 'longitude': -93.2007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55305', 'place_name': 'Hopkins', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9528, 'longitude': -93.4372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55311', 'place_name': 'Maple Grove', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0725, 'longitude': -93.4558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55316', 'place_name': 'Champlin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.17, 'longitude': -93.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55323', 'place_name': 'Crystal Bay', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.953, 'longitude': -93.5763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55327', 'place_name': 'Dayton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1982, 'longitude': -93.4668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55331', 'place_name': 'Excelsior', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9007, 'longitude': -93.5791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55340', 'place_name': 'Hamel', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.08, 'longitude': -93.576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55343', 'place_name': 'Hopkins', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.914, 'longitude': -93.4481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55344', 'place_name': 'Eden Prairie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8574, 'longitude': -93.4376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55345', 'place_name': 'Minnetonka', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9138, 'longitude': -93.485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55346', 'place_name': 'Eden Prairie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8771, 'longitude': -93.483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55347', 'place_name': 'Eden Prairie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8342, 'longitude': -93.4389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55348', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0072, 'longitude': -93.6558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55356', 'place_name': 'Long Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9912, 'longitude': -93.5818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55357', 'place_name': 'Loretto', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1061, 'longitude': -93.6692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55359', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9787, 'longitude': -93.7002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55361', 'place_name': 'Minnetonka Beach', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9402, 'longitude': -93.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55364', 'place_name': 'Mound', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9382, 'longitude': -93.6561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55369', 'place_name': 'Osseo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1284, 'longitude': -93.4589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55374', 'place_name': 'Rogers', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1715, 'longitude': -93.5814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55375', 'place_name': 'Saint Bonifacius', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9041, 'longitude': -93.749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55384', 'place_name': 'Spring Park', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9356, 'longitude': -93.6341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55391', 'place_name': 'Wayzata', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9847, 'longitude': -93.5422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55392', 'place_name': 'Navarre', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55401', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9835, 'longitude': -93.2683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55402', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9762, 'longitude': -93.2759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55403', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9673, 'longitude': -93.2828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55404', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9609, 'longitude': -93.2642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55405', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9702, 'longitude': -93.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55406', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9384, 'longitude': -93.2214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55407', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9378, 'longitude': -93.2545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55408', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9466, 'longitude': -93.2862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55409', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9264, 'longitude': -93.2818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55410', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9124, 'longitude': -93.3188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55411', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9996, 'longitude': -93.3005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55412', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0242, 'longitude': -93.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55413', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.998, 'longitude': -93.2552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55414', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9779, 'longitude': -93.2199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55415', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9742, 'longitude': -93.2585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55416', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9497, 'longitude': -93.3373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55417', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9054, 'longitude': -93.2361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55418', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0192, 'longitude': -93.2401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55419', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9026, 'longitude': -93.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55420', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8358, 'longitude': -93.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55422', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0096, 'longitude': -93.3424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55423', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8756, 'longitude': -93.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55424', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9052, 'longitude': -93.3403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55425', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8427, 'longitude': -93.2363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55426', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.955, 'longitude': -93.3829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55427', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45, 'longitude': -93.391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55428', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0632, 'longitude': -93.3811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55429', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0645, 'longitude': -93.3413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55430', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0639, 'longitude': -93.3022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55431', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8288, 'longitude': -93.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55435', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8735, 'longitude': -93.3346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55436', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9034, 'longitude': -93.374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55437', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8261, 'longitude': -93.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55438', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8266, 'longitude': -93.375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55439', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8744, 'longitude': -93.3753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55440', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55441', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0058, 'longitude': -93.4193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55442', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0467, 'longitude': -93.431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55443', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1194, 'longitude': -93.3431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55444', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1178, 'longitude': -93.3054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55445', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1232, 'longitude': -93.3797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55446', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.04, 'longitude': -93.4865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55447', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0033, 'longitude': -93.4875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55450', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.8811, 'longitude': -93.2207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55454', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9682, 'longitude': -93.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55455', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9735, 'longitude': -93.2331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55458', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55459', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55460', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55467', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.9861, 'longitude': -93.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55470', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55472', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55474', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55478', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55479', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55480', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55483', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55484', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55485', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55486', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55487', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55488', 'place_name': 'Minneapolis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 44.98, 'longitude': -93.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55569', 'place_name': 'Osseo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.1194, 'longitude': -93.4025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55570', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55571', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55572', 'place_name': 'Rockford', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0883, 'longitude': -93.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55573', 'place_name': 'Young America', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55574', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55575', 'place_name': 'Howard Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0608, 'longitude': -94.0733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55576', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55577', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55578', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55579', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55593', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55595', 'place_name': 'Loretto', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55596', 'place_name': 'Loretto', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55597', 'place_name': 'Loretto', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55598', 'place_name': 'Loretto', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55599', 'place_name': 'Loretto', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hennepin', 'locality_code': '53', 'latitude': 45.0159, 'longitude': -93.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55919', 'place_name': 'Brownsville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Houston', 'locality_code': '55', 'latitude': 43.6707, 'longitude': -91.3012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55921', 'place_name': 'Caledonia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Houston', 'locality_code': '55', 'latitude': 43.6221, 'longitude': -91.4837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55931', 'place_name': 'Eitzen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Houston', 'locality_code': '55', 'latitude': 43.5084, 'longitude': -91.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55941', 'place_name': 'Hokah', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Houston', 'locality_code': '55', 'latitude': 43.7509, 'longitude': -91.3455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55943', 'place_name': 'Houston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Houston', 'locality_code': '55', 'latitude': 43.7929, 'longitude': -91.5626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55947', 'place_name': 'La Crescent', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Houston', 'locality_code': '55', 'latitude': 43.8307, 'longitude': -91.3263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55974', 'place_name': 'Spring Grove', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Houston', 'locality_code': '55', 'latitude': 43.5623, 'longitude': -91.6368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56433', 'place_name': 'Akeley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hubbard', 'locality_code': '57', 'latitude': 47.001, 'longitude': -94.7234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56436', 'place_name': 'Benedict', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hubbard', 'locality_code': '57', 'latitude': 47.158, 'longitude': -94.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56458', 'place_name': 'Lake George', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hubbard', 'locality_code': '57', 'latitude': 47.215, 'longitude': -95.0021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56461', 'place_name': 'Laporte', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hubbard', 'locality_code': '57', 'latitude': 47.2368, 'longitude': -94.7772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56467', 'place_name': 'Nevis', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hubbard', 'locality_code': '57', 'latitude': 46.9319, 'longitude': -94.846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56470', 'place_name': 'Park Rapids', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Hubbard', 'locality_code': '57', 'latitude': 46.9377, 'longitude': -95.0383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55006', 'place_name': 'Braham', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Isanti', 'locality_code': '59', 'latitude': 45.7175, 'longitude': -93.2037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55008', 'place_name': 'Cambridge', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Isanti', 'locality_code': '59', 'latitude': 45.5576, 'longitude': -93.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55017', 'place_name': 'Dalbo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Isanti', 'locality_code': '59', 'latitude': 45.6787, 'longitude': -93.4419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55029', 'place_name': 'Grandy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Isanti', 'locality_code': '59', 'latitude': 45.6352, 'longitude': -93.1952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55040', 'place_name': 'Isanti', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Isanti', 'locality_code': '59', 'latitude': 45.4682, 'longitude': -93.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55080', 'place_name': 'Stanchfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Isanti', 'locality_code': '59', 'latitude': 45.6675, 'longitude': -93.2433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55709', 'place_name': 'Bovey', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.2868, 'longitude': -93.3723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55716', 'place_name': 'Calumet', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.3229, 'longitude': -93.2763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55721', 'place_name': 'Cohasset', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.2691, 'longitude': -93.6392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55722', 'place_name': 'Coleraine', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.2888, 'longitude': -93.4277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55730', 'place_name': 'Grand Rapids', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.2372, 'longitude': -93.5302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55742', 'place_name': 'Goodland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.1924, 'longitude': -93.1469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55744', 'place_name': 'Grand Rapids', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.2348, 'longitude': -93.5115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55745', 'place_name': 'Grand Rapids', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.2372, 'longitude': -93.5302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55753', 'place_name': 'Keewatin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.398, 'longitude': -93.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55764', 'place_name': 'Marble', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.3219, 'longitude': -93.2939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55769', 'place_name': 'Nashwauk', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.42, 'longitude': -93.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55775', 'place_name': 'Pengilly', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.3151, 'longitude': -93.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55784', 'place_name': 'Swan River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.0739, 'longitude': -93.1964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55786', 'place_name': 'Taconite', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.3164, 'longitude': -93.3904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55793', 'place_name': 'Warba', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.1361, 'longitude': -93.2764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56628', 'place_name': 'Bigfork', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.7502, 'longitude': -93.6707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56631', 'place_name': 'Bowstring', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.543, 'longitude': -93.7966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56636', 'place_name': 'Deer River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.3829, 'longitude': -93.8498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56637', 'place_name': 'Talmoon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.5888, 'longitude': -93.7749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56639', 'place_name': 'Effie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.8472, 'longitude': -93.5799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56657', 'place_name': 'Marcell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.5485, 'longitude': -93.6236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56659', 'place_name': 'Max', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.6147, 'longitude': -94.068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56680', 'place_name': 'Spring Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.6359, 'longitude': -93.922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56681', 'place_name': 'Squaw Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.6362, 'longitude': -94.1475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56688', 'place_name': 'Wirt', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Itasca', 'locality_code': '61', 'latitude': 47.7462, 'longitude': -93.963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56111', 'place_name': 'Alpha', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Jackson', 'locality_code': '63', 'latitude': 43.5946, 'longitude': -94.9051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56137', 'place_name': 'Heron Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Jackson', 'locality_code': '63', 'latitude': 43.7979, 'longitude': -95.3267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56143', 'place_name': 'Jackson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Jackson', 'locality_code': '63', 'latitude': 43.6457, 'longitude': -94.9938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56150', 'place_name': 'Lakefield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Jackson', 'locality_code': '63', 'latitude': 43.6545, 'longitude': -95.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56161', 'place_name': 'Okabena', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Jackson', 'locality_code': '63', 'latitude': 43.723, 'longitude': -95.3381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55051', 'place_name': 'Mora', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kanabec', 'locality_code': '65', 'latitude': 45.8958, 'longitude': -93.2942, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '56358', 'place_name': 'Ogilvie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kanabec', 'locality_code': '65', 'latitude': 45.8476, 'longitude': -93.4359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56201', 'place_name': 'Willmar', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.1393, 'longitude': -95.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56209', 'place_name': 'Atwater', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.1116, 'longitude': -94.7938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56216', 'place_name': 'Blomkest', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 44.9501, 'longitude': -95.0588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56251', 'place_name': 'Kandiyohi', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.1426, 'longitude': -94.9183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56253', 'place_name': 'Lake Lillian', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 44.966, 'longitude': -94.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56273', 'place_name': 'New London', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.2949, 'longitude': -94.948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56279', 'place_name': 'Pennock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.131, 'longitude': -95.1753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56281', 'place_name': 'Prinsburg', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 44.9371, 'longitude': -95.1865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56282', 'place_name': 'Raymond', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.0181, 'longitude': -95.2208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56288', 'place_name': 'Spicer', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.2241, 'longitude': -94.9116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56289', 'place_name': 'Sunburg', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kandiyohi', 'locality_code': '67', 'latitude': 45.3583, 'longitude': -95.2049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56720', 'place_name': 'Donaldson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.5722, 'longitude': -96.8964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56728', 'place_name': 'Hallock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.7749, 'longitude': -96.9445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56729', 'place_name': 'Halma', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.6669, 'longitude': -96.5969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56731', 'place_name': 'Humboldt', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.9211, 'longitude': -97.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56732', 'place_name': 'Karlstad', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.5916, 'longitude': -96.5511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56733', 'place_name': 'Kennedy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.6337, 'longitude': -96.9614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56734', 'place_name': 'Lake Bronson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.7787, 'longitude': -96.6431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56735', 'place_name': 'Lancaster', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.9153, 'longitude': -96.6366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56740', 'place_name': 'Noyes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.9975, 'longitude': -97.2045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56755', 'place_name': 'Saint Vincent', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Kittson', 'locality_code': '69', 'latitude': 48.9458, 'longitude': -97.1703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56627', 'place_name': 'Big Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.156, 'longitude': -93.7296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56629', 'place_name': 'Birchdale', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.6247, 'longitude': -94.1677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56649', 'place_name': 'International Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.601, 'longitude': -93.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56653', 'place_name': 'Littlefork', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.3852, 'longitude': -93.5399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56654', 'place_name': 'Loman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.5164, 'longitude': -93.8407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56658', 'place_name': 'Margie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.0904, 'longitude': -93.8292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56660', 'place_name': 'Mizpah', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 47.9495, 'longitude': -94.1467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56661', 'place_name': 'Northome', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 47.844, 'longitude': -94.2043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56668', 'place_name': 'Ranier', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.613, 'longitude': -93.3488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56669', 'place_name': 'Kabetogama', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.2463, 'longitude': -93.7842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56679', 'place_name': 'South International Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Koochiching', 'locality_code': '71', 'latitude': 48.5866, 'longitude': -93.399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56212', 'place_name': 'Bellingham', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lac qui Parle', 'locality_code': '73', 'latitude': 45.1556, 'longitude': -96.3224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56218', 'place_name': 'Boyd', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lac qui Parle', 'locality_code': '73', 'latitude': 44.8507, 'longitude': -95.9421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56232', 'place_name': 'Dawson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lac qui Parle', 'locality_code': '73', 'latitude': 44.9327, 'longitude': -96.0545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56256', 'place_name': 'Madison', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lac qui Parle', 'locality_code': '73', 'latitude': 44.9946, 'longitude': -96.1645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56257', 'place_name': 'Marietta', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lac qui Parle', 'locality_code': '73', 'latitude': 44.9636, 'longitude': -96.4094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55601', 'place_name': 'Beaver Bay', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake', 'locality_code': '75', 'latitude': 47.256, 'longitude': -91.3566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55603', 'place_name': 'Finland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake', 'locality_code': '75', 'latitude': 47.4197, 'longitude': -91.2096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55607', 'place_name': 'Isabella', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake', 'locality_code': '75', 'latitude': 47.6604, 'longitude': -91.4989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55609', 'place_name': 'Knife River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake', 'locality_code': '75', 'latitude': 46.9539, 'longitude': -91.778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55614', 'place_name': 'Silver Bay', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake', 'locality_code': '75', 'latitude': 47.3585, 'longitude': -91.2205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55616', 'place_name': 'Two Harbors', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake', 'locality_code': '75', 'latitude': 47.0394, 'longitude': -91.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56623', 'place_name': 'Baudette', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake of the Woods', 'locality_code': '77', 'latitude': 48.6927, 'longitude': -94.5995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56686', 'place_name': 'Williams', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake of the Woods', 'locality_code': '77', 'latitude': 48.8022, 'longitude': -94.9556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56711', 'place_name': 'Angle Inlet', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake of the Woods', 'locality_code': '77', 'latitude': 49.3453, 'longitude': -95.0627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56741', 'place_name': 'Oak Island', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lake of the Woods', 'locality_code': '77', 'latitude': 49.3135, 'longitude': -94.8492, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '56017', 'place_name': 'Cleveland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.3201, 'longitude': -93.8286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56028', 'place_name': 'Elysian', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.2231, 'longitude': -93.6965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56050', 'place_name': 'Kasota', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.2842, 'longitude': -93.9453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56052', 'place_name': 'Kilkenny', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.3133, 'longitude': -93.5741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56057', 'place_name': 'Le Center', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.3853, 'longitude': -93.7214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56058', 'place_name': 'Le Sueur', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.4582, 'longitude': -93.8856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56069', 'place_name': 'Montgomery', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.4356, 'longitude': -93.581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56071', 'place_name': 'New Prague', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.5402, 'longitude': -93.5805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56096', 'place_name': 'Waterville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Le Sueur', 'locality_code': '79', 'latitude': 44.2238, 'longitude': -93.5751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56113', 'place_name': 'Arco', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 44.4091, 'longitude': -96.1999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56136', 'place_name': 'Hendricks', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 44.4995, 'longitude': -96.4078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56142', 'place_name': 'Ivanhoe', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 44.4633, 'longitude': -96.2473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56149', 'place_name': 'Lake Benton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 44.2782, 'longitude': -96.291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56178', 'place_name': 'Tyler', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 44.2773, 'longitude': -96.1302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56115', 'place_name': 'Balaton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.2253, 'longitude': -95.8838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56132', 'place_name': 'Garvin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.2293, 'longitude': -95.7672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56157', 'place_name': 'Lynd', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.4032, 'longitude': -95.9233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56169', 'place_name': 'Russell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.3201, 'longitude': -95.9426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56175', 'place_name': 'Tracy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.2342, 'longitude': -95.6213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56229', 'place_name': 'Cottonwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.6003, 'longitude': -95.6925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56239', 'place_name': 'Ghent', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.5078, 'longitude': -95.8936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56258', 'place_name': 'Marshall', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.4481, 'longitude': -95.7795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56264', 'place_name': 'Minneota', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.5587, 'longitude': -95.9767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56291', 'place_name': 'Taunton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Lyon', 'locality_code': '83', 'latitude': 44.5951, 'longitude': -96.0526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55312', 'place_name': 'Brownton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.7281, 'longitude': -94.3306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55336', 'place_name': 'Glencoe', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.778, 'longitude': -94.1616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55350', 'place_name': 'Hutchinson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.8946, 'longitude': -94.3847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55354', 'place_name': 'Lester Prairie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.8739, 'longitude': -94.0551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55370', 'place_name': 'Plato', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.7657, 'longitude': -94.0506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55381', 'place_name': 'Silver Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.9139, 'longitude': -94.1974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55385', 'place_name': 'Stewart', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.7259, 'longitude': -94.4516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55395', 'place_name': 'Winsted', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'McLeod', 'locality_code': '85', 'latitude': 44.9585, 'longitude': -94.0552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56516', 'place_name': 'Bejou', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mahnomen', 'locality_code': '87', 'latitude': 47.4491, 'longitude': -95.9454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56557', 'place_name': 'Mahnomen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mahnomen', 'locality_code': '87', 'latitude': 47.3362, 'longitude': -95.8856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56566', 'place_name': 'Naytahwaush', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mahnomen', 'locality_code': '87', 'latitude': 47.2601, 'longitude': -95.6283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56589', 'place_name': 'Waubun', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mahnomen', 'locality_code': '87', 'latitude': 47.192, 'longitude': -95.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56710', 'place_name': 'Alvarado', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.202, 'longitude': -96.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56713', 'place_name': 'Argyle', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.3314, 'longitude': -96.8671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56724', 'place_name': 'Gatzke', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.4104, 'longitude': -95.7903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56727', 'place_name': 'Grygla', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.3071, 'longitude': -95.6398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56737', 'place_name': 'Middle River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.4426, 'longitude': -96.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56738', 'place_name': 'Newfolden', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.2895, 'longitude': -96.255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56744', 'place_name': 'Oslo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.2066, 'longitude': -97.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56757', 'place_name': 'Stephen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.4525, 'longitude': -96.8674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56758', 'place_name': 'Strandquist', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.4526, 'longitude': -96.4723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56760', 'place_name': 'Viking', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.2349, 'longitude': -96.4749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56762', 'place_name': 'Warren', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Marshall', 'locality_code': '89', 'latitude': 48.2614, 'longitude': -96.7726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56031', 'place_name': 'Fairmont', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.6376, 'longitude': -94.451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56039', 'place_name': 'Granada', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.7061, 'longitude': -94.3307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56075', 'place_name': 'Northrop', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.7353, 'longitude': -94.4357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56088', 'place_name': 'Truman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.82, 'longitude': -94.4319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56121', 'place_name': 'Ceylon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.5382, 'longitude': -94.6149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56127', 'place_name': 'Dunnell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.5531, 'longitude': -94.7876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56162', 'place_name': 'Ormsby', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.8616, 'longitude': -94.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56171', 'place_name': 'Sherburn', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.6611, 'longitude': -94.7269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56176', 'place_name': 'Trimont', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.7827, 'longitude': -94.7186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56181', 'place_name': 'Welcome', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Martin', 'locality_code': '91', 'latitude': 43.6705, 'longitude': -94.5886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55324', 'place_name': 'Darwin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Meeker', 'locality_code': '93', 'latitude': 45.1029, 'longitude': -94.4249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55325', 'place_name': 'Dassel', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Meeker', 'locality_code': '93', 'latitude': 45.1032, 'longitude': -94.3305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55329', 'place_name': 'Eden Valley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Meeker', 'locality_code': '93', 'latitude': 45.302, 'longitude': -94.6039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55355', 'place_name': 'Litchfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Meeker', 'locality_code': '93', 'latitude': 45.1263, 'longitude': -94.5268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55389', 'place_name': 'Watkins', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Meeker', 'locality_code': '93', 'latitude': 45.3087, 'longitude': -94.4297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56228', 'place_name': 'Cosmos', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Meeker', 'locality_code': '93', 'latitude': 44.959, 'longitude': -94.6978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56243', 'place_name': 'Grove City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Meeker', 'locality_code': '93', 'latitude': 45.1532, 'longitude': -94.6878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55371', 'place_name': 'Princeton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 45.5851, 'longitude': -93.5961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56313', 'place_name': 'Bock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 45.7845, 'longitude': -93.5522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56330', 'place_name': 'Foreston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 45.7028, 'longitude': -93.6958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56342', 'place_name': 'Isle', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 46.1696, 'longitude': -93.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56353', 'place_name': 'Milaca', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 45.7795, 'longitude': -93.6453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56359', 'place_name': 'Onamia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 46.0902, 'longitude': -93.6867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56363', 'place_name': 'Pease', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 45.6974, 'longitude': -93.6465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56386', 'place_name': 'Wahkon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mille Lacs', 'locality_code': '95', 'latitude': 46.1121, 'longitude': -93.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56314', 'place_name': 'Bowlus', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.8121, 'longitude': -94.4175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56317', 'place_name': 'Buckman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.8975, 'longitude': -94.0936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56328', 'place_name': 'Flensburg', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.9552, 'longitude': -94.535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56338', 'place_name': 'Hillman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 46.0678, 'longitude': -93.8812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56344', 'place_name': 'Lastrup', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 46.0394, 'longitude': -94.0633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56345', 'place_name': 'Little Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.9811, 'longitude': -94.3604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56364', 'place_name': 'Pierz', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 46.0081, 'longitude': -94.0853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56373', 'place_name': 'Royalton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.8589, 'longitude': -94.2211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56382', 'place_name': 'Swanville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.9431, 'longitude': -94.6289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56384', 'place_name': 'Upsala', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.8097, 'longitude': -94.5755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56388', 'place_name': 'Waite Park', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 45.5572, 'longitude': -94.2242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56443', 'place_name': 'Cushing', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 46.2022, 'longitude': -94.6185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56466', 'place_name': 'Motley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 46.2881, 'longitude': -94.5638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56475', 'place_name': 'Randall', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Morrison', 'locality_code': '97', 'latitude': 46.0734, 'longitude': -94.5005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55909', 'place_name': 'Adams', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.5591, 'longitude': -92.7305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55912', 'place_name': 'Austin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.6695, 'longitude': -92.9784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55918', 'place_name': 'Brownsdale', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.7248, 'longitude': -92.8738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55926', 'place_name': 'Dexter', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.716, 'longitude': -92.7268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55933', 'place_name': 'Elkton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.6348, 'longitude': -92.7104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55936', 'place_name': 'Grand Meadow', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.7101, 'longitude': -92.5692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55950', 'place_name': 'Lansing', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.7452, 'longitude': -92.9702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55951', 'place_name': 'Le Roy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.5315, 'longitude': -92.5065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55953', 'place_name': 'Lyle', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.5309, 'longitude': -92.9328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55967', 'place_name': 'Racine', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.79, 'longitude': -92.531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55970', 'place_name': 'Rose Creek', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.6036, 'longitude': -92.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55973', 'place_name': 'Sargeant', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.809, 'longitude': -92.7595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55977', 'place_name': 'Taopi', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.5458, 'longitude': -92.6335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55982', 'place_name': 'Waltham', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Mower', 'locality_code': '99', 'latitude': 43.807, 'longitude': -92.8734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56114', 'place_name': 'Avoca', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 43.9706, 'longitude': -95.6002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56122', 'place_name': 'Chandler', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 43.9163, 'longitude': -95.9296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56123', 'place_name': 'Currie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 44.0946, 'longitude': -95.6953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56125', 'place_name': 'Dovray', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 44.0533, 'longitude': -95.5499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56131', 'place_name': 'Fulda', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 43.8753, 'longitude': -95.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56141', 'place_name': 'Iona', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 43.9026, 'longitude': -95.7718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56151', 'place_name': 'Lake Wilson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 44.0095, 'longitude': -95.9797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56172', 'place_name': 'Slayton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Murray', 'locality_code': '101', 'latitude': 43.9856, 'longitude': -95.7554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56003', 'place_name': 'Mankato', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nicollet', 'locality_code': '103', 'latitude': 44.2172, 'longitude': -94.0942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56021', 'place_name': 'Courtland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nicollet', 'locality_code': '103', 'latitude': 44.2791, 'longitude': -94.3482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56054', 'place_name': 'Lafayette', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nicollet', 'locality_code': '103', 'latitude': 44.4073, 'longitude': -94.4365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56074', 'place_name': 'Nicollet', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nicollet', 'locality_code': '103', 'latitude': 44.2724, 'longitude': -94.1867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56082', 'place_name': 'Saint Peter', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nicollet', 'locality_code': '103', 'latitude': 44.3351, 'longitude': -93.9811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56110', 'place_name': 'Adrian', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.6197, 'longitude': -95.9273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56117', 'place_name': 'Bigelow', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.5336, 'longitude': -95.6515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56119', 'place_name': 'Brewster', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.7032, 'longitude': -95.4807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56129', 'place_name': 'Ellsworth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.5265, 'longitude': -96.0112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56153', 'place_name': 'Leota', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.8404, 'longitude': -96.0128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56155', 'place_name': 'Lismore', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.7339, 'longitude': -95.9682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56165', 'place_name': 'Reading', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.7136, 'longitude': -95.7389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56167', 'place_name': 'Round Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.562, 'longitude': -95.4502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56168', 'place_name': 'Rushmore', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.624, 'longitude': -95.7767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56185', 'place_name': 'Wilmont', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.7692, 'longitude': -95.8324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56187', 'place_name': 'Worthington', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Nobles', 'locality_code': '105', 'latitude': 43.6286, 'longitude': -95.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56510', 'place_name': 'Ada', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.3253, 'longitude': -96.5973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56519', 'place_name': 'Borup', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.1896, 'longitude': -96.553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56541', 'place_name': 'Flom', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.1588, 'longitude': -96.1309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56545', 'place_name': 'Gary', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.3675, 'longitude': -96.2152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56548', 'place_name': 'Halstad', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.3551, 'longitude': -96.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56550', 'place_name': 'Hendrum', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.2689, 'longitude': -96.7987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56574', 'place_name': 'Perley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.1831, 'longitude': -96.7777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56581', 'place_name': 'Shelly', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.4554, 'longitude': -96.7838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56584', 'place_name': 'Twin Valley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Norman', 'locality_code': '107', 'latitude': 47.2509, 'longitude': -96.2464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55901', 'place_name': 'Rochester', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.0496, 'longitude': -92.4896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55902', 'place_name': 'Rochester', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.0032, 'longitude': -92.4835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55903', 'place_name': 'Rochester', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 43.9966, 'longitude': -92.5409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55904', 'place_name': 'Rochester', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.0105, 'longitude': -92.3973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55905', 'place_name': 'Rochester', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.0225, 'longitude': -92.4668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55906', 'place_name': 'Rochester', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.1078, 'longitude': -92.4053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55920', 'place_name': 'Byron', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.0373, 'longitude': -92.6308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55929', 'place_name': 'Dover', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.0015, 'longitude': -92.1415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55934', 'place_name': 'Eyota', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.0099, 'longitude': -92.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55960', 'place_name': 'Oronoco', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 44.1489, 'longitude': -92.485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55976', 'place_name': 'Stewartville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Olmsted', 'locality_code': '109', 'latitude': 43.8555, 'longitude': -92.4885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56324', 'place_name': 'Dalton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.1738, 'longitude': -95.9156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56361', 'place_name': 'Parkers Prairie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.153, 'longitude': -95.3289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56515', 'place_name': 'Battle Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.3142, 'longitude': -95.7144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56518', 'place_name': 'Bluffton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.4918, 'longitude': -95.2236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56524', 'place_name': 'Clitherall', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.2757, 'longitude': -95.6308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56527', 'place_name': 'Deer Creek', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.3911, 'longitude': -95.3214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56528', 'place_name': 'Dent', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.5554, 'longitude': -95.7644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56533', 'place_name': 'Elizabeth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.3803, 'longitude': -96.1326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56534', 'place_name': 'Erhard', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.4948, 'longitude': -96.0593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56537', 'place_name': 'Fergus Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.276, 'longitude': -96.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56538', 'place_name': 'Fergus Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.283, 'longitude': -96.0776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56551', 'place_name': 'Henning', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.3256, 'longitude': -95.3852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56567', 'place_name': 'New York Mills', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.5559, 'longitude': -95.4047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56571', 'place_name': 'Ottertail', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.4177, 'longitude': -95.5436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56572', 'place_name': 'Pelican Rapids', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.5994, 'longitude': -96.0662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56573', 'place_name': 'Perham', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.6031, 'longitude': -95.5818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56576', 'place_name': 'Richville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.4434, 'longitude': -95.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56586', 'place_name': 'Underwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.3265, 'longitude': -95.8415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56587', 'place_name': 'Vergas', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.6706, 'longitude': -95.7948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56588', 'place_name': 'Vining', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Otter Tail', 'locality_code': '111', 'latitude': 46.2195, 'longitude': -95.506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56701', 'place_name': 'Thief River Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pennington', 'locality_code': '113', 'latitude': 48.1191, 'longitude': -96.1811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56725', 'place_name': 'Goodridge', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pennington', 'locality_code': '113', 'latitude': 48.0686, 'longitude': -95.7283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56754', 'place_name': 'Saint Hilaire', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pennington', 'locality_code': '113', 'latitude': 48.0109, 'longitude': -96.2249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55007', 'place_name': 'Brook Park', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 45.9474, 'longitude': -93.0736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55030', 'place_name': 'Grasston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 45.8566, 'longitude': -93.0813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55036', 'place_name': 'Henriette', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 45.8712, 'longitude': -93.1196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55037', 'place_name': 'Hinckley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.0189, 'longitude': -92.8993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55063', 'place_name': 'Pine City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 45.8363, 'longitude': -92.9042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55067', 'place_name': 'Rock Creek', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 45.7575, 'longitude': -92.9624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55072', 'place_name': 'Sandstone', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.1325, 'longitude': -92.589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55704', 'place_name': 'Askov', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.1964, 'longitude': -92.7528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55712', 'place_name': 'Bruno', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.2845, 'longitude': -92.619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55735', 'place_name': 'Finlayson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.2121, 'longitude': -92.9389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55756', 'place_name': 'Kerrick', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.3792, 'longitude': -92.578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55783', 'place_name': 'Sturgeon Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.3837, 'longitude': -92.8182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55795', 'place_name': 'Willow River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pine', 'locality_code': '115', 'latitude': 46.2949, 'longitude': -92.8309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56128', 'place_name': 'Edgerton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pipestone', 'locality_code': '117', 'latitude': 43.8824, 'longitude': -96.1463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56139', 'place_name': 'Holland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pipestone', 'locality_code': '117', 'latitude': 44.0759, 'longitude': -96.1903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56140', 'place_name': 'Ihlen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pipestone', 'locality_code': '117', 'latitude': 43.9072, 'longitude': -96.3673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56144', 'place_name': 'Jasper', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pipestone', 'locality_code': '117', 'latitude': 43.8568, 'longitude': -96.385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56164', 'place_name': 'Pipestone', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pipestone', 'locality_code': '117', 'latitude': 43.9893, 'longitude': -96.2652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56170', 'place_name': 'Ruthton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pipestone', 'locality_code': '117', 'latitude': 44.1682, 'longitude': -96.0871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56186', 'place_name': 'Woodstock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pipestone', 'locality_code': '117', 'latitude': 43.9873, 'longitude': -96.1192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56517', 'place_name': 'Beltrami', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.5721, 'longitude': -96.4549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56523', 'place_name': 'Climax', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.6837, 'longitude': -96.8715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56535', 'place_name': 'Erskine', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.6618, 'longitude': -96.0122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56540', 'place_name': 'Fertile', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.5361, 'longitude': -96.2803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56542', 'place_name': 'Fosston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.5816, 'longitude': -95.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56556', 'place_name': 'Mcintosh', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.6522, 'longitude': -95.8863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56568', 'place_name': 'Nielsville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.5373, 'longitude': -96.7574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56592', 'place_name': 'Winger', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.5375, 'longitude': -95.9941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56646', 'place_name': 'Gully', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.7697, 'longitude': -95.641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56651', 'place_name': 'Lengby', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.5158, 'longitude': -95.6359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56684', 'place_name': 'Trail', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.7478, 'longitude': -95.7607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56716', 'place_name': 'Crookston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.7797, 'longitude': -96.5931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56721', 'place_name': 'East Grand Forks', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.9318, 'longitude': -97.0213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56722', 'place_name': 'Euclid', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.9845, 'longitude': -96.6428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56723', 'place_name': 'Fisher', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.8003, 'longitude': -96.8015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56736', 'place_name': 'Mentor', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Polk', 'locality_code': '119', 'latitude': 47.6576, 'longitude': -96.1778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56323', 'place_name': 'Cyrus', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pope', 'locality_code': '121', 'latitude': 45.6414, 'longitude': -95.7096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56327', 'place_name': 'Farwell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pope', 'locality_code': '121', 'latitude': 45.7244, 'longitude': -95.6656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56334', 'place_name': 'Glenwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pope', 'locality_code': '121', 'latitude': 45.6429, 'longitude': -95.3868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56349', 'place_name': 'Lowry', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pope', 'locality_code': '121', 'latitude': 45.7105, 'longitude': -95.5322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56381', 'place_name': 'Starbuck', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pope', 'locality_code': '121', 'latitude': 45.5926, 'longitude': -95.5421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56385', 'place_name': 'Villard', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Pope', 'locality_code': '121', 'latitude': 45.7118, 'longitude': -95.2414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55101', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9512, 'longitude': -93.0902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55102', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9372, 'longitude': -93.1209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55103', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9608, 'longitude': -93.1216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55104', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9532, 'longitude': -93.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55105', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9347, 'longitude': -93.1651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55106', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9684, 'longitude': -93.0488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55107', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9325, 'longitude': -93.088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55108', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9806, 'longitude': -93.1771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55109', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0132, 'longitude': -93.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55110', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.08, 'longitude': -93.0223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55112', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0788, 'longitude': -93.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55113', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0139, 'longitude': -93.1571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55114', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.968, 'longitude': -93.1981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55116', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.914, 'longitude': -93.1727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55117', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9995, 'longitude': -93.0969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55119', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9414, 'longitude': -93.0107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55126', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0736, 'longitude': -93.138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55127', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0803, 'longitude': -93.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55130', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.973, 'longitude': -93.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55131', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.973, 'longitude': -93.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55133', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0059, 'longitude': -93.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55144', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0059, 'longitude': -93.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55145', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9444, 'longitude': -93.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55146', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9427, 'longitude': -93.0828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55155', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9522, 'longitude': -93.0955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55164', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9909, 'longitude': -93.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55165', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0059, 'longitude': -93.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55170', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 44.9444, 'longitude': -93.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55172', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0059, 'longitude': -93.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55175', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0059, 'longitude': -93.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55187', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0059, 'longitude': -93.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55188', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Ramsey', 'locality_code': '123', 'latitude': 45.0059, 'longitude': -93.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56715', 'place_name': 'Brooks', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Red Lake', 'locality_code': '125', 'latitude': 47.8129, 'longitude': -96.0117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56742', 'place_name': 'Oklee', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Red Lake', 'locality_code': '125', 'latitude': 47.8286, 'longitude': -95.8617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56748', 'place_name': 'Plummer', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Red Lake', 'locality_code': '125', 'latitude': 47.9113, 'longitude': -95.9646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56750', 'place_name': 'Red Lake Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Red Lake', 'locality_code': '125', 'latitude': 47.8823, 'longitude': -96.2681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56083', 'place_name': 'Sanborn', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.2183, 'longitude': -95.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56152', 'place_name': 'Lamberton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.2378, 'longitude': -95.2739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56166', 'place_name': 'Revere', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.2391, 'longitude': -95.3557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56180', 'place_name': 'Walnut Grove', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.2294, 'longitude': -95.4965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56214', 'place_name': 'Belview', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.6055, 'longitude': -95.3178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56224', 'place_name': 'Clements', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.3943, 'longitude': -95.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56255', 'place_name': 'Lucan', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.4132, 'longitude': -95.4119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56263', 'place_name': 'Milroy', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.4365, 'longitude': -95.5545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56266', 'place_name': 'Morgan', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.3926, 'longitude': -94.9218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56283', 'place_name': 'Redwood Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.5394, 'longitude': -95.1169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56287', 'place_name': 'Seaforth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.4772, 'longitude': -95.3264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56292', 'place_name': 'Vesta', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.5051, 'longitude': -95.4118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56293', 'place_name': 'Wabasso', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.4059, 'longitude': -95.2632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56294', 'place_name': 'Wanda', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Redwood', 'locality_code': '127', 'latitude': 44.3149, 'longitude': -95.213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55310', 'place_name': 'Bird Island', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.7507, 'longitude': -94.8716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55314', 'place_name': 'Buffalo Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.7709, 'longitude': -94.5912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55332', 'place_name': 'Fairfax', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.5329, 'longitude': -94.7256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55333', 'place_name': 'Franklin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.5421, 'longitude': -94.8931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55342', 'place_name': 'Hector', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.7485, 'longitude': -94.7058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56230', 'place_name': 'Danube', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.7919, 'longitude': -95.0972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56270', 'place_name': 'Morton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.5662, 'longitude': -95.0268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56277', 'place_name': 'Olivia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.7706, 'longitude': -94.9727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56284', 'place_name': 'Renville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.7776, 'longitude': -95.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56285', 'place_name': 'Sacred Heart', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Renville', 'locality_code': '129', 'latitude': 44.7975, 'longitude': -95.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55019', 'place_name': 'Dundas', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.3955, 'longitude': -93.2037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55021', 'place_name': 'Faribault', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.2945, 'longitude': -93.2818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55046', 'place_name': 'Lonsdale', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.4477, 'longitude': -93.4252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55052', 'place_name': 'Morristown', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.2342, 'longitude': -93.4525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55053', 'place_name': 'Nerstrand', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.3538, 'longitude': -93.0855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55057', 'place_name': 'Northfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.4587, 'longitude': -93.1668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55087', 'place_name': 'Warsaw', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.2485, 'longitude': -93.3949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55088', 'place_name': 'Webster', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rice', 'locality_code': '131', 'latitude': 44.5003, 'longitude': -93.3826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56116', 'place_name': 'Beaver Creek', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.6223, 'longitude': -96.3698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56134', 'place_name': 'Hardwick', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.7911, 'longitude': -96.2161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56138', 'place_name': 'Hills', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.5335, 'longitude': -96.3645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56146', 'place_name': 'Kanaranzi', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.5758, 'longitude': -96.0945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56147', 'place_name': 'Kenneth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.7637, 'longitude': -96.1089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56156', 'place_name': 'Luverne', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.6614, 'longitude': -96.2216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56158', 'place_name': 'Magnolia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.644, 'longitude': -96.0769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56173', 'place_name': 'Steen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Rock', 'locality_code': '133', 'latitude': 43.5317, 'longitude': -96.2439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56673', 'place_name': 'Roosevelt', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.8279, 'longitude': -95.1119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56682', 'place_name': 'Swift', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.8533, 'longitude': -95.2213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56714', 'place_name': 'Badger', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.7913, 'longitude': -96.0965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56726', 'place_name': 'Greenbush', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.6957, 'longitude': -96.1871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56751', 'place_name': 'Roseau', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.7048, 'longitude': -95.7504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56756', 'place_name': 'Salol', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.8522, 'longitude': -95.5356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56759', 'place_name': 'Strathcona', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.5459, 'longitude': -96.0879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56761', 'place_name': 'Wannaska', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.6452, 'longitude': -95.7072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56763', 'place_name': 'Warroad', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Roseau', 'locality_code': '135', 'latitude': 48.9111, 'longitude': -95.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55602', 'place_name': 'Brimson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.3142, 'longitude': -91.8625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55702', 'place_name': 'Alborn', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.9782, 'longitude': -92.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55703', 'place_name': 'Angora', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.7577, 'longitude': -92.6413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55705', 'place_name': 'Aurora', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.4951, 'longitude': -92.2415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55706', 'place_name': 'Babbitt', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.7091, 'longitude': -91.957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55708', 'place_name': 'Biwabik', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.5328, 'longitude': -92.3408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55710', 'place_name': 'Britt', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.655, 'longitude': -92.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55711', 'place_name': 'Brookston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.8384, 'longitude': -92.643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55713', 'place_name': 'Buhl', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.4932, 'longitude': -92.7643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55717', 'place_name': 'Canyon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.0785, 'longitude': -92.4594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55719', 'place_name': 'Chisholm', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.5007, 'longitude': -92.8617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55723', 'place_name': 'Cook', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.8442, 'longitude': -92.721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55724', 'place_name': 'Cotton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.1521, 'longitude': -92.4352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55725', 'place_name': 'Crane Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 48.2594, 'longitude': -92.4896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55731', 'place_name': 'Ely', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.9034, 'longitude': -91.857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55732', 'place_name': 'Embarrass', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.6658, 'longitude': -92.2101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55734', 'place_name': 'Eveleth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.451, 'longitude': -92.528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55736', 'place_name': 'Floodwood', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.9076, 'longitude': -92.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55738', 'place_name': 'Forbes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.2732, 'longitude': -92.6756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55741', 'place_name': 'Gilbert', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.4885, 'longitude': -92.4025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55746', 'place_name': 'Hibbing', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.4156, 'longitude': -92.9356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55747', 'place_name': 'Hibbing', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.4272, 'longitude': -92.9377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55750', 'place_name': 'Hoyt Lakes', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.515, 'longitude': -92.14, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55751', 'place_name': 'Iron', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.4115, 'longitude': -92.6195, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '55758', 'place_name': 'Kinney', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.5121, 'longitude': -92.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55763', 'place_name': 'Makinen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.3416, 'longitude': -92.3446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55765', 'place_name': 'Meadowlands', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.1021, 'longitude': -92.7884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55766', 'place_name': 'Melrude', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.2496, 'longitude': -92.4123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55768', 'place_name': 'Mountain Iron', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.5133, 'longitude': -92.6243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55771', 'place_name': 'Orr', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 48.1439, 'longitude': -92.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55772', 'place_name': 'Nett Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 48.111, 'longitude': -93.0941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55777', 'place_name': 'Virginia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.5233, 'longitude': -92.5366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55779', 'place_name': 'Saginaw', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.8795, 'longitude': -92.3917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55781', 'place_name': 'Side Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.6671, 'longitude': -93.0424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55782', 'place_name': 'Soudan', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.821, 'longitude': -92.2464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55790', 'place_name': 'Tower', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.8089, 'longitude': -92.2878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55791', 'place_name': 'Twig', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.8944, 'longitude': -92.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55792', 'place_name': 'Virginia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.5371, 'longitude': -92.5285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55796', 'place_name': 'Winton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 47.9263, 'longitude': -91.8007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55801', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7833, 'longitude': -92.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55802', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7685, 'longitude': -92.0865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55803', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.8749, 'longitude': -92.0941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55804', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.8551, 'longitude': -92.0074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55805', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7987, 'longitude': -92.0946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55806', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7715, 'longitude': -92.1279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55807', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7408, 'longitude': -92.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55808', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.681, 'longitude': -92.2226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55810', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7606, 'longitude': -92.266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55811', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.8147, 'longitude': -92.1998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55812', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.8106, 'longitude': -92.0767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55814', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7833, 'longitude': -92.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55815', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7833, 'longitude': -92.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55816', 'place_name': 'Duluth', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'St. Louis', 'locality_code': '137', 'latitude': 46.7833, 'longitude': -92.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55020', 'place_name': 'Elko New Market', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Scott', 'locality_code': '139', 'latitude': 44.5647, 'longitude': -93.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55054', 'place_name': 'Elko New Market', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Scott', 'locality_code': '139', 'latitude': 44.5647, 'longitude': -93.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55352', 'place_name': 'Jordan', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Scott', 'locality_code': '139', 'latitude': 44.6713, 'longitude': -93.6195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55372', 'place_name': 'Prior Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Scott', 'locality_code': '139', 'latitude': 44.7107, 'longitude': -93.4101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55378', 'place_name': 'Savage', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Scott', 'locality_code': '139', 'latitude': 44.7615, 'longitude': -93.3434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55379', 'place_name': 'Shakopee', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Scott', 'locality_code': '139', 'latitude': 44.7793, 'longitude': -93.5197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56011', 'place_name': 'Belle Plaine', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Scott', 'locality_code': '139', 'latitude': 44.6139, 'longitude': -93.7604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55308', 'place_name': 'Becker', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sherburne', 'locality_code': '141', 'latitude': 45.4365, 'longitude': -93.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55309', 'place_name': 'Big Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sherburne', 'locality_code': '141', 'latitude': 45.3506, 'longitude': -93.7399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55319', 'place_name': 'Clear Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sherburne', 'locality_code': '141', 'latitude': 45.4795, 'longitude': -93.9684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55330', 'place_name': 'Elk River', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sherburne', 'locality_code': '141', 'latitude': 45.3136, 'longitude': -93.5814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55377', 'place_name': 'Santiago', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sherburne', 'locality_code': '141', 'latitude': 45.5402, 'longitude': -93.8154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55398', 'place_name': 'Zimmerman', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sherburne', 'locality_code': '141', 'latitude': 45.4553, 'longitude': -93.5879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55307', 'place_name': 'Arlington', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sibley', 'locality_code': '143', 'latitude': 44.6153, 'longitude': -94.0762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55334', 'place_name': 'Gaylord', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sibley', 'locality_code': '143', 'latitude': 44.5463, 'longitude': -94.1955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55335', 'place_name': 'Gibbon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sibley', 'locality_code': '143', 'latitude': 44.5606, 'longitude': -94.5467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55338', 'place_name': 'Green Isle', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sibley', 'locality_code': '143', 'latitude': 44.6791, 'longitude': -94.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55366', 'place_name': 'New Auburn', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sibley', 'locality_code': '143', 'latitude': 44.6735, 'longitude': -94.2293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55396', 'place_name': 'Winthrop', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sibley', 'locality_code': '143', 'latitude': 44.5436, 'longitude': -94.3698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56044', 'place_name': 'Henderson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Sibley', 'locality_code': '143', 'latitude': 44.5344, 'longitude': -93.9345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55353', 'place_name': 'Kimball', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.3436, 'longitude': -94.3028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56301', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.541, 'longitude': -94.1819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56302', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56303', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5713, 'longitude': -94.2036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56304', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5521, 'longitude': -94.1284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56307', 'place_name': 'Albany', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.6151, 'longitude': -94.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56310', 'place_name': 'Avon', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.6122, 'longitude': -94.436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56312', 'place_name': 'Belgrade', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.4865, 'longitude': -94.9699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56316', 'place_name': 'Brooten', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5011, 'longitude': -95.1245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56320', 'place_name': 'Cold Spring', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.45, 'longitude': -94.4378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56321', 'place_name': 'Collegeville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5783, 'longitude': -94.4199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56325', 'place_name': 'Elrosa', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5636, 'longitude': -94.9464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56331', 'place_name': 'Freeport', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.6731, 'longitude': -94.6785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56335', 'place_name': 'Greenwald', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5971, 'longitude': -94.8515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56340', 'place_name': 'Holdingford', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.7249, 'longitude': -94.4581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56352', 'place_name': 'Melrose', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.6582, 'longitude': -94.8198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56356', 'place_name': 'New Munich', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.6297, 'longitude': -94.7519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56362', 'place_name': 'Paynesville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.3988, 'longitude': -94.7157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56368', 'place_name': 'Richmond', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.4605, 'longitude': -94.5361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56369', 'place_name': 'Rockville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.4719, 'longitude': -94.3408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56371', 'place_name': 'Roscoe', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.4332, 'longitude': -94.6366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56372', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56374', 'place_name': 'Saint Joseph', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5651, 'longitude': -94.3367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56375', 'place_name': 'Saint Stephen', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.7118, 'longitude': -94.2817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56376', 'place_name': 'Saint Martin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5019, 'longitude': -94.6689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56377', 'place_name': 'Sartell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.6318, 'longitude': -94.2136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56378', 'place_name': 'Sauk Centre', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.7281, 'longitude': -94.9682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56387', 'place_name': 'Waite Park', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5497, 'longitude': -94.2245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56393', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56395', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56396', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56397', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56398', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56399', 'place_name': 'Saint Cloud', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stearns', 'locality_code': '145', 'latitude': 45.5608, 'longitude': -94.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55049', 'place_name': 'Medford', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Steele', 'locality_code': '147', 'latitude': 44.1741, 'longitude': -93.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55060', 'place_name': 'Owatonna', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Steele', 'locality_code': '147', 'latitude': 44.0805, 'longitude': -93.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55917', 'place_name': 'Blooming Prairie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Steele', 'locality_code': '147', 'latitude': 43.8977, 'longitude': -93.0608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56026', 'place_name': 'Ellendale', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Steele', 'locality_code': '147', 'latitude': 43.8826, 'longitude': -93.3195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56046', 'place_name': 'Hope', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Steele', 'locality_code': '147', 'latitude': 43.9619, 'longitude': -93.276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56207', 'place_name': 'Alberta', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stevens', 'locality_code': '149', 'latitude': 45.5571, 'longitude': -96.0498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56221', 'place_name': 'Chokio', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stevens', 'locality_code': '149', 'latitude': 45.5524, 'longitude': -96.1733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56235', 'place_name': 'Donnelly', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stevens', 'locality_code': '149', 'latitude': 45.7014, 'longitude': -96.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56244', 'place_name': 'Hancock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stevens', 'locality_code': '149', 'latitude': 45.4985, 'longitude': -95.8008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56267', 'place_name': 'Morris', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Stevens', 'locality_code': '149', 'latitude': 45.5921, 'longitude': -95.9172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56208', 'place_name': 'Appleton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Swift', 'locality_code': '151', 'latitude': 45.2054, 'longitude': -95.9949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56215', 'place_name': 'Benson', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Swift', 'locality_code': '151', 'latitude': 45.3129, 'longitude': -95.5766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56226', 'place_name': 'Clontarf', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Swift', 'locality_code': '151', 'latitude': 45.3763, 'longitude': -95.6787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56231', 'place_name': 'Danvers', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Swift', 'locality_code': '151', 'latitude': 45.2818, 'longitude': -95.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56249', 'place_name': 'Holloway', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Swift', 'locality_code': '151', 'latitude': 45.2708, 'longitude': -95.9164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56252', 'place_name': 'Kerkhoven', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Swift', 'locality_code': '151', 'latitude': 45.2096, 'longitude': -95.3115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56271', 'place_name': 'Murdock', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Swift', 'locality_code': '151', 'latitude': 45.2161, 'longitude': -95.4049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56318', 'place_name': 'Burtrum', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 45.888, 'longitude': -94.6962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56336', 'place_name': 'Grey Eagle', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 45.8252, 'longitude': -94.7467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56347', 'place_name': 'Long Prairie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 45.9747, 'longitude': -94.8656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56389', 'place_name': 'West Union', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 45.7995, 'longitude': -95.0821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56437', 'place_name': 'Bertha', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 46.2515, 'longitude': -95.0357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56438', 'place_name': 'Browerville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 46.0905, 'longitude': -94.8346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56440', 'place_name': 'Clarissa', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 46.1373, 'longitude': -94.9572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56446', 'place_name': 'Eagle Bend', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 46.117, 'longitude': -95.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56453', 'place_name': 'Hewitt', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 46.325, 'longitude': -95.0504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56479', 'place_name': 'Staples', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Todd', 'locality_code': '153', 'latitude': 46.3536, 'longitude': -94.7633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56219', 'place_name': 'Browns Valley', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Traverse', 'locality_code': '155', 'latitude': 45.6069, 'longitude': -96.8063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56236', 'place_name': 'Dumont', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Traverse', 'locality_code': '155', 'latitude': 45.6717, 'longitude': -96.4061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56296', 'place_name': 'Wheaton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Traverse', 'locality_code': '155', 'latitude': 45.8111, 'longitude': -96.4866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56583', 'place_name': 'Tintah', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Traverse', 'locality_code': '155', 'latitude': 46.0074, 'longitude': -96.3593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55041', 'place_name': 'Lake City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.4305, 'longitude': -92.2838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55932', 'place_name': 'Elgin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.1358, 'longitude': -92.2535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55945', 'place_name': 'Kellogg', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.2739, 'longitude': -92.1095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55956', 'place_name': 'Mazeppa', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.2646, 'longitude': -92.5207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55957', 'place_name': 'Millville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.2359, 'longitude': -92.2672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55964', 'place_name': 'Plainview', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.1637, 'longitude': -92.1621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55968', 'place_name': 'Reads Landing', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.3977, 'longitude': -92.0893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55981', 'place_name': 'Wabasha', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.3703, 'longitude': -92.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55991', 'place_name': 'Zumbro Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wabasha', 'locality_code': '157', 'latitude': 44.2427, 'longitude': -92.4256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56434', 'place_name': 'Aldrich', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wadena', 'locality_code': '159', 'latitude': 46.3797, 'longitude': -94.9364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56464', 'place_name': 'Menahga', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wadena', 'locality_code': '159', 'latitude': 46.7572, 'longitude': -95.0714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56477', 'place_name': 'Sebeka', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wadena', 'locality_code': '159', 'latitude': 46.6306, 'longitude': -95.0681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56481', 'place_name': 'Verndale', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wadena', 'locality_code': '159', 'latitude': 46.5065, 'longitude': -94.9676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56482', 'place_name': 'Wadena', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wadena', 'locality_code': '159', 'latitude': 46.4401, 'longitude': -95.1283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56048', 'place_name': 'Janesville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Waseca', 'locality_code': '161', 'latitude': 44.1168, 'longitude': -93.7095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56072', 'place_name': 'New Richland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Waseca', 'locality_code': '161', 'latitude': 43.8937, 'longitude': -93.4995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56091', 'place_name': 'Waldorf', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Waseca', 'locality_code': '161', 'latitude': 43.9399, 'longitude': -93.7043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56093', 'place_name': 'Waseca', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Waseca', 'locality_code': '161', 'latitude': 44.0834, 'longitude': -93.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55001', 'place_name': 'Afton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.8697, 'longitude': -92.8234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55003', 'place_name': 'Bayport', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.0214, 'longitude': -92.7844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55016', 'place_name': 'Cottage Grove', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.8308, 'longitude': -92.9393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55025', 'place_name': 'Forest Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.2685, 'longitude': -92.9749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55038', 'place_name': 'Hugo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.1824, 'longitude': -92.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55042', 'place_name': 'Lake Elmo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.9946, 'longitude': -92.9056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55043', 'place_name': 'Lakeland', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.9394, 'longitude': -92.7716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55047', 'place_name': 'Marine On Saint Croix', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.1988, 'longitude': -92.8258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55055', 'place_name': 'Newport', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.8725, 'longitude': -92.9986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55071', 'place_name': 'Saint Paul Park', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.8344, 'longitude': -92.9873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55073', 'place_name': 'Scandia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.2697, 'longitude': -92.8292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55082', 'place_name': 'Stillwater', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.0614, 'longitude': -92.8474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55083', 'place_name': 'Stillwater', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.021, 'longitude': -92.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55090', 'place_name': 'Willernie', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.0535, 'longitude': -92.957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55115', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 45.071, 'longitude': -92.9391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55125', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.9197, 'longitude': -92.9439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55128', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.9913, 'longitude': -92.9487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55129', 'place_name': 'Saint Paul', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Washington', 'locality_code': '163', 'latitude': 44.8985, 'longitude': -92.923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56022', 'place_name': 'Darfur', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Watonwan', 'locality_code': '165', 'latitude': 44.0513, 'longitude': -94.838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56056', 'place_name': 'La Salle', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Watonwan', 'locality_code': '165', 'latitude': 44.0727, 'longitude': -94.5795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56060', 'place_name': 'Lewisville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Watonwan', 'locality_code': '165', 'latitude': 43.9209, 'longitude': -94.4289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56062', 'place_name': 'Madelia', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Watonwan', 'locality_code': '165', 'latitude': 44.0499, 'longitude': -94.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56081', 'place_name': 'Saint James', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Watonwan', 'locality_code': '165', 'latitude': 43.9875, 'longitude': -94.6229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56120', 'place_name': 'Butterfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Watonwan', 'locality_code': '165', 'latitude': 43.9654, 'longitude': -94.7956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56160', 'place_name': 'Odin', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Watonwan', 'locality_code': '165', 'latitude': 43.8824, 'longitude': -94.774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56520', 'place_name': 'Breckenridge', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wilkin', 'locality_code': '167', 'latitude': 46.2797, 'longitude': -96.5622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56522', 'place_name': 'Campbell', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wilkin', 'locality_code': '167', 'latitude': 46.1402, 'longitude': -96.4433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56543', 'place_name': 'Foxhome', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wilkin', 'locality_code': '167', 'latitude': 46.2584, 'longitude': -96.3176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56553', 'place_name': 'Kent', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wilkin', 'locality_code': '167', 'latitude': 46.4378, 'longitude': -96.6852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56565', 'place_name': 'Nashua', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wilkin', 'locality_code': '167', 'latitude': 46.0537, 'longitude': -96.316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56579', 'place_name': 'Rothsay', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wilkin', 'locality_code': '167', 'latitude': 46.5094, 'longitude': -96.2887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56594', 'place_name': 'Wolverton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wilkin', 'locality_code': '167', 'latitude': 46.555, 'longitude': -96.6149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55910', 'place_name': 'Altura', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 44.1361, 'longitude': -91.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55925', 'place_name': 'Dakota', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 43.9148, 'longitude': -91.394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55942', 'place_name': 'Homer', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 44.02, 'longitude': -91.6819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55952', 'place_name': 'Lewiston', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 43.9702, 'longitude': -91.8662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55959', 'place_name': 'Minnesota City', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 44.0832, 'longitude': -91.7418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55969', 'place_name': 'Rollingstone', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 44.1025, 'longitude': -91.8158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55972', 'place_name': 'Saint Charles', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 43.9585, 'longitude': -92.0517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55979', 'place_name': 'Utica', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 43.9587, 'longitude': -91.9417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55987', 'place_name': 'Winona', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 44.03, 'longitude': -91.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55988', 'place_name': 'Stockton', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Winona', 'locality_code': '169', 'latitude': 44.0252, 'longitude': -91.7708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55301', 'place_name': 'Albertville', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.2534, 'longitude': -93.6469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55302', 'place_name': 'Annandale', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.2483, 'longitude': -94.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55313', 'place_name': 'Buffalo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.1814, 'longitude': -93.8635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55320', 'place_name': 'Clearwater', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.3877, 'longitude': -94.0452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55321', 'place_name': 'Cokato', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.0748, 'longitude': -94.1911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55328', 'place_name': 'Delano', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.0342, 'longitude': -93.8016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55341', 'place_name': 'Hanover', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.1602, 'longitude': -93.6734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55349', 'place_name': 'Howard Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.0616, 'longitude': -94.0695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55358', 'place_name': 'Maple Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.2202, 'longitude': -93.9638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55362', 'place_name': 'Monticello', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.2956, 'longitude': -93.8023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55363', 'place_name': 'Montrose', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.0442, 'longitude': -93.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55373', 'place_name': 'Rockford', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.0882, 'longitude': -93.7237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55376', 'place_name': 'Saint Michael', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.2064, 'longitude': -93.6593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55380', 'place_name': 'Silver Creek', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.3158, 'longitude': -93.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55382', 'place_name': 'South Haven', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.2925, 'longitude': -94.2119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55390', 'place_name': 'Waverly', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.0666, 'longitude': -93.9664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '55592', 'place_name': 'Maple Plain', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Wright', 'locality_code': '171', 'latitude': 45.2009, 'longitude': -93.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56220', 'place_name': 'Canby', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Yellow Medicine', 'locality_code': '173', 'latitude': 44.7202, 'longitude': -96.2784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56223', 'place_name': 'Clarkfield', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Yellow Medicine', 'locality_code': '173', 'latitude': 44.7743, 'longitude': -95.8304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56237', 'place_name': 'Echo', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Yellow Medicine', 'locality_code': '173', 'latitude': 44.631, 'longitude': -95.4182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56241', 'place_name': 'Granite Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Yellow Medicine', 'locality_code': '173', 'latitude': 44.8087, 'longitude': -95.5516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56245', 'place_name': 'Hanley Falls', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Yellow Medicine', 'locality_code': '173', 'latitude': 44.6789, 'longitude': -95.6825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56280', 'place_name': 'Porter', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Yellow Medicine', 'locality_code': '173', 'latitude': 44.6565, 'longitude': -96.1581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '56297', 'place_name': 'Wood Lake', 'state': 'Minnesota', 'state_ab': 'MN', 'county': 'Yellow Medicine', 'locality_code': '173', 'latitude': 44.6379, 'longitude': -95.5409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63501', 'place_name': 'Kirksville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Adair', 'locality_code': '1', 'latitude': 40.1908, 'longitude': -92.5856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63533', 'place_name': 'Brashear', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Adair', 'locality_code': '1', 'latitude': 40.1959, 'longitude': -92.4333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63540', 'place_name': 'Gibbs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Adair', 'locality_code': '1', 'latitude': 40.104, 'longitude': -92.4066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63546', 'place_name': 'Greentop', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Adair', 'locality_code': '1', 'latitude': 40.3446, 'longitude': -92.5567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63559', 'place_name': 'Novinger', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Adair', 'locality_code': '1', 'latitude': 40.2685, 'longitude': -92.7172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64421', 'place_name': 'Amazonia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 39.9092, 'longitude': -94.9113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64427', 'place_name': 'Bolckow', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 40.1007, 'longitude': -94.8847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64436', 'place_name': 'Cosby', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 39.8555, 'longitude': -94.6977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64449', 'place_name': 'Fillmore', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 40.0142, 'longitude': -94.9555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64459', 'place_name': 'Helena', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 39.9295, 'longitude': -94.6465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64480', 'place_name': 'Rea', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 40.0593, 'longitude': -94.7002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64483', 'place_name': 'Rosendale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 40.0399, 'longitude': -94.8328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64485', 'place_name': 'Savannah', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 39.9168, 'longitude': -94.8267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64506', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Andrew', 'locality_code': '3', 'latitude': 39.7893, 'longitude': -94.8043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64446', 'place_name': 'Fairfax', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Atchison', 'locality_code': '5', 'latitude': 40.3302, 'longitude': -95.3751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64482', 'place_name': 'Rock Port', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Atchison', 'locality_code': '5', 'latitude': 40.4306, 'longitude': -95.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64491', 'place_name': 'Tarkio', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Atchison', 'locality_code': '5', 'latitude': 40.4418, 'longitude': -95.3786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64496', 'place_name': 'Watson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Atchison', 'locality_code': '5', 'latitude': 40.478, 'longitude': -95.6193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64498', 'place_name': 'Westboro', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Atchison', 'locality_code': '5', 'latitude': 40.5357, 'longitude': -95.3134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63345', 'place_name': 'Farber', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.2742, 'longitude': -91.5798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63352', 'place_name': 'Laddonia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.2425, 'longitude': -91.6454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63382', 'place_name': 'Vandalia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.2949, 'longitude': -91.4883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65232', 'place_name': 'Benton City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.1209, 'longitude': -91.7661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65264', 'place_name': 'Martinsburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.0968, 'longitude': -91.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65265', 'place_name': 'Mexico', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.1712, 'longitude': -91.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65280', 'place_name': 'Rush Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.21, 'longitude': -91.7216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65285', 'place_name': 'Thompson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Audrain', 'locality_code': '7', 'latitude': 39.2128, 'longitude': -92.0046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64874', 'place_name': 'Wheaton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.7651, 'longitude': -94.0492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65623', 'place_name': 'Butterfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.749, 'longitude': -93.9064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65625', 'place_name': 'Cassville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.6784, 'longitude': -93.8467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65641', 'place_name': 'Eagle Rock', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.548, 'longitude': -93.7336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65647', 'place_name': 'Exeter', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.6815, 'longitude': -93.9702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65658', 'place_name': 'Golden', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.5625, 'longitude': -93.623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65708', 'place_name': 'Monett', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.9212, 'longitude': -93.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65734', 'place_name': 'Purdy', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.8069, 'longitude': -93.9164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65745', 'place_name': 'Seligman', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.5276, 'longitude': -93.9359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65747', 'place_name': 'Shell Knob', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.6167, 'longitude': -93.6249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65772', 'place_name': 'Washburn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barry', 'locality_code': '9', 'latitude': 36.5807, 'longitude': -93.992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64748', 'place_name': 'Golden City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barton', 'locality_code': '11', 'latitude': 37.3995, 'longitude': -94.1027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64759', 'place_name': 'Lamar', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barton', 'locality_code': '11', 'latitude': 37.5191, 'longitude': -94.3364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64762', 'place_name': 'Liberal', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barton', 'locality_code': '11', 'latitude': 37.5725, 'longitude': -94.5204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64766', 'place_name': 'Milford', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barton', 'locality_code': '11', 'latitude': 37.5848, 'longitude': -94.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64769', 'place_name': 'Mindenmines', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Barton', 'locality_code': '11', 'latitude': 37.452, 'longitude': -94.5756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64720', 'place_name': 'Adrian', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.4125, 'longitude': -94.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64722', 'place_name': 'Amoret', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.2605, 'longitude': -94.5734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64723', 'place_name': 'Amsterdam', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.3954, 'longitude': -94.5763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64730', 'place_name': 'Butler', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.2712, 'longitude': -94.3137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64742', 'place_name': 'Drexel', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.4956, 'longitude': -94.5928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64745', 'place_name': 'Foster', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.1661, 'longitude': -94.5075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64752', 'place_name': 'Hume', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.09, 'longitude': -94.5838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64779', 'place_name': 'Rich Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.0944, 'longitude': -94.3635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64780', 'place_name': 'Rockville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bates', 'locality_code': '13', 'latitude': 38.0766, 'longitude': -94.1299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65325', 'place_name': 'Cole Camp', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Benton', 'locality_code': '15', 'latitude': 38.4531, 'longitude': -93.1915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65326', 'place_name': 'Edwards', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Benton', 'locality_code': '15', 'latitude': 38.1906, 'longitude': -93.1471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65335', 'place_name': 'Ionia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Benton', 'locality_code': '15', 'latitude': 38.5019, 'longitude': -93.3224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65338', 'place_name': 'Lincoln', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Benton', 'locality_code': '15', 'latitude': 38.4073, 'longitude': -93.3668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65355', 'place_name': 'Warsaw', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Benton', 'locality_code': '15', 'latitude': 38.2431, 'longitude': -93.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63662', 'place_name': 'Patton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.4733, 'longitude': -90.05, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63750', 'place_name': 'Gipsy', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.147, 'longitude': -90.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63751', 'place_name': 'Glenallen', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.3231, 'longitude': -90.0515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63760', 'place_name': 'Leopold', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.2609, 'longitude': -89.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63764', 'place_name': 'Marble Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.3061, 'longitude': -89.9823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63781', 'place_name': 'Sedgewickville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.537, 'longitude': -89.9272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63782', 'place_name': 'Sturdivant', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.071, 'longitude': -90.0092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63787', 'place_name': 'Zalma', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Bollinger', 'locality_code': '17', 'latitude': 37.1365, 'longitude': -90.0757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65010', 'place_name': 'Ashland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.7878, 'longitude': -92.2537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65039', 'place_name': 'Hartsburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.7159, 'longitude': -92.2864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65201', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9382, 'longitude': -92.3049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65202', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.995, 'longitude': -92.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65203', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9348, 'longitude': -92.3639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65205', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 39.0447, 'longitude': -92.3496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65211', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9517, 'longitude': -92.3341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65212', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9376, 'longitude': -92.3304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65215', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9532, 'longitude': -92.3208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65216', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9517, 'longitude': -92.3341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65217', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9517, 'longitude': -92.3341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65218', 'place_name': 'Columbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9517, 'longitude': -92.3341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65240', 'place_name': 'Centralia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 39.1961, 'longitude': -92.1472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65255', 'place_name': 'Hallsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 39.1054, 'longitude': -92.2239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65256', 'place_name': 'Harrisburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 39.1203, 'longitude': -92.441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65279', 'place_name': 'Rocheport', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9756, 'longitude': -92.5079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65284', 'place_name': 'Sturgeon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 39.2057, 'longitude': -92.2953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65299', 'place_name': 'Mid Missouri', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Boone', 'locality_code': '19', 'latitude': 38.9033, 'longitude': -92.1022, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64401', 'place_name': 'Agency', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.6662, 'longitude': -94.717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64440', 'place_name': 'De Kalb', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.5834, 'longitude': -94.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64443', 'place_name': 'Easton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.7517, 'longitude': -94.6582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64448', 'place_name': 'Faucett', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.5891, 'longitude': -94.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64484', 'place_name': 'Rushville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.5653, 'longitude': -95.0413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64501', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.7688, 'longitude': -94.8385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64502', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.7686, 'longitude': -94.8466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64503', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.734, 'longitude': -94.8171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64504', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.7076, 'longitude': -94.8677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64505', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.7965, 'longitude': -94.8443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64507', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.7551, 'longitude': -94.8173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64508', 'place_name': 'Saint Joseph', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Buchanan', 'locality_code': '21', 'latitude': 39.6763, 'longitude': -94.8574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63901', 'place_name': 'Poplar Bluff', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.7662, 'longitude': -90.4166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63902', 'place_name': 'Poplar Bluff', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.7125, 'longitude': -90.407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63932', 'place_name': 'Broseley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.6899, 'longitude': -90.2508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63938', 'place_name': 'Fagus', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.5114, 'longitude': -90.267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63940', 'place_name': 'Fisk', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.7836, 'longitude': -90.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63945', 'place_name': 'Harviell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.6723, 'longitude': -90.5583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63954', 'place_name': 'Neelyville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.571, 'longitude': -90.4995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63961', 'place_name': 'Qulin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.5818, 'longitude': -90.2617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63962', 'place_name': 'Rombauer', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Butler', 'locality_code': '23', 'latitude': 36.8431, 'longitude': -90.2801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64624', 'place_name': 'Braymer', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Caldwell', 'locality_code': '25', 'latitude': 39.5915, 'longitude': -93.7887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64625', 'place_name': 'Breckenridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Caldwell', 'locality_code': '25', 'latitude': 39.7582, 'longitude': -93.8068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64637', 'place_name': 'Cowgill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Caldwell', 'locality_code': '25', 'latitude': 39.5643, 'longitude': -93.9295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64644', 'place_name': 'Hamilton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Caldwell', 'locality_code': '25', 'latitude': 39.7364, 'longitude': -93.9909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64649', 'place_name': 'Kidder', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Caldwell', 'locality_code': '25', 'latitude': 39.7803, 'longitude': -94.1024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64650', 'place_name': 'Kingston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Caldwell', 'locality_code': '25', 'latitude': 39.6508, 'longitude': -94.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64671', 'place_name': 'Polo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Caldwell', 'locality_code': '25', 'latitude': 39.5647, 'longitude': -94.0743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63388', 'place_name': 'Williamsburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.8874, 'longitude': -91.7689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65043', 'place_name': 'Holts Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.6328, 'longitude': -92.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65059', 'place_name': 'Mokane', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.6998, 'longitude': -91.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65063', 'place_name': 'New Bloomfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.71, 'longitude': -92.083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65067', 'place_name': 'Portland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.7109, 'longitude': -91.7177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65077', 'place_name': 'Steedman', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.7566, 'longitude': -91.7888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65080', 'place_name': 'Tebbetts', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.6402, 'longitude': -91.9673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65231', 'place_name': 'Auxvasse', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 39.0122, 'longitude': -91.8858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65251', 'place_name': 'Fulton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.8518, 'longitude': -91.9605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65262', 'place_name': 'Kingdom City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Callaway', 'locality_code': '27', 'latitude': 38.9551, 'longitude': -91.952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65020', 'place_name': 'Camdenton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 38.0185, 'longitude': -92.7677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65049', 'place_name': 'Lake Ozark', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 38.2003, 'longitude': -92.6684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65052', 'place_name': 'Linn Creek', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 38.0605, 'longitude': -92.6831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65065', 'place_name': 'Osage Beach', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 38.138, 'longitude': -92.6664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65079', 'place_name': 'Sunrise Beach', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 38.1558, 'longitude': -92.7854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65324', 'place_name': 'Climax Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 38.1396, 'longitude': -92.9537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65567', 'place_name': 'Stoutland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 37.8693, 'longitude': -92.5114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65591', 'place_name': 'Montreal', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 37.9851, 'longitude': -92.547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65786', 'place_name': 'Macks Creek', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 37.9616, 'longitude': -92.9603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65787', 'place_name': 'Roach', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Camden', 'locality_code': '29', 'latitude': 38.1025, 'longitude': -92.9148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63701', 'place_name': 'Cape Girardeau', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.3169, 'longitude': -89.5459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63702', 'place_name': 'Cape Girardeau', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.3506, 'longitude': -89.5094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63703', 'place_name': 'Cape Girardeau', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.3059, 'longitude': -89.5181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63739', 'place_name': 'Burfordville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.3632, 'longitude': -89.8206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63743', 'place_name': 'Daisy', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.5151, 'longitude': -89.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63744', 'place_name': 'Delta', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.1967, 'longitude': -89.7362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63745', 'place_name': 'Dutchtown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.2424, 'longitude': -89.6977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63747', 'place_name': 'Friedheim', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.5669, 'longitude': -89.8376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63752', 'place_name': 'Gordonville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.3092, 'longitude': -89.6989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63755', 'place_name': 'Jackson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.3879, 'longitude': -89.6519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63766', 'place_name': 'Millersville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.4401, 'longitude': -89.795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63769', 'place_name': 'Oak Ridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.5258, 'longitude': -89.7508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63770', 'place_name': 'Old Appleton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.5975, 'longitude': -89.703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63779', 'place_name': 'Pocahontas', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.5007, 'longitude': -89.6396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63785', 'place_name': 'Whitewater', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cape Girardeau', 'locality_code': '31', 'latitude': 37.2781, 'longitude': -89.8061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64622', 'place_name': 'Bogard', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.4994, 'longitude': -93.5374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64623', 'place_name': 'Bosworth', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.4767, 'longitude': -93.3335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64633', 'place_name': 'Carrollton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.3673, 'longitude': -93.4926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64639', 'place_name': 'De Witt', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.384, 'longitude': -93.2238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64643', 'place_name': 'Hale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.5953, 'longitude': -93.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64668', 'place_name': 'Norborne', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.3299, 'longitude': -93.6761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64680', 'place_name': 'Stet', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.4231, 'longitude': -93.7588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64682', 'place_name': 'Tina', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carroll', 'locality_code': '33', 'latitude': 39.5518, 'longitude': -93.4647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63937', 'place_name': 'Ellsinore', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carter', 'locality_code': '35', 'latitude': 36.9453, 'longitude': -90.7485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63941', 'place_name': 'Fremont', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carter', 'locality_code': '35', 'latitude': 36.9172, 'longitude': -91.144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63943', 'place_name': 'Grandin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carter', 'locality_code': '35', 'latitude': 36.828, 'longitude': -90.7942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63965', 'place_name': 'Van Buren', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Carter', 'locality_code': '35', 'latitude': 37.0015, 'longitude': -91.0007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64012', 'place_name': 'Belton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.8161, 'longitude': -94.5328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64078', 'place_name': 'Peculiar', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.7165, 'longitude': -94.4405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64080', 'place_name': 'Pleasant Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.7859, 'longitude': -94.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64083', 'place_name': 'Raymore', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.8019, 'longitude': -94.4529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64090', 'place_name': 'Strasburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.7658, 'longitude': -94.1609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64701', 'place_name': 'Harrisonville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.6419, 'longitude': -94.3285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64725', 'place_name': 'Archie', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.4986, 'longitude': -94.363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64734', 'place_name': 'Cleveland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.6898, 'longitude': -94.5695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64739', 'place_name': 'Creighton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.5078, 'longitude': -94.0926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64743', 'place_name': 'East Lynne', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.6682, 'longitude': -94.2333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64746', 'place_name': 'Freeman', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.6245, 'longitude': -94.4956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64747', 'place_name': 'Garden City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cass', 'locality_code': '37', 'latitude': 38.5681, 'longitude': -94.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64744', 'place_name': 'El Dorado Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cedar', 'locality_code': '39', 'latitude': 37.8652, 'longitude': -94.0124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64756', 'place_name': 'Jerico Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cedar', 'locality_code': '39', 'latitude': 37.6613, 'longitude': -94.0129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65607', 'place_name': 'Caplinger Mills', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cedar', 'locality_code': '39', 'latitude': 37.7942, 'longitude': -93.8044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65785', 'place_name': 'Stockton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cedar', 'locality_code': '39', 'latitude': 37.7241, 'longitude': -93.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64660', 'place_name': 'Mendon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.5828, 'longitude': -93.0892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64676', 'place_name': 'Rothville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.6627, 'longitude': -93.0467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64681', 'place_name': 'Sumner', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.655, 'longitude': -93.2241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65236', 'place_name': 'Brunswick', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.4374, 'longitude': -93.1187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65246', 'place_name': 'Dalton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.4035, 'longitude': -92.9944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65261', 'place_name': 'Keytesville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.4794, 'longitude': -92.9302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65281', 'place_name': 'Salisbury', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.4319, 'longitude': -92.8014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65286', 'place_name': 'Triplett', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Chariton', 'locality_code': '41', 'latitude': 39.5011, 'longitude': -93.1928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65610', 'place_name': 'Billings', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 37.0628, 'longitude': -93.5476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65620', 'place_name': 'Bruner', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.999, 'longitude': -92.9692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65629', 'place_name': 'Chadwick', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.922, 'longitude': -93.0451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65630', 'place_name': 'Chestnutridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.8359, 'longitude': -93.2291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65631', 'place_name': 'Clever', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 37.0447, 'longitude': -93.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65657', 'place_name': 'Garrison', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.8389, 'longitude': -93.0196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65669', 'place_name': 'Highlandville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.9408, 'longitude': -93.268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65714', 'place_name': 'Nixa', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 37.0512, 'longitude': -93.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65720', 'place_name': 'Oldfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.9404, 'longitude': -92.9528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65721', 'place_name': 'Ozark', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 37.0169, 'longitude': -93.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65753', 'place_name': 'Sparta', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.9775, 'longitude': -93.1065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65754', 'place_name': 'Spokane', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.8636, 'longitude': -93.2754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '72643', 'place_name': 'Lead Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Christian', 'locality_code': '43', 'latitude': 36.9404, 'longitude': -92.9528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63430', 'place_name': 'Alexandria', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clark', 'locality_code': '45', 'latitude': 40.3445, 'longitude': -91.5154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63445', 'place_name': 'Kahoka', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clark', 'locality_code': '45', 'latitude': 40.4266, 'longitude': -91.725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63453', 'place_name': 'Luray', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clark', 'locality_code': '45', 'latitude': 40.4931, 'longitude': -91.8912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63465', 'place_name': 'Revere', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clark', 'locality_code': '45', 'latitude': 40.5172, 'longitude': -91.6753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63466', 'place_name': 'Saint Patrick', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clark', 'locality_code': '45', 'latitude': 40.4312, 'longitude': -91.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63472', 'place_name': 'Wayland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clark', 'locality_code': '45', 'latitude': 40.4001, 'longitude': -91.5842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63474', 'place_name': 'Wyaconda', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clark', 'locality_code': '45', 'latitude': 40.3721, 'longitude': -91.9071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64024', 'place_name': 'Excelsior Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.3392, 'longitude': -94.2261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64048', 'place_name': 'Holt', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.4289, 'longitude': -94.3689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64060', 'place_name': 'Kearney', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.3652, 'longitude': -94.3621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64068', 'place_name': 'Liberty', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2461, 'longitude': -94.4191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64069', 'place_name': 'Liberty', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2461, 'longitude': -94.4191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64072', 'place_name': 'Missouri City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2458, 'longitude': -94.2924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64073', 'place_name': 'Mosby', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.3149, 'longitude': -94.2939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64089', 'place_name': 'Smithville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.3917, 'longitude': -94.5592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64116', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.1479, 'longitude': -94.568, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64117', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.1651, 'longitude': -94.5256, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64118', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2133, 'longitude': -94.5743, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64119', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.1979, 'longitude': -94.5199, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64144', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2829, 'longitude': -94.409, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64155', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2758, 'longitude': -94.5704, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64156', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2901, 'longitude': -94.5336, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64157', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2767, 'longitude': -94.4595, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64158', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.2284, 'longitude': -94.472, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64161', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.1661, 'longitude': -94.464, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64162', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.1562, 'longitude': -94.4797, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64165', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.3113, 'longitude': -94.5431, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64166', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.3294, 'longitude': -94.5199, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64167', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clay', 'locality_code': '47', 'latitude': 39.32, 'longitude': -94.4877, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '64429', 'place_name': 'Cameron', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clinton', 'locality_code': '49', 'latitude': 39.7309, 'longitude': -94.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64454', 'place_name': 'Gower', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clinton', 'locality_code': '49', 'latitude': 39.602, 'longitude': -94.5965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64465', 'place_name': 'Lathrop', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clinton', 'locality_code': '49', 'latitude': 39.5177, 'longitude': -94.3093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64477', 'place_name': 'Plattsburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clinton', 'locality_code': '49', 'latitude': 39.5705, 'longitude': -94.4338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64492', 'place_name': 'Trimble', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clinton', 'locality_code': '49', 'latitude': 39.4871, 'longitude': -94.5512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64493', 'place_name': 'Turney', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Clinton', 'locality_code': '49', 'latitude': 39.6318, 'longitude': -94.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65023', 'place_name': 'Centertown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.6297, 'longitude': -92.3995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65032', 'place_name': 'Eugene', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.3424, 'longitude': -92.3823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65040', 'place_name': 'Henley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.3445, 'longitude': -92.3224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65053', 'place_name': 'Lohman', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5484, 'longitude': -92.3842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65074', 'place_name': 'Russellville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5005, 'longitude': -92.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65076', 'place_name': 'Saint Thomas', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.3912, 'longitude': -92.1894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65101', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5462, 'longitude': -92.1525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65102', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65103', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65104', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65105', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65106', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65107', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65108', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65109', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5773, 'longitude': -92.2443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65110', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5767, 'longitude': -92.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65111', 'place_name': 'Jefferson City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cole', 'locality_code': '51', 'latitude': 38.5309, 'longitude': -92.2493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65068', 'place_name': 'Prairie Home', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cooper', 'locality_code': '53', 'latitude': 38.8253, 'longitude': -92.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65233', 'place_name': 'Boonville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cooper', 'locality_code': '53', 'latitude': 38.9536, 'longitude': -92.745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65237', 'place_name': 'Bunceton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cooper', 'locality_code': '53', 'latitude': 38.7881, 'longitude': -92.7994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65276', 'place_name': 'Pilot Grove', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cooper', 'locality_code': '53', 'latitude': 38.8712, 'longitude': -92.9305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65287', 'place_name': 'Wooldridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cooper', 'locality_code': '53', 'latitude': 38.8983, 'longitude': -92.5667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65322', 'place_name': 'Blackwater', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cooper', 'locality_code': '53', 'latitude': 38.9727, 'longitude': -92.9683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65348', 'place_name': 'Otterville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Cooper', 'locality_code': '53', 'latitude': 38.7161, 'longitude': -93.0108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65441', 'place_name': 'Bourbon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 38.172, 'longitude': -91.2225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65446', 'place_name': 'Cherryville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 37.8066, 'longitude': -91.2348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65449', 'place_name': 'Cook Sta', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 37.8242, 'longitude': -91.5623, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '65453', 'place_name': 'Cuba', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 38.0926, 'longitude': -91.4081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65456', 'place_name': 'Davisville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 37.787, 'longitude': -91.2116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65535', 'place_name': 'Leasburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 38.092, 'longitude': -91.2965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65565', 'place_name': 'Steelville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 37.8904, 'longitude': -91.3032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65586', 'place_name': 'Wesco', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Crawford', 'locality_code': '55', 'latitude': 37.8585, 'longitude': -91.4267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65603', 'place_name': 'Arcola', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dade', 'locality_code': '57', 'latitude': 37.5512, 'longitude': -93.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65635', 'place_name': 'Dadeville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dade', 'locality_code': '57', 'latitude': 37.5105, 'longitude': -93.6956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65646', 'place_name': 'Everton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dade', 'locality_code': '57', 'latitude': 37.3425, 'longitude': -93.7024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65661', 'place_name': 'Greenfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dade', 'locality_code': '57', 'latitude': 37.4197, 'longitude': -93.8407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65682', 'place_name': 'Lockwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dade', 'locality_code': '57', 'latitude': 37.386, 'longitude': -93.9541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65752', 'place_name': 'South Greenfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dade', 'locality_code': '57', 'latitude': 37.3743, 'longitude': -93.8445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65590', 'place_name': 'Long Lane', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dallas', 'locality_code': '59', 'latitude': 37.5808, 'longitude': -92.9309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65622', 'place_name': 'Buffalo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dallas', 'locality_code': '59', 'latitude': 37.6429, 'longitude': -93.0906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65685', 'place_name': 'Louisburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dallas', 'locality_code': '59', 'latitude': 37.7542, 'longitude': -93.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65764', 'place_name': 'Tunas', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dallas', 'locality_code': '59', 'latitude': 37.8392, 'longitude': -92.9808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65767', 'place_name': 'Urbana', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dallas', 'locality_code': '59', 'latitude': 37.8523, 'longitude': -93.151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65783', 'place_name': 'Windyville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dallas', 'locality_code': '59', 'latitude': 37.7182, 'longitude': -92.9379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64620', 'place_name': 'Altamont', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 39.896, 'longitude': -94.0897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64636', 'place_name': 'Coffey', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 40.0999, 'longitude': -94.0252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64640', 'place_name': 'Gallatin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 39.9025, 'longitude': -93.9787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64642', 'place_name': 'Gilman City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 40.145, 'longitude': -93.832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64647', 'place_name': 'Jameson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 40.0046, 'longitude': -93.9597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64648', 'place_name': 'Jamesport', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 39.9837, 'longitude': -93.78, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64654', 'place_name': 'Lock Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 39.8489, 'longitude': -93.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64670', 'place_name': 'Pattonsburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 40.0428, 'longitude': -94.1343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64689', 'place_name': 'Winston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Daviess', 'locality_code': '61', 'latitude': 39.8499, 'longitude': -94.1487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64422', 'place_name': 'Amity', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'DeKalb', 'locality_code': '63', 'latitude': 39.8837, 'longitude': -94.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64430', 'place_name': 'Clarksdale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'DeKalb', 'locality_code': '63', 'latitude': 39.8137, 'longitude': -94.5421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64469', 'place_name': 'Maysville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'DeKalb', 'locality_code': '63', 'latitude': 39.9112, 'longitude': -94.3548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64474', 'place_name': 'Osborn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'DeKalb', 'locality_code': '63', 'latitude': 39.7912, 'longitude': -94.3974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64490', 'place_name': 'Stewartsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'DeKalb', 'locality_code': '63', 'latitude': 39.7984, 'longitude': -94.5175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64494', 'place_name': 'Union Star', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'DeKalb', 'locality_code': '63', 'latitude': 39.9846, 'longitude': -94.5787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64497', 'place_name': 'Weatherby', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'DeKalb', 'locality_code': '63', 'latitude': 39.9277, 'longitude': -94.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65440', 'place_name': 'Boss', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dent', 'locality_code': '65', 'latitude': 37.6373, 'longitude': -91.2109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65501', 'place_name': 'Jadwin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dent', 'locality_code': '65', 'latitude': 37.4867, 'longitude': -91.571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65532', 'place_name': 'Lake Spring', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dent', 'locality_code': '65', 'latitude': 37.7825, 'longitude': -91.6788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65541', 'place_name': 'Lenox', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dent', 'locality_code': '65', 'latitude': 37.6531, 'longitude': -91.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65560', 'place_name': 'Salem', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dent', 'locality_code': '65', 'latitude': 37.617, 'longitude': -91.5258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65608', 'place_name': 'Ava', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Douglas', 'locality_code': '67', 'latitude': 36.9407, 'longitude': -92.6765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65638', 'place_name': 'Drury', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Douglas', 'locality_code': '67', 'latitude': 36.9319, 'longitude': -92.3664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65755', 'place_name': 'Squires', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Douglas', 'locality_code': '67', 'latitude': 36.8504, 'longitude': -92.5844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65768', 'place_name': 'Vanzant', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Douglas', 'locality_code': '67', 'latitude': 36.9698, 'longitude': -92.3029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63821', 'place_name': 'Arbyrd', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.0501, 'longitude': -90.2284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63829', 'place_name': 'Cardwell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.0434, 'longitude': -90.2907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63837', 'place_name': 'Clarkton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.4478, 'longitude': -89.9729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63847', 'place_name': 'Gibson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.4412, 'longitude': -90.0309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63852', 'place_name': 'Holcomb', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.3885, 'longitude': -90.0208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63855', 'place_name': 'Hornersville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.0627, 'longitude': -90.0816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63857', 'place_name': 'Kennett', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.2407, 'longitude': -90.0491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63863', 'place_name': 'Malden', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.5672, 'longitude': -89.9737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63875', 'place_name': 'Rives', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.0937, 'longitude': -90.0134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63876', 'place_name': 'Senath', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.1324, 'longitude': -90.1632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63880', 'place_name': 'Whiteoak', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.3133, 'longitude': -90.1658, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63933', 'place_name': 'Campbell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Dunklin', 'locality_code': '69', 'latitude': 36.5197, 'longitude': -90.0829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63013', 'place_name': 'Beaufort', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.4294, 'longitude': -91.1709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63014', 'place_name': 'Berger', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.6444, 'longitude': -91.3374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63015', 'place_name': 'Catawissa', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.4047, 'longitude': -90.7806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63037', 'place_name': 'Gerald', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.3507, 'longitude': -91.2931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63039', 'place_name': 'Gray Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.503, 'longitude': -90.8292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63055', 'place_name': 'Labadie', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.52, 'longitude': -90.877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63056', 'place_name': 'Leslie', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.4555, 'longitude': -91.2328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63060', 'place_name': 'Lonedell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.2743, 'longitude': -90.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63061', 'place_name': 'Luebbering', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.2615, 'longitude': -90.8027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63068', 'place_name': 'New Haven', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.574, 'longitude': -91.2291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63069', 'place_name': 'Pacific', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.4922, 'longitude': -90.748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63072', 'place_name': 'Robertsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.3816, 'longitude': -90.8016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63073', 'place_name': 'Saint Albans', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.5792, 'longitude': -90.7751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63077', 'place_name': 'Saint Clair', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.3299, 'longitude': -90.9713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63079', 'place_name': 'Stanton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.2745, 'longitude': -91.1057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63080', 'place_name': 'Sullivan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.2307, 'longitude': -91.1567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63084', 'place_name': 'Union', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.4456, 'longitude': -91.0206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63089', 'place_name': 'Villa Ridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.4601, 'longitude': -90.8822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63090', 'place_name': 'Washington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Franklin', 'locality_code': '71', 'latitude': 38.5459, 'longitude': -91.0193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63091', 'place_name': 'Rosebud', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gasconade', 'locality_code': '73', 'latitude': 38.3853, 'longitude': -91.3974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65014', 'place_name': 'Bland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gasconade', 'locality_code': '73', 'latitude': 38.3074, 'longitude': -91.6263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65036', 'place_name': 'Gasconade', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gasconade', 'locality_code': '73', 'latitude': 38.6703, 'longitude': -91.5592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65041', 'place_name': 'Hermann', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gasconade', 'locality_code': '73', 'latitude': 38.5876, 'longitude': -91.4991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65061', 'place_name': 'Morrison', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gasconade', 'locality_code': '73', 'latitude': 38.606, 'longitude': -91.658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65062', 'place_name': 'Mount Sterling', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gasconade', 'locality_code': '73', 'latitude': 38.4956, 'longitude': -91.6515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65066', 'place_name': 'Owensville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gasconade', 'locality_code': '73', 'latitude': 38.3511, 'longitude': -91.4867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64402', 'place_name': 'Albany', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gentry', 'locality_code': '75', 'latitude': 40.2513, 'longitude': -94.327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64438', 'place_name': 'Darlington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gentry', 'locality_code': '75', 'latitude': 40.1955, 'longitude': -94.4049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64453', 'place_name': 'Gentry', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gentry', 'locality_code': '75', 'latitude': 40.3411, 'longitude': -94.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64463', 'place_name': 'King City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gentry', 'locality_code': '75', 'latitude': 40.0652, 'longitude': -94.5234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64489', 'place_name': 'Stanberry', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gentry', 'locality_code': '75', 'latitude': 40.2293, 'longitude': -94.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64657', 'place_name': 'Mc Fall', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Gentry', 'locality_code': '75', 'latitude': 40.1051, 'longitude': -94.3003, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '65604', 'place_name': 'Ash Grove', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.316, 'longitude': -93.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65612', 'place_name': 'Bois D Arc', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2214, 'longitude': -93.5447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65619', 'place_name': 'Brookline', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1634, 'longitude': -93.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65648', 'place_name': 'Fair Grove', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.3721, 'longitude': -93.1428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65738', 'place_name': 'Republic', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.123, 'longitude': -93.48, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65757', 'place_name': 'Strafford', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2797, 'longitude': -93.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65765', 'place_name': 'Turners', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1809, 'longitude': -93.1555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65770', 'place_name': 'Walnut Grove', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.3943, 'longitude': -93.5044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65781', 'place_name': 'Willard', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2962, 'longitude': -93.4259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65801', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2581, 'longitude': -93.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65802', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2117, 'longitude': -93.299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65803', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2593, 'longitude': -93.2912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65804', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1654, 'longitude': -93.2522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65805', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2581, 'longitude': -93.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65806', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2031, 'longitude': -93.2971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65807', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1668, 'longitude': -93.3085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65808', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2581, 'longitude': -93.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65809', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1852, 'longitude': -93.2057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65810', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1136, 'longitude': -93.2896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65814', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2581, 'longitude': -93.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65817', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2581, 'longitude': -93.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65890', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2581, 'longitude': -93.3437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65897', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1987, 'longitude': -93.2784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65898', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.2153, 'longitude': -93.2982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65899', 'place_name': 'Springfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Greene', 'locality_code': '77', 'latitude': 37.1815, 'longitude': -93.2596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64641', 'place_name': 'Galt', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Grundy', 'locality_code': '79', 'latitude': 40.144, 'longitude': -93.3953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64652', 'place_name': 'Laredo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Grundy', 'locality_code': '79', 'latitude': 40.0144, 'longitude': -93.4407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64679', 'place_name': 'Spickard', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Grundy', 'locality_code': '79', 'latitude': 40.2439, 'longitude': -93.5944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64683', 'place_name': 'Trenton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Grundy', 'locality_code': '79', 'latitude': 40.0823, 'longitude': -93.6086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64424', 'place_name': 'Bethany', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.2601, 'longitude': -94.0189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64426', 'place_name': 'Blythedale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.5024, 'longitude': -93.8954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64442', 'place_name': 'Eagleville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.4912, 'longitude': -93.9951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64458', 'place_name': 'Hatfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.5219, 'longitude': -94.1691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64467', 'place_name': 'Martinsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.3662, 'longitude': -94.1645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64471', 'place_name': 'New Hampton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.2444, 'longitude': -94.1786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64481', 'place_name': 'Ridgeway', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.3999, 'longitude': -93.9575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64632', 'place_name': 'Cainsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Harrison', 'locality_code': '81', 'latitude': 40.4578, 'longitude': -93.759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64726', 'place_name': 'Blairstown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Henry', 'locality_code': '83', 'latitude': 38.5319, 'longitude': -93.9221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64735', 'place_name': 'Clinton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Henry', 'locality_code': '83', 'latitude': 38.4018, 'longitude': -93.785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64740', 'place_name': 'Deepwater', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Henry', 'locality_code': '83', 'latitude': 38.2432, 'longitude': -93.7303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64770', 'place_name': 'Montrose', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Henry', 'locality_code': '83', 'latitude': 38.2597, 'longitude': -93.9952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64788', 'place_name': 'Urich', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Henry', 'locality_code': '83', 'latitude': 38.4449, 'longitude': -93.9785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65323', 'place_name': 'Calhoun', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Henry', 'locality_code': '83', 'latitude': 38.4858, 'longitude': -93.6459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65360', 'place_name': 'Windsor', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Henry', 'locality_code': '83', 'latitude': 38.5272, 'longitude': -93.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65634', 'place_name': 'Cross Timbers', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Hickory', 'locality_code': '85', 'latitude': 38.0239, 'longitude': -93.1978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65668', 'place_name': 'Hermitage', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Hickory', 'locality_code': '85', 'latitude': 37.8969, 'longitude': -93.2979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65724', 'place_name': 'Pittsburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Hickory', 'locality_code': '85', 'latitude': 37.8442, 'longitude': -93.3356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65732', 'place_name': 'Preston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Hickory', 'locality_code': '85', 'latitude': 37.939, 'longitude': -93.1713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65735', 'place_name': 'Quincy', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Hickory', 'locality_code': '85', 'latitude': 38.0084, 'longitude': -93.4724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65774', 'place_name': 'Weaubleau', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Hickory', 'locality_code': '85', 'latitude': 37.8906, 'longitude': -93.5419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65779', 'place_name': 'Wheatland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Hickory', 'locality_code': '85', 'latitude': 37.9103, 'longitude': -93.3981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64437', 'place_name': 'Craig', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Holt', 'locality_code': '87', 'latitude': 40.1267, 'longitude': -95.3291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64451', 'place_name': 'Forest City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Holt', 'locality_code': '87', 'latitude': 39.9897, 'longitude': -95.1916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64466', 'place_name': 'Maitland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Holt', 'locality_code': '87', 'latitude': 40.1991, 'longitude': -95.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64470', 'place_name': 'Mound City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Holt', 'locality_code': '87', 'latitude': 40.1362, 'longitude': -95.2138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64473', 'place_name': 'Oregon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Holt', 'locality_code': '87', 'latitude': 39.9809, 'longitude': -95.1234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65230', 'place_name': 'Armstrong', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howard', 'locality_code': '89', 'latitude': 39.2566, 'longitude': -92.709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65248', 'place_name': 'Fayette', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howard', 'locality_code': '89', 'latitude': 39.143, 'longitude': -92.6583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65250', 'place_name': 'Franklin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howard', 'locality_code': '89', 'latitude': 39.0668, 'longitude': -92.8316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65254', 'place_name': 'Glasgow', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howard', 'locality_code': '89', 'latitude': 39.2257, 'longitude': -92.8318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65274', 'place_name': 'New Franklin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howard', 'locality_code': '89', 'latitude': 39.02, 'longitude': -92.7386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65548', 'place_name': 'Mountain View', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.9892, 'longitude': -91.7099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65626', 'place_name': 'Caulfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.6035, 'longitude': -92.0678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65688', 'place_name': 'Brandsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.6488, 'longitude': -91.6976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65775', 'place_name': 'West Plains', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.7284, 'longitude': -91.8717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65777', 'place_name': 'Moody', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.533, 'longitude': -91.9898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65788', 'place_name': 'Peace Valley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.8091, 'longitude': -91.6938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65789', 'place_name': 'Pomona', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.8441, 'longitude': -91.9137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65790', 'place_name': 'Pottersville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.7068, 'longitude': -92.044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65793', 'place_name': 'Willow Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Howell', 'locality_code': '91', 'latitude': 36.9958, 'longitude': -91.9405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63620', 'place_name': 'Annapolis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.3981, 'longitude': -90.6702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63621', 'place_name': 'Arcadia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.4871, 'longitude': -90.6062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63623', 'place_name': 'Belleview', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.682, 'longitude': -90.7991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63636', 'place_name': 'Des Arc', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.2955, 'longitude': -90.6279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63650', 'place_name': 'Ironton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.6168, 'longitude': -90.5985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63656', 'place_name': 'Middle Brook', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.5055, 'longitude': -90.845, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63663', 'place_name': 'Pilot Knob', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.625, 'longitude': -90.646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63675', 'place_name': 'Vulcan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.306, 'longitude': -90.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65439', 'place_name': 'Bixby', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.6603, 'longitude': -91.1151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65566', 'place_name': 'Viburnum', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Iron', 'locality_code': '93', 'latitude': 37.7151, 'longitude': -91.1289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64002', 'place_name': 'Lees Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9285, 'longitude': -94.3983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64013', 'place_name': 'Blue Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.017, 'longitude': -94.2816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64014', 'place_name': 'Blue Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0152, 'longitude': -94.2604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64015', 'place_name': 'Blue Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.015, 'longitude': -94.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64016', 'place_name': 'Buckner', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1303, 'longitude': -94.2062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64029', 'place_name': 'Grain Valley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0274, 'longitude': -94.2087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64030', 'place_name': 'Grandview', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8819, 'longitude': -94.5205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64034', 'place_name': 'Greenwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8644, 'longitude': -94.2815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64050', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0983, 'longitude': -94.4111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64051', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0911, 'longitude': -94.4155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64052', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.075, 'longitude': -94.4499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64053', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.105, 'longitude': -94.4625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64054', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.11, 'longitude': -94.4401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64055', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0545, 'longitude': -94.4039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64056', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1177, 'longitude': -94.3596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64057', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0731, 'longitude': -94.3533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64058', 'place_name': 'Independence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1412, 'longitude': -94.3515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64063', 'place_name': 'Lees Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.912, 'longitude': -94.3517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64064', 'place_name': 'Lees Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9953, 'longitude': -94.3652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64065', 'place_name': 'Lees Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9529, 'longitude': -94.4058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64066', 'place_name': 'Levasy', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1356, 'longitude': -94.133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64070', 'place_name': 'Lone Jack', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8918, 'longitude': -94.1615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64075', 'place_name': 'Oak Grove', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9985, 'longitude': -94.1399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64081', 'place_name': 'Lees Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9142, 'longitude': -94.4073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64082', 'place_name': 'Lees Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8518, 'longitude': -94.3944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64086', 'place_name': 'Lees Summit', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.944, 'longitude': -94.2881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64088', 'place_name': 'Sibley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1584, 'longitude': -94.1844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64101', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1024, 'longitude': -94.5986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64102', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0861, 'longitude': -94.6066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64105', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1025, 'longitude': -94.5901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64106', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1052, 'longitude': -94.5699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64108', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0837, 'longitude': -94.5868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64109', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0663, 'longitude': -94.5674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64110', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0361, 'longitude': -94.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64111', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0565, 'longitude': -94.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64112', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0382, 'longitude': -94.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64113', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0123, 'longitude': -94.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64114', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9621, 'longitude': -94.5959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64120', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1222, 'longitude': -94.5487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64121', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64123', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1136, 'longitude': -94.5235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64124', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1068, 'longitude': -94.5394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64125', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.1042, 'longitude': -94.4923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64126', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0923, 'longitude': -94.5047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64127', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0883, 'longitude': -94.5366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64128', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0659, 'longitude': -94.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64129', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0401, 'longitude': -94.4951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64130', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0351, 'longitude': -94.5467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64131', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9713, 'longitude': -94.5774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64132', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9911, 'longitude': -94.5522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64133', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0323, 'longitude': -94.47, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64134', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9296, 'longitude': -94.5009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64136', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0187, 'longitude': -94.4008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64137', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9299, 'longitude': -94.5405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64138', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9528, 'longitude': -94.4705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64139', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.9659, 'longitude': -94.4061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64141', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64145', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8977, 'longitude': -94.5976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64146', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8973, 'longitude': -94.5764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64147', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8549, 'longitude': -94.5568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64148', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64149', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 38.8606, 'longitude': -94.4636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64170', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64171', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64179', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64180', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64184', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64187', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64188', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64191', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64196', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64197', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64198', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64199', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64999', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jackson', 'locality_code': '95', 'latitude': 39.0997, 'longitude': -94.5786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64755', 'place_name': 'Jasper', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.3362, 'longitude': -94.3013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64801', 'place_name': 'Joplin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.0969, 'longitude': -94.5051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64802', 'place_name': 'Joplin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.0842, 'longitude': -94.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64803', 'place_name': 'Joplin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.0842, 'longitude': -94.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64804', 'place_name': 'Joplin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.0465, 'longitude': -94.5103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64830', 'place_name': 'Alba', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.2367, 'longitude': -94.418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64832', 'place_name': 'Asbury', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.2942, 'longitude': -94.5655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64833', 'place_name': 'Avilla', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.1953, 'longitude': -94.1297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64834', 'place_name': 'Carl Junction', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.1795, 'longitude': -94.555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64835', 'place_name': 'Carterville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.1507, 'longitude': -94.4359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64836', 'place_name': 'Carthage', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.1597, 'longitude': -94.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64841', 'place_name': 'Duenweg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.076, 'longitude': -94.4071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64848', 'place_name': 'La Russell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.1739, 'longitude': -94.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64849', 'place_name': 'Neck City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.257, 'longitude': -94.4444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64855', 'place_name': 'Oronogo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.2717, 'longitude': -94.4865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64857', 'place_name': 'Purcell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.2423, 'longitude': -94.4352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64859', 'place_name': 'Reeds', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.1225, 'longitude': -94.1613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64862', 'place_name': 'Sarcoxie', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.0724, 'longitude': -94.1151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64870', 'place_name': 'Webb City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jasper', 'locality_code': '97', 'latitude': 37.144, 'longitude': -94.4727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63010', 'place_name': 'Arnold', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.4305, 'longitude': -90.387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63012', 'place_name': 'Barnhart', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.3384, 'longitude': -90.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63016', 'place_name': 'Cedar Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.3573, 'longitude': -90.6498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63019', 'place_name': 'Crystal City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.23, 'longitude': -90.3825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63020', 'place_name': 'De Soto', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.1204, 'longitude': -90.5546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63023', 'place_name': 'Dittmer', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.3155, 'longitude': -90.6911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63028', 'place_name': 'Festus', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.1879, 'longitude': -90.4286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63030', 'place_name': 'Fletcher', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.1659, 'longitude': -90.7335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63041', 'place_name': 'Grubville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.251, 'longitude': -90.7901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63047', 'place_name': 'Hematite', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.202, 'longitude': -90.481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63048', 'place_name': 'Herculaneum', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.2625, 'longitude': -90.3896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63049', 'place_name': 'High Ridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.4728, 'longitude': -90.5281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63050', 'place_name': 'Hillsboro', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.2586, 'longitude': -90.5782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63051', 'place_name': 'House Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.4131, 'longitude': -90.5575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63052', 'place_name': 'Imperial', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.4069, 'longitude': -90.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63053', 'place_name': 'Kimmswick', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.3653, 'longitude': -90.3629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63057', 'place_name': 'Liguori', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.3419, 'longitude': -90.4082, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63065', 'place_name': 'Mapaville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.2489, 'longitude': -90.4835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63066', 'place_name': 'Morse Mill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.2809, 'longitude': -90.6521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63070', 'place_name': 'Pevely', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Jefferson', 'locality_code': '99', 'latitude': 38.2799, 'longitude': -90.4111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64019', 'place_name': 'Centerview', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.7897, 'longitude': -93.8702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64040', 'place_name': 'Holden', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.7186, 'longitude': -93.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64061', 'place_name': 'Kingsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.8178, 'longitude': -94.0462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64093', 'place_name': 'Warrensburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.7667, 'longitude': -93.7273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64733', 'place_name': 'Chilhowee', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.6126, 'longitude': -93.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64761', 'place_name': 'Leeton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.5831, 'longitude': -93.6947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65305', 'place_name': 'Whiteman Air Force Base', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.7318, 'longitude': -93.5731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65336', 'place_name': 'Knob Noster', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Johnson', 'locality_code': '101', 'latitude': 38.7667, 'longitude': -93.5585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63446', 'place_name': 'Knox City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Knox', 'locality_code': '103', 'latitude': 40.1384, 'longitude': -92.0077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63458', 'place_name': 'Newark', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Knox', 'locality_code': '103', 'latitude': 39.9931, 'longitude': -91.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63460', 'place_name': 'Novelty', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Knox', 'locality_code': '103', 'latitude': 40.0125, 'longitude': -92.2082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63464', 'place_name': 'Plevna', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Knox', 'locality_code': '103', 'latitude': 39.9765, 'longitude': -92.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63531', 'place_name': 'Baring', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Knox', 'locality_code': '103', 'latitude': 40.2509, 'longitude': -92.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63537', 'place_name': 'Edina', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Knox', 'locality_code': '103', 'latitude': 40.1795, 'longitude': -92.1455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63547', 'place_name': 'Hurdland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Knox', 'locality_code': '103', 'latitude': 40.1609, 'longitude': -92.2791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65463', 'place_name': 'Eldridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Laclede', 'locality_code': '105', 'latitude': 37.8346, 'longitude': -92.7382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65470', 'place_name': 'Falcon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Laclede', 'locality_code': '105', 'latitude': 37.6061, 'longitude': -92.3466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65536', 'place_name': 'Lebanon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Laclede', 'locality_code': '105', 'latitude': 37.685, 'longitude': -92.655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65543', 'place_name': 'Lynchburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Laclede', 'locality_code': '105', 'latitude': 37.5054, 'longitude': -92.3202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65632', 'place_name': 'Conway', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Laclede', 'locality_code': '105', 'latitude': 37.5085, 'longitude': -92.7891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65722', 'place_name': 'Phillipsburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Laclede', 'locality_code': '105', 'latitude': 37.5832, 'longitude': -92.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64001', 'place_name': 'Alma', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.1048, 'longitude': -93.5429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64011', 'place_name': 'Bates City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.0219, 'longitude': -94.0798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64020', 'place_name': 'Concordia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 38.9776, 'longitude': -93.5812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64021', 'place_name': 'Corder', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.1024, 'longitude': -93.6391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64022', 'place_name': 'Dover', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.1926, 'longitude': -93.6684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64037', 'place_name': 'Higginsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.0705, 'longitude': -93.7133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64067', 'place_name': 'Lexington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.1742, 'longitude': -93.8714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64071', 'place_name': 'Mayview', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.0459, 'longitude': -93.8353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64074', 'place_name': 'Napoleon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.114, 'longitude': -94.0709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64076', 'place_name': 'Odessa', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 38.9829, 'longitude': -93.9757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64096', 'place_name': 'Waverly', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.2055, 'longitude': -93.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64097', 'place_name': 'Wellington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 39.1258, 'longitude': -93.9855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65327', 'place_name': 'Emma', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lafayette', 'locality_code': '107', 'latitude': 38.9717, 'longitude': -93.4947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65605', 'place_name': 'Aurora', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 36.9709, 'longitude': -93.718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65654', 'place_name': 'Freistatt', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 37.0211, 'longitude': -93.8974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65664', 'place_name': 'Halltown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 37.1944, 'longitude': -93.6275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65705', 'place_name': 'Marionville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 37.0009, 'longitude': -93.6413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65707', 'place_name': 'Miller', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 37.2225, 'longitude': -93.8422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65712', 'place_name': 'Mount Vernon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 37.1045, 'longitude': -93.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65723', 'place_name': 'Pierce City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 36.973, 'longitude': -94.0024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65756', 'place_name': 'Stotts City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 37.1031, 'longitude': -93.9543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65769', 'place_name': 'Verona', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lawrence', 'locality_code': '109', 'latitude': 36.937, 'longitude': -93.8005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63435', 'place_name': 'Canton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 40.1437, 'longitude': -91.548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63438', 'place_name': 'Durham', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 39.9625, 'longitude': -91.6704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63440', 'place_name': 'Ewing', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 39.9962, 'longitude': -91.7216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63447', 'place_name': 'La Belle', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 40.1164, 'longitude': -91.9171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63448', 'place_name': 'La Grange', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 40.0391, 'longitude': -91.5182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63452', 'place_name': 'Lewistown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 40.0867, 'longitude': -91.8157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63457', 'place_name': 'Monticello', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 40.1184, 'longitude': -91.7121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63473', 'place_name': 'Williamstown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lewis', 'locality_code': '111', 'latitude': 40.2491, 'longitude': -91.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63343', 'place_name': 'Elsberry', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 39.159, 'longitude': -90.816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63347', 'place_name': 'Foley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 39.053, 'longitude': -90.7775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63349', 'place_name': 'Hawk Point', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 38.9766, 'longitude': -91.1211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63362', 'place_name': 'Moscow Mills', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 38.9482, 'longitude': -90.9138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63369', 'place_name': 'Old Monroe', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 38.9346, 'longitude': -90.7782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63370', 'place_name': 'Olney', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 39.0839, 'longitude': -91.2432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63377', 'place_name': 'Silex', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 39.1166, 'longitude': -91.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63379', 'place_name': 'Troy', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 39.0012, 'longitude': -90.9624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63381', 'place_name': 'Truxton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 38.967, 'longitude': -91.2126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63387', 'place_name': 'Whiteside', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 39.1853, 'longitude': -91.0168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63389', 'place_name': 'Winfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Lincoln', 'locality_code': '113', 'latitude': 38.9897, 'longitude': -90.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63557', 'place_name': 'New Boston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.9332, 'longitude': -92.916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64628', 'place_name': 'Brookfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.7846, 'longitude': -93.0719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64630', 'place_name': 'Browning', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 40.029, 'longitude': -93.1607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64631', 'place_name': 'Bucklin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.8006, 'longitude': -92.8928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64651', 'place_name': 'Laclede', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.7837, 'longitude': -93.168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64653', 'place_name': 'Linneus', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.9099, 'longitude': -93.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64658', 'place_name': 'Marceline', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.7125, 'longitude': -92.9455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64659', 'place_name': 'Meadville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.7795, 'longitude': -93.3014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64674', 'place_name': 'Purdin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Linn', 'locality_code': '115', 'latitude': 39.9529, 'longitude': -93.17, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64601', 'place_name': 'Chillicothe', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Livingston', 'locality_code': '117', 'latitude': 39.7966, 'longitude': -93.5509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64635', 'place_name': 'Chula', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Livingston', 'locality_code': '117', 'latitude': 39.9226, 'longitude': -93.4841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64638', 'place_name': 'Dawn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Livingston', 'locality_code': '117', 'latitude': 39.6665, 'longitude': -93.5964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64656', 'place_name': 'Ludlow', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Livingston', 'locality_code': '117', 'latitude': 39.6551, 'longitude': -93.7046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64664', 'place_name': 'Mooresville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Livingston', 'locality_code': '117', 'latitude': 39.7425, 'longitude': -93.7169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64686', 'place_name': 'Utica', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Livingston', 'locality_code': '117', 'latitude': 39.7417, 'longitude': -93.6289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64688', 'place_name': 'Wheeling', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Livingston', 'locality_code': '117', 'latitude': 39.8011, 'longitude': -93.3868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64831', 'place_name': 'Anderson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.6506, 'longitude': -94.4436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64843', 'place_name': 'Goodman', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.7323, 'longitude': -94.3986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64847', 'place_name': 'Lanagan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.606, 'longitude': -94.4551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64854', 'place_name': 'Noel', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.5417, 'longitude': -94.4906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64856', 'place_name': 'Pineville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.574, 'longitude': -94.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64861', 'place_name': 'Rocky Comfort', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.7175, 'longitude': -94.1091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64863', 'place_name': 'South West City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.5319, 'longitude': -94.5961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64868', 'place_name': 'Tiff City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.6684, 'longitude': -94.6172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65730', 'place_name': 'Powell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'McDonald', 'locality_code': '119', 'latitude': 36.6237, 'longitude': -94.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63431', 'place_name': 'Anabel', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.7428, 'longitude': -92.328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63530', 'place_name': 'Atlanta', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.9146, 'longitude': -92.475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63532', 'place_name': 'Bevier', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.7497, 'longitude': -92.5619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63534', 'place_name': 'Callao', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.7448, 'longitude': -92.6351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63538', 'place_name': 'Elmer', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.9415, 'longitude': -92.6424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63539', 'place_name': 'Ethel', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.9146, 'longitude': -92.7664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63549', 'place_name': 'La Plata', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 40.0208, 'longitude': -92.5077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63552', 'place_name': 'Macon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.7481, 'longitude': -92.4622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63558', 'place_name': 'New Cambria', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.7551, 'longitude': -92.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65247', 'place_name': 'Excello', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Macon', 'locality_code': '121', 'latitude': 39.6455, 'longitude': -92.4757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63645', 'place_name': 'Fredericktown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Madison', 'locality_code': '123', 'latitude': 37.4906, 'longitude': -90.3362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63655', 'place_name': 'Marquand', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Madison', 'locality_code': '123', 'latitude': 37.4274, 'longitude': -90.1741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65013', 'place_name': 'Belle', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Maries', 'locality_code': '125', 'latitude': 38.2711, 'longitude': -91.7303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65443', 'place_name': 'Brinktown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Maries', 'locality_code': '125', 'latitude': 38.1483, 'longitude': -92.1015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65580', 'place_name': 'Vichy', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Maries', 'locality_code': '125', 'latitude': 38.098, 'longitude': -91.7788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65582', 'place_name': 'Vienna', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Maries', 'locality_code': '125', 'latitude': 38.1919, 'longitude': -91.9422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63401', 'place_name': 'Hannibal', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Marion', 'locality_code': '127', 'latitude': 39.7064, 'longitude': -91.3839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63454', 'place_name': 'Maywood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Marion', 'locality_code': '127', 'latitude': 39.9333, 'longitude': -91.6148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63461', 'place_name': 'Palmyra', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Marion', 'locality_code': '127', 'latitude': 39.7913, 'longitude': -91.5368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63463', 'place_name': 'Philadelphia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Marion', 'locality_code': '127', 'latitude': 39.8359, 'longitude': -91.7538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63471', 'place_name': 'Taylor', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Marion', 'locality_code': '127', 'latitude': 39.9145, 'longitude': -91.5278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64661', 'place_name': 'Mercer', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mercer', 'locality_code': '129', 'latitude': 40.5169, 'longitude': -93.5242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64673', 'place_name': 'Princeton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mercer', 'locality_code': '129', 'latitude': 40.3855, 'longitude': -93.5774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65017', 'place_name': 'Brumley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.0709, 'longitude': -92.4747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65026', 'place_name': 'Eldon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.3401, 'longitude': -92.5736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65047', 'place_name': 'Kaiser', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.1637, 'longitude': -92.5799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65064', 'place_name': 'Olean', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.4109, 'longitude': -92.5294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65075', 'place_name': 'Saint Elizabeth', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.2712, 'longitude': -92.2635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65082', 'place_name': 'Tuscumbia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.2181, 'longitude': -92.4461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65083', 'place_name': 'Ulman', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.1505, 'longitude': -92.433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65486', 'place_name': 'Iberia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Miller', 'locality_code': '131', 'latitude': 38.1219, 'longitude': -92.2989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63820', 'place_name': 'Anniston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mississippi', 'locality_code': '133', 'latitude': 36.8259, 'longitude': -89.3279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63823', 'place_name': 'Bertrand', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mississippi', 'locality_code': '133', 'latitude': 36.8927, 'longitude': -89.4483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63834', 'place_name': 'Charleston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mississippi', 'locality_code': '133', 'latitude': 36.9213, 'longitude': -89.3342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63845', 'place_name': 'East Prairie', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mississippi', 'locality_code': '133', 'latitude': 36.7776, 'longitude': -89.3726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63881', 'place_name': 'Wolf Island', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mississippi', 'locality_code': '133', 'latitude': 36.7392, 'longitude': -89.2103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63882', 'place_name': 'Wyatt', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Mississippi', 'locality_code': '133', 'latitude': 36.9092, 'longitude': -89.2226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65018', 'place_name': 'California', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.6224, 'longitude': -92.5456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65025', 'place_name': 'Clarksburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.6432, 'longitude': -92.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65034', 'place_name': 'Fortuna', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.5667, 'longitude': -92.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65042', 'place_name': 'High Point', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.6749, 'longitude': -92.6109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65046', 'place_name': 'Jamestown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.7793, 'longitude': -92.4807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65050', 'place_name': 'Latham', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.5466, 'longitude': -92.6817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65055', 'place_name': 'Mc Girk', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.6749, 'longitude': -92.6109, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '65081', 'place_name': 'Tipton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Moniteau', 'locality_code': '135', 'latitude': 38.6548, 'longitude': -92.7814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63456', 'place_name': 'Monroe City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Monroe', 'locality_code': '137', 'latitude': 39.6546, 'longitude': -91.723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65258', 'place_name': 'Holliday', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Monroe', 'locality_code': '137', 'latitude': 39.4904, 'longitude': -92.1318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65263', 'place_name': 'Madison', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Monroe', 'locality_code': '137', 'latitude': 39.4615, 'longitude': -92.2287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65275', 'place_name': 'Paris', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Monroe', 'locality_code': '137', 'latitude': 39.4932, 'longitude': -92.0113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65282', 'place_name': 'Santa Fe', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Monroe', 'locality_code': '137', 'latitude': 39.3989, 'longitude': -91.8294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65283', 'place_name': 'Stoutsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Monroe', 'locality_code': '137', 'latitude': 39.5594, 'longitude': -91.8297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63333', 'place_name': 'Bellflower', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 39.0012, 'longitude': -91.3489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63350', 'place_name': 'High Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 38.8902, 'longitude': -91.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63351', 'place_name': 'Jonesburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 38.8717, 'longitude': -91.3019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63359', 'place_name': 'Middletown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 39.1055, 'longitude': -91.3873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63361', 'place_name': 'Montgomery City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 38.9839, 'longitude': -91.5085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63363', 'place_name': 'New Florence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 38.9023, 'longitude': -91.4909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63384', 'place_name': 'Wellsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 39.0765, 'longitude': -91.5645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65069', 'place_name': 'Rhineland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Montgomery', 'locality_code': '139', 'latitude': 38.7942, 'longitude': -91.5737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65011', 'place_name': 'Barnett', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.3967, 'longitude': -92.6686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65037', 'place_name': 'Gravois Mills', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.2584, 'longitude': -92.823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65038', 'place_name': 'Laurie', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.1992, 'longitude': -92.8335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65072', 'place_name': 'Rocky Mount', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.2911, 'longitude': -92.7059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65078', 'place_name': 'Stover', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.4414, 'longitude': -92.9947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65084', 'place_name': 'Versailles', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.4365, 'longitude': -92.8258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65329', 'place_name': 'Florence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.6101, 'longitude': -92.9986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65354', 'place_name': 'Syracuse', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Morgan', 'locality_code': '141', 'latitude': 38.6547, 'longitude': -92.8929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63828', 'place_name': 'Canalou', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.7504, 'longitude': -89.6918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63833', 'place_name': 'Catron', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.6876, 'longitude': -89.7706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63848', 'place_name': 'Gideon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.4538, 'longitude': -89.9135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63860', 'place_name': 'Kewanee', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.6726, 'longitude': -89.5639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63862', 'place_name': 'Lilbourn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.5853, 'longitude': -89.6112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63866', 'place_name': 'Marston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.519, 'longitude': -89.6126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63867', 'place_name': 'Matthews', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.7154, 'longitude': -89.6287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63868', 'place_name': 'Morehouse', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.8504, 'longitude': -89.6847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63869', 'place_name': 'New Madrid', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.6073, 'longitude': -89.5366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63870', 'place_name': 'Parma', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.5856, 'longitude': -89.819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63873', 'place_name': 'Portageville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.4279, 'longitude': -89.7002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63874', 'place_name': 'Risco', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.5534, 'longitude': -89.8179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63878', 'place_name': 'Tallapoosa', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'New Madrid', 'locality_code': '143', 'latitude': 36.503, 'longitude': -89.8224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64840', 'place_name': 'Diamond', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 37.006, 'longitude': -94.3204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64842', 'place_name': 'Fairview', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.8254, 'longitude': -94.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64844', 'place_name': 'Granby', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.9066, 'longitude': -94.2643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64850', 'place_name': 'Neosho', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.8706, 'longitude': -94.3862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64853', 'place_name': 'Newtonia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.8767, 'longitude': -94.1855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64858', 'place_name': 'Racine', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.901, 'longitude': -94.5321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64864', 'place_name': 'Saginaw', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 37.024, 'longitude': -94.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64865', 'place_name': 'Seneca', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.8408, 'longitude': -94.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64866', 'place_name': 'Stark City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.8785, 'longitude': -94.1548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64867', 'place_name': 'Stella', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 36.7516, 'longitude': -94.2086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64873', 'place_name': 'Wentworth', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Newton', 'locality_code': '145', 'latitude': 37.0177, 'longitude': -94.0514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64423', 'place_name': 'Barnard', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.1862, 'longitude': -94.8056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64428', 'place_name': 'Burlington Junction', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.4475, 'longitude': -95.063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64431', 'place_name': 'Clearmont', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.5175, 'longitude': -95.0055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64432', 'place_name': 'Clyde', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.2635, 'longitude': -94.6687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64433', 'place_name': 'Conception', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.2428, 'longitude': -94.6869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64434', 'place_name': 'Conception Junction', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.2659, 'longitude': -94.6915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64445', 'place_name': 'Elmo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.5185, 'longitude': -95.1236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64455', 'place_name': 'Graham', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.2012, 'longitude': -95.0121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64457', 'place_name': 'Guilford', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.1746, 'longitude': -94.6951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64461', 'place_name': 'Hopkins', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.5483, 'longitude': -94.8189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64468', 'place_name': 'Maryville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.3434, 'longitude': -94.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64475', 'place_name': 'Parnell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.44, 'longitude': -94.6233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64476', 'place_name': 'Pickering', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.4591, 'longitude': -94.8411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64479', 'place_name': 'Ravenwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.3579, 'longitude': -94.6805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64487', 'place_name': 'Skidmore', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Nodaway', 'locality_code': '147', 'latitude': 40.2896, 'longitude': -95.0792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65606', 'place_name': 'Alton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Oregon', 'locality_code': '149', 'latitude': 36.6929, 'longitude': -91.3971, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '65690', 'place_name': 'Couch', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Oregon', 'locality_code': '149', 'latitude': 36.5853, 'longitude': -91.2724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65692', 'place_name': 'Koshkonong', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Oregon', 'locality_code': '149', 'latitude': 36.6056, 'longitude': -91.6304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65778', 'place_name': 'Myrtle', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Oregon', 'locality_code': '149', 'latitude': 36.5217, 'longitude': -91.2706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65791', 'place_name': 'Thayer', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Oregon', 'locality_code': '149', 'latitude': 36.5327, 'longitude': -91.5418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65001', 'place_name': 'Argyle', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.2986, 'longitude': -92.0155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65016', 'place_name': 'Bonnots Mill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.5533, 'longitude': -91.9293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65024', 'place_name': 'Chamois', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.6527, 'longitude': -91.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65035', 'place_name': 'Freeburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.3551, 'longitude': -91.9276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65048', 'place_name': 'Koeltztown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.3615, 'longitude': -92.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65051', 'place_name': 'Linn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.4739, 'longitude': -91.8195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65054', 'place_name': 'Loose Creek', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.4717, 'longitude': -91.9591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65058', 'place_name': 'Meta', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.25, 'longitude': -92.1358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65085', 'place_name': 'Westphalia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Osage', 'locality_code': '151', 'latitude': 38.427, 'longitude': -92.0392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65609', 'place_name': 'Bakersfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.5332, 'longitude': -92.1507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65618', 'place_name': 'Brixey', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.759, 'longitude': -92.4026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65637', 'place_name': 'Dora', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.756, 'longitude': -92.2378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65655', 'place_name': 'Gainesville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.5901, 'longitude': -92.4162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65666', 'place_name': 'Hardenville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.5892, 'longitude': -92.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65676', 'place_name': 'Isabella', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.5749, 'longitude': -92.6053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65715', 'place_name': 'Noble', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.7441, 'longitude': -92.5769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65729', 'place_name': 'Pontiac', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.5156, 'longitude': -92.6038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65741', 'place_name': 'Rockbridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.7895, 'longitude': -92.4091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65760', 'place_name': 'Tecumseh', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.5875, 'longitude': -92.2598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65761', 'place_name': 'Theodosia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.583, 'longitude': -92.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65762', 'place_name': 'Thornfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.6875, 'longitude': -92.6534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65766', 'place_name': 'Udall', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.544, 'longitude': -92.2588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65773', 'place_name': 'Wasola', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.7573, 'longitude': -92.5093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65784', 'place_name': 'Zanoni', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ozark', 'locality_code': '153', 'latitude': 36.6862, 'longitude': -92.3318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63826', 'place_name': 'Braggadocio', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.1753, 'longitude': -89.8295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63827', 'place_name': 'Bragg City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.2732, 'longitude': -89.8736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63830', 'place_name': 'Caruthersville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.1802, 'longitude': -89.6683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63839', 'place_name': 'Cooter', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.0476, 'longitude': -89.8091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63840', 'place_name': 'Deering', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.1909, 'longitude': -89.8829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63849', 'place_name': 'Gobler', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.159, 'longitude': -89.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63851', 'place_name': 'Hayti', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.2337, 'longitude': -89.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63853', 'place_name': 'Holland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.0559, 'longitude': -89.8709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63877', 'place_name': 'Steele', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.0915, 'longitude': -89.8346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63879', 'place_name': 'Wardell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pemiscot', 'locality_code': '155', 'latitude': 36.3478, 'longitude': -89.8181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63732', 'place_name': 'Altenburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Perry', 'locality_code': '157', 'latitude': 37.6279, 'longitude': -89.5745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63737', 'place_name': 'Brazeau', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Perry', 'locality_code': '157', 'latitude': 37.6633, 'longitude': -89.6529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63746', 'place_name': 'Farrar', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Perry', 'locality_code': '157', 'latitude': 37.7078, 'longitude': -89.6948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63748', 'place_name': 'Frohna', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Perry', 'locality_code': '157', 'latitude': 37.6686, 'longitude': -89.6619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63775', 'place_name': 'Perryville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Perry', 'locality_code': '157', 'latitude': 37.7174, 'longitude': -89.8737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63776', 'place_name': 'Mc Bride', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Perry', 'locality_code': '157', 'latitude': 37.7348, 'longitude': -89.8116, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63783', 'place_name': 'Uniontown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Perry', 'locality_code': '157', 'latitude': 37.6073, 'longitude': -89.6798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65301', 'place_name': 'Sedalia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.6961, 'longitude': -93.2323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65302', 'place_name': 'Sedalia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.7045, 'longitude': -93.2283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65332', 'place_name': 'Green Ridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.619, 'longitude': -93.4374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65333', 'place_name': 'Houstonia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.9106, 'longitude': -93.3325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65334', 'place_name': 'Hughesville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.8494, 'longitude': -93.2159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65337', 'place_name': 'La Monte', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.7753, 'longitude': -93.4313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65345', 'place_name': 'Mora', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.5207, 'longitude': -93.2272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65350', 'place_name': 'Smithton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pettis', 'locality_code': '159', 'latitude': 38.66, 'longitude': -93.1088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65401', 'place_name': 'Rolla', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.9485, 'longitude': -91.7603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65402', 'place_name': 'Rolla', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.9514, 'longitude': -91.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65409', 'place_name': 'Rolla', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.9514, 'longitude': -91.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65436', 'place_name': 'Beulah', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.6158, 'longitude': -91.9064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65461', 'place_name': 'Duke', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.6603, 'longitude': -92.0107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65462', 'place_name': 'Edgar Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.7365, 'longitude': -91.8906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65529', 'place_name': 'Jerome', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.9262, 'longitude': -91.9777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65550', 'place_name': 'Newburg', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 37.9008, 'longitude': -91.8807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65559', 'place_name': 'Saint James', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Phelps', 'locality_code': '161', 'latitude': 38.0056, 'longitude': -91.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63330', 'place_name': 'Annada', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.2558, 'longitude': -90.8224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63334', 'place_name': 'Bowling Green', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.3346, 'longitude': -91.1962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63336', 'place_name': 'Clarksville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.3465, 'longitude': -90.9362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63339', 'place_name': 'Curryville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.3257, 'longitude': -91.3493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63344', 'place_name': 'Eolia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.2431, 'longitude': -91.0093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63353', 'place_name': 'Louisiana', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.4336, 'longitude': -91.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63433', 'place_name': 'Ashburn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.561, 'longitude': -91.1844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63441', 'place_name': 'Frankford', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pike', 'locality_code': '163', 'latitude': 39.4892, 'longitude': -91.3031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64018', 'place_name': 'Camden Point', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.4515, 'longitude': -94.7444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64028', 'place_name': 'Farley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.2839, 'longitude': -94.8302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64079', 'place_name': 'Platte City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.3602, 'longitude': -94.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64092', 'place_name': 'Waldron', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.2289, 'longitude': -94.8057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64098', 'place_name': 'Weston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.4453, 'longitude': -94.9145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64150', 'place_name': 'Riverside', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.1776, 'longitude': -94.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64151', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.2127, 'longitude': -94.6383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64152', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.2176, 'longitude': -94.7238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64153', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.2627, 'longitude': -94.697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64154', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.2547, 'longitude': -94.6354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64163', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.3402, 'longitude': -94.6908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64164', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.3426, 'longitude': -94.6446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64168', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.3432, 'longitude': -94.8516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64190', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.3432, 'longitude': -94.8516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64195', 'place_name': 'Kansas City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.3432, 'longitude': -94.8516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64439', 'place_name': 'Dearborn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.5172, 'longitude': -94.7664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64444', 'place_name': 'Edgerton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Platte', 'locality_code': '165', 'latitude': 39.4742, 'longitude': -94.6352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65601', 'place_name': 'Aldrich', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.5057, 'longitude': -93.5576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65613', 'place_name': 'Bolivar', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.6085, 'longitude': -93.4126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65617', 'place_name': 'Brighton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.4728, 'longitude': -93.3603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65640', 'place_name': 'Dunnegan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.7031, 'longitude': -93.5216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65645', 'place_name': 'Eudora', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.4767, 'longitude': -93.5397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65649', 'place_name': 'Fair Play', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.6335, 'longitude': -93.6064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65650', 'place_name': 'Flemington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.7803, 'longitude': -93.4471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65663', 'place_name': 'Half Way', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.6018, 'longitude': -93.242, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '65674', 'place_name': 'Humansville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.7923, 'longitude': -93.5795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65710', 'place_name': 'Morrisville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.4686, 'longitude': -93.4275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65725', 'place_name': 'Pleasant Hope', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.4615, 'longitude': -93.2617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65727', 'place_name': 'Polk', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Polk', 'locality_code': '167', 'latitude': 37.7292, 'longitude': -93.2994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65452', 'place_name': 'Crocker', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.9446, 'longitude': -92.27, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65457', 'place_name': 'Devils Elbow', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.8512, 'longitude': -92.0569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65459', 'place_name': 'Dixon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.9848, 'longitude': -92.0897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65473', 'place_name': 'Fort Leonard Wood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.7677, 'longitude': -92.112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65534', 'place_name': 'Laquey', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.6953, 'longitude': -92.2808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65556', 'place_name': 'Richland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.8528, 'longitude': -92.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65583', 'place_name': 'Waynesville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.7676, 'longitude': -92.2105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65584', 'place_name': 'Saint Robert', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Pulaski', 'locality_code': '169', 'latitude': 37.8283, 'longitude': -92.131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63551', 'place_name': 'Livonia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Putnam', 'locality_code': '171', 'latitude': 40.5112, 'longitude': -92.7241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63565', 'place_name': 'Unionville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Putnam', 'locality_code': '171', 'latitude': 40.4815, 'longitude': -92.9951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63567', 'place_name': 'Worthington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Putnam', 'locality_code': '171', 'latitude': 40.4084, 'longitude': -92.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64655', 'place_name': 'Lucerne', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Putnam', 'locality_code': '171', 'latitude': 40.4382, 'longitude': -93.2867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64672', 'place_name': 'Powersville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Putnam', 'locality_code': '171', 'latitude': 40.5492, 'longitude': -93.3002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63436', 'place_name': 'Center', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ralls', 'locality_code': '173', 'latitude': 39.5154, 'longitude': -91.5398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63459', 'place_name': 'New London', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ralls', 'locality_code': '173', 'latitude': 39.5917, 'longitude': -91.396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63462', 'place_name': 'Perry', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ralls', 'locality_code': '173', 'latitude': 39.4207, 'longitude': -91.6641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63467', 'place_name': 'Saverton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ralls', 'locality_code': '173', 'latitude': 39.65, 'longitude': -91.2705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65239', 'place_name': 'Cairo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.5114, 'longitude': -92.44, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65243', 'place_name': 'Clark', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.2811, 'longitude': -92.3427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65244', 'place_name': 'Clifton Hill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.426, 'longitude': -92.6677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65257', 'place_name': 'Higbee', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.3055, 'longitude': -92.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65259', 'place_name': 'Huntsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.4354, 'longitude': -92.553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65260', 'place_name': 'Jacksonville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.5791, 'longitude': -92.4315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65270', 'place_name': 'Moberly', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.4202, 'longitude': -92.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65278', 'place_name': 'Renick', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Randolph', 'locality_code': '175', 'latitude': 39.3414, 'longitude': -92.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64017', 'place_name': 'Camden', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ray', 'locality_code': '177', 'latitude': 39.2048, 'longitude': -94.0259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64035', 'place_name': 'Hardin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ray', 'locality_code': '177', 'latitude': 39.3504, 'longitude': -93.8409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64036', 'place_name': 'Henrietta', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ray', 'locality_code': '177', 'latitude': 39.2367, 'longitude': -93.9369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64062', 'place_name': 'Lawson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ray', 'locality_code': '177', 'latitude': 39.4401, 'longitude': -94.1966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64077', 'place_name': 'Orrick', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ray', 'locality_code': '177', 'latitude': 39.2116, 'longitude': -94.1239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64084', 'place_name': 'Rayville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ray', 'locality_code': '177', 'latitude': 39.3853, 'longitude': -94.0284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64085', 'place_name': 'Richmond', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ray', 'locality_code': '177', 'latitude': 39.2793, 'longitude': -93.9792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63625', 'place_name': 'Black', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Reynolds', 'locality_code': '179', 'latitude': 37.5473, 'longitude': -90.9917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63629', 'place_name': 'Bunker', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Reynolds', 'locality_code': '179', 'latitude': 37.4772, 'longitude': -91.1927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63633', 'place_name': 'Centerville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Reynolds', 'locality_code': '179', 'latitude': 37.4285, 'longitude': -90.9757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63638', 'place_name': 'Ellington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Reynolds', 'locality_code': '179', 'latitude': 37.2398, 'longitude': -90.9589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63654', 'place_name': 'Lesterville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Reynolds', 'locality_code': '179', 'latitude': 37.482, 'longitude': -90.8425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63665', 'place_name': 'Redford', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Reynolds', 'locality_code': '179', 'latitude': 37.32, 'longitude': -90.8985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63666', 'place_name': 'Reynolds', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Reynolds', 'locality_code': '179', 'latitude': 37.4009, 'longitude': -91.0735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63931', 'place_name': 'Briar', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ripley', 'locality_code': '181', 'latitude': 36.661, 'longitude': -90.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63935', 'place_name': 'Doniphan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ripley', 'locality_code': '181', 'latitude': 36.6501, 'longitude': -90.8106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63939', 'place_name': 'Fairdealing', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ripley', 'locality_code': '181', 'latitude': 36.6704, 'longitude': -90.6335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63942', 'place_name': 'Gatewood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ripley', 'locality_code': '181', 'latitude': 36.5626, 'longitude': -91.0703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63953', 'place_name': 'Naylor', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ripley', 'locality_code': '181', 'latitude': 36.5843, 'longitude': -90.6124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63955', 'place_name': 'Oxly', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ripley', 'locality_code': '181', 'latitude': 36.5874, 'longitude': -90.692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63301', 'place_name': 'Saint Charles', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.8014, 'longitude': -90.5065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63302', 'place_name': 'Saint Charles', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7839, 'longitude': -90.4812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63303', 'place_name': 'Saint Charles', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7622, 'longitude': -90.5471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63304', 'place_name': 'Saint Charles', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7378, 'longitude': -90.6234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63332', 'place_name': 'Augusta', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.5728, 'longitude': -90.8815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63338', 'place_name': 'Cottleville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7462, 'longitude': -90.654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63341', 'place_name': 'Defiance', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.6616, 'longitude': -90.8302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63346', 'place_name': 'Flinthill', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7509, 'longitude': -90.5368, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63348', 'place_name': 'Foristell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7626, 'longitude': -90.9343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63365', 'place_name': 'New Melle', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7163, 'longitude': -90.8751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63366', 'place_name': 'O Fallon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.8239, 'longitude': -90.7427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63367', 'place_name': 'Lake Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7936, 'longitude': -90.7854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63368', 'place_name': 'O Fallon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7513, 'longitude': -90.7296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63373', 'place_name': 'Portage Des Sioux', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.9259, 'longitude': -90.3863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63376', 'place_name': 'Saint Peters', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.7802, 'longitude': -90.6228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63385', 'place_name': 'Wentzville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.802, 'longitude': -90.8534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63386', 'place_name': 'West Alton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saint Charles', 'locality_code': '183', 'latitude': 38.8758, 'longitude': -90.2384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64724', 'place_name': 'Appleton City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Clair', 'locality_code': '185', 'latitude': 38.1848, 'longitude': -94.0229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64738', 'place_name': 'Collins', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Clair', 'locality_code': '185', 'latitude': 37.881, 'longitude': -93.6608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64763', 'place_name': 'Lowry City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Clair', 'locality_code': '185', 'latitude': 38.1404, 'longitude': -93.7114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64776', 'place_name': 'Osceola', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Clair', 'locality_code': '185', 'latitude': 38.0286, 'longitude': -93.7536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64781', 'place_name': 'Roscoe', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Clair', 'locality_code': '185', 'latitude': 37.9728, 'longitude': -93.8122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63627', 'place_name': 'Bloomsdale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ste. Genevieve', 'locality_code': '186', 'latitude': 38.0451, 'longitude': -90.2805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63670', 'place_name': 'Sainte Genevieve', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ste. Genevieve', 'locality_code': '186', 'latitude': 37.8655, 'longitude': -90.1752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63673', 'place_name': 'Saint Mary', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Ste. Genevieve', 'locality_code': '186', 'latitude': 37.8325, 'longitude': -89.977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63036', 'place_name': 'French Village', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.9961, 'longitude': -90.4005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63087', 'place_name': 'Valles Mines', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.9998, 'longitude': -90.4407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63601', 'place_name': 'Park Hills', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.8498, 'longitude': -90.4885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63624', 'place_name': 'Bismarck', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.7539, 'longitude': -90.5984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63626', 'place_name': 'Blackwell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 38.0544, 'longitude': -90.6279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63628', 'place_name': 'Bonne Terre', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.9231, 'longitude': -90.5554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63637', 'place_name': 'Doe Run', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.7348, 'longitude': -90.4968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63640', 'place_name': 'Farmington', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.7773, 'longitude': -90.4094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63651', 'place_name': 'Knob Lick', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.6754, 'longitude': -90.3677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63653', 'place_name': 'Leadwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Francois', 'locality_code': '187', 'latitude': 37.8577, 'longitude': -90.5879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63005', 'place_name': 'Chesterfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6318, 'longitude': -90.6142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63006', 'place_name': 'Chesterfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6631, 'longitude': -90.5771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63011', 'place_name': 'Ballwin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6091, 'longitude': -90.5598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63017', 'place_name': 'Chesterfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6491, 'longitude': -90.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63021', 'place_name': 'Ballwin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.577, 'longitude': -90.5255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63022', 'place_name': 'Ballwin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5951, 'longitude': -90.5462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63024', 'place_name': 'Ballwin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5951, 'longitude': -90.5462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63025', 'place_name': 'Eureka', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5128, 'longitude': -90.6306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63026', 'place_name': 'Fenton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5015, 'longitude': -90.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63031', 'place_name': 'Florissant', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.8069, 'longitude': -90.3401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63032', 'place_name': 'Florissant', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6383, 'longitude': -90.4271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63033', 'place_name': 'Florissant', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7947, 'longitude': -90.2831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63034', 'place_name': 'Florissant', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.8338, 'longitude': -90.2936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63038', 'place_name': 'Glencoe', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5878, 'longitude': -90.6639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63040', 'place_name': 'Grover', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5667, 'longitude': -90.631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63042', 'place_name': 'Hazelwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7809, 'longitude': -90.3669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63043', 'place_name': 'Maryland Heights', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7229, 'longitude': -90.4474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63044', 'place_name': 'Bridgeton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7506, 'longitude': -90.4161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63045', 'place_name': 'Earth City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7689, 'longitude': -90.4662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63074', 'place_name': 'Saint Ann', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7259, 'longitude': -90.3864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63088', 'place_name': 'Valley Park', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5576, 'longitude': -90.4924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63099', 'place_name': 'Fenton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6383, 'longitude': -90.4271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63105', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6459, 'longitude': -90.3264, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63114', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7023, 'longitude': -90.3644, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63117', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6295, 'longitude': -90.3342, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63119', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5893, 'longitude': -90.3481, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63121', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7071, 'longitude': -90.3055, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63122', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5781, 'longitude': -90.4256, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63123', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5476, 'longitude': -90.3241, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63124', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6372, 'longitude': -90.3776, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63125', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5222, 'longitude': -90.3021, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63126', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5495, 'longitude': -90.3811, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63127', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.5355, 'longitude': -90.407, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63128', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.4915, 'longitude': -90.3772, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63129', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.4566, 'longitude': -90.3282, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63130', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6669, 'longitude': -90.3225, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63131', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6171, 'longitude': -90.4504, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63132', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6746, 'longitude': -90.3747, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63133', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6779, 'longitude': -90.3033, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63134', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7435, 'longitude': -90.341, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63135', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7497, 'longitude': -90.3012, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63136', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7196, 'longitude': -90.27, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63137', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7468, 'longitude': -90.2131, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63138', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.8033, 'longitude': -90.2065, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63140', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7375, 'longitude': -90.3265, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63141', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6565, 'longitude': -90.4542, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63143', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6111, 'longitude': -90.3225, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63144', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6182, 'longitude': -90.3489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63145', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6383, 'longitude': -90.4271, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63146', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.7033, 'longitude': -90.4618, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63151', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6383, 'longitude': -90.4271, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63167', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis', 'locality_code': '189', 'latitude': 38.6383, 'longitude': -90.4271, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '65320', 'place_name': 'Arrow Rock', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.0694, 'longitude': -92.9487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65321', 'place_name': 'Blackburn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.0988, 'longitude': -93.4281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65330', 'place_name': 'Gilliam', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.2447, 'longitude': -92.9932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65339', 'place_name': 'Malta Bend', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.1481, 'longitude': -93.3776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65340', 'place_name': 'Marshall', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.1614, 'longitude': -93.2444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65344', 'place_name': 'Miami', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.2821, 'longitude': -93.1968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65347', 'place_name': 'Nelson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.0104, 'longitude': -93.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65349', 'place_name': 'Slater', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 39.2163, 'longitude': -93.0547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65351', 'place_name': 'Sweet Springs', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Saline', 'locality_code': '195', 'latitude': 38.966, 'longitude': -93.4247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63535', 'place_name': 'Coatsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Schuyler', 'locality_code': '197', 'latitude': 40.5665, 'longitude': -92.6388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63536', 'place_name': 'Downing', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Schuyler', 'locality_code': '197', 'latitude': 40.4875, 'longitude': -92.3694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63541', 'place_name': 'Glenwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Schuyler', 'locality_code': '197', 'latitude': 40.5149, 'longitude': -92.5886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63548', 'place_name': 'Lancaster', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Schuyler', 'locality_code': '197', 'latitude': 40.5253, 'longitude': -92.5264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63561', 'place_name': 'Queen City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Schuyler', 'locality_code': '197', 'latitude': 40.4152, 'longitude': -92.5663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63432', 'place_name': 'Arbela', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scotland', 'locality_code': '199', 'latitude': 40.4863, 'longitude': -92.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63442', 'place_name': 'Granger', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scotland', 'locality_code': '199', 'latitude': 40.4533, 'longitude': -92.1474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63543', 'place_name': 'Gorin', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scotland', 'locality_code': '199', 'latitude': 40.3622, 'longitude': -92.014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63555', 'place_name': 'Memphis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scotland', 'locality_code': '199', 'latitude': 40.4619, 'longitude': -92.1851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63563', 'place_name': 'Rutledge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scotland', 'locality_code': '199', 'latitude': 40.329, 'longitude': -92.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63736', 'place_name': 'Benton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.0697, 'longitude': -89.5664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63740', 'place_name': 'Chaffee', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.1726, 'longitude': -89.6457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63742', 'place_name': 'Commerce', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.157, 'longitude': -89.4484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63758', 'place_name': 'Kelso', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.1858, 'longitude': -89.5575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63767', 'place_name': 'Morley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.0411, 'longitude': -89.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63771', 'place_name': 'Oran', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.087, 'longitude': -89.6734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63774', 'place_name': 'Perkins', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.0948, 'longitude': -89.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63780', 'place_name': 'Scott City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.2077, 'longitude': -89.5181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63784', 'place_name': 'Vanduser', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 36.9912, 'longitude': -89.6885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63801', 'place_name': 'Sikeston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 36.8911, 'longitude': -89.582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63824', 'place_name': 'Blodgett', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Scott', 'locality_code': '201', 'latitude': 37.0042, 'longitude': -89.5266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65438', 'place_name': 'Birch Tree', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shannon', 'locality_code': '203', 'latitude': 36.9476, 'longitude': -91.5008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65466', 'place_name': 'Eminence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shannon', 'locality_code': '203', 'latitude': 37.1626, 'longitude': -91.4519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65546', 'place_name': 'Montier', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shannon', 'locality_code': '203', 'latitude': 36.987, 'longitude': -91.5754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65588', 'place_name': 'Winona', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shannon', 'locality_code': '203', 'latitude': 37.0169, 'longitude': -91.3121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63434', 'place_name': 'Bethel', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.8922, 'longitude': -92.0316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63437', 'place_name': 'Clarence', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.7366, 'longitude': -92.253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63439', 'place_name': 'Emden', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.8019, 'longitude': -91.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63443', 'place_name': 'Hunnewell', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.7018, 'longitude': -91.8832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63450', 'place_name': 'Lentner', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.7123, 'longitude': -92.1489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63451', 'place_name': 'Leonard', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.9076, 'longitude': -92.1947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63468', 'place_name': 'Shelbina', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.6947, 'longitude': -92.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63469', 'place_name': 'Shelbyville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Shelby', 'locality_code': '205', 'latitude': 39.8108, 'longitude': -92.0498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63730', 'place_name': 'Advance', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 37.0922, 'longitude': -89.9106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63735', 'place_name': 'Bell City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 37.0116, 'longitude': -89.7984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63738', 'place_name': 'Brownwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 37.0828, 'longitude': -89.9523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63822', 'place_name': 'Bernie', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 36.6727, 'longitude': -89.9878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63825', 'place_name': 'Bloomfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 36.8989, 'longitude': -89.9456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63841', 'place_name': 'Dexter', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 36.7885, 'longitude': -89.9639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63846', 'place_name': 'Essex', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 36.8109, 'longitude': -89.8366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63850', 'place_name': 'Grayridge', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 36.8283, 'longitude': -89.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63936', 'place_name': 'Dudley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 36.811, 'longitude': -90.121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63960', 'place_name': 'Puxico', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stoddard', 'locality_code': '207', 'latitude': 36.9422, 'longitude': -90.1623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65611', 'place_name': 'Blue Eye', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.5493, 'longitude': -93.3388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65624', 'place_name': 'Cape Fair', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.7311, 'longitude': -93.5674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65633', 'place_name': 'Crane', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.9258, 'longitude': -93.5303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65656', 'place_name': 'Galena', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.8198, 'longitude': -93.4811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65675', 'place_name': 'Hurley', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.9305, 'longitude': -93.4965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65681', 'place_name': 'Lampe', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.5767, 'longitude': -93.4516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65686', 'place_name': 'Kimberling City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.6393, 'longitude': -93.4372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65728', 'place_name': 'Ponce De Leon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.8759, 'longitude': -93.3516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65737', 'place_name': 'Reeds Spring', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Stone', 'locality_code': '209', 'latitude': 36.6907, 'longitude': -93.3447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63544', 'place_name': 'Green Castle', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.2703, 'longitude': -92.878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63545', 'place_name': 'Green City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.2601, 'longitude': -92.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63556', 'place_name': 'Milan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.1844, 'longitude': -93.1361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63560', 'place_name': 'Pollock', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.3385, 'longitude': -93.1115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63566', 'place_name': 'Winigan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.0371, 'longitude': -92.9301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64645', 'place_name': 'Harris', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.3075, 'longitude': -93.3501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64646', 'place_name': 'Humphreys', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.1144, 'longitude': -93.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64667', 'place_name': 'Newtown', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Sullivan', 'locality_code': '211', 'latitude': 40.3612, 'longitude': -93.3073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65614', 'place_name': 'Bradleyville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.7659, 'longitude': -92.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65615', 'place_name': 'Branson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.661, 'longitude': -93.2358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65616', 'place_name': 'Branson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.669, 'longitude': -93.2481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65627', 'place_name': 'Cedarcreek', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.571, 'longitude': -93.0172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65653', 'place_name': 'Forsyth', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.6955, 'longitude': -93.115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65672', 'place_name': 'Hollister', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.6107, 'longitude': -93.2286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65673', 'place_name': 'Hollister', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.6179, 'longitude': -93.2162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65679', 'place_name': 'Kirbyville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.5792, 'longitude': -93.1263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65680', 'place_name': 'Kissee Mills', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.6704, 'longitude': -93.0377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65726', 'place_name': 'Point Lookout', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.6165, 'longitude': -93.2418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65731', 'place_name': 'Powersite', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.6578, 'longitude': -93.1243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65733', 'place_name': 'Protem', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.5286, 'longitude': -92.8465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65739', 'place_name': 'Ridgedale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.5247, 'longitude': -93.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65740', 'place_name': 'Rockaway Beach', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.7137, 'longitude': -93.1715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65744', 'place_name': 'Rueter', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.6314, 'longitude': -92.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65759', 'place_name': 'Taneyville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.7405, 'longitude': -93.028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65771', 'place_name': 'Walnut Shade', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Taney', 'locality_code': '213', 'latitude': 36.7704, 'longitude': -93.2148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65444', 'place_name': 'Bucyrus', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.3972, 'longitude': -92.0465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65464', 'place_name': 'Elk Creek', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.1878, 'longitude': -91.9134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65468', 'place_name': 'Eunice', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.248, 'longitude': -91.7834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65479', 'place_name': 'Hartshorn', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.2843, 'longitude': -91.6834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65483', 'place_name': 'Houston', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.3218, 'longitude': -91.953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65484', 'place_name': 'Huggins', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.3538, 'longitude': -92.2153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65542', 'place_name': 'Licking', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.5091, 'longitude': -91.8556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65552', 'place_name': 'Plato', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.5122, 'longitude': -92.1709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65555', 'place_name': 'Raymondville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.3569, 'longitude': -91.8131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65557', 'place_name': 'Roby', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.5156, 'longitude': -92.139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65564', 'place_name': 'Solo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.2428, 'longitude': -91.9624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65570', 'place_name': 'Success', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.4626, 'longitude': -92.0909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65571', 'place_name': 'Summersville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.1484, 'longitude': -91.6828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65589', 'place_name': 'Yukon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.2311, 'longitude': -91.8244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65689', 'place_name': 'Cabool', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Texas', 'locality_code': '215', 'latitude': 37.1314, 'longitude': -92.1144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64728', 'place_name': 'Bronaugh', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.69, 'longitude': -94.486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64741', 'place_name': 'Deerfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.8197, 'longitude': -94.5608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64750', 'place_name': 'Harwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.953, 'longitude': -94.1402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64765', 'place_name': 'Metz', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.9975, 'longitude': -94.4433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64767', 'place_name': 'Milo', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.7446, 'longitude': -94.3046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64771', 'place_name': 'Moundville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.7476, 'longitude': -94.4496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64772', 'place_name': 'Nevada', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.8409, 'longitude': -94.3571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64778', 'place_name': 'Richards', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.9061, 'longitude': -94.5592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64783', 'place_name': 'Schell City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 38.0094, 'longitude': -94.1579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64784', 'place_name': 'Sheldon', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.684, 'longitude': -94.2548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64790', 'place_name': 'Walker', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Vernon', 'locality_code': '217', 'latitude': 37.893, 'longitude': -94.2293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63342', 'place_name': 'Dutzow', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Warren', 'locality_code': '219', 'latitude': 38.606, 'longitude': -90.9962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63357', 'place_name': 'Marthasville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Warren', 'locality_code': '219', 'latitude': 38.6512, 'longitude': -91.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63378', 'place_name': 'Treloar', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Warren', 'locality_code': '219', 'latitude': 38.6445, 'longitude': -91.1879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63380', 'place_name': 'Truesdale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Warren', 'locality_code': '219', 'latitude': 38.8117, 'longitude': -91.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63383', 'place_name': 'Warrenton', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Warren', 'locality_code': '219', 'latitude': 38.805, 'longitude': -91.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63390', 'place_name': 'Wright City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Warren', 'locality_code': '219', 'latitude': 38.8097, 'longitude': -91.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63071', 'place_name': 'Richwoods', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 38.1496, 'longitude': -90.831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63622', 'place_name': 'Belgrade', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 37.7889, 'longitude': -90.8613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63630', 'place_name': 'Cadet', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 38.0125, 'longitude': -90.7439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63631', 'place_name': 'Caledonia', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 37.7639, 'longitude': -90.7409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63648', 'place_name': 'Irondale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 37.8296, 'longitude': -90.6984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63660', 'place_name': 'Mineral Point', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 37.9156, 'longitude': -90.7193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63664', 'place_name': 'Potosi', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 37.9549, 'longitude': -90.8415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63674', 'place_name': 'Tiff', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Washington', 'locality_code': '221', 'latitude': 38.0192, 'longitude': -90.6529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63632', 'place_name': 'Cascade', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.2995, 'longitude': -90.2693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63763', 'place_name': 'Mc Gee', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.1196, 'longitude': -90.445, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '63934', 'place_name': 'Clubb', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.2145, 'longitude': -90.3457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63944', 'place_name': 'Greenville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.1108, 'longitude': -90.4514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63950', 'place_name': 'Lodi', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.1196, 'longitude': -90.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63951', 'place_name': 'Lowndes', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.1343, 'longitude': -90.2544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63952', 'place_name': 'Mill Spring', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.0675, 'longitude': -90.6746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63956', 'place_name': 'Patterson', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.1884, 'longitude': -90.5507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63957', 'place_name': 'Piedmont', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.1573, 'longitude': -90.699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63964', 'place_name': 'Silva', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 37.2119, 'longitude': -90.4375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63966', 'place_name': 'Wappapello', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 36.9356, 'longitude': -90.2709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63967', 'place_name': 'Williamsville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wayne', 'locality_code': '223', 'latitude': 36.9638, 'longitude': -90.4879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65636', 'place_name': 'Diggins', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Webster', 'locality_code': '225', 'latitude': 37.1726, 'longitude': -92.8543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65644', 'place_name': 'Elkland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Webster', 'locality_code': '225', 'latitude': 37.4336, 'longitude': -93.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65652', 'place_name': 'Fordland', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Webster', 'locality_code': '225', 'latitude': 37.1447, 'longitude': -92.9111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65706', 'place_name': 'Marshfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Webster', 'locality_code': '225', 'latitude': 37.3312, 'longitude': -92.925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65713', 'place_name': 'Niangua', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Webster', 'locality_code': '225', 'latitude': 37.3985, 'longitude': -92.7763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65742', 'place_name': 'Rogersville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Webster', 'locality_code': '225', 'latitude': 37.131, 'longitude': -93.0964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65746', 'place_name': 'Seymour', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Webster', 'locality_code': '225', 'latitude': 37.1667, 'longitude': -92.7857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64420', 'place_name': 'Allendale', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Worth', 'locality_code': '227', 'latitude': 40.4855, 'longitude': -94.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64441', 'place_name': 'Denver', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Worth', 'locality_code': '227', 'latitude': 40.4181, 'longitude': -94.3066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64456', 'place_name': 'Grant City', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Worth', 'locality_code': '227', 'latitude': 40.4924, 'longitude': -94.3979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64486', 'place_name': 'Sheridan', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Worth', 'locality_code': '227', 'latitude': 40.4928, 'longitude': -94.5701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '64499', 'place_name': 'Worth', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Worth', 'locality_code': '227', 'latitude': 40.3939, 'longitude': -94.4398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65660', 'place_name': 'Graff', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wright', 'locality_code': '229', 'latitude': 37.3262, 'longitude': -92.2647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65662', 'place_name': 'Grovespring', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wright', 'locality_code': '229', 'latitude': 37.4947, 'longitude': -92.6001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65667', 'place_name': 'Hartville', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wright', 'locality_code': '229', 'latitude': 37.2735, 'longitude': -92.5181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65702', 'place_name': 'Macomb', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wright', 'locality_code': '229', 'latitude': 37.1049, 'longitude': -92.4821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65704', 'place_name': 'Mansfield', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wright', 'locality_code': '229', 'latitude': 37.1273, 'longitude': -92.5936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65711', 'place_name': 'Mountain Grove', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wright', 'locality_code': '229', 'latitude': 37.1626, 'longitude': -92.2839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '65717', 'place_name': 'Norwood', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'Wright', 'locality_code': '229', 'latitude': 37.0687, 'longitude': -92.4082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63101', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6346, 'longitude': -90.1913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63102', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6352, 'longitude': -90.1864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63103', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6332, 'longitude': -90.2164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63104', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6128, 'longitude': -90.2185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63106', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6442, 'longitude': -90.2082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63107', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6645, 'longitude': -90.2125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63108', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6445, 'longitude': -90.2544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63109', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.5855, 'longitude': -90.2929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63110', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6185, 'longitude': -90.2564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63111', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.5633, 'longitude': -90.2495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63112', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6616, 'longitude': -90.2819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63113', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.659, 'longitude': -90.2496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63115', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6756, 'longitude': -90.2385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63116', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.5814, 'longitude': -90.2625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63118', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.5943, 'longitude': -90.2309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63120', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6909, 'longitude': -90.2595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63139', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6108, 'longitude': -90.292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63147', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.7139, 'longitude': -90.2375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63150', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6273, 'longitude': -90.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63155', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6273, 'longitude': -90.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63156', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63157', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63158', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63160', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63163', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63164', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63166', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63169', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6273, 'longitude': -90.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63171', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63177', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63178', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63179', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63180', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6273, 'longitude': -90.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63182', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6273, 'longitude': -90.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63188', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6273, 'longitude': -90.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63195', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63197', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6273, 'longitude': -90.1979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '63199', 'place_name': 'Saint Louis', 'state': 'Missouri', 'state_ab': 'MO', 'county': 'St. Louis (city)', 'locality_code': '510', 'latitude': 38.6531, 'longitude': -90.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39120', 'place_name': 'Natchez', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Adams', 'locality_code': '1', 'latitude': 31.5492, 'longitude': -91.3642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39121', 'place_name': 'Natchez', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Adams', 'locality_code': '1', 'latitude': 31.4706, 'longitude': -91.4044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39122', 'place_name': 'Natchez', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Adams', 'locality_code': '1', 'latitude': 31.5604, 'longitude': -91.4032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39165', 'place_name': 'Sibley', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Adams', 'locality_code': '1', 'latitude': 31.4706, 'longitude': -91.4044, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39190', 'place_name': 'Washington', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Adams', 'locality_code': '1', 'latitude': 31.5788, 'longitude': -91.2993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38834', 'place_name': 'Corinth', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Alcorn', 'locality_code': '3', 'latitude': 34.8759, 'longitude': -88.5916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38835', 'place_name': 'Corinth', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Alcorn', 'locality_code': '3', 'latitude': 34.9205, 'longitude': -88.5218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38846', 'place_name': 'Glen', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Alcorn', 'locality_code': '3', 'latitude': 34.878, 'longitude': -88.4359, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '38865', 'place_name': 'Rienzi', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Alcorn', 'locality_code': '3', 'latitude': 34.7968, 'longitude': -88.5795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39633', 'place_name': 'Crosby', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Amite', 'locality_code': '5', 'latitude': 31.291, 'longitude': -91.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39638', 'place_name': 'Gloster', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Amite', 'locality_code': '5', 'latitude': 31.1903, 'longitude': -90.924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39645', 'place_name': 'Liberty', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Amite', 'locality_code': '5', 'latitude': 31.1384, 'longitude': -90.7133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39664', 'place_name': 'Smithdale', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Amite', 'locality_code': '5', 'latitude': 31.3672, 'longitude': -90.6752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39067', 'place_name': 'Ethel', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Attala', 'locality_code': '7', 'latitude': 33.1204, 'longitude': -89.4659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39090', 'place_name': 'Kosciusko', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Attala', 'locality_code': '7', 'latitude': 33.0446, 'longitude': -89.5724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39107', 'place_name': 'Mc Adams', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Attala', 'locality_code': '7', 'latitude': 33.0828, 'longitude': -89.6412, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39108', 'place_name': 'Mc Cool', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Attala', 'locality_code': '7', 'latitude': 33.1632, 'longitude': -89.3268, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39160', 'place_name': 'Sallis', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Attala', 'locality_code': '7', 'latitude': 33.001, 'longitude': -89.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38603', 'place_name': 'Ashland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Benton', 'locality_code': '9', 'latitude': 34.8346, 'longitude': -89.1427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38633', 'place_name': 'Hickory Flat', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Benton', 'locality_code': '9', 'latitude': 34.6244, 'longitude': -89.1862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38647', 'place_name': 'Michigan City', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Benton', 'locality_code': '9', 'latitude': 34.9608, 'longitude': -89.2267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38720', 'place_name': 'Alligator', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 34.1294, 'longitude': -90.7382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38725', 'place_name': 'Benoit', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.6448, 'longitude': -91.0338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38726', 'place_name': 'Beulah', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.788, 'longitude': -90.9795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38730', 'place_name': 'Boyle', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.6891, 'longitude': -90.7838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38732', 'place_name': 'Cleveland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.743, 'longitude': -90.7309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38733', 'place_name': 'Cleveland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.624, 'longitude': -90.8195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38740', 'place_name': 'Duncan', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 34.047, 'longitude': -90.7652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38746', 'place_name': 'Gunnison', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.9439, 'longitude': -90.9319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38759', 'place_name': 'Merigold', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.8373, 'longitude': -90.7256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38762', 'place_name': 'Mound Bayou', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.886, 'longitude': -90.7302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38764', 'place_name': 'Pace', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.7915, 'longitude': -90.857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38769', 'place_name': 'Rosedale', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.8432, 'longitude': -90.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38772', 'place_name': 'Scott', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.5629, 'longitude': -91.0391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38773', 'place_name': 'Shaw', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.6021, 'longitude': -90.7746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38774', 'place_name': 'Shelby', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.9491, 'longitude': -90.7625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38781', 'place_name': 'Winstonville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Bolivar', 'locality_code': '11', 'latitude': 33.9101, 'longitude': -90.7515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38839', 'place_name': 'Derma', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.8562, 'longitude': -89.3032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38878', 'place_name': 'Vardaman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.919, 'longitude': -89.1921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38913', 'place_name': 'Banner', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 34.0949, 'longitude': -89.4154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38914', 'place_name': 'Big Creek', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.8514, 'longitude': -89.4378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38915', 'place_name': 'Bruce', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 34.0066, 'longitude': -89.3484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38916', 'place_name': 'Calhoun City', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.8408, 'longitude': -89.3178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38951', 'place_name': 'Pittsboro', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.9443, 'longitude': -89.3376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38955', 'place_name': 'Slate Spring', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.7439, 'longitude': -89.3753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39751', 'place_name': 'Mantee', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 33.7052, 'longitude': -89.1051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38917', 'place_name': 'Carrollton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Carroll', 'locality_code': '15', 'latitude': 33.5208, 'longitude': -89.9506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38923', 'place_name': 'Coila', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Carroll', 'locality_code': '15', 'latitude': 33.3731, 'longitude': -89.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38943', 'place_name': 'Mc Carley', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Carroll', 'locality_code': '15', 'latitude': 33.5864, 'longitude': -89.8513, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '38947', 'place_name': 'North Carrollton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Carroll', 'locality_code': '15', 'latitude': 33.5324, 'longitude': -89.9001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38954', 'place_name': 'Sidon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Carroll', 'locality_code': '15', 'latitude': 33.4095, 'longitude': -90.1779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39176', 'place_name': 'Vaiden', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Carroll', 'locality_code': '15', 'latitude': 33.3343, 'longitude': -89.757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38850', 'place_name': 'Houlka', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Chickasaw', 'locality_code': '17', 'latitude': 34.0561, 'longitude': -89.0531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38851', 'place_name': 'Houston', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Chickasaw', 'locality_code': '17', 'latitude': 33.9026, 'longitude': -88.967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38860', 'place_name': 'Okolona', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Chickasaw', 'locality_code': '17', 'latitude': 33.9694, 'longitude': -88.7638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38875', 'place_name': 'Trebloc', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Chickasaw', 'locality_code': '17', 'latitude': 33.9068, 'longitude': -88.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38877', 'place_name': 'Van Vleet', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Chickasaw', 'locality_code': '17', 'latitude': 33.9871, 'longitude': -88.8988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39776', 'place_name': 'Woodland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Chickasaw', 'locality_code': '17', 'latitude': 33.8066, 'longitude': -89.0256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39735', 'place_name': 'Ackerman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Choctaw', 'locality_code': '19', 'latitude': 33.3517, 'longitude': -89.2014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39745', 'place_name': 'French Camp', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Choctaw', 'locality_code': '19', 'latitude': 33.2898, 'longitude': -89.3999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39772', 'place_name': 'Weir', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Choctaw', 'locality_code': '19', 'latitude': 33.2645, 'longitude': -89.2804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39086', 'place_name': 'Hermanville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Claiborne', 'locality_code': '21', 'latitude': 31.9564, 'longitude': -90.8446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39144', 'place_name': 'Pattison', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Claiborne', 'locality_code': '21', 'latitude': 31.851, 'longitude': -90.8283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39150', 'place_name': 'Port Gibson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Claiborne', 'locality_code': '21', 'latitude': 31.961, 'longitude': -90.984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39330', 'place_name': 'Enterprise', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clarke', 'locality_code': '23', 'latitude': 32.1563, 'longitude': -88.8474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39347', 'place_name': 'Pachuta', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clarke', 'locality_code': '23', 'latitude': 32.0217, 'longitude': -88.8851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39355', 'place_name': 'Quitman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clarke', 'locality_code': '23', 'latitude': 32.0668, 'longitude': -88.6788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39360', 'place_name': 'Shubuta', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clarke', 'locality_code': '23', 'latitude': 31.9607, 'longitude': -88.7168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39363', 'place_name': 'Stonewall', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clarke', 'locality_code': '23', 'latitude': 32.1564, 'longitude': -88.7748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39741', 'place_name': 'Cedarbluff', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clay', 'locality_code': '25', 'latitude': 33.6162, 'longitude': -88.8267, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39754', 'place_name': 'Montpelier', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clay', 'locality_code': '25', 'latitude': 33.7179, 'longitude': -88.9478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39755', 'place_name': 'Pheba', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clay', 'locality_code': '25', 'latitude': 33.5961, 'longitude': -88.9518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39773', 'place_name': 'West Point', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Clay', 'locality_code': '25', 'latitude': 33.6076, 'longitude': -88.6503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38614', 'place_name': 'Clarksdale', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.256, 'longitude': -90.6348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38617', 'place_name': 'Coahoma', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.3668, 'longitude': -90.5232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38630', 'place_name': 'Farrell', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.2643, 'longitude': -90.6723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38631', 'place_name': 'Friars Point', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.3668, 'longitude': -90.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38639', 'place_name': 'Jonestown', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.3037, 'longitude': -90.4294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38644', 'place_name': 'Lula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.4618, 'longitude': -90.4981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38645', 'place_name': 'Lyon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.2474, 'longitude': -90.4981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38669', 'place_name': 'Sherard', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.1953, 'longitude': -90.7335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38739', 'place_name': 'Dublin', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.0604, 'longitude': -90.5011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38767', 'place_name': 'Rena Lara', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Coahoma', 'locality_code': '27', 'latitude': 34.1412, 'longitude': -90.7865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39059', 'place_name': 'Crystal Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Copiah', 'locality_code': '29', 'latitude': 31.9933, 'longitude': -90.3744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39077', 'place_name': 'Gallman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Copiah', 'locality_code': '29', 'latitude': 31.9288, 'longitude': -90.3926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39078', 'place_name': 'Georgetown', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Copiah', 'locality_code': '29', 'latitude': 31.8552, 'longitude': -90.2127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39083', 'place_name': 'Hazlehurst', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Copiah', 'locality_code': '29', 'latitude': 31.8562, 'longitude': -90.4051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39191', 'place_name': 'Wesson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Copiah', 'locality_code': '29', 'latitude': 31.6901, 'longitude': -90.4131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39119', 'place_name': 'Mount Olive', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Covington', 'locality_code': '31', 'latitude': 31.7613, 'longitude': -89.6551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39428', 'place_name': 'Collins', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Covington', 'locality_code': '31', 'latitude': 31.6707, 'longitude': -89.5438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39479', 'place_name': 'Seminary', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Covington', 'locality_code': '31', 'latitude': 31.5285, 'longitude': -89.4816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38632', 'place_name': 'Hernando', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.8096, 'longitude': -90.0095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38637', 'place_name': 'Horn Lake', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.9519, 'longitude': -90.0507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38641', 'place_name': 'Lake Cormorant', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.8937, 'longitude': -90.1608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38651', 'place_name': 'Nesbit', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.8992, 'longitude': -90.0122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38654', 'place_name': 'Olive Branch', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.9441, 'longitude': -89.8544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38671', 'place_name': 'Southaven', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.9771, 'longitude': -89.9992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38672', 'place_name': 'Southaven', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.9474, 'longitude': -89.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38680', 'place_name': 'Walls', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.9641, 'longitude': -90.1208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38686', 'place_name': 'Walls', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'DeSoto', 'locality_code': '33', 'latitude': 34.9582, 'longitude': -90.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39401', 'place_name': 'Hattiesburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.3146, 'longitude': -89.3065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39402', 'place_name': 'Hattiesburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.3098, 'longitude': -89.3775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39403', 'place_name': 'Hattiesburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.3566, 'longitude': -89.3824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39404', 'place_name': 'Hattiesburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.1721, 'longitude': -89.2948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39406', 'place_name': 'Hattiesburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.1721, 'longitude': -89.2948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39407', 'place_name': 'Hattiesburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.1721, 'longitude': -89.2948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39425', 'place_name': 'Brooklyn', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.0591, 'longitude': -89.0796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39465', 'place_name': 'Petal', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Forrest', 'locality_code': '35', 'latitude': 31.3472, 'longitude': -89.2222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39630', 'place_name': 'Bude', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Franklin', 'locality_code': '37', 'latitude': 31.4593, 'longitude': -90.8457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39647', 'place_name': 'Mc Call Creek', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Franklin', 'locality_code': '37', 'latitude': 31.4908, 'longitude': -90.7836, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39653', 'place_name': 'Meadville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Franklin', 'locality_code': '37', 'latitude': 31.4285, 'longitude': -90.8578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39661', 'place_name': 'Roxie', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Franklin', 'locality_code': '37', 'latitude': 31.504, 'longitude': -91.0625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39452', 'place_name': 'Lucedale', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'George', 'locality_code': '39', 'latitude': 30.8668, 'longitude': -88.649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39362', 'place_name': 'State Line', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Greene', 'locality_code': '41', 'latitude': 31.3916, 'longitude': -88.5171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39451', 'place_name': 'Leakesville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Greene', 'locality_code': '41', 'latitude': 31.1238, 'longitude': -88.5595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39456', 'place_name': 'Mc Lain', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Greene', 'locality_code': '41', 'latitude': 31.0867, 'longitude': -88.7977, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39461', 'place_name': 'Neely', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Greene', 'locality_code': '41', 'latitude': 31.1793, 'longitude': -88.7198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38901', 'place_name': 'Grenada', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Grenada', 'locality_code': '43', 'latitude': 33.7751, 'longitude': -89.8087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38902', 'place_name': 'Grenada', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Grenada', 'locality_code': '43', 'latitude': 33.769, 'longitude': -89.8084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38926', 'place_name': 'Elliott', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Grenada', 'locality_code': '43', 'latitude': 33.6895, 'longitude': -89.7583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38929', 'place_name': 'Gore Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Grenada', 'locality_code': '43', 'latitude': 33.7245, 'longitude': -89.5754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38940', 'place_name': 'Holcomb', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Grenada', 'locality_code': '43', 'latitude': 33.7551, 'longitude': -90.0333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38960', 'place_name': 'Tie Plant', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Grenada', 'locality_code': '43', 'latitude': 33.7872, 'longitude': -89.8219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39520', 'place_name': 'Bay Saint Louis', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.2956, 'longitude': -89.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39521', 'place_name': 'Bay Saint Louis', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.4032, 'longitude': -89.4982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39522', 'place_name': 'Stennis Space Center', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.4032, 'longitude': -89.4982, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39525', 'place_name': 'Diamondhead', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.3728, 'longitude': -89.3779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39529', 'place_name': 'Stennis Space Center', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.4032, 'longitude': -89.4982, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39556', 'place_name': 'Kiln', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.4875, 'longitude': -89.4187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39558', 'place_name': 'Lakeshore', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.2391, 'longitude': -89.4595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39572', 'place_name': 'Pearlington', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.2508, 'longitude': -89.6011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39576', 'place_name': 'Waveland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hancock', 'locality_code': '45', 'latitude': 30.2914, 'longitude': -89.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39501', 'place_name': 'Gulfport', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.3826, 'longitude': -89.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39502', 'place_name': 'Gulfport', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4158, 'longitude': -89.0684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39503', 'place_name': 'Gulfport', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4601, 'longitude': -89.0886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39505', 'place_name': 'Gulfport', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4158, 'longitude': -89.0684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39506', 'place_name': 'Gulfport', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4158, 'longitude': -89.0684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39507', 'place_name': 'Gulfport', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.3962, 'longitude': -89.0353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39530', 'place_name': 'Biloxi', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4035, 'longitude': -88.8971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39531', 'place_name': 'Biloxi', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4033, 'longitude': -88.9605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39532', 'place_name': 'Biloxi', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.511, 'longitude': -88.9681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39533', 'place_name': 'Biloxi', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.396, 'longitude': -88.8853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39534', 'place_name': 'Biloxi', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4067, 'longitude': -88.9211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39535', 'place_name': 'Biloxi', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4158, 'longitude': -89.0684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39540', 'place_name': 'Diberville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.4383, 'longitude': -88.8989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39560', 'place_name': 'Long Beach', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.3598, 'longitude': -89.1646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39571', 'place_name': 'Pass Christian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.3989, 'longitude': -89.2843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39574', 'place_name': 'Saucier', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Harrison', 'locality_code': '47', 'latitude': 30.5961, 'longitude': -89.1477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39041', 'place_name': 'Bolton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3778, 'longitude': -90.4474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39056', 'place_name': 'Clinton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3411, 'longitude': -90.3229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39058', 'place_name': 'Clinton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3415, 'longitude': -90.3218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39060', 'place_name': 'Clinton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3113, 'longitude': -90.3972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39066', 'place_name': 'Edwards', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.316, 'longitude': -90.5984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39154', 'place_name': 'Raymond', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.1961, 'longitude': -90.4753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39170', 'place_name': 'Terry', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.1147, 'longitude': -90.3241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39174', 'place_name': 'Tougaloo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3953, 'longitude': -90.1544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39175', 'place_name': 'Utica', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.1229, 'longitude': -90.6047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39201', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2935, 'longitude': -90.1867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39202', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3149, 'longitude': -90.1782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39203', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3081, 'longitude': -90.2021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39204', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2832, 'longitude': -90.2306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39205', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39206', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.37, 'longitude': -90.1738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39207', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39209', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3184, 'longitude': -90.2446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39210', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3218, 'longitude': -90.1771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39211', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3739, 'longitude': -90.1293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39212', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2435, 'longitude': -90.2612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39213', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3553, 'longitude': -90.2171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39215', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39216', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3386, 'longitude': -90.1708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39217', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2974, 'longitude': -90.2081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39225', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39236', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39250', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39269', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.3003, 'longitude': -90.1886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39271', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39272', 'place_name': 'Byram', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.1888, 'longitude': -90.2595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39282', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39283', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39284', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39286', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39289', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39296', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Hinds', 'locality_code': '49', 'latitude': 32.2988, 'longitude': -90.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38924', 'place_name': 'Cruger', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Holmes', 'locality_code': '51', 'latitude': 33.311, 'longitude': -90.2316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39063', 'place_name': 'Durant', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Holmes', 'locality_code': '51', 'latitude': 33.0828, 'longitude': -89.8612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39079', 'place_name': 'Goodman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Holmes', 'locality_code': '51', 'latitude': 32.9892, 'longitude': -89.9433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39095', 'place_name': 'Lexington', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Holmes', 'locality_code': '51', 'latitude': 33.125, 'longitude': -90.0557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39146', 'place_name': 'Pickens', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Holmes', 'locality_code': '51', 'latitude': 32.8905, 'longitude': -89.9737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39169', 'place_name': 'Tchula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Holmes', 'locality_code': '51', 'latitude': 33.1624, 'longitude': -90.25, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39192', 'place_name': 'West', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Holmes', 'locality_code': '51', 'latitude': 33.1883, 'longitude': -89.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38754', 'place_name': 'Isola', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Humphreys', 'locality_code': '53', 'latitude': 33.2471, 'longitude': -90.604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39038', 'place_name': 'Belzoni', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Humphreys', 'locality_code': '53', 'latitude': 33.1842, 'longitude': -90.4924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39097', 'place_name': 'Louise', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Humphreys', 'locality_code': '53', 'latitude': 32.9919, 'longitude': -90.5893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39115', 'place_name': 'Midnight', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Humphreys', 'locality_code': '53', 'latitude': 33.0496, 'longitude': -90.5734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39166', 'place_name': 'Silver City', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Humphreys', 'locality_code': '53', 'latitude': 33.0507, 'longitude': -90.4928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38745', 'place_name': 'Grace', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Issaquena', 'locality_code': '55', 'latitude': 32.9775, 'longitude': -90.983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39113', 'place_name': 'Mayersville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Issaquena', 'locality_code': '55', 'latitude': 32.9013, 'longitude': -91.0286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39177', 'place_name': 'Valley Park', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Issaquena', 'locality_code': '55', 'latitude': 32.6323, 'longitude': -90.8542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38843', 'place_name': 'Fulton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Itawamba', 'locality_code': '57', 'latitude': 34.2745, 'longitude': -88.3793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38847', 'place_name': 'Golden', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Itawamba', 'locality_code': '57', 'latitude': 34.4812, 'longitude': -88.1842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38855', 'place_name': 'Mantachie', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Itawamba', 'locality_code': '57', 'latitude': 34.3243, 'longitude': -88.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38858', 'place_name': 'Nettleton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Itawamba', 'locality_code': '57', 'latitude': 34.0821, 'longitude': -88.6052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38876', 'place_name': 'Tremont', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Itawamba', 'locality_code': '57', 'latitude': 34.2335, 'longitude': -88.2392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39552', 'place_name': 'Escatawpa', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.4411, 'longitude': -88.6345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39553', 'place_name': 'Gautier', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.398, 'longitude': -88.6412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39555', 'place_name': 'Hurley', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.7132, 'longitude': -88.5197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39562', 'place_name': 'Moss Point', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.5471, 'longitude': -88.4927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39563', 'place_name': 'Moss Point', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.425, 'longitude': -88.5233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39564', 'place_name': 'Ocean Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.4404, 'longitude': -88.7801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39565', 'place_name': 'Vancleave', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.5405, 'longitude': -88.6875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39566', 'place_name': 'Ocean Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.4113, 'longitude': -88.8278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39567', 'place_name': 'Pascagoula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.3658, 'longitude': -88.5561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39568', 'place_name': 'Pascagoula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.4411, 'longitude': -88.6345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39569', 'place_name': 'Pascagoula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.3658, 'longitude': -88.5561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39581', 'place_name': 'Pascagoula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.3664, 'longitude': -88.5289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39595', 'place_name': 'Pascagoula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jackson', 'locality_code': '59', 'latitude': 30.3658, 'longitude': -88.5561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39338', 'place_name': 'Louin', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 32.0997, 'longitude': -89.2199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39348', 'place_name': 'Paulding', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 32.0167, 'longitude': -89.0584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39356', 'place_name': 'Rose Hill', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 32.1489, 'longitude': -89.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39366', 'place_name': 'Vossburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 31.9506, 'longitude': -88.9707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39422', 'place_name': 'Bay Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 31.9449, 'longitude': -89.2338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39439', 'place_name': 'Heidelberg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 31.882, 'longitude': -88.9981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39460', 'place_name': 'Moss', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 31.8152, 'longitude': -89.1778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39481', 'place_name': 'Stringer', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jasper', 'locality_code': '61', 'latitude': 31.8447, 'longitude': -89.2621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39069', 'place_name': 'Fayette', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jefferson', 'locality_code': '63', 'latitude': 31.7121, 'longitude': -91.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39081', 'place_name': 'Harriston', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jefferson', 'locality_code': '63', 'latitude': 31.74, 'longitude': -91.0509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39096', 'place_name': 'Lorman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jefferson', 'locality_code': '63', 'latitude': 31.8383, 'longitude': -91.0957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39668', 'place_name': 'Union Church', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jefferson', 'locality_code': '63', 'latitude': 31.7105, 'longitude': -90.8259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39421', 'place_name': 'Bassfield', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jefferson Davis', 'locality_code': '65', 'latitude': 31.5037, 'longitude': -89.7027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39427', 'place_name': 'Carson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jefferson Davis', 'locality_code': '65', 'latitude': 31.4814, 'longitude': -89.8279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39474', 'place_name': 'Prentiss', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jefferson Davis', 'locality_code': '65', 'latitude': 31.6057, 'longitude': -89.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39436', 'place_name': 'Eastabuchie', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.4555, 'longitude': -89.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39437', 'place_name': 'Ellisville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.5797, 'longitude': -89.2231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39440', 'place_name': 'Laurel', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.7054, 'longitude': -89.1312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39441', 'place_name': 'Laurel', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.7277, 'longitude': -89.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39442', 'place_name': 'Laurel', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.6823, 'longitude': -89.0406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39443', 'place_name': 'Laurel', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.7138, 'longitude': -89.0759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39459', 'place_name': 'Moselle', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.4836, 'longitude': -89.3206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39477', 'place_name': 'Sandersville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.7909, 'longitude': -89.0414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39480', 'place_name': 'Soso', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Jones', 'locality_code': '67', 'latitude': 31.7594, 'longitude': -89.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39328', 'place_name': 'De Kalb', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Kemper', 'locality_code': '69', 'latitude': 32.7162, 'longitude': -88.7332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39352', 'place_name': 'Porterville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Kemper', 'locality_code': '69', 'latitude': 32.6368, 'longitude': -88.4984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39354', 'place_name': 'Preston', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Kemper', 'locality_code': '69', 'latitude': 32.8826, 'longitude': -88.8289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39358', 'place_name': 'Scooba', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Kemper', 'locality_code': '69', 'latitude': 32.8402, 'longitude': -88.4883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38601', 'place_name': 'Abbeville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.4719, 'longitude': -89.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38655', 'place_name': 'Oxford', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.3308, 'longitude': -89.4835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38673', 'place_name': 'Taylor', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.2849, 'longitude': -89.6273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38675', 'place_name': 'Tula', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.3582, 'longitude': -89.4839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38677', 'place_name': 'University', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.3659, 'longitude': -89.5254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38685', 'place_name': 'Waterford', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.5476, 'longitude': -89.6129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38874', 'place_name': 'Toccopola', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.2265, 'longitude': -89.2519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38949', 'place_name': 'Paris', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lafayette', 'locality_code': '71', 'latitude': 34.1787, 'longitude': -89.4598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39455', 'place_name': 'Lumberton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lamar', 'locality_code': '73', 'latitude': 31.0013, 'longitude': -89.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39475', 'place_name': 'Purvis', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lamar', 'locality_code': '73', 'latitude': 31.1496, 'longitude': -89.4623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39482', 'place_name': 'Sumrall', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lamar', 'locality_code': '73', 'latitude': 31.36, 'longitude': -89.5777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39301', 'place_name': 'Meridian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.3574, 'longitude': -88.656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39302', 'place_name': 'Meridian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.3643, 'longitude': -88.7037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39303', 'place_name': 'Meridian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.4012, 'longitude': -88.6523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39304', 'place_name': 'Meridian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.4208, 'longitude': -88.646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39305', 'place_name': 'Meridian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.4401, 'longitude': -88.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39307', 'place_name': 'Meridian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.3736, 'longitude': -88.7436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39309', 'place_name': 'Meridian', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.5505, 'longitude': -88.6132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39320', 'place_name': 'Bailey', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.4676, 'longitude': -88.7228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39325', 'place_name': 'Collinsville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.5643, 'longitude': -88.875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39326', 'place_name': 'Daleville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.5511, 'longitude': -88.6609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39335', 'place_name': 'Lauderdale', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.5022, 'longitude': -88.4956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39342', 'place_name': 'Marion', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.4245, 'longitude': -88.6483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39364', 'place_name': 'Toomsuba', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lauderdale', 'locality_code': '75', 'latitude': 32.4296, 'longitude': -88.4892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39140', 'place_name': 'Newhebron', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lawrence', 'locality_code': '77', 'latitude': 31.73, 'longitude': -90.0153, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39641', 'place_name': 'Jayess', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lawrence', 'locality_code': '77', 'latitude': 31.4036, 'longitude': -90.1864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39654', 'place_name': 'Monticello', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lawrence', 'locality_code': '77', 'latitude': 31.5238, 'longitude': -90.128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39656', 'place_name': 'Oak Vale', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lawrence', 'locality_code': '77', 'latitude': 31.442, 'longitude': -89.9827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39663', 'place_name': 'Silver Creek', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lawrence', 'locality_code': '77', 'latitude': 31.5755, 'longitude': -90.0173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39665', 'place_name': 'Sontag', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lawrence', 'locality_code': '77', 'latitude': 31.6524, 'longitude': -90.2043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39051', 'place_name': 'Carthage', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leake', 'locality_code': '79', 'latitude': 32.7852, 'longitude': -89.5241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39094', 'place_name': 'Lena', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leake', 'locality_code': '79', 'latitude': 32.6446, 'longitude': -89.5494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39109', 'place_name': 'Madden', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leake', 'locality_code': '79', 'latitude': 32.6909, 'longitude': -89.3554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39171', 'place_name': 'Thomastown', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leake', 'locality_code': '79', 'latitude': 32.864, 'longitude': -89.6695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39189', 'place_name': 'Walnut Grove', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leake', 'locality_code': '79', 'latitude': 32.6134, 'longitude': -89.4105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38801', 'place_name': 'Tupelo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.2538, 'longitude': -88.7209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38802', 'place_name': 'Tupelo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.2345, 'longitude': -88.7671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38803', 'place_name': 'Tupelo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.1876, 'longitude': -88.7785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38804', 'place_name': 'Tupelo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.2823, 'longitude': -88.6715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38824', 'place_name': 'Baldwyn', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.528, 'longitude': -88.6375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38826', 'place_name': 'Belden', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.3057, 'longitude': -88.8462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38849', 'place_name': 'Guntown', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.4563, 'longitude': -88.6975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38857', 'place_name': 'Mooreville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.2808, 'longitude': -88.595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38862', 'place_name': 'Plantersville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.2011, 'longitude': -88.6335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38866', 'place_name': 'Saltillo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.3831, 'longitude': -88.6674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38868', 'place_name': 'Shannon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.121, 'longitude': -88.7342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38879', 'place_name': 'Verona', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lee', 'locality_code': '81', 'latitude': 34.1943, 'longitude': -88.7198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38930', 'place_name': 'Greenwood', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.5159, 'longitude': -90.1726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38935', 'place_name': 'Greenwood', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.5162, 'longitude': -90.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38941', 'place_name': 'Itta Bena', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.4798, 'longitude': -90.3394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38944', 'place_name': 'Minter City', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.7515, 'longitude': -90.3133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38945', 'place_name': 'Money', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.6507, 'longitude': -90.1969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38946', 'place_name': 'Morgan City', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.3807, 'longitude': -90.3504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38952', 'place_name': 'Schlater', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.6244, 'longitude': -90.362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38959', 'place_name': 'Swiftown', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Leflore', 'locality_code': '83', 'latitude': 33.3809, 'longitude': -90.3496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39601', 'place_name': 'Brookhaven', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lincoln', 'locality_code': '85', 'latitude': 31.5858, 'longitude': -90.452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39602', 'place_name': 'Brookhaven', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lincoln', 'locality_code': '85', 'latitude': 31.5334, 'longitude': -90.4907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39603', 'place_name': 'Brookhaven', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lincoln', 'locality_code': '85', 'latitude': 31.6123, 'longitude': -90.4467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39629', 'place_name': 'Bogue Chitto', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lincoln', 'locality_code': '85', 'latitude': 31.4563, 'longitude': -90.4732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39662', 'place_name': 'Ruth', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lincoln', 'locality_code': '85', 'latitude': 31.3795, 'longitude': -90.2867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39701', 'place_name': 'Columbus', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.4109, 'longitude': -88.5047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39702', 'place_name': 'Columbus', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.4812, 'longitude': -88.3554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39703', 'place_name': 'Columbus', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.4841, 'longitude': -88.284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39704', 'place_name': 'Columbus', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.5485, 'longitude': -88.3796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39705', 'place_name': 'Columbus', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.5508, 'longitude': -88.4865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39710', 'place_name': 'Columbus', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.5163, 'longitude': -88.4601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39736', 'place_name': 'Artesia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.4115, 'longitude': -88.6443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39743', 'place_name': 'Crawford', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.3219, 'longitude': -88.5671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39753', 'place_name': 'Mayhew', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.4838, 'longitude': -88.6409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39766', 'place_name': 'Steens', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Lowndes', 'locality_code': '87', 'latitude': 33.5671, 'longitude': -88.3278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39045', 'place_name': 'Camden', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.7853, 'longitude': -89.8698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39046', 'place_name': 'Canton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.6205, 'longitude': -90.0061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39071', 'place_name': 'Flora', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.5578, 'longitude': -90.3235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39110', 'place_name': 'Madison', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.4671, 'longitude': -90.1087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39130', 'place_name': 'Madison', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.4618, 'longitude': -90.1154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39157', 'place_name': 'Ridgeland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.4122, 'longitude': -90.1207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39158', 'place_name': 'Ridgeland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.4285, 'longitude': -90.1323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39163', 'place_name': 'Sharon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Madison', 'locality_code': '89', 'latitude': 32.6424, 'longitude': -90.0907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39429', 'place_name': 'Columbia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marion', 'locality_code': '91', 'latitude': 31.2559, 'longitude': -89.7998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39478', 'place_name': 'Sandy Hook', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marion', 'locality_code': '91', 'latitude': 31.0479, 'longitude': -89.8183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39483', 'place_name': 'Foxworth', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marion', 'locality_code': '91', 'latitude': 31.2473, 'longitude': -89.9311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39643', 'place_name': 'Kokomo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marion', 'locality_code': '91', 'latitude': 31.244, 'longitude': -90.0194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38611', 'place_name': 'Byhalia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.8854, 'longitude': -89.6763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38634', 'place_name': 'Holly Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.7676, 'longitude': -89.4487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38635', 'place_name': 'Holly Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.7471, 'longitude': -89.4897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38642', 'place_name': 'Lamar', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.9271, 'longitude': -89.3163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38649', 'place_name': 'Mount Pleasant', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.9536, 'longitude': -89.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38659', 'place_name': 'Potts Camp', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.6047, 'longitude': -89.3151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38661', 'place_name': 'Red Banks', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.8937, 'longitude': -89.5649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38679', 'place_name': 'Victoria', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Marshall', 'locality_code': '93', 'latitude': 34.8708, 'longitude': -89.6408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38821', 'place_name': 'Amory', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.9844, 'longitude': -88.4709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38825', 'place_name': 'Becker', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.8698, 'longitude': -88.4622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38844', 'place_name': 'Gattman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.8742, 'longitude': -88.2588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38848', 'place_name': 'Greenwood Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.8871, 'longitude': -88.3089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38870', 'place_name': 'Smithville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 34.0648, 'longitude': -88.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39730', 'place_name': 'Aberdeen', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.8284, 'longitude': -88.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39740', 'place_name': 'Caledonia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.6865, 'longitude': -88.3145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39746', 'place_name': 'Hamilton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.7404, 'longitude': -88.4112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39756', 'place_name': 'Prairie', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Monroe', 'locality_code': '95', 'latitude': 33.7836, 'longitude': -88.6642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38925', 'place_name': 'Duck Hill', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 33.5632, 'longitude': -89.6419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38967', 'place_name': 'Winona', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 33.4858, 'longitude': -89.7277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39747', 'place_name': 'Kilmichael', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 33.4165, 'longitude': -89.5696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39767', 'place_name': 'Stewart', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Montgomery', 'locality_code': '97', 'latitude': 33.5101, 'longitude': -89.479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39350', 'place_name': 'Philadelphia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Neshoba', 'locality_code': '99', 'latitude': 32.7572, 'longitude': -89.1154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39365', 'place_name': 'Union', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Neshoba', 'locality_code': '99', 'latitude': 32.6439, 'longitude': -89.112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39057', 'place_name': 'Conehatta', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Newton', 'locality_code': '101', 'latitude': 32.467, 'longitude': -89.269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39323', 'place_name': 'Chunky', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Newton', 'locality_code': '101', 'latitude': 32.3505, 'longitude': -88.9551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39327', 'place_name': 'Decatur', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Newton', 'locality_code': '101', 'latitude': 32.4358, 'longitude': -89.1168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39332', 'place_name': 'Hickory', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Newton', 'locality_code': '101', 'latitude': 32.32, 'longitude': -89.0093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39336', 'place_name': 'Lawrence', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Newton', 'locality_code': '101', 'latitude': 32.2876, 'longitude': -89.2724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39337', 'place_name': 'Little Rock', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Newton', 'locality_code': '101', 'latitude': 32.5049, 'longitude': -88.9955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39345', 'place_name': 'Newton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Newton', 'locality_code': '101', 'latitude': 32.3244, 'longitude': -89.184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39341', 'place_name': 'Macon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Noxubee', 'locality_code': '103', 'latitude': 33.1027, 'longitude': -88.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39361', 'place_name': 'Shuqualak', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Noxubee', 'locality_code': '103', 'latitude': 32.9769, 'longitude': -88.5594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39739', 'place_name': 'Brooksville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Noxubee', 'locality_code': '103', 'latitude': 33.2346, 'longitude': -88.5823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39759', 'place_name': 'Starkville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Oktibbeha', 'locality_code': '105', 'latitude': 33.4505, 'longitude': -88.8196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39760', 'place_name': 'Starkville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Oktibbeha', 'locality_code': '105', 'latitude': 33.4599, 'longitude': -88.8322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39762', 'place_name': 'Mississippi State', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Oktibbeha', 'locality_code': '105', 'latitude': 33.4156, 'longitude': -88.7433, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39769', 'place_name': 'Sturgis', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Oktibbeha', 'locality_code': '105', 'latitude': 33.357, 'longitude': -89.0473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38606', 'place_name': 'Batesville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Panola', 'locality_code': '107', 'latitude': 34.3115, 'longitude': -89.9443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38619', 'place_name': 'Como', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Panola', 'locality_code': '107', 'latitude': 34.5137, 'longitude': -89.9155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38620', 'place_name': 'Courtland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Panola', 'locality_code': '107', 'latitude': 34.2596, 'longitude': -89.9396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38621', 'place_name': 'Crenshaw', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Panola', 'locality_code': '107', 'latitude': 34.4491, 'longitude': -90.1701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38658', 'place_name': 'Pope', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Panola', 'locality_code': '107', 'latitude': 34.1906, 'longitude': -90.0027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38665', 'place_name': 'Sarah', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Panola', 'locality_code': '107', 'latitude': 34.591, 'longitude': -90.162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38666', 'place_name': 'Sardis', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Panola', 'locality_code': '107', 'latitude': 34.4276, 'longitude': -89.9221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39426', 'place_name': 'Carriere', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pearl River', 'locality_code': '109', 'latitude': 30.6178, 'longitude': -89.5779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39457', 'place_name': 'Mc Neill', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pearl River', 'locality_code': '109', 'latitude': 30.6669, 'longitude': -89.6734, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39463', 'place_name': 'Nicholson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pearl River', 'locality_code': '109', 'latitude': 30.5637, 'longitude': -89.5578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39466', 'place_name': 'Picayune', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pearl River', 'locality_code': '109', 'latitude': 30.5418, 'longitude': -89.691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39470', 'place_name': 'Poplarville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pearl River', 'locality_code': '109', 'latitude': 30.8524, 'longitude': -89.5648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39423', 'place_name': 'Beaumont', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Perry', 'locality_code': '111', 'latitude': 31.1693, 'longitude': -88.92, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39462', 'place_name': 'New Augusta', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Perry', 'locality_code': '111', 'latitude': 31.2026, 'longitude': -89.0367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39464', 'place_name': 'Ovett', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Perry', 'locality_code': '111', 'latitude': 31.4738, 'longitude': -89.0396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39476', 'place_name': 'Richton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Perry', 'locality_code': '111', 'latitude': 31.3434, 'longitude': -88.9101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39632', 'place_name': 'Chatawa', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pike', 'locality_code': '113', 'latitude': 31.1145, 'longitude': -90.4875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39635', 'place_name': 'Fernwood', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pike', 'locality_code': '113', 'latitude': 31.1855, 'longitude': -90.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39648', 'place_name': 'Mccomb', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pike', 'locality_code': '113', 'latitude': 31.1769, 'longitude': -90.4016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39649', 'place_name': 'Mccomb', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pike', 'locality_code': '113', 'latitude': 31.2438, 'longitude': -90.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39652', 'place_name': 'Magnolia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pike', 'locality_code': '113', 'latitude': 31.1217, 'longitude': -90.4831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39657', 'place_name': 'Osyka', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pike', 'locality_code': '113', 'latitude': 31.0217, 'longitude': -90.479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39666', 'place_name': 'Summit', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pike', 'locality_code': '113', 'latitude': 31.2975, 'longitude': -90.4654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38820', 'place_name': 'Algoma', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pontotoc', 'locality_code': '115', 'latitude': 34.1715, 'longitude': -89.0328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38841', 'place_name': 'Ecru', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pontotoc', 'locality_code': '115', 'latitude': 34.3366, 'longitude': -89.0109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38863', 'place_name': 'Pontotoc', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pontotoc', 'locality_code': '115', 'latitude': 34.217, 'longitude': -88.9868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38864', 'place_name': 'Randolph', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pontotoc', 'locality_code': '115', 'latitude': 34.1617, 'longitude': -89.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38869', 'place_name': 'Sherman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pontotoc', 'locality_code': '115', 'latitude': 34.3575, 'longitude': -88.8351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38871', 'place_name': 'Thaxton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Pontotoc', 'locality_code': '115', 'latitude': 34.3136, 'longitude': -89.1515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38829', 'place_name': 'Booneville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Prentiss', 'locality_code': '117', 'latitude': 34.6694, 'longitude': -88.5443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38856', 'place_name': 'Marietta', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Prentiss', 'locality_code': '117', 'latitude': 34.5011, 'longitude': -88.4498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38859', 'place_name': 'New Site', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Prentiss', 'locality_code': '117', 'latitude': 34.5315, 'longitude': -88.3875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38880', 'place_name': 'Wheeler', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Prentiss', 'locality_code': '117', 'latitude': 34.6126, 'longitude': -88.5822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38609', 'place_name': 'Belen', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Quitman', 'locality_code': '119', 'latitude': 34.2351, 'longitude': -90.2927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38622', 'place_name': 'Crowder', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Quitman', 'locality_code': '119', 'latitude': 34.1731, 'longitude': -90.1364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38623', 'place_name': 'Darling', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Quitman', 'locality_code': '119', 'latitude': 34.359, 'longitude': -90.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38628', 'place_name': 'Falcon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Quitman', 'locality_code': '119', 'latitude': 34.3932, 'longitude': -90.2565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38643', 'place_name': 'Lambert', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Quitman', 'locality_code': '119', 'latitude': 34.1837, 'longitude': -90.263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38646', 'place_name': 'Marks', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Quitman', 'locality_code': '119', 'latitude': 34.2607, 'longitude': -90.2816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38964', 'place_name': 'Vance', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Quitman', 'locality_code': '119', 'latitude': 34.0936, 'longitude': -90.3752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39042', 'place_name': 'Brandon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.3038, 'longitude': -89.964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39043', 'place_name': 'Brandon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.269, 'longitude': -89.9875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39047', 'place_name': 'Brandon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.3886, 'longitude': -89.9584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39073', 'place_name': 'Florence', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.1535, 'longitude': -90.1312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39145', 'place_name': 'Pelahatchie', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.318, 'longitude': -89.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39148', 'place_name': 'Piney Woods', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.0627, 'longitude': -89.9929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39151', 'place_name': 'Puckett', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.1062, 'longitude': -89.7836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39161', 'place_name': 'Sandhill', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.4983, 'longitude': -89.8686, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39167', 'place_name': 'Star', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.094, 'longitude': -90.0462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39193', 'place_name': 'Whitfield', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.2348, 'longitude': -90.0726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39208', 'place_name': 'Pearl', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.2604, 'longitude': -90.0897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39218', 'place_name': 'Richland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.2287, 'longitude': -90.1591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39232', 'place_name': 'Flowood', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.3299, 'longitude': -90.0915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39288', 'place_name': 'Pearl', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.2746, 'longitude': -90.132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39298', 'place_name': 'Jackson', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Rankin', 'locality_code': '121', 'latitude': 32.3199, 'longitude': -89.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39074', 'place_name': 'Forest', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.347, 'longitude': -89.4672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39080', 'place_name': 'Harperville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.4925, 'longitude': -89.4946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39087', 'place_name': 'Hillsboro', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.4706, 'longitude': -89.5171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39092', 'place_name': 'Lake', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.3459, 'longitude': -89.3414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39098', 'place_name': 'Ludlow', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.566, 'longitude': -89.7135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39117', 'place_name': 'Morton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.4029, 'longitude': -89.5949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39152', 'place_name': 'Pulaski', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.2745, 'longitude': -89.5627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39359', 'place_name': 'Sebastopol', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Scott', 'locality_code': '123', 'latitude': 32.5729, 'longitude': -89.3351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38721', 'place_name': 'Anguilla', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sharkey', 'locality_code': '125', 'latitude': 32.9739, 'longitude': -90.8316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38765', 'place_name': 'Panther Burn', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sharkey', 'locality_code': '125', 'latitude': 33.0662, 'longitude': -90.8684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39054', 'place_name': 'Cary', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sharkey', 'locality_code': '125', 'latitude': 32.806, 'longitude': -90.9268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39061', 'place_name': 'Delta City', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sharkey', 'locality_code': '125', 'latitude': 33.074, 'longitude': -90.7951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39159', 'place_name': 'Rolling Fork', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sharkey', 'locality_code': '125', 'latitude': 32.8733, 'longitude': -90.8833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39044', 'place_name': 'Braxton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Simpson', 'locality_code': '127', 'latitude': 32.0016, 'longitude': -89.9672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39062', 'place_name': 'D Lo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Simpson', 'locality_code': '127', 'latitude': 31.9857, 'longitude': -89.9012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39082', 'place_name': 'Harrisville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Simpson', 'locality_code': '127', 'latitude': 31.9676, 'longitude': -90.1054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39111', 'place_name': 'Magee', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Simpson', 'locality_code': '127', 'latitude': 31.8495, 'longitude': -89.7503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39114', 'place_name': 'Mendenhall', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Simpson', 'locality_code': '127', 'latitude': 31.9494, 'longitude': -89.8095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39149', 'place_name': 'Pinola', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Simpson', 'locality_code': '127', 'latitude': 31.8277, 'longitude': -90.0088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39116', 'place_name': 'Mize', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Smith', 'locality_code': '129', 'latitude': 31.8473, 'longitude': -89.5741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39153', 'place_name': 'Raleigh', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Smith', 'locality_code': '129', 'latitude': 32.0508, 'longitude': -89.5088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39168', 'place_name': 'Taylorsville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Smith', 'locality_code': '129', 'latitude': 31.8394, 'longitude': -89.4049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39561', 'place_name': 'Mc Henry', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Stone', 'locality_code': '131', 'latitude': 30.6975, 'longitude': -89.1536, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '39573', 'place_name': 'Perkinston', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Stone', 'locality_code': '131', 'latitude': 30.7669, 'longitude': -89.14, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39577', 'place_name': 'Wiggins', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Stone', 'locality_code': '131', 'latitude': 30.8609, 'longitude': -89.1324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38736', 'place_name': 'Doddsville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.63, 'longitude': -90.5264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38737', 'place_name': 'Drew', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.867, 'longitude': -90.5406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38738', 'place_name': 'Parchman', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.9179, 'longitude': -90.4965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38749', 'place_name': 'Indianola', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.451, 'longitude': -90.6551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38751', 'place_name': 'Indianola', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.451, 'longitude': -90.6551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38753', 'place_name': 'Inverness', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.349, 'longitude': -90.6051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38761', 'place_name': 'Moorhead', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.4783, 'longitude': -90.5143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38768', 'place_name': 'Rome', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.9632, 'longitude': -90.4784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38771', 'place_name': 'Ruleville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.7241, 'longitude': -90.5527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38778', 'place_name': 'Sunflower', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Sunflower', 'locality_code': '133', 'latitude': 33.5567, 'longitude': -90.5451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38920', 'place_name': 'Cascilla', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.9079, 'longitude': -90.0362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38921', 'place_name': 'Charleston', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.9726, 'longitude': -90.1116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38927', 'place_name': 'Enid', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 34.1263, 'longitude': -90.0044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38928', 'place_name': 'Glendora', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.8573, 'longitude': -90.288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38950', 'place_name': 'Philipp', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.7574, 'longitude': -90.2091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38957', 'place_name': 'Sumner', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.9833, 'longitude': -90.3895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38958', 'place_name': 'Swan Lake', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.9292, 'longitude': -90.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38962', 'place_name': 'Tippo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.9121, 'longitude': -90.1806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38963', 'place_name': 'Tutwiler', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 34.0148, 'longitude': -90.4318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38966', 'place_name': 'Webb', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tallahatchie', 'locality_code': '135', 'latitude': 33.9473, 'longitude': -90.3443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38602', 'place_name': 'Arkabutla', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tate', 'locality_code': '137', 'latitude': 34.6863, 'longitude': -90.1068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38618', 'place_name': 'Coldwater', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tate', 'locality_code': '137', 'latitude': 34.6924, 'longitude': -89.9869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38638', 'place_name': 'Independence', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tate', 'locality_code': '137', 'latitude': 34.6959, 'longitude': -89.8288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38668', 'place_name': 'Senatobia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tate', 'locality_code': '137', 'latitude': 34.6323, 'longitude': -89.8855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38610', 'place_name': 'Blue Mountain', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tippah', 'locality_code': '139', 'latitude': 34.671, 'longitude': -89.0088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38625', 'place_name': 'Dumas', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tippah', 'locality_code': '139', 'latitude': 34.6491, 'longitude': -88.8072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38629', 'place_name': 'Falkner', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tippah', 'locality_code': '139', 'latitude': 34.8417, 'longitude': -88.9525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38663', 'place_name': 'Ripley', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tippah', 'locality_code': '139', 'latitude': 34.7509, 'longitude': -88.924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38674', 'place_name': 'Tiplersville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tippah', 'locality_code': '139', 'latitude': 34.9029, 'longitude': -88.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38683', 'place_name': 'Walnut', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tippah', 'locality_code': '139', 'latitude': 34.9527, 'longitude': -88.9053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38827', 'place_name': 'Belmont', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tishomingo', 'locality_code': '141', 'latitude': 34.5102, 'longitude': -88.2309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38833', 'place_name': 'Burnsville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tishomingo', 'locality_code': '141', 'latitude': 34.8579, 'longitude': -88.307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38838', 'place_name': 'Dennis', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tishomingo', 'locality_code': '141', 'latitude': 34.5497, 'longitude': -88.2117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38852', 'place_name': 'Iuka', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tishomingo', 'locality_code': '141', 'latitude': 34.8089, 'longitude': -88.1983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38873', 'place_name': 'Tishomingo', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tishomingo', 'locality_code': '141', 'latitude': 34.6478, 'longitude': -88.2194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38626', 'place_name': 'Dundee', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tunica', 'locality_code': '143', 'latitude': 34.5357, 'longitude': -90.3693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38664', 'place_name': 'Robinsonville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tunica', 'locality_code': '143', 'latitude': 34.8093, 'longitude': -90.3052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38670', 'place_name': 'Sledge', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tunica', 'locality_code': '143', 'latitude': 34.3823, 'longitude': -90.209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38676', 'place_name': 'Tunica', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Tunica', 'locality_code': '143', 'latitude': 34.6884, 'longitude': -90.3685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38627', 'place_name': 'Etta', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Union', 'locality_code': '145', 'latitude': 34.4352, 'longitude': -89.1767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38650', 'place_name': 'Myrtle', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Union', 'locality_code': '145', 'latitude': 34.5402, 'longitude': -89.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38652', 'place_name': 'New Albany', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Union', 'locality_code': '145', 'latitude': 34.4851, 'longitude': -89.0031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38828', 'place_name': 'Blue Springs', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Union', 'locality_code': '145', 'latitude': 34.4273, 'longitude': -88.859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39667', 'place_name': 'Tylertown', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Walthall', 'locality_code': '147', 'latitude': 31.1466, 'longitude': -90.1169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39156', 'place_name': 'Redwood', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Warren', 'locality_code': '149', 'latitude': 32.4867, 'longitude': -90.7859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39180', 'place_name': 'Vicksburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Warren', 'locality_code': '149', 'latitude': 32.3258, 'longitude': -90.8507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39181', 'place_name': 'Vicksburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Warren', 'locality_code': '149', 'latitude': 32.3486, 'longitude': -90.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39182', 'place_name': 'Vicksburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Warren', 'locality_code': '149', 'latitude': 32.3486, 'longitude': -90.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39183', 'place_name': 'Vicksburg', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Warren', 'locality_code': '149', 'latitude': 32.386, 'longitude': -90.84, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38701', 'place_name': 'Greenville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.3787, 'longitude': -91.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38702', 'place_name': 'Greenville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.4258, 'longitude': -90.9946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38703', 'place_name': 'Greenville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.4085, 'longitude': -91.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38704', 'place_name': 'Greenville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.2534, 'longitude': -90.9185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38722', 'place_name': 'Arcola', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.2698, 'longitude': -90.8798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38723', 'place_name': 'Avon', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.2301, 'longitude': -91.0473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38731', 'place_name': 'Chatham', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.1007, 'longitude': -91.0979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38744', 'place_name': 'Glen Allan', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.0254, 'longitude': -91.0092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38748', 'place_name': 'Hollandale', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.149, 'longitude': -90.9041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38756', 'place_name': 'Leland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.3985, 'longitude': -90.8839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38760', 'place_name': 'Metcalfe', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.4546, 'longitude': -90.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38776', 'place_name': 'Stoneville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.4096, 'longitude': -90.9104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38780', 'place_name': 'Wayside', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.269, 'longitude': -91.0337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38782', 'place_name': 'Winterville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Washington', 'locality_code': '151', 'latitude': 33.5018, 'longitude': -91.0584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39322', 'place_name': 'Buckatunna', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Wayne', 'locality_code': '153', 'latitude': 31.5391, 'longitude': -88.5289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39324', 'place_name': 'Clara', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Wayne', 'locality_code': '153', 'latitude': 31.5937, 'longitude': -88.7048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39367', 'place_name': 'Waynesboro', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Wayne', 'locality_code': '153', 'latitude': 31.6754, 'longitude': -88.6782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39737', 'place_name': 'Bellefontaine', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Webster', 'locality_code': '155', 'latitude': 33.6487, 'longitude': -89.3101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39744', 'place_name': 'Eupora', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Webster', 'locality_code': '155', 'latitude': 33.5494, 'longitude': -89.2904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39750', 'place_name': 'Maben', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Webster', 'locality_code': '155', 'latitude': 33.5686, 'longitude': -89.0605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39752', 'place_name': 'Mathiston', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Webster', 'locality_code': '155', 'latitude': 33.5415, 'longitude': -89.1275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39771', 'place_name': 'Walthall', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Webster', 'locality_code': '155', 'latitude': 33.607, 'longitude': -89.2752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39631', 'place_name': 'Centreville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Wilkinson', 'locality_code': '157', 'latitude': 31.0893, 'longitude': -91.096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39669', 'place_name': 'Woodville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Wilkinson', 'locality_code': '157', 'latitude': 31.1459, 'longitude': -91.3076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39339', 'place_name': 'Louisville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Winston', 'locality_code': '159', 'latitude': 33.1058, 'longitude': -89.0287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39346', 'place_name': 'Noxapater', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Winston', 'locality_code': '159', 'latitude': 32.9789, 'longitude': -89.1221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38922', 'place_name': 'Coffeeville', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yalobusha', 'locality_code': '161', 'latitude': 33.9215, 'longitude': -89.6782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38948', 'place_name': 'Oakland', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yalobusha', 'locality_code': '161', 'latitude': 34.0756, 'longitude': -89.8877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38953', 'place_name': 'Scobey', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yalobusha', 'locality_code': '161', 'latitude': 33.9253, 'longitude': -89.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38961', 'place_name': 'Tillatoba', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yalobusha', 'locality_code': '161', 'latitude': 33.9852, 'longitude': -89.8945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38965', 'place_name': 'Water Valley', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yalobusha', 'locality_code': '161', 'latitude': 34.1525, 'longitude': -89.638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39039', 'place_name': 'Benton', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yazoo', 'locality_code': '163', 'latitude': 32.8158, 'longitude': -90.2815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39040', 'place_name': 'Bentonia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yazoo', 'locality_code': '163', 'latitude': 32.7, 'longitude': -90.3722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39088', 'place_name': 'Holly Bluff', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yazoo', 'locality_code': '163', 'latitude': 32.8415, 'longitude': -90.7231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39162', 'place_name': 'Satartia', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yazoo', 'locality_code': '163', 'latitude': 32.6125, 'longitude': -90.5965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39173', 'place_name': 'Tinsley', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yazoo', 'locality_code': '163', 'latitude': 32.7628, 'longitude': -90.3628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39179', 'place_name': 'Vaughan', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yazoo', 'locality_code': '163', 'latitude': 32.8015, 'longitude': -90.0981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '39194', 'place_name': 'Yazoo City', 'state': 'Mississippi', 'state_ab': 'MS', 'county': 'Yazoo', 'locality_code': '163', 'latitude': 32.8594, 'longitude': -90.4031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59724', 'place_name': 'Dell', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 44.723, 'longitude': -112.6972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59725', 'place_name': 'Dillon', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 45.2339, 'longitude': -112.6405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59732', 'place_name': 'Glen', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 45.4766, 'longitude': -112.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59736', 'place_name': 'Jackson', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 45.3687, 'longitude': -113.3598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59739', 'place_name': 'Lima', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 44.6441, 'longitude': -112.5625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59746', 'place_name': 'Polaris', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 45.3696, 'longitude': -113.1195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59761', 'place_name': 'Wisdom', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 45.6519, 'longitude': -113.4729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59762', 'place_name': 'Wise River', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Beaverhead', 'locality_code': '1', 'latitude': 45.7424, 'longitude': -112.9963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59016', 'place_name': 'Busby', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.5541, 'longitude': -106.8723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59022', 'place_name': 'Crow Agency', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.6296, 'longitude': -107.4973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59025', 'place_name': 'Decker', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.1797, 'longitude': -106.8721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59031', 'place_name': 'Garryowen', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.5187, 'longitude': -107.4817, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59034', 'place_name': 'Hardin', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.7498, 'longitude': -107.6075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59035', 'place_name': 'Fort Smith', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.3127, 'longitude': -107.9371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59050', 'place_name': 'Lodge Grass', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.3166, 'longitude': -107.3675, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59066', 'place_name': 'Pryor', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.4297, 'longitude': -108.5332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59075', 'place_name': 'Saint Xavier', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.3985, 'longitude': -107.8893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59089', 'place_name': 'Wyola', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 45.1089, 'longitude': -107.4303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59523', 'place_name': 'Chinook', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Blaine', 'locality_code': '5', 'latitude': 48.5799, 'longitude': -109.2225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59526', 'place_name': 'Harlem', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Blaine', 'locality_code': '5', 'latitude': 48.5398, 'longitude': -108.7693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59527', 'place_name': 'Hays', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Blaine', 'locality_code': '5', 'latitude': 47.9892, 'longitude': -108.6943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59529', 'place_name': 'Hogeland', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Blaine', 'locality_code': '5', 'latitude': 48.8571, 'longitude': -108.6677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59535', 'place_name': 'Lloyd', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Blaine', 'locality_code': '5', 'latitude': 47.9647, 'longitude': -109.2671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59542', 'place_name': 'Turner', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Blaine', 'locality_code': '5', 'latitude': 48.8328, 'longitude': -108.3961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59547', 'place_name': 'Zurich', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Blaine', 'locality_code': '5', 'latitude': 48.5844, 'longitude': -109.0304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59641', 'place_name': 'Radersburg', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Broadwater', 'locality_code': '7', 'latitude': 46.2069, 'longitude': -111.6344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59643', 'place_name': 'Toston', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Broadwater', 'locality_code': '7', 'latitude': 46.1709, 'longitude': -111.5899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59644', 'place_name': 'Townsend', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Broadwater', 'locality_code': '7', 'latitude': 46.3346, 'longitude': -111.4919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59647', 'place_name': 'Winston', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Broadwater', 'locality_code': '7', 'latitude': 46.4545, 'longitude': -111.651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59007', 'place_name': 'Bearcreek', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.1608, 'longitude': -109.1571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59008', 'place_name': 'Belfry', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.0498, 'longitude': -109.0788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59013', 'place_name': 'Boyd', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.4577, 'longitude': -109.0665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59014', 'place_name': 'Bridger', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.2857, 'longitude': -108.9082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59026', 'place_name': 'Edgar', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.4647, 'longitude': -108.8524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59029', 'place_name': 'Fromberg', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.4027, 'longitude': -108.9057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59041', 'place_name': 'Joliet', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.4941, 'longitude': -108.9922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59068', 'place_name': 'Red Lodge', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.1965, 'longitude': -109.2688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59070', 'place_name': 'Roberts', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.3672, 'longitude': -109.1769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59071', 'place_name': 'Roscoe', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carbon', 'locality_code': '9', 'latitude': 45.268, 'longitude': -109.5658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59311', 'place_name': 'Alzada', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carter', 'locality_code': '11', 'latitude': 45.1562, 'longitude': -104.2617, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59316', 'place_name': 'Boyes', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carter', 'locality_code': '11', 'latitude': 45.268, 'longitude': -105.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59319', 'place_name': 'Capitol', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carter', 'locality_code': '11', 'latitude': 45.4361, 'longitude': -104.0655, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59324', 'place_name': 'Ekalaka', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carter', 'locality_code': '11', 'latitude': 45.8805, 'longitude': -104.504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59332', 'place_name': 'Hammond', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Carter', 'locality_code': '11', 'latitude': 45.5671, 'longitude': -104.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59401', 'place_name': 'Great Falls', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.5098, 'longitude': -111.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59402', 'place_name': 'Malmstrom Afb', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.5002, 'longitude': -111.3008, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59403', 'place_name': 'Great Falls', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.5002, 'longitude': -111.3008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59404', 'place_name': 'Great Falls', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.5098, 'longitude': -111.3405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59405', 'place_name': 'Great Falls', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.495, 'longitude': -111.2502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59406', 'place_name': 'Great Falls', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.62, 'longitude': -111.2393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59412', 'place_name': 'Belt', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.3821, 'longitude': -110.9081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59414', 'place_name': 'Black Eagle', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.5262, 'longitude': -111.2764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59421', 'place_name': 'Cascade', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.2912, 'longitude': -111.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59443', 'place_name': 'Fort Shaw', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.5055, 'longitude': -111.8103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59463', 'place_name': 'Monarch', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.0722, 'longitude': -110.871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59465', 'place_name': 'Neihart', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 46.9391, 'longitude': -110.7328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59472', 'place_name': 'Sand Coulee', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.4021, 'longitude': -111.1661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59477', 'place_name': 'Simms', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.4958, 'longitude': -111.8861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59480', 'place_name': 'Stockett', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.3217, 'longitude': -111.1287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59483', 'place_name': 'Sun River', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.481, 'longitude': -111.7242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59485', 'place_name': 'Ulm', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.3539, 'longitude': -111.5954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59487', 'place_name': 'Vaughn', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Cascade', 'locality_code': '13', 'latitude': 47.5624, 'longitude': -111.577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59420', 'place_name': 'Carter', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Chouteau', 'locality_code': '15', 'latitude': 47.781, 'longitude': -110.9786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59440', 'place_name': 'Floweree', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Chouteau', 'locality_code': '15', 'latitude': 47.6584, 'longitude': -111.1214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59442', 'place_name': 'Fort Benton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Chouteau', 'locality_code': '15', 'latitude': 47.924, 'longitude': -110.6052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59446', 'place_name': 'Geraldine', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Chouteau', 'locality_code': '15', 'latitude': 47.6024, 'longitude': -110.2765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59450', 'place_name': 'Highwood', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Chouteau', 'locality_code': '15', 'latitude': 47.5816, 'longitude': -110.7887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59460', 'place_name': 'Loma', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Chouteau', 'locality_code': '15', 'latitude': 47.9546, 'longitude': -110.4995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59520', 'place_name': 'Big Sandy', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Chouteau', 'locality_code': '15', 'latitude': 48.1497, 'longitude': -110.0776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59301', 'place_name': 'Miles City', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Custer', 'locality_code': '17', 'latitude': 46.4075, 'longitude': -105.8332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59336', 'place_name': 'Ismay', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Custer', 'locality_code': '17', 'latitude': 46.4132, 'longitude': -105.2091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59338', 'place_name': 'Kinsey', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Custer', 'locality_code': '17', 'latitude': 46.5708, 'longitude': -105.6569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59351', 'place_name': 'Volborg', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Custer', 'locality_code': '17', 'latitude': 45.8428, 'longitude': -105.6811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59222', 'place_name': 'Flaxville', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Daniels', 'locality_code': '19', 'latitude': 48.7472, 'longitude': -105.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59253', 'place_name': 'Peerless', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Daniels', 'locality_code': '19', 'latitude': 48.7808, 'longitude': -105.8006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59263', 'place_name': 'Scobey', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Daniels', 'locality_code': '19', 'latitude': 48.7854, 'longitude': -105.417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59276', 'place_name': 'Whitetail', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Daniels', 'locality_code': '19', 'latitude': 48.8956, 'longitude': -105.1617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59259', 'place_name': 'Richey', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Dawson', 'locality_code': '21', 'latitude': 47.6229, 'longitude': -105.017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59315', 'place_name': 'Bloomfield', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Dawson', 'locality_code': '21', 'latitude': 47.41, 'longitude': -104.9596, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59330', 'place_name': 'Glendive', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Dawson', 'locality_code': '21', 'latitude': 47.1008, 'longitude': -104.7287, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59339', 'place_name': 'Lindsay', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Dawson', 'locality_code': '21', 'latitude': 47.2024, 'longitude': -105.2089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59711', 'place_name': 'Anaconda', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Deer Lodge', 'locality_code': '23', 'latitude': 46.1299, 'longitude': -112.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59756', 'place_name': 'Warm Springs', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Deer Lodge', 'locality_code': '23', 'latitude': 46.1813, 'longitude': -112.7848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59313', 'place_name': 'Baker', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fallon', 'locality_code': '25', 'latitude': 46.3552, 'longitude': -104.2667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59344', 'place_name': 'Plevna', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fallon', 'locality_code': '25', 'latitude': 46.4112, 'longitude': -104.5713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59354', 'place_name': 'Willard', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fallon', 'locality_code': '25', 'latitude': 46.1939, 'longitude': -104.3699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59032', 'place_name': 'Grass Range', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 47.0259, 'longitude': -108.8271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59418', 'place_name': 'Buffalo', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 46.8211, 'longitude': -109.8285, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59424', 'place_name': 'Coffee Creek', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 47.3467, 'longitude': -110.0908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59430', 'place_name': 'Denton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 47.3191, 'longitude': -109.8789, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59441', 'place_name': 'Forest Grove', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 46.9914, 'longitude': -109.0802, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59451', 'place_name': 'Hilger', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 47.2539, 'longitude': -109.3599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59457', 'place_name': 'Lewistown', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 47.0563, 'longitude': -109.4203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59464', 'place_name': 'Moore', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 46.9755, 'longitude': -109.6969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59471', 'place_name': 'Roy', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 47.3678, 'longitude': -108.8634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59489', 'place_name': 'Winifred', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Fergus', 'locality_code': '27', 'latitude': 47.6408, 'longitude': -109.2364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59901', 'place_name': 'Kalispell', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.2028, 'longitude': -114.3039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59903', 'place_name': 'Kalispell', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.2237, 'longitude': -114.4296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59904', 'place_name': 'Kalispell', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.2404, 'longitude': -114.2561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59911', 'place_name': 'Bigfork', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.0633, 'longitude': -114.0726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59912', 'place_name': 'Columbia Falls', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.3534, 'longitude': -114.1784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59913', 'place_name': 'Coram', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.4342, 'longitude': -114.0584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59916', 'place_name': 'Essex', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.278, 'longitude': -113.6126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59919', 'place_name': 'Hungry Horse', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.3858, 'longitude': -114.061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59920', 'place_name': 'Kila', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.0744, 'longitude': -114.5104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59921', 'place_name': 'Lake Mc Donald', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.2989, 'longitude': -113.9497, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59922', 'place_name': 'Lakeside', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.0215, 'longitude': -114.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59925', 'place_name': 'Marion', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.0836, 'longitude': -114.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59926', 'place_name': 'Martin City', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.3916, 'longitude': -114.0382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59927', 'place_name': 'Olney', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.5455, 'longitude': -114.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59928', 'place_name': 'Polebridge', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.8206, 'longitude': -114.3836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59932', 'place_name': 'Somers', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.0793, 'longitude': -114.2355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59936', 'place_name': 'West Glacier', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.5, 'longitude': -113.9787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59937', 'place_name': 'Whitefish', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Flathead', 'locality_code': '29', 'latitude': 48.404, 'longitude': -114.3509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59714', 'place_name': 'Belgrade', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.7801, 'longitude': -111.1439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59715', 'place_name': 'Bozeman', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.6693, 'longitude': -111.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59716', 'place_name': 'Big Sky', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.2847, 'longitude': -111.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59717', 'place_name': 'Bozeman', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.628, 'longitude': -110.9013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59718', 'place_name': 'Bozeman', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.6681, 'longitude': -111.2404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59719', 'place_name': 'Bozeman', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.628, 'longitude': -110.9013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59730', 'place_name': 'Gallatin Gateway', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.339, 'longitude': -111.2485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59741', 'place_name': 'Manhattan', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.798, 'longitude': -111.3146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59752', 'place_name': 'Three Forks', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.8811, 'longitude': -111.5436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59758', 'place_name': 'West Yellowstone', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 44.6621, 'longitude': -111.1041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59760', 'place_name': 'Willow Creek', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.7827, 'longitude': -111.6345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59771', 'place_name': 'Bozeman', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.7246, 'longitude': -111.1238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59772', 'place_name': 'Bozeman', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Gallatin', 'locality_code': '31', 'latitude': 45.6361, 'longitude': -111.0647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59058', 'place_name': 'Mosby', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Garfield', 'locality_code': '33', 'latitude': 46.9005, 'longitude': -107.7891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59077', 'place_name': 'Sand Springs', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Garfield', 'locality_code': '33', 'latitude': 47.1008, 'longitude': -107.4856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59318', 'place_name': 'Brusett', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Garfield', 'locality_code': '33', 'latitude': 47.4253, 'longitude': -107.2668, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59322', 'place_name': 'Cohagen', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Garfield', 'locality_code': '33', 'latitude': 47.1263, 'longitude': -106.4981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59337', 'place_name': 'Jordan', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Garfield', 'locality_code': '33', 'latitude': 47.3208, 'longitude': -106.9101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59411', 'place_name': 'Babb', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Glacier', 'locality_code': '35', 'latitude': 48.8788, 'longitude': -113.3681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59417', 'place_name': 'Browning', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Glacier', 'locality_code': '35', 'latitude': 48.5569, 'longitude': -113.0134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59427', 'place_name': 'Cut Bank', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Glacier', 'locality_code': '35', 'latitude': 48.6603, 'longitude': -112.3654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59434', 'place_name': 'East Glacier Park', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Glacier', 'locality_code': '35', 'latitude': 48.4457, 'longitude': -113.219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59046', 'place_name': 'Lavina', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Golden Valley', 'locality_code': '37', 'latitude': 46.3291, 'longitude': -108.9959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59074', 'place_name': 'Ryegate', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Golden Valley', 'locality_code': '37', 'latitude': 46.2724, 'longitude': -109.2761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59832', 'place_name': 'Drummond', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Granite', 'locality_code': '39', 'latitude': 46.6647, 'longitude': -113.2426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59837', 'place_name': 'Hall', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Granite', 'locality_code': '39', 'latitude': 46.5825, 'longitude': -113.2087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59858', 'place_name': 'Philipsburg', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Granite', 'locality_code': '39', 'latitude': 46.3189, 'longitude': -113.3126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59501', 'place_name': 'Havre', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Hill', 'locality_code': '41', 'latitude': 48.5561, 'longitude': -109.688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59521', 'place_name': 'Box Elder', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Hill', 'locality_code': '41', 'latitude': 48.2841, 'longitude': -109.8205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59525', 'place_name': 'Gildford', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Hill', 'locality_code': '41', 'latitude': 48.5927, 'longitude': -110.2836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59528', 'place_name': 'Hingham', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Hill', 'locality_code': '41', 'latitude': 48.587, 'longitude': -110.4275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59530', 'place_name': 'Inverness', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Hill', 'locality_code': '41', 'latitude': 48.593, 'longitude': -110.688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59532', 'place_name': 'Kremlin', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Hill', 'locality_code': '41', 'latitude': 48.56, 'longitude': -110.0513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59540', 'place_name': 'Rudyard', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Hill', 'locality_code': '41', 'latitude': 48.586, 'longitude': -110.5552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59631', 'place_name': 'Basin', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Jefferson', 'locality_code': '43', 'latitude': 46.3296, 'longitude': -112.1967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59632', 'place_name': 'Boulder', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Jefferson', 'locality_code': '43', 'latitude': 46.2306, 'longitude': -112.1138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59634', 'place_name': 'Clancy', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Jefferson', 'locality_code': '43', 'latitude': 46.4652, 'longitude': -111.9864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59638', 'place_name': 'Jefferson City', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Jefferson', 'locality_code': '43', 'latitude': 46.3679, 'longitude': -112.0232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59721', 'place_name': 'Cardwell', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Jefferson', 'locality_code': '43', 'latitude': 45.8941, 'longitude': -111.7809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59759', 'place_name': 'Whitehall', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Jefferson', 'locality_code': '43', 'latitude': 45.8771, 'longitude': -112.1245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59447', 'place_name': 'Geyser', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Judith Basin', 'locality_code': '45', 'latitude': 47.2598, 'longitude': -110.4839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59452', 'place_name': 'Hobson', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Judith Basin', 'locality_code': '45', 'latitude': 46.9968, 'longitude': -109.8756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59462', 'place_name': 'Moccasin', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Judith Basin', 'locality_code': '45', 'latitude': 47.0916, 'longitude': -109.8901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59469', 'place_name': 'Raynesford', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Judith Basin', 'locality_code': '45', 'latitude': 47.2604, 'longitude': -110.7047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59479', 'place_name': 'Stanford', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Judith Basin', 'locality_code': '45', 'latitude': 47.1489, 'longitude': -110.1961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59821', 'place_name': 'Arlee', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.186, 'longitude': -114.076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59824', 'place_name': 'Charlo', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.4385, 'longitude': -114.1723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59855', 'place_name': 'Pablo', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.6002, 'longitude': -114.119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59860', 'place_name': 'Polson', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.6876, 'longitude': -114.1404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59863', 'place_name': 'Ravalli', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.2772, 'longitude': -114.1807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59864', 'place_name': 'Ronan', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.5525, 'longitude': -114.1054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59865', 'place_name': 'Saint Ignatius', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.33, 'longitude': -114.0758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59910', 'place_name': 'Big Arm', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.7952, 'longitude': -114.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59914', 'place_name': 'Dayton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.8607, 'longitude': -114.2809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59915', 'place_name': 'Elmo', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.8305, 'longitude': -114.3496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59929', 'place_name': 'Proctor', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.9404, 'longitude': -114.3832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59931', 'place_name': 'Rollins', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lake', 'locality_code': '47', 'latitude': 47.9182, 'longitude': -114.225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59410', 'place_name': 'Augusta', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 47.4537, 'longitude': -112.3883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59601', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.6131, 'longitude': -112.0213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59602', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.7074, 'longitude': -111.958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59604', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.6672, 'longitude': -111.9689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59620', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.5927, 'longitude': -112.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59623', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.5901, 'longitude': -112.0402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59624', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.5927, 'longitude': -112.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59625', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.6018, 'longitude': -112.0413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59626', 'place_name': 'Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.5927, 'longitude': -112.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59633', 'place_name': 'Canyon Creek', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.7627, 'longitude': -112.2795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59635', 'place_name': 'East Helena', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.5973, 'longitude': -111.9051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59636', 'place_name': 'Fort Harrison', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.6197, 'longitude': -112.1099, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59639', 'place_name': 'Lincoln', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.9575, 'longitude': -112.6651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59640', 'place_name': 'Marysville', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 46.7499, 'longitude': -112.2994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59648', 'place_name': 'Wolf Creek', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lewis and Clark', 'locality_code': '49', 'latitude': 47.0856, 'longitude': -112.1476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59522', 'place_name': 'Chester', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Liberty', 'locality_code': '51', 'latitude': 48.4541, 'longitude': -110.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59531', 'place_name': 'Joplin', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Liberty', 'locality_code': '51', 'latitude': 48.6498, 'longitude': -110.7914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59545', 'place_name': 'Whitlash', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Liberty', 'locality_code': '51', 'latitude': 48.911, 'longitude': -111.1075, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59917', 'place_name': 'Eureka', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lincoln', 'locality_code': '53', 'latitude': 48.8428, 'longitude': -115.0049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59918', 'place_name': 'Fortine', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lincoln', 'locality_code': '53', 'latitude': 48.7586, 'longitude': -114.8809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59923', 'place_name': 'Libby', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lincoln', 'locality_code': '53', 'latitude': 48.3773, 'longitude': -115.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59930', 'place_name': 'Rexford', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lincoln', 'locality_code': '53', 'latitude': 48.9179, 'longitude': -115.2129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59933', 'place_name': 'Stryker', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lincoln', 'locality_code': '53', 'latitude': 48.6741, 'longitude': -114.7702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59934', 'place_name': 'Trego', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lincoln', 'locality_code': '53', 'latitude': 48.7052, 'longitude': -114.8693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59935', 'place_name': 'Troy', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Lincoln', 'locality_code': '53', 'latitude': 48.4791, 'longitude': -115.8817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59214', 'place_name': 'Brockway', 'state': 'Montana', 'state_ab': 'MT', 'county': 'McCone', 'locality_code': '55', 'latitude': 47.2485, 'longitude': -105.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59215', 'place_name': 'Circle', 'state': 'Montana', 'state_ab': 'MT', 'county': 'McCone', 'locality_code': '55', 'latitude': 47.4264, 'longitude': -105.6148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59274', 'place_name': 'Vida', 'state': 'Montana', 'state_ab': 'MT', 'county': 'McCone', 'locality_code': '55', 'latitude': 47.832, 'longitude': -105.493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59710', 'place_name': 'Alder', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.1939, 'longitude': -112.0568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59720', 'place_name': 'Cameron', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.139, 'longitude': -111.6508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59729', 'place_name': 'Ennis', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.3545, 'longitude': -111.687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59735', 'place_name': 'Harrison', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.7423, 'longitude': -111.8461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59740', 'place_name': 'Mc Allister', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.408, 'longitude': -111.7761, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59745', 'place_name': 'Norris', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.5323, 'longitude': -111.6943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59747', 'place_name': 'Pony', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.6585, 'longitude': -111.8944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59749', 'place_name': 'Sheridan', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.423, 'longitude': -112.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59751', 'place_name': 'Silver Star', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.7, 'longitude': -112.2535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59754', 'place_name': 'Twin Bridges', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.5311, 'longitude': -112.3495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59755', 'place_name': 'Virginia City', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Madison', 'locality_code': '57', 'latitude': 45.2938, 'longitude': -111.9461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59053', 'place_name': 'Martinsdale', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Meagher', 'locality_code': '59', 'latitude': 46.4581, 'longitude': -110.4324, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59642', 'place_name': 'Ringling', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Meagher', 'locality_code': '59', 'latitude': 46.2716, 'longitude': -110.8072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59645', 'place_name': 'White Sulphur Springs', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Meagher', 'locality_code': '59', 'latitude': 46.6332, 'longitude': -111.0506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59820', 'place_name': 'Alberton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Mineral', 'locality_code': '61', 'latitude': 46.9806, 'longitude': -114.4921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59830', 'place_name': 'De Borgia', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Mineral', 'locality_code': '61', 'latitude': 47.3888, 'longitude': -115.3479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59842', 'place_name': 'Haugan', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Mineral', 'locality_code': '61', 'latitude': 47.3833, 'longitude': -115.3996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59866', 'place_name': 'Saint Regis', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Mineral', 'locality_code': '61', 'latitude': 47.3369, 'longitude': -115.1703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59867', 'place_name': 'Saltese', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Mineral', 'locality_code': '61', 'latitude': 47.4102, 'longitude': -115.5096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59872', 'place_name': 'Superior', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Mineral', 'locality_code': '61', 'latitude': 47.1721, 'longitude': -114.8885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59801', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.8563, 'longitude': -114.0252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59802', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.9006, 'longitude': -114.0027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59803', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.8224, 'longitude': -114.0265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59804', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.8467, 'longitude': -114.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59806', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.8721, 'longitude': -113.994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59807', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.9103, 'longitude': -113.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59808', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.9776, 'longitude': -114.0619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59812', 'place_name': 'Missoula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.8721, 'longitude': -113.994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59823', 'place_name': 'Bonner', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.8733, 'longitude': -113.8645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59825', 'place_name': 'Clinton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.7673, 'longitude': -113.7038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59826', 'place_name': 'Condon', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 47.5097, 'longitude': -113.7075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59834', 'place_name': 'Frenchtown', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 47.0471, 'longitude': -114.2683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59846', 'place_name': 'Huson', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 47.066, 'longitude': -114.4219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59847', 'place_name': 'Lolo', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.7585, 'longitude': -114.1097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59851', 'place_name': 'Milltown', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 46.8737, 'longitude': -113.8783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59868', 'place_name': 'Seeley Lake', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Missoula', 'locality_code': '63', 'latitude': 47.1789, 'longitude': -113.481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59054', 'place_name': 'Melstone', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Musselshell', 'locality_code': '65', 'latitude': 46.5986, 'longitude': -107.8692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59059', 'place_name': 'Musselshell', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Musselshell', 'locality_code': '65', 'latitude': 46.5186, 'longitude': -108.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59072', 'place_name': 'Roundup', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Musselshell', 'locality_code': '65', 'latitude': 46.4225, 'longitude': -108.5438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59073', 'place_name': 'Roundup', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Musselshell', 'locality_code': '65', 'latitude': 46.4452, 'longitude': -108.5418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59018', 'place_name': 'Clyde Park', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.8341, 'longitude': -110.6222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59020', 'place_name': 'Cooke City', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.0234, 'longitude': -109.907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59027', 'place_name': 'Emigrant', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.2708, 'longitude': -110.7921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59030', 'place_name': 'Gardiner', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.0849, 'longitude': -110.5715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59047', 'place_name': 'Livingston', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.6546, 'longitude': -110.5609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59065', 'place_name': 'Pray', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.3331, 'longitude': -110.7137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59081', 'place_name': 'Silver Gate', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.0046, 'longitude': -109.9854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59082', 'place_name': 'Springdale', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.7383, 'longitude': -110.2271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59086', 'place_name': 'Wilsall', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Park', 'locality_code': '67', 'latitude': 45.9484, 'longitude': -110.6061, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59084', 'place_name': 'Teigen', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Petroleum', 'locality_code': '69', 'latitude': 47.0366, 'longitude': -108.5968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59087', 'place_name': 'Winnett', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Petroleum', 'locality_code': '69', 'latitude': 46.9438, 'longitude': -108.3184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59261', 'place_name': 'Saco', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Phillips', 'locality_code': '71', 'latitude': 48.6389, 'longitude': -107.4293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59524', 'place_name': 'Dodson', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Phillips', 'locality_code': '71', 'latitude': 48.395, 'longitude': -108.2465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59537', 'place_name': 'Loring', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Phillips', 'locality_code': '71', 'latitude': 48.7983, 'longitude': -107.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59538', 'place_name': 'Malta', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Phillips', 'locality_code': '71', 'latitude': 48.3692, 'longitude': -107.8408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59544', 'place_name': 'Whitewater', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Phillips', 'locality_code': '71', 'latitude': 48.7595, 'longitude': -107.6276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59546', 'place_name': 'Zortman', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Phillips', 'locality_code': '71', 'latitude': 47.7698, 'longitude': -108.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59416', 'place_name': 'Brady', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Pondera', 'locality_code': '73', 'latitude': 48.0312, 'longitude': -111.755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59425', 'place_name': 'Conrad', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Pondera', 'locality_code': '73', 'latitude': 48.1783, 'longitude': -111.9397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59432', 'place_name': 'Dupuyer', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Pondera', 'locality_code': '73', 'latitude': 48.1925, 'longitude': -112.4995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59448', 'place_name': 'Heart Butte', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Pondera', 'locality_code': '73', 'latitude': 48.2777, 'longitude': -112.8456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59456', 'place_name': 'Ledger', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Pondera', 'locality_code': '73', 'latitude': 48.2643, 'longitude': -111.3886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59486', 'place_name': 'Valier', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Pondera', 'locality_code': '73', 'latitude': 48.2795, 'longitude': -112.3033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59062', 'place_name': 'Otter', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powder River', 'locality_code': '75', 'latitude': 45.0903, 'longitude': -106.1499, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59314', 'place_name': 'Biddle', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powder River', 'locality_code': '75', 'latitude': 45.0994, 'longitude': -105.3383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59317', 'place_name': 'Broadus', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powder River', 'locality_code': '75', 'latitude': 45.2572, 'longitude': -105.2568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59343', 'place_name': 'Olive', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powder River', 'locality_code': '75', 'latitude': 45.5506, 'longitude': -105.528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59345', 'place_name': 'Powderville', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powder River', 'locality_code': '75', 'latitude': 45.7589, 'longitude': -105.1153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59713', 'place_name': 'Avon', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powell', 'locality_code': '77', 'latitude': 46.5972, 'longitude': -112.602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59722', 'place_name': 'Deer Lodge', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powell', 'locality_code': '77', 'latitude': 46.3881, 'longitude': -112.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59728', 'place_name': 'Elliston', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powell', 'locality_code': '77', 'latitude': 46.5034, 'longitude': -112.4007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59731', 'place_name': 'Garrison', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powell', 'locality_code': '77', 'latitude': 46.5948, 'longitude': -112.7756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59733', 'place_name': 'Gold Creek', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powell', 'locality_code': '77', 'latitude': 46.59, 'longitude': -112.9706, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59843', 'place_name': 'Helmville', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powell', 'locality_code': '77', 'latitude': 46.83, 'longitude': -112.9413, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59854', 'place_name': 'Ovando', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Powell', 'locality_code': '77', 'latitude': 47.0067, 'longitude': -113.0905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59326', 'place_name': 'Fallon', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Prairie', 'locality_code': '79', 'latitude': 46.7866, 'longitude': -105.1161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59341', 'place_name': 'Mildred', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Prairie', 'locality_code': '79', 'latitude': 46.6758, 'longitude': -104.96, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59349', 'place_name': 'Terry', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Prairie', 'locality_code': '79', 'latitude': 46.829, 'longitude': -105.3706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59827', 'place_name': 'Conner', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 45.919, 'longitude': -114.059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59828', 'place_name': 'Corvallis', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.3142, 'longitude': -114.096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59829', 'place_name': 'Darby', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.028, 'longitude': -114.1938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59833', 'place_name': 'Florence', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.631, 'longitude': -114.0945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59835', 'place_name': 'Grantsdale', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.2035, 'longitude': -114.1418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59840', 'place_name': 'Hamilton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.2395, 'longitude': -114.1679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59841', 'place_name': 'Pinesdale', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.3329, 'longitude': -114.2235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59870', 'place_name': 'Stevensville', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.5267, 'longitude': -114.0478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59871', 'place_name': 'Sula', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 45.8433, 'longitude': -113.8748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59875', 'place_name': 'Victor', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Ravalli', 'locality_code': '81', 'latitude': 46.4005, 'longitude': -114.1665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59217', 'place_name': 'Crane', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Richland', 'locality_code': '83', 'latitude': 47.5758, 'longitude': -104.2624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59221', 'place_name': 'Fairview', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Richland', 'locality_code': '83', 'latitude': 47.8916, 'longitude': -104.2302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59243', 'place_name': 'Lambert', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Richland', 'locality_code': '83', 'latitude': 47.7459, 'longitude': -104.5987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59262', 'place_name': 'Savage', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Richland', 'locality_code': '83', 'latitude': 47.5194, 'longitude': -104.2845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59270', 'place_name': 'Sidney', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Richland', 'locality_code': '83', 'latitude': 47.713, 'longitude': -104.1634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59201', 'place_name': 'Wolf Point', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Roosevelt', 'locality_code': '85', 'latitude': 48.1119, 'longitude': -105.6293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59212', 'place_name': 'Bainville', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Roosevelt', 'locality_code': '85', 'latitude': 48.158, 'longitude': -104.1995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59213', 'place_name': 'Brockton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Roosevelt', 'locality_code': '85', 'latitude': 48.2101, 'longitude': -104.8548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59218', 'place_name': 'Culbertson', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Roosevelt', 'locality_code': '85', 'latitude': 48.1495, 'longitude': -104.5132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59226', 'place_name': 'Froid', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Roosevelt', 'locality_code': '85', 'latitude': 48.3345, 'longitude': -104.4961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59242', 'place_name': 'Homestead', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Roosevelt', 'locality_code': '85', 'latitude': 48.435, 'longitude': -104.4389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59255', 'place_name': 'Poplar', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Roosevelt', 'locality_code': '85', 'latitude': 48.1307, 'longitude': -105.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59003', 'place_name': 'Ashland', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 45.5827, 'longitude': -106.2797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59004', 'place_name': 'Ashland', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 45.5944, 'longitude': -106.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59012', 'place_name': 'Birney', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 45.2862, 'longitude': -106.5095, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59039', 'place_name': 'Ingomar', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 46.5767, 'longitude': -107.3723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59043', 'place_name': 'Lame Deer', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 45.6032, 'longitude': -106.5654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59083', 'place_name': 'Sumatra', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 46.6183, 'longitude': -107.5512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59312', 'place_name': 'Angela', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 46.73, 'longitude': -106.2011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59323', 'place_name': 'Colstrip', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 45.9344, 'longitude': -106.6368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59327', 'place_name': 'Forsyth', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 46.2819, 'longitude': -106.6991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59333', 'place_name': 'Hathaway', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 46.2761, 'longitude': -106.1967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59347', 'place_name': 'Rosebud', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Rosebud', 'locality_code': '87', 'latitude': 46.4352, 'longitude': -106.352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59831', 'place_name': 'Dixon', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 47.3131, 'longitude': -114.3056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59844', 'place_name': 'Heron', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 48.0537, 'longitude': -115.9407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59845', 'place_name': 'Hot Springs', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 47.5914, 'longitude': -114.6597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59848', 'place_name': 'Lonepine', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 47.7251, 'longitude': -114.657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59853', 'place_name': 'Noxon', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 48.0768, 'longitude': -115.8582, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59856', 'place_name': 'Paradise', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 47.3878, 'longitude': -114.799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59859', 'place_name': 'Plains', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 47.4734, 'longitude': -114.893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59873', 'place_name': 'Thompson Falls', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 47.6016, 'longitude': -115.3602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59874', 'place_name': 'Trout Creek', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sanders', 'locality_code': '89', 'latitude': 47.8111, 'longitude': -115.5592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59211', 'place_name': 'Antelope', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.6968, 'longitude': -104.4529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59219', 'place_name': 'Dagmar', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.6093, 'longitude': -104.2401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59247', 'place_name': 'Medicine Lake', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.4852, 'longitude': -104.4375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59252', 'place_name': 'Outlook', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.8817, 'longitude': -104.7415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59254', 'place_name': 'Plentywood', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.7788, 'longitude': -104.56, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59256', 'place_name': 'Raymond', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.8764, 'longitude': -104.5802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59257', 'place_name': 'Redstone', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.728, 'longitude': -104.9402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59258', 'place_name': 'Reserve', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.5905, 'longitude': -104.6279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59275', 'place_name': 'Westby', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sheridan', 'locality_code': '91', 'latitude': 48.8587, 'longitude': -104.1247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59701', 'place_name': 'Butte', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 45.9979, 'longitude': -112.5988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59702', 'place_name': 'Butte', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 45.9053, 'longitude': -112.6377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59703', 'place_name': 'Butte', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 45.9053, 'longitude': -112.6377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59707', 'place_name': 'Butte', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 46.0038, 'longitude': -112.5347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59727', 'place_name': 'Divide', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 45.803, 'longitude': -112.809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59743', 'place_name': 'Melrose', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 45.6319, 'longitude': -112.6845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59748', 'place_name': 'Ramsay', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 46.0058, 'longitude': -112.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59750', 'place_name': 'Butte', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Silver Bow', 'locality_code': '93', 'latitude': 46.0033, 'longitude': -112.7159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59001', 'place_name': 'Absarokee', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.5154, 'longitude': -109.4692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59019', 'place_name': 'Columbus', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.6262, 'longitude': -109.2571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59028', 'place_name': 'Fishtail', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.4002, 'longitude': -109.5821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59057', 'place_name': 'Molt', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.8615, 'longitude': -108.9731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59061', 'place_name': 'Nye', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.441, 'longitude': -109.8271, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59063', 'place_name': 'Park City', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.6329, 'longitude': -108.9293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59067', 'place_name': 'Rapelje', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.9795, 'longitude': -109.2761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59069', 'place_name': 'Reed Point', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Stillwater', 'locality_code': '95', 'latitude': 45.7439, 'longitude': -109.5224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59011', 'place_name': 'Big Timber', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sweet Grass', 'locality_code': '97', 'latitude': 45.8283, 'longitude': -109.9631, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59033', 'place_name': 'Greycliff', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sweet Grass', 'locality_code': '97', 'latitude': 45.7633, 'longitude': -109.7846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59052', 'place_name': 'Mc Leod', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sweet Grass', 'locality_code': '97', 'latitude': 45.5963, 'longitude': -109.9357, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59055', 'place_name': 'Melville', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Sweet Grass', 'locality_code': '97', 'latitude': 46.104, 'longitude': -109.7808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59419', 'place_name': 'Bynum', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Teton', 'locality_code': '99', 'latitude': 47.99, 'longitude': -112.2762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59422', 'place_name': 'Choteau', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Teton', 'locality_code': '99', 'latitude': 47.838, 'longitude': -112.2021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59433', 'place_name': 'Dutton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Teton', 'locality_code': '99', 'latitude': 47.8601, 'longitude': -111.69, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59436', 'place_name': 'Fairfield', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Teton', 'locality_code': '99', 'latitude': 47.6143, 'longitude': -112.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59467', 'place_name': 'Pendroy', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Teton', 'locality_code': '99', 'latitude': 48.0879, 'longitude': -112.3261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59468', 'place_name': 'Power', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Teton', 'locality_code': '99', 'latitude': 47.6798, 'longitude': -111.7169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59435', 'place_name': 'Ethridge', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.5578, 'longitude': -112.1206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59444', 'place_name': 'Galata', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.8111, 'longitude': -111.4704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59454', 'place_name': 'Kevin', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.7508, 'longitude': -111.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59461', 'place_name': 'Lothair', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.4717, 'longitude': -111.2322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59466', 'place_name': 'Oilmont', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.74, 'longitude': -111.8409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59474', 'place_name': 'Shelby', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.5037, 'longitude': -111.8391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59482', 'place_name': 'Sunburst', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.8516, 'longitude': -111.7442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59484', 'place_name': 'Sweet Grass', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Toole', 'locality_code': '101', 'latitude': 48.9961, 'longitude': -111.9606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59010', 'place_name': 'Bighorn', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Treasure', 'locality_code': '103', 'latitude': 45.997, 'longitude': -107.31, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59038', 'place_name': 'Hysham', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Treasure', 'locality_code': '103', 'latitude': 46.2765, 'longitude': -107.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59076', 'place_name': 'Sanders', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Treasure', 'locality_code': '103', 'latitude': 46.2914, 'longitude': -107.0967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59223', 'place_name': 'Fort Peck', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.0089, 'longitude': -106.4486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59225', 'place_name': 'Frazer', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.2959, 'longitude': -106.0324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59230', 'place_name': 'Glasgow', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.2034, 'longitude': -106.6094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59231', 'place_name': 'Saint Marie', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.4039, 'longitude': -106.5428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59240', 'place_name': 'Glentana', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.8481, 'longitude': -106.2495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59241', 'place_name': 'Hinsdale', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.4007, 'longitude': -107.0098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59244', 'place_name': 'Larslan', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.5822, 'longitude': -106.2835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59248', 'place_name': 'Nashua', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.1322, 'longitude': -106.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59250', 'place_name': 'Opheim', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.8702, 'longitude': -106.3658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59260', 'place_name': 'Richland', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.6507, 'longitude': -106.1192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59273', 'place_name': 'Vandalia', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Valley', 'locality_code': '105', 'latitude': 48.3547, 'longitude': -106.9098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59036', 'place_name': 'Harlowton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Wheatland', 'locality_code': '107', 'latitude': 46.4477, 'longitude': -109.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59078', 'place_name': 'Shawmut', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Wheatland', 'locality_code': '107', 'latitude': 46.3869, 'longitude': -109.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59085', 'place_name': 'Two Dot', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Wheatland', 'locality_code': '107', 'latitude': 46.4242, 'longitude': -110.0712, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '59453', 'place_name': 'Judith Gap', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Wheatland', 'locality_code': '107', 'latitude': 46.6623, 'longitude': -109.6755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59353', 'place_name': 'Wibaux', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Wibaux', 'locality_code': '109', 'latitude': 46.9646, 'longitude': -104.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59002', 'place_name': 'Acton', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.9291, 'longitude': -108.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59006', 'place_name': 'Ballantine', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.9547, 'longitude': -108.1231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59015', 'place_name': 'Broadview', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 46.0821, 'longitude': -108.8091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59024', 'place_name': 'Custer', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 46.1302, 'longitude': -107.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59037', 'place_name': 'Huntley', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.8905, 'longitude': -108.285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59044', 'place_name': 'Laurel', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.6745, 'longitude': -108.769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59064', 'place_name': 'Pompeys Pillar', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.9838, 'longitude': -107.9154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59079', 'place_name': 'Shepherd', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.9461, 'longitude': -108.3426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59088', 'place_name': 'Worden', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.9779, 'longitude': -108.1533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59101', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7745, 'longitude': -108.5005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59102', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7813, 'longitude': -108.5727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59103', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59104', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59105', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.9497, 'longitude': -108.599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59106', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7753, 'longitude': -108.6519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59107', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.8252, 'longitude': -108.3934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59108', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59111', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59112', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59114', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59115', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59116', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '59117', 'place_name': 'Billings', 'state': 'Montana', 'state_ab': 'MT', 'county': 'Yellowstone', 'locality_code': '111', 'latitude': 45.7833, 'longitude': -108.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27201', 'place_name': 'Alamance', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.0318, 'longitude': -79.4856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27202', 'place_name': 'Altamahaw', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.1855, 'longitude': -79.5055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27215', 'place_name': 'Burlington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.0318, 'longitude': -79.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27216', 'place_name': 'Burlington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.0475, 'longitude': -79.4797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27217', 'place_name': 'Burlington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.1288, 'longitude': -79.4114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27244', 'place_name': 'Elon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.1029, 'longitude': -79.5067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27253', 'place_name': 'Graham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.031, 'longitude': -79.3814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27258', 'place_name': 'Haw River', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.0915, 'longitude': -79.3642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27302', 'place_name': 'Mebane', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.0979, 'longitude': -79.2719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27340', 'place_name': 'Saxapahaw', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 35.9488, 'longitude': -79.3297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27349', 'place_name': 'Snow Camp', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 35.9066, 'longitude': -79.4279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27359', 'place_name': 'Swepsonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alamance', 'locality_code': '1', 'latitude': 36.0214, 'longitude': -79.3574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28636', 'place_name': 'Hiddenite', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alexander', 'locality_code': '3', 'latitude': 35.9504, 'longitude': -81.0487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28678', 'place_name': 'Stony Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alexander', 'locality_code': '3', 'latitude': 35.8661, 'longitude': -81.0641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28681', 'place_name': 'Taylorsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alexander', 'locality_code': '3', 'latitude': 35.901, 'longitude': -81.2124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28623', 'place_name': 'Ennice', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 36.5253, 'longitude': -80.9771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28627', 'place_name': 'Glade Valley', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 36.4429, 'longitude': -81.0168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28663', 'place_name': 'Piney Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 36.5276, 'longitude': -81.3019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28668', 'place_name': 'Roaring Gap', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 36.3836, 'longitude': -81.0188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28675', 'place_name': 'Sparta', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 36.5089, 'longitude': -81.1384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28007', 'place_name': 'Ansonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Anson', 'locality_code': '7', 'latitude': 35.1046, 'longitude': -80.1092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28091', 'place_name': 'Lilesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Anson', 'locality_code': '7', 'latitude': 34.9689, 'longitude': -79.9721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28102', 'place_name': 'Mc Farlan', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Anson', 'locality_code': '7', 'latitude': 34.8136, 'longitude': -79.9776, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28119', 'place_name': 'Morven', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Anson', 'locality_code': '7', 'latitude': 34.8511, 'longitude': -80.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28133', 'place_name': 'Peachland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Anson', 'locality_code': '7', 'latitude': 35.0054, 'longitude': -80.2829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28135', 'place_name': 'Polkton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Anson', 'locality_code': '7', 'latitude': 34.9823, 'longitude': -80.1538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28170', 'place_name': 'Wadesboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Anson', 'locality_code': '7', 'latitude': 34.9809, 'longitude': -80.0696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28615', 'place_name': 'Creston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.45, 'longitude': -81.6506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28617', 'place_name': 'Crumpler', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.4641, 'longitude': -81.4039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28626', 'place_name': 'Fleetwood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.2814, 'longitude': -81.514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28629', 'place_name': 'Glendale Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.3405, 'longitude': -81.3653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28631', 'place_name': 'Grassy Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.5415, 'longitude': -81.4468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28640', 'place_name': 'Jefferson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.409, 'longitude': -81.4396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28643', 'place_name': 'Lansing', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.5176, 'longitude': -81.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28644', 'place_name': 'Laurel Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.4449, 'longitude': -81.2606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28672', 'place_name': 'Scottville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.4833, 'longitude': -81.3276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28684', 'place_name': 'Todd', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.3245, 'longitude': -81.5874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28693', 'place_name': 'Warrensville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.4572, 'longitude': -81.5465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28694', 'place_name': 'West Jefferson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Ashe', 'locality_code': '9', 'latitude': 36.3776, 'longitude': -81.4872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28604', 'place_name': 'Banner Elk', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.1705, 'longitude': -81.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28616', 'place_name': 'Crossnore', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.0218, 'longitude': -81.9296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28622', 'place_name': 'Elk Park', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.1646, 'longitude': -81.9639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28646', 'place_name': 'Linville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.0665, 'longitude': -81.8704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28652', 'place_name': 'Minneapolis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.0993, 'longitude': -81.9871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28653', 'place_name': 'Montezuma', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.0651, 'longitude': -81.9017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28657', 'place_name': 'Newland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.059, 'longitude': -81.9303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28662', 'place_name': 'Pineola', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.0285, 'longitude': -81.8915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28664', 'place_name': 'Plumtree', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Avery', 'locality_code': '11', 'latitude': 36.0441, 'longitude': -82.0037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27806', 'place_name': 'Aurora', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.3023, 'longitude': -76.7994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27808', 'place_name': 'Bath', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.4702, 'longitude': -76.7715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27810', 'place_name': 'Belhaven', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.4458, 'longitude': -76.6391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27814', 'place_name': 'Blounts Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.382, 'longitude': -76.925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27817', 'place_name': 'Chocowinity', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.4814, 'longitude': -77.0868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27821', 'place_name': 'Edward', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.3236, 'longitude': -76.8794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27860', 'place_name': 'Pantego', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.6201, 'longitude': -76.6988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27865', 'place_name': 'Pinetown', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.5758, 'longitude': -76.8076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27889', 'place_name': 'Washington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 35.5884, 'longitude': -77.1404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27805', 'place_name': 'Aulander', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.1475, 'longitude': -77.1141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27847', 'place_name': 'Kelford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.1871, 'longitude': -77.1898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27849', 'place_name': 'Lewiston Woodville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.0933, 'longitude': -77.1439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27872', 'place_name': 'Roxobel', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.195, 'longitude': -77.2602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27924', 'place_name': 'Colerain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.1901, 'longitude': -76.8548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27957', 'place_name': 'Merry Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.0871, 'longitude': -76.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27967', 'place_name': 'Powellsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.2257, 'longitude': -76.933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27983', 'place_name': 'Windsor', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bertie', 'locality_code': '15', 'latitude': 36.0159, 'longitude': -76.9336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28320', 'place_name': 'Bladenboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.5658, 'longitude': -78.7793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28332', 'place_name': 'Dublin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.6568, 'longitude': -78.7264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28337', 'place_name': 'Elizabethtown', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.6471, 'longitude': -78.5747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28392', 'place_name': 'Tar Heel', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.7465, 'longitude': -78.8134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28399', 'place_name': 'White Oak', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.7662, 'longitude': -78.7301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28433', 'place_name': 'Clarkton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.503, 'longitude': -78.6313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28434', 'place_name': 'Council', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.429, 'longitude': -78.4115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28448', 'place_name': 'Kelly', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Bladen', 'locality_code': '17', 'latitude': 34.4591, 'longitude': -78.2942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28404', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 34.2257, 'longitude': -77.9447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28420', 'place_name': 'Ash', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 34.0659, 'longitude': -78.5056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28422', 'place_name': 'Bolivia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 34.026, 'longitude': -78.1681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28451', 'place_name': 'Leland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 34.268, 'longitude': -78.0578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28452', 'place_name': 'Longwood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.9973, 'longitude': -78.5541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28459', 'place_name': 'Shallotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.9334, 'longitude': -78.4129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28461', 'place_name': 'Southport', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.9654, 'longitude': -78.0359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28462', 'place_name': 'Supply', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 34.0231, 'longitude': -78.2884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28465', 'place_name': 'Oak Island', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.9161, 'longitude': -78.1255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28467', 'place_name': 'Calabash', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.9047, 'longitude': -78.5744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28468', 'place_name': 'Sunset Beach', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.8836, 'longitude': -78.52, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28469', 'place_name': 'Ocean Isle Beach', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.8913, 'longitude': -78.4298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28470', 'place_name': 'Shallotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 33.9637, 'longitude': -78.4064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28479', 'place_name': 'Winnabow', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Brunswick', 'locality_code': '19', 'latitude': 34.1553, 'longitude': -78.0558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28701', 'place_name': 'Alexander', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.7064, 'longitude': -82.6311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28704', 'place_name': 'Arden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.4637, 'longitude': -82.5354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28709', 'place_name': 'Barnardsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.7748, 'longitude': -82.4567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28711', 'place_name': 'Black Mountain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.5986, 'longitude': -82.2902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28715', 'place_name': 'Candler', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.5376, 'longitude': -82.7001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28728', 'place_name': 'Enka', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.4988, 'longitude': -82.708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28730', 'place_name': 'Fairview', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.5258, 'longitude': -82.3985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28748', 'place_name': 'Leicester', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6498, 'longitude': -82.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28757', 'place_name': 'Montreat', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6415, 'longitude': -82.3156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28759', 'place_name': 'Mills River', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.3906, 'longitude': -82.568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28770', 'place_name': 'Ridgecrest', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6186, 'longitude': -82.3005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28776', 'place_name': 'Skyland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.4835, 'longitude': -82.5207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28778', 'place_name': 'Swannanoa', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6172, 'longitude': -82.407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28787', 'place_name': 'Weaverville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.7126, 'longitude': -82.5491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28801', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.5971, 'longitude': -82.5565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28802', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6237, 'longitude': -82.6671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28803', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.5393, 'longitude': -82.518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28804', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6374, 'longitude': -82.5646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28805', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6004, 'longitude': -82.4918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28806', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.5808, 'longitude': -82.6078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28810', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6203, 'longitude': -82.5286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28813', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.5004, 'longitude': -82.5026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28814', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6648, 'longitude': -82.4927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28815', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6203, 'longitude': -82.5286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28816', 'place_name': 'Asheville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Buncombe', 'locality_code': '21', 'latitude': 35.6203, 'longitude': -82.5286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28612', 'place_name': 'Connelly Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.7429, 'longitude': -81.5134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28619', 'place_name': 'Drexel', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.7579, 'longitude': -81.6043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28628', 'place_name': 'Glen Alpine', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.729, 'longitude': -81.7793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28637', 'place_name': 'Hildebran', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.718, 'longitude': -81.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28641', 'place_name': 'Jonas Ridge', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.9726, 'longitude': -81.8948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28647', 'place_name': 'Linville Falls', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.9593, 'longitude': -81.9429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28655', 'place_name': 'Morganton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.7346, 'longitude': -81.7042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28666', 'place_name': 'Icard', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.7274, 'longitude': -81.4706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28671', 'place_name': 'Rutherford College', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.7485, 'longitude': -81.5226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28680', 'place_name': 'Morganton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.7507, 'longitude': -81.6953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28690', 'place_name': 'Valdese', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Burke', 'locality_code': '23', 'latitude': 35.7447, 'longitude': -81.567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28025', 'place_name': 'Concord', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.3716, 'longitude': -80.53, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28026', 'place_name': 'Concord', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.3463, 'longitude': -80.5411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28027', 'place_name': 'Concord', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.4141, 'longitude': -80.6162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28075', 'place_name': 'Harrisburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.3247, 'longitude': -80.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28081', 'place_name': 'Kannapolis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.502, 'longitude': -80.6359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28082', 'place_name': 'Kannapolis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.3463, 'longitude': -80.5411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28083', 'place_name': 'Kannapolis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.4848, 'longitude': -80.6015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28107', 'place_name': 'Midland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.2477, 'longitude': -80.5319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28124', 'place_name': 'Mount Pleasant', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cabarrus', 'locality_code': '25', 'latitude': 35.4146, 'longitude': -80.4171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28611', 'place_name': 'Collettsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caldwell', 'locality_code': '27', 'latitude': 35.9946, 'longitude': -81.7266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28630', 'place_name': 'Granite Falls', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caldwell', 'locality_code': '27', 'latitude': 35.7965, 'longitude': -81.4306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28633', 'place_name': 'Lenoir', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caldwell', 'locality_code': '27', 'latitude': 35.914, 'longitude': -81.539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28638', 'place_name': 'Hudson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caldwell', 'locality_code': '27', 'latitude': 35.8403, 'longitude': -81.4897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28645', 'place_name': 'Lenoir', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caldwell', 'locality_code': '27', 'latitude': 35.9149, 'longitude': -81.5398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28661', 'place_name': 'Patterson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caldwell', 'locality_code': '27', 'latitude': 35.9973, 'longitude': -81.5626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28667', 'place_name': 'Rhodhiss', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caldwell', 'locality_code': '27', 'latitude': 35.7772, 'longitude': -81.4302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27921', 'place_name': 'Camden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Camden', 'locality_code': '29', 'latitude': 36.325, 'longitude': -76.15, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27974', 'place_name': 'Shiloh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Camden', 'locality_code': '29', 'latitude': 36.2584, 'longitude': -76.0432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27976', 'place_name': 'South Mills', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Camden', 'locality_code': '29', 'latitude': 36.4536, 'longitude': -76.3033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28511', 'place_name': 'Atlantic', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.8888, 'longitude': -76.3521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28512', 'place_name': 'Atlantic Beach', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.6991, 'longitude': -76.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28516', 'place_name': 'Beaufort', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.758, 'longitude': -76.6228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28520', 'place_name': 'Cedar Island', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 35.0082, 'longitude': -76.316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28524', 'place_name': 'Davis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7974, 'longitude': -76.4602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28528', 'place_name': 'Gloucester', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7344, 'longitude': -76.5394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28531', 'place_name': 'Harkers Island', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.6966, 'longitude': -76.5583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28553', 'place_name': 'Marshallberg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7265, 'longitude': -76.5173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28557', 'place_name': 'Morehead City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7253, 'longitude': -76.7531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28570', 'place_name': 'Newport', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7551, 'longitude': -76.9069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28575', 'place_name': 'Salter Path', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.6885, 'longitude': -76.8861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28577', 'place_name': 'Sealevel', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.8769, 'longitude': -76.3898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28579', 'place_name': 'Smyrna', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7593, 'longitude': -76.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28581', 'place_name': 'Stacy', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.8412, 'longitude': -76.4289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28582', 'place_name': 'Stella', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7777, 'longitude': -77.1308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28589', 'place_name': 'Williston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.7893, 'longitude': -76.5052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28594', 'place_name': 'Emerald Isle', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Carteret', 'locality_code': '31', 'latitude': 34.6662, 'longitude': -77.026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27212', 'place_name': 'Blanch', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caswell', 'locality_code': '33', 'latitude': 36.4664, 'longitude': -79.2755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27291', 'place_name': 'Leasburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caswell', 'locality_code': '33', 'latitude': 36.4151, 'longitude': -79.1942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27305', 'place_name': 'Milton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caswell', 'locality_code': '33', 'latitude': 36.5158, 'longitude': -79.2087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27311', 'place_name': 'Pelham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caswell', 'locality_code': '33', 'latitude': 36.4899, 'longitude': -79.4736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27314', 'place_name': 'Prospect Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caswell', 'locality_code': '33', 'latitude': 36.2932, 'longitude': -79.2156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27315', 'place_name': 'Providence', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caswell', 'locality_code': '33', 'latitude': 36.4873, 'longitude': -79.4041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27379', 'place_name': 'Yanceyville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Caswell', 'locality_code': '33', 'latitude': 36.3907, 'longitude': -79.3465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28601', 'place_name': 'Hickory', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.7576, 'longitude': -81.3289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28602', 'place_name': 'Hickory', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.6884, 'longitude': -81.3612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28603', 'place_name': 'Hickory', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.6799, 'longitude': -81.2872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28609', 'place_name': 'Catawba', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.6757, 'longitude': -81.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28610', 'place_name': 'Claremont', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.7211, 'longitude': -81.1297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28613', 'place_name': 'Conover', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.7313, 'longitude': -81.2165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28650', 'place_name': 'Maiden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.5759, 'longitude': -81.1745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28658', 'place_name': 'Newton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.6498, 'longitude': -81.2425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28673', 'place_name': 'Sherrills Ford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.5962, 'longitude': -81.0339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28682', 'place_name': 'Terrell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Catawba', 'locality_code': '35', 'latitude': 35.5836, 'longitude': -80.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27207', 'place_name': 'Bear Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.6129, 'longitude': -79.3726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27208', 'place_name': 'Bennett', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.5673, 'longitude': -79.5225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27213', 'place_name': 'Bonlee', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.6482, 'longitude': -79.4149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27228', 'place_name': 'Bynum', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.7835, 'longitude': -79.1298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27252', 'place_name': 'Goldston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.5643, 'longitude': -79.3385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27256', 'place_name': 'Gulf', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.5604, 'longitude': -79.2817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27312', 'place_name': 'Pittsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.7694, 'longitude': -79.1755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27344', 'place_name': 'Siler City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.7354, 'longitude': -79.4566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27559', 'place_name': 'Moncure', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chatham', 'locality_code': '37', 'latitude': 35.6306, 'longitude': -79.0839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28781', 'place_name': 'Topton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cherokee', 'locality_code': '39', 'latitude': 35.2151, 'longitude': -83.6461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28901', 'place_name': 'Andrews', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cherokee', 'locality_code': '39', 'latitude': 35.1959, 'longitude': -83.8228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28903', 'place_name': 'Culberson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cherokee', 'locality_code': '39', 'latitude': 34.9917, 'longitude': -84.1677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28905', 'place_name': 'Marble', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cherokee', 'locality_code': '39', 'latitude': 35.1475, 'longitude': -83.9381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28906', 'place_name': 'Murphy', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cherokee', 'locality_code': '39', 'latitude': 35.1312, 'longitude': -84.0388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27932', 'place_name': 'Edenton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chowan', 'locality_code': '41', 'latitude': 36.0908, 'longitude': -76.6224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27980', 'place_name': 'Tyner', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Chowan', 'locality_code': '41', 'latitude': 36.2502, 'longitude': -76.6428, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28902', 'place_name': 'Brasstown', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Clay', 'locality_code': '43', 'latitude': 35.0261, 'longitude': -83.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28904', 'place_name': 'Hayesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Clay', 'locality_code': '43', 'latitude': 35.0417, 'longitude': -83.7867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28909', 'place_name': 'Warne', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Clay', 'locality_code': '43', 'latitude': 35.0024, 'longitude': -83.9045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28017', 'place_name': 'Boiling Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.2543, 'longitude': -81.667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28020', 'place_name': 'Casar', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.5145, 'longitude': -81.6357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28038', 'place_name': 'Earl', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.197, 'longitude': -81.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28042', 'place_name': 'Fallston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.429, 'longitude': -81.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28073', 'place_name': 'Grover', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.1836, 'longitude': -81.4552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28086', 'place_name': 'Kings Mountain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.2516, 'longitude': -81.3806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28089', 'place_name': 'Lattimore', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.3182, 'longitude': -81.6607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28090', 'place_name': 'Lawndale', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.4449, 'longitude': -81.5336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28114', 'place_name': 'Mooresboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.2295, 'longitude': -81.7492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28136', 'place_name': 'Polkville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.3961, 'longitude': -81.6303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28150', 'place_name': 'Shelby', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.312, 'longitude': -81.5568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28151', 'place_name': 'Shelby', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.2924, 'longitude': -81.5356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28152', 'place_name': 'Shelby', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.2689, 'longitude': -81.5337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28169', 'place_name': 'Waco', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cleveland', 'locality_code': '45', 'latitude': 35.3615, 'longitude': -81.4287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28423', 'place_name': 'Bolton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3091, 'longitude': -78.3372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28424', 'place_name': 'Brunswick', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.2907, 'longitude': -78.6994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28430', 'place_name': 'Cerro Gordo', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3025, 'longitude': -78.9216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28431', 'place_name': 'Chadbourn', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3223, 'longitude': -78.8267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28432', 'place_name': 'Clarendon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.1761, 'longitude': -78.7637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28436', 'place_name': 'Delco', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.2838, 'longitude': -78.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28438', 'place_name': 'Evergreen', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.4204, 'longitude': -78.8947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28439', 'place_name': 'Fair Bluff', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3023, 'longitude': -79.0175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28442', 'place_name': 'Hallsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3181, 'longitude': -78.6043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28450', 'place_name': 'Lake Waccamaw', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3394, 'longitude': -78.5102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28455', 'place_name': 'Nakina', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.1153, 'longitude': -78.657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28456', 'place_name': 'Riegelwood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3471, 'longitude': -78.2575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28463', 'place_name': 'Tabor City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.1233, 'longitude': -78.8232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28472', 'place_name': 'Whiteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Columbus', 'locality_code': '47', 'latitude': 34.3241, 'longitude': -78.716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28519', 'place_name': 'Bridgeton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.1215, 'longitude': -77.0208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28523', 'place_name': 'Cove City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.2023, 'longitude': -77.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28526', 'place_name': 'Dover', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.2554, 'longitude': -77.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28527', 'place_name': 'Ernul', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.2547, 'longitude': -77.0502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28532', 'place_name': 'Havelock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 34.8968, 'longitude': -76.89, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28533', 'place_name': 'Cherry Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 34.9038, 'longitude': -76.9, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28560', 'place_name': 'New Bern', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.1204, 'longitude': -76.9842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28561', 'place_name': 'New Bern', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.1037, 'longitude': -77.0759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28562', 'place_name': 'New Bern', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.1004, 'longitude': -77.1029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28563', 'place_name': 'New Bern', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.1109, 'longitude': -77.0634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28564', 'place_name': 'New Bern', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.1109, 'longitude': -77.0634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28586', 'place_name': 'Vanceboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Craven', 'locality_code': '49', 'latitude': 35.3063, 'longitude': -77.1716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28301', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0743, 'longitude': -78.8836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28302', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0343, 'longitude': -78.9088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28303', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0742, 'longitude': -78.965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28304', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0257, 'longitude': -78.9705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28305', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.056, 'longitude': -78.9047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28306', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0019, 'longitude': -78.9364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28307', 'place_name': 'Fort Bragg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.1416, 'longitude': -79.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28308', 'place_name': 'Pope Army Airfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0635, 'longitude': -78.8943, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28309', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0397, 'longitude': -78.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28310', 'place_name': 'Fort Bragg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0506, 'longitude': -78.8038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28311', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.1294, 'longitude': -78.8982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28312', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 34.9549, 'longitude': -78.7408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28314', 'place_name': 'Fayetteville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0583, 'longitude': -79.008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28331', 'place_name': 'Cumberland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0049, 'longitude': -78.9673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28342', 'place_name': 'Falcon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.1899, 'longitude': -78.6483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28344', 'place_name': 'Godwin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.1969, 'longitude': -78.6625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28348', 'place_name': 'Hope Mills', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 34.9536, 'longitude': -78.9354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28356', 'place_name': 'Linden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.2276, 'longitude': -78.8004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28390', 'place_name': 'Spring Lake', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.183, 'longitude': -78.9786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28391', 'place_name': 'Stedman', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.0347, 'longitude': -78.6949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28395', 'place_name': 'Wade', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Cumberland', 'locality_code': '51', 'latitude': 35.1606, 'longitude': -78.7249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27916', 'place_name': 'Aydlett', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.3045, 'longitude': -75.9029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27917', 'place_name': 'Barco', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.3588, 'longitude': -75.9793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27923', 'place_name': 'Coinjock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.3751, 'longitude': -75.934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27927', 'place_name': 'Corolla', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.3206, 'longitude': -75.8132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27929', 'place_name': 'Currituck', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.4398, 'longitude': -76.0055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27939', 'place_name': 'Grandy', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.2339, 'longitude': -75.8768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27941', 'place_name': 'Harbinger', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.1025, 'longitude': -75.8169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27947', 'place_name': 'Jarvisburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.1714, 'longitude': -75.8621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27950', 'place_name': 'Knotts Island', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.5232, 'longitude': -75.9702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27956', 'place_name': 'Maple', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.3987, 'longitude': -76.0039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27958', 'place_name': 'Moyock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.4871, 'longitude': -76.1146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27964', 'place_name': 'Point Harbor', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.0781, 'longitude': -75.7983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27965', 'place_name': 'Poplar Branch', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.2737, 'longitude': -75.9097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27966', 'place_name': 'Powells Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.1207, 'longitude': -75.8273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27973', 'place_name': 'Shawboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Currituck', 'locality_code': '53', 'latitude': 36.3779, 'longitude': -76.0945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27915', 'place_name': 'Avon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.3521, 'longitude': -75.5104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27920', 'place_name': 'Buxton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.2677, 'longitude': -75.5424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27936', 'place_name': 'Frisco', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.2338, 'longitude': -75.6145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27943', 'place_name': 'Hatteras', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.2193, 'longitude': -75.6902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27948', 'place_name': 'Kill Devil Hills', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 36.0088, 'longitude': -75.6757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27949', 'place_name': 'Kitty Hawk', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 36.0646, 'longitude': -75.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27953', 'place_name': 'Manns Harbor', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.8238, 'longitude': -75.8467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27954', 'place_name': 'Manteo', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.8948, 'longitude': -75.6714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27959', 'place_name': 'Nags Head', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.8865, 'longitude': -75.6038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27968', 'place_name': 'Rodanthe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.5935, 'longitude': -75.4679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27972', 'place_name': 'Salvo', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.5546, 'longitude': -75.4693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27978', 'place_name': 'Stumpy Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.6985, 'longitude': -75.7728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27981', 'place_name': 'Wanchese', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.8622, 'longitude': -75.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27982', 'place_name': 'Waves', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Dare', 'locality_code': '55', 'latitude': 35.565, 'longitude': -75.4663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27239', 'place_name': 'Denton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.6196, 'longitude': -80.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27292', 'place_name': 'Lexington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.8231, 'longitude': -80.262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27293', 'place_name': 'Lexington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.8829, 'longitude': -80.276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27294', 'place_name': 'Lexington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.824, 'longitude': -80.2534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27295', 'place_name': 'Lexington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.8684, 'longitude': -80.315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27299', 'place_name': 'Linwood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.7562, 'longitude': -80.3749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27351', 'place_name': 'Southmont', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.6605, 'longitude': -80.2836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27360', 'place_name': 'Thomasville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.8713, 'longitude': -80.0913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27361', 'place_name': 'Thomasville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.8829, 'longitude': -80.276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27373', 'place_name': 'Wallburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 36.0101, 'longitude': -80.1392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27374', 'place_name': 'Welcome', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davidson', 'locality_code': '57', 'latitude': 35.9029, 'longitude': -80.257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27006', 'place_name': 'Advance', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davie', 'locality_code': '59', 'latitude': 36.0065, 'longitude': -80.4463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27014', 'place_name': 'Cooleemee', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davie', 'locality_code': '59', 'latitude': 35.8104, 'longitude': -80.5559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27028', 'place_name': 'Mocksville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Davie', 'locality_code': '59', 'latitude': 35.922, 'longitude': -80.537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28325', 'place_name': 'Calypso', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 35.1538, 'longitude': -78.1053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28341', 'place_name': 'Faison', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 35.1199, 'longitude': -78.118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28349', 'place_name': 'Kenansville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 35.0152, 'longitude': -77.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28398', 'place_name': 'Warsaw', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 35.018, 'longitude': -78.031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28453', 'place_name': 'Magnolia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 34.8957, 'longitude': -78.0432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28458', 'place_name': 'Rose Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 34.8235, 'longitude': -78.0166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28464', 'place_name': 'Teachey', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 34.77, 'longitude': -78.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28466', 'place_name': 'Wallace', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 34.7542, 'longitude': -77.9429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28508', 'place_name': 'Albertson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 35.1176, 'longitude': -77.8515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28518', 'place_name': 'Beulaville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 34.934, 'longitude': -77.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28521', 'place_name': 'Chinquapin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Duplin', 'locality_code': '61', 'latitude': 34.8276, 'longitude': -77.7636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27503', 'place_name': 'Bahama', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.1566, 'longitude': -78.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27572', 'place_name': 'Rougemont', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.2393, 'longitude': -78.9019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27701', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 35.9967, 'longitude': -78.8966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27702', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0512, 'longitude': -78.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27703', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 35.9781, 'longitude': -78.8439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27704', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0383, 'longitude': -78.8764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27705', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0218, 'longitude': -78.9478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27706', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 35.997, 'longitude': -78.9422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27707', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 35.9631, 'longitude': -78.9315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27708', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0287, 'longitude': -78.924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27709', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0512, 'longitude': -78.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27710', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0512, 'longitude': -78.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27711', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0512, 'longitude': -78.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27712', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0918, 'longitude': -78.9299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27713', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 35.9112, 'longitude': -78.9178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27715', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0512, 'longitude': -78.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27717', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 36.0512, 'longitude': -78.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27722', 'place_name': 'Durham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Durham', 'locality_code': '63', 'latitude': 35.994, 'longitude': -78.8986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27801', 'place_name': 'Rocky Mount', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 35.9427, 'longitude': -77.7608, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '27802', 'place_name': 'Rocky Mount', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 35.9356, 'longitude': -77.7808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27809', 'place_name': 'Battleboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 36.0067, 'longitude': -77.7074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27819', 'place_name': 'Conetoe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 35.8178, 'longitude': -77.4533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27852', 'place_name': 'Macclesfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 35.751, 'longitude': -77.6706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27864', 'place_name': 'Pinetops', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 35.7885, 'longitude': -77.6378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27881', 'place_name': 'Speed', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 35.9679, 'longitude': -77.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27886', 'place_name': 'Tarboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Edgecombe', 'locality_code': '65', 'latitude': 35.8983, 'longitude': -77.5421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27009', 'place_name': 'Belews Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.2269, 'longitude': -80.093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27010', 'place_name': 'Bethania', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.183, 'longitude': -80.3387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27012', 'place_name': 'Clemmons', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0341, 'longitude': -80.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27023', 'place_name': 'Lewisville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0967, 'longitude': -80.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27040', 'place_name': 'Pfafftown', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.1669, 'longitude': -80.3798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27045', 'place_name': 'Rural Hall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.2293, 'longitude': -80.2936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27050', 'place_name': 'Tobaccoville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.2336, 'longitude': -80.3915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27051', 'place_name': 'Walkertown', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.18, 'longitude': -80.1629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27094', 'place_name': 'Rural Hall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.2404, 'longitude': -80.2934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27098', 'place_name': 'Rural Hall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.2404, 'longitude': -80.2934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27099', 'place_name': 'Rural Hall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.2404, 'longitude': -80.2934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27101', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.1024, 'longitude': -80.2228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27102', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0323, 'longitude': -80.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27103', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0671, 'longitude': -80.3025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27104', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.092, 'longitude': -80.3224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27105', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.144, 'longitude': -80.2376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27106', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.1428, 'longitude': -80.3069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27107', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0403, 'longitude': -80.1933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27108', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27109', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27110', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27111', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0999, 'longitude': -80.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27113', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0999, 'longitude': -80.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27114', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0999, 'longitude': -80.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27115', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0999, 'longitude': -80.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27116', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0999, 'longitude': -80.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27117', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27120', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0999, 'longitude': -80.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27127', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0425, 'longitude': -80.2609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27130', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27150', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27152', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27155', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27157', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27198', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0275, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27199', 'place_name': 'Winston-Salem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.0999, 'longitude': -80.2442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27284', 'place_name': 'Kernersville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.1165, 'longitude': -80.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27285', 'place_name': 'Kernersville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Forsyth', 'locality_code': '67', 'latitude': 36.1199, 'longitude': -80.0737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27508', 'place_name': 'Bunn', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Franklin', 'locality_code': '69', 'latitude': 35.9577, 'longitude': -78.2498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27525', 'place_name': 'Franklinton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Franklin', 'locality_code': '69', 'latitude': 36.0955, 'longitude': -78.4486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27549', 'place_name': 'Louisburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Franklin', 'locality_code': '69', 'latitude': 36.0578, 'longitude': -78.2586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27596', 'place_name': 'Youngsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Franklin', 'locality_code': '69', 'latitude': 36.0249, 'longitude': -78.4744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28006', 'place_name': 'Alexis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.4069, 'longitude': -81.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28012', 'place_name': 'Belmont', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.244, 'longitude': -81.044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28016', 'place_name': 'Bessemer City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2849, 'longitude': -81.2863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28021', 'place_name': 'Cherryville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.3747, 'longitude': -81.3509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28032', 'place_name': 'Cramerton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2396, 'longitude': -81.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28034', 'place_name': 'Dallas', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.3349, 'longitude': -81.1862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28035', 'place_name': 'Davidson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.4993, 'longitude': -80.8486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28052', 'place_name': 'Gastonia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2449, 'longitude': -81.2194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28053', 'place_name': 'Gastonia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2751, 'longitude': -81.2134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28054', 'place_name': 'Gastonia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2495, 'longitude': -81.133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28055', 'place_name': 'Gastonia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.284, 'longitude': -81.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28056', 'place_name': 'Gastonia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2172, 'longitude': -81.1252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28077', 'place_name': 'High Shoals', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.4041, 'longitude': -81.2029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28098', 'place_name': 'Lowell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2655, 'longitude': -81.096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28101', 'place_name': 'Mc Adenville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.2578, 'longitude': -81.0788, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28120', 'place_name': 'Mount Holly', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.3119, 'longitude': -81.0306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28164', 'place_name': 'Stanley', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gaston', 'locality_code': '71', 'latitude': 35.3516, 'longitude': -81.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27926', 'place_name': 'Corapeake', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gates', 'locality_code': '73', 'latitude': 36.5179, 'longitude': -76.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27935', 'place_name': 'Eure', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gates', 'locality_code': '73', 'latitude': 36.4341, 'longitude': -76.8463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27937', 'place_name': 'Gates', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gates', 'locality_code': '73', 'latitude': 36.5036, 'longitude': -76.7646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27938', 'place_name': 'Gatesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gates', 'locality_code': '73', 'latitude': 36.4072, 'longitude': -76.7325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27946', 'place_name': 'Hobbsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gates', 'locality_code': '73', 'latitude': 36.3543, 'longitude': -76.6178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27969', 'place_name': 'Roduco', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gates', 'locality_code': '73', 'latitude': 36.4618, 'longitude': -76.8125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27979', 'place_name': 'Sunbury', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Gates', 'locality_code': '73', 'latitude': 36.4316, 'longitude': -76.6096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28733', 'place_name': 'Fontana Dam', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Graham', 'locality_code': '75', 'latitude': 35.4231, 'longitude': -83.7795, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28771', 'place_name': 'Robbinsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Graham', 'locality_code': '75', 'latitude': 35.3259, 'longitude': -83.7888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27507', 'place_name': 'Bullock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 36.5076, 'longitude': -78.5646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27509', 'place_name': 'Butner', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 36.1359, 'longitude': -78.7636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27522', 'place_name': 'Creedmoor', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 36.1224, 'longitude': -78.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27527', 'place_name': 'Clayton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 35.6577, 'longitude': -78.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27528', 'place_name': 'Clayton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 35.6555, 'longitude': -78.4611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27565', 'place_name': 'Oxford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 36.3313, 'longitude': -78.6134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27574', 'place_name': 'Roxboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 36.3942, 'longitude': -78.9863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27581', 'place_name': 'Stem', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 36.1999, 'longitude': -78.7222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27582', 'place_name': 'Stovall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Granville', 'locality_code': '77', 'latitude': 36.4482, 'longitude': -78.5703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27888', 'place_name': 'Walstonburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Greene', 'locality_code': '79', 'latitude': 35.5882, 'longitude': -77.6983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28538', 'place_name': 'Hookerton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Greene', 'locality_code': '79', 'latitude': 35.438, 'longitude': -77.5656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28554', 'place_name': 'Maury', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Greene', 'locality_code': '79', 'latitude': 35.4821, 'longitude': -77.5861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28580', 'place_name': 'Snow Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Greene', 'locality_code': '79', 'latitude': 35.4438, 'longitude': -77.6956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27214', 'place_name': 'Browns Summit', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.2019, 'longitude': -79.7101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27233', 'place_name': 'Climax', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.9345, 'longitude': -79.7019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27235', 'place_name': 'Colfax', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1003, 'longitude': -80.0103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27249', 'place_name': 'Gibsonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1183, 'longitude': -79.5685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27260', 'place_name': 'High Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.954, 'longitude': -79.9884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27261', 'place_name': 'High Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0807, 'longitude': -80.0244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27262', 'place_name': 'High Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.9734, 'longitude': -80.0107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27263', 'place_name': 'High Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.9359, 'longitude': -79.9395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27264', 'place_name': 'High Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0807, 'longitude': -80.0244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27265', 'place_name': 'High Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0036, 'longitude': -80.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27268', 'place_name': 'High Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.9698, 'longitude': -79.9936, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '27282', 'place_name': 'Jamestown', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.999, 'longitude': -79.9293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27283', 'place_name': 'Julian', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.9543, 'longitude': -79.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27301', 'place_name': 'Mc Leansville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1163, 'longitude': -79.6684, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '27310', 'place_name': 'Oak Ridge', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1673, 'longitude': -79.9804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27313', 'place_name': 'Pleasant Garden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 35.9522, 'longitude': -79.7549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27342', 'place_name': 'Sedalia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0756, 'longitude': -79.6206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27357', 'place_name': 'Stokesdale', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.2552, 'longitude': -79.9705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27358', 'place_name': 'Summerfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.2245, 'longitude': -79.8901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27377', 'place_name': 'Whitsett', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.033, 'longitude': -79.5972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27401', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0697, 'longitude': -79.7682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27402', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27403', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0641, 'longitude': -79.8202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27404', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27405', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1214, 'longitude': -79.7733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27406', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.022, 'longitude': -79.7821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27407', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0334, 'longitude': -79.8626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27408', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1064, 'longitude': -79.8165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27409', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0777, 'longitude': -79.9086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27410', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1032, 'longitude': -79.8794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27411', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27412', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0661, 'longitude': -79.8067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27413', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27415', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27416', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27417', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27419', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27420', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.113, 'longitude': -79.7759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27425', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27427', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27429', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27435', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27438', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27455', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.1824, 'longitude': -79.806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27495', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27497', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0798, 'longitude': -79.8282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27498', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27499', 'place_name': 'Greensboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Guilford', 'locality_code': '81', 'latitude': 36.0726, 'longitude': -79.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27823', 'place_name': 'Enfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.1973, 'longitude': -77.7129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27839', 'place_name': 'Halifax', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.3049, 'longitude': -77.5607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27843', 'place_name': 'Hobgood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.0594, 'longitude': -77.4061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27844', 'place_name': 'Hollister', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.259, 'longitude': -77.9319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27850', 'place_name': 'Littleton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.4169, 'longitude': -77.8528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27870', 'place_name': 'Roanoke Rapids', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.4461, 'longitude': -77.6731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27874', 'place_name': 'Scotland Neck', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.1301, 'longitude': -77.4273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27887', 'place_name': 'Tillery', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.2352, 'longitude': -77.5026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27890', 'place_name': 'Weldon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.4206, 'longitude': -77.6035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27501', 'place_name': 'Angier', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.4897, 'longitude': -78.7249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27506', 'place_name': 'Buies Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.4132, 'longitude': -78.7356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27521', 'place_name': 'Coats', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.4082, 'longitude': -78.6627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27543', 'place_name': 'Kipling', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.4799, 'longitude': -78.8211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27546', 'place_name': 'Lillington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.332, 'longitude': -78.9212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27552', 'place_name': 'Mamers', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.4168, 'longitude': -78.9334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28323', 'place_name': 'Bunnlevel', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.3119, 'longitude': -78.8405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28334', 'place_name': 'Dunn', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.3165, 'longitude': -78.6151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28335', 'place_name': 'Dunn', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.3063, 'longitude': -78.6089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28339', 'place_name': 'Erwin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.3287, 'longitude': -78.6859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28368', 'place_name': 'Olivia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Harnett', 'locality_code': '85', 'latitude': 35.3596, 'longitude': -79.1097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28716', 'place_name': 'Canton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Haywood', 'locality_code': '87', 'latitude': 35.5127, 'longitude': -82.8413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28721', 'place_name': 'Clyde', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Haywood', 'locality_code': '87', 'latitude': 35.5597, 'longitude': -82.9216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28738', 'place_name': 'Hazelwood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Haywood', 'locality_code': '87', 'latitude': 35.4683, 'longitude': -83.0028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28745', 'place_name': 'Lake Junaluska', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Haywood', 'locality_code': '87', 'latitude': 35.5258, 'longitude': -82.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28751', 'place_name': 'Maggie Valley', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Haywood', 'locality_code': '87', 'latitude': 35.5201, 'longitude': -83.0929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28785', 'place_name': 'Waynesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Haywood', 'locality_code': '87', 'latitude': 35.533, 'longitude': -82.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28786', 'place_name': 'Waynesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Haywood', 'locality_code': '87', 'latitude': 35.5018, 'longitude': -82.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28710', 'place_name': 'Bat Cave', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.4515, 'longitude': -82.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28724', 'place_name': 'Dana', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3293, 'longitude': -82.3754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28726', 'place_name': 'East Flat Rock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.2799, 'longitude': -82.4204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28727', 'place_name': 'Edneyville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.394, 'longitude': -82.3409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28729', 'place_name': 'Etowah', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3172, 'longitude': -82.5977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28731', 'place_name': 'Flat Rock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.289, 'longitude': -82.3916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28732', 'place_name': 'Fletcher', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.4499, 'longitude': -82.4966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28735', 'place_name': 'Gerton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.4759, 'longitude': -82.3505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28739', 'place_name': 'Hendersonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3192, 'longitude': -82.5, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28742', 'place_name': 'Horse Shoe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3432, 'longitude': -82.5565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28758', 'place_name': 'Mountain Home', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3711, 'longitude': -82.4938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28760', 'place_name': 'Naples', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3817, 'longitude': -82.4813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28784', 'place_name': 'Tuxedo', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.2174, 'longitude': -82.4178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28790', 'place_name': 'Zirconia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.2153, 'longitude': -82.4574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28791', 'place_name': 'Hendersonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3464, 'longitude': -82.525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28792', 'place_name': 'Hendersonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.3613, 'longitude': -82.4264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28793', 'place_name': 'Hendersonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Henderson', 'locality_code': '89', 'latitude': 35.2927, 'longitude': -82.5036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27818', 'place_name': 'Como', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hertford', 'locality_code': '91', 'latitude': 36.5015, 'longitude': -77.0094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27855', 'place_name': 'Murfreesboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hertford', 'locality_code': '91', 'latitude': 36.4319, 'longitude': -77.1027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27910', 'place_name': 'Ahoskie', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hertford', 'locality_code': '91', 'latitude': 36.2957, 'longitude': -76.9966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27922', 'place_name': 'Cofield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hertford', 'locality_code': '91', 'latitude': 36.3333, 'longitude': -76.8746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27942', 'place_name': 'Harrellsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hertford', 'locality_code': '91', 'latitude': 36.2866, 'longitude': -76.7767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27986', 'place_name': 'Winton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hertford', 'locality_code': '91', 'latitude': 36.3826, 'longitude': -76.936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28376', 'place_name': 'Raeford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hoke', 'locality_code': '93', 'latitude': 34.989, 'longitude': -79.2228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27824', 'place_name': 'Engelhard', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hyde', 'locality_code': '95', 'latitude': 35.5149, 'longitude': -76.0303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27826', 'place_name': 'Fairfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hyde', 'locality_code': '95', 'latitude': 35.5659, 'longitude': -76.2318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27875', 'place_name': 'Scranton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hyde', 'locality_code': '95', 'latitude': 35.4717, 'longitude': -76.4951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27885', 'place_name': 'Swanquarter', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hyde', 'locality_code': '95', 'latitude': 35.4222, 'longitude': -76.2875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27960', 'place_name': 'Ocracoke', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Hyde', 'locality_code': '95', 'latitude': 35.1397, 'longitude': -75.8931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28010', 'place_name': 'Barium Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.7192, 'longitude': -80.8991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28115', 'place_name': 'Mooresville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.5774, 'longitude': -80.8226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28117', 'place_name': 'Mooresville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.584, 'longitude': -80.8685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28123', 'place_name': 'Mount Mourne', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.5432, 'longitude': -80.8473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28166', 'place_name': 'Troutman', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.6863, 'longitude': -80.8822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28625', 'place_name': 'Statesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.8651, 'longitude': -80.8858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28634', 'place_name': 'Harmony', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.958, 'longitude': -80.7585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28660', 'place_name': 'Olin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.9593, 'longitude': -80.8511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28677', 'place_name': 'Statesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.799, 'longitude': -80.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28687', 'place_name': 'Statesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.7826, 'longitude': -80.8873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28688', 'place_name': 'Turnersburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.9085, 'longitude': -80.8073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28689', 'place_name': 'Union Grove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 36.0369, 'longitude': -80.8967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28699', 'place_name': 'Scotts', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Iredell', 'locality_code': '97', 'latitude': 35.831, 'longitude': -81.0076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28707', 'place_name': 'Balsam', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.4268, 'longitude': -83.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28717', 'place_name': 'Cashiers', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.0971, 'longitude': -83.0871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28723', 'place_name': 'Cullowhee', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.2409, 'longitude': -83.1475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28725', 'place_name': 'Dillsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.3735, 'longitude': -83.2592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28736', 'place_name': 'Glenville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.1882, 'longitude': -83.09, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28779', 'place_name': 'Sylva', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.3481, 'longitude': -83.2031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28783', 'place_name': 'Tuckasegee', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.2599, 'longitude': -83.0749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28788', 'place_name': 'Webster', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.3462, 'longitude': -83.2193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28789', 'place_name': 'Whittier', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jackson', 'locality_code': '99', 'latitude': 35.4469, 'longitude': -83.2872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27504', 'place_name': 'Benson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.4037, 'longitude': -78.5421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27520', 'place_name': 'Clayton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.6348, 'longitude': -78.451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27524', 'place_name': 'Four Oaks', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.404, 'longitude': -78.4153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27542', 'place_name': 'Kenly', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.6077, 'longitude': -78.1382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27555', 'place_name': 'Micro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.5638, 'longitude': -78.2044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27557', 'place_name': 'Middlesex', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.7665, 'longitude': -78.2062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27568', 'place_name': 'Pine Level', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.5132, 'longitude': -78.2444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27569', 'place_name': 'Princeton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.4558, 'longitude': -78.1674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27576', 'place_name': 'Selma', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.5565, 'longitude': -78.264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27577', 'place_name': 'Smithfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.5068, 'longitude': -78.3479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27593', 'place_name': 'Wilsons Mills', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Johnston', 'locality_code': '101', 'latitude': 35.5907, 'longitude': -78.3607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28522', 'place_name': 'Comfort', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jones', 'locality_code': '103', 'latitude': 35.0051, 'longitude': -77.5231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28555', 'place_name': 'Maysville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jones', 'locality_code': '103', 'latitude': 34.8691, 'longitude': -77.2315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28573', 'place_name': 'Pollocksville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jones', 'locality_code': '103', 'latitude': 35.0151, 'longitude': -77.2287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28585', 'place_name': 'Trenton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Jones', 'locality_code': '103', 'latitude': 35.0745, 'longitude': -77.4595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27237', 'place_name': 'Cumnock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lee', 'locality_code': '105', 'latitude': 35.4676, 'longitude': -79.1653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27330', 'place_name': 'Sanford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lee', 'locality_code': '105', 'latitude': 35.4698, 'longitude': -79.1717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27331', 'place_name': 'Sanford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lee', 'locality_code': '105', 'latitude': 35.4799, 'longitude': -79.1803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27332', 'place_name': 'Sanford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lee', 'locality_code': '105', 'latitude': 35.4469, 'longitude': -79.138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27505', 'place_name': 'Broadway', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lee', 'locality_code': '105', 'latitude': 35.4181, 'longitude': -79.0435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28355', 'place_name': 'Lemon Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lee', 'locality_code': '105', 'latitude': 35.3896, 'longitude': -79.1945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28501', 'place_name': 'Kinston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lenoir', 'locality_code': '107', 'latitude': 35.2783, 'longitude': -77.586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28502', 'place_name': 'Kinston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lenoir', 'locality_code': '107', 'latitude': 35.2627, 'longitude': -77.5816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28503', 'place_name': 'Kinston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lenoir', 'locality_code': '107', 'latitude': 35.3191, 'longitude': -77.595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28504', 'place_name': 'Kinston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lenoir', 'locality_code': '107', 'latitude': 35.206, 'longitude': -77.6576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28525', 'place_name': 'Deep Run', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lenoir', 'locality_code': '107', 'latitude': 35.163, 'longitude': -77.6928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28551', 'place_name': 'La Grange', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lenoir', 'locality_code': '107', 'latitude': 35.3054, 'longitude': -77.7686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28572', 'place_name': 'Pink Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lenoir', 'locality_code': '107', 'latitude': 35.0573, 'longitude': -77.6943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28033', 'place_name': 'Crouse', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lincoln', 'locality_code': '109', 'latitude': 35.421, 'longitude': -81.3054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28037', 'place_name': 'Denver', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lincoln', 'locality_code': '109', 'latitude': 35.4837, 'longitude': -80.9898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28080', 'place_name': 'Iron Station', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lincoln', 'locality_code': '109', 'latitude': 35.4657, 'longitude': -81.107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28092', 'place_name': 'Lincolnton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lincoln', 'locality_code': '109', 'latitude': 35.4851, 'longitude': -81.1818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28093', 'place_name': 'Lincolnton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lincoln', 'locality_code': '109', 'latitude': 35.4848, 'longitude': -81.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28168', 'place_name': 'Vale', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Lincoln', 'locality_code': '109', 'latitude': 35.5188, 'longitude': -81.4589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28737', 'place_name': 'Glenwood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'McDowell', 'locality_code': '111', 'latitude': 35.7387, 'longitude': -82.0595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28749', 'place_name': 'Little Switzerland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'McDowell', 'locality_code': '111', 'latitude': 35.8493, 'longitude': -82.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28752', 'place_name': 'Marion', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'McDowell', 'locality_code': '111', 'latitude': 35.6819, 'longitude': -82.018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28761', 'place_name': 'Nebo', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'McDowell', 'locality_code': '111', 'latitude': 35.6732, 'longitude': -81.9056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28762', 'place_name': 'Old Fort', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'McDowell', 'locality_code': '111', 'latitude': 35.6169, 'longitude': -82.1686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28734', 'place_name': 'Franklin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Macon', 'locality_code': '113', 'latitude': 35.181, 'longitude': -83.3885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28741', 'place_name': 'Highlands', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Macon', 'locality_code': '113', 'latitude': 35.0705, 'longitude': -83.216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28744', 'place_name': 'Franklin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Macon', 'locality_code': '113', 'latitude': 35.1823, 'longitude': -83.3815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28763', 'place_name': 'Otto', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Macon', 'locality_code': '113', 'latitude': 35.0515, 'longitude': -83.3854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28775', 'place_name': 'Scaly Mountain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Macon', 'locality_code': '113', 'latitude': 35.0311, 'longitude': -83.3274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28743', 'place_name': 'Hot Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Madison', 'locality_code': '115', 'latitude': 35.8082, 'longitude': -82.9005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28753', 'place_name': 'Marshall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Madison', 'locality_code': '115', 'latitude': 35.8597, 'longitude': -82.7105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28754', 'place_name': 'Mars Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Madison', 'locality_code': '115', 'latitude': 35.8528, 'longitude': -82.5254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27825', 'place_name': 'Everetts', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.8349, 'longitude': -77.1736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27840', 'place_name': 'Hamilton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.9446, 'longitude': -77.2097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27841', 'place_name': 'Hassell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.9086, 'longitude': -77.2763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27846', 'place_name': 'Jamesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.7839, 'longitude': -76.8983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27857', 'place_name': 'Oak City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.9597, 'longitude': -77.3004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27861', 'place_name': 'Parmele', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.8165, 'longitude': -77.3141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27871', 'place_name': 'Robersonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.8218, 'longitude': -77.26, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27892', 'place_name': 'Williamston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Martin', 'locality_code': '117', 'latitude': 35.8212, 'longitude': -77.1022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28031', 'place_name': 'Cornelius', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.4733, 'longitude': -80.8726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28036', 'place_name': 'Davidson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.4858, 'longitude': -80.794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28070', 'place_name': 'Huntersville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.4107, 'longitude': -80.8429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28078', 'place_name': 'Huntersville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.4011, 'longitude': -80.8695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28104', 'place_name': 'Matthews', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.0604, 'longitude': -80.6958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28105', 'place_name': 'Matthews', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1149, 'longitude': -80.705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28106', 'place_name': 'Matthews', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28126', 'place_name': 'Newell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2768, 'longitude': -80.7165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28130', 'place_name': 'Paw Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28134', 'place_name': 'Pineville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.0709, 'longitude': -80.8859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28201', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28202', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.229, 'longitude': -80.8419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28203', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2081, 'longitude': -80.8583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28204', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2132, 'longitude': -80.8231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28205', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.22, 'longitude': -80.7881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28206', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2522, 'longitude': -80.8265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28207', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1935, 'longitude': -80.8272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28208', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2358, 'longitude': -80.8964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28209', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1796, 'longitude': -80.8559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28210', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1316, 'longitude': -80.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28211', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1677, 'longitude': -80.7932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28212', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1908, 'longitude': -80.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28213', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2836, 'longitude': -80.7638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28214', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2731, 'longitude': -80.9571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28215', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.244, 'longitude': -80.7387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28216', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2834, 'longitude': -80.8702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28217', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1714, 'longitude': -80.9084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28218', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28219', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28220', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28221', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28222', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28223', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.3041, 'longitude': -80.7267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28224', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28226', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.0869, 'longitude': -80.8167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28227', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1936, 'longitude': -80.6846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28228', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28229', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28230', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28231', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28232', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28233', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28234', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28235', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28236', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28237', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28241', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28242', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28243', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28244', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28246', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2275, 'longitude': -80.8425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28247', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.0656, 'longitude': -80.8511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28250', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28253', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28254', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28255', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28256', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28258', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28260', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28262', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.3183, 'longitude': -80.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28263', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2268, 'longitude': -80.8432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28265', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28266', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28269', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2886, 'longitude': -80.8209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28270', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1355, 'longitude': -80.7669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28272', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28273', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1287, 'longitude': -80.9338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28274', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.1879, 'longitude': -80.8317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28275', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28277', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.0552, 'longitude': -80.8195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28278', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2072, 'longitude': -80.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28280', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28281', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28282', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2242, 'longitude': -80.8447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28284', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28285', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28287', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28288', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28289', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2271, 'longitude': -80.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28290', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28296', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.2252, 'longitude': -80.8458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28297', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28299', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mecklenburg', 'locality_code': '119', 'latitude': 35.26, 'longitude': -80.8042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28705', 'place_name': 'Bakersville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mitchell', 'locality_code': '121', 'latitude': 36.0286, 'longitude': -82.1711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28765', 'place_name': 'Penland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mitchell', 'locality_code': '121', 'latitude': 35.9219, 'longitude': -82.1107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28777', 'place_name': 'Spruce Pine', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Mitchell', 'locality_code': '121', 'latitude': 35.906, 'longitude': -82.0705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27209', 'place_name': 'Biscoe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Montgomery', 'locality_code': '123', 'latitude': 35.3599, 'longitude': -79.7798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27229', 'place_name': 'Candor', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Montgomery', 'locality_code': '123', 'latitude': 35.2234, 'longitude': -79.7876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27247', 'place_name': 'Ether', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Montgomery', 'locality_code': '123', 'latitude': 35.4514, 'longitude': -79.7834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27306', 'place_name': 'Mount Gilead', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Montgomery', 'locality_code': '123', 'latitude': 35.2274, 'longitude': -79.9871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27356', 'place_name': 'Star', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Montgomery', 'locality_code': '123', 'latitude': 35.4211, 'longitude': -79.7826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27371', 'place_name': 'Troy', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Montgomery', 'locality_code': '123', 'latitude': 35.3777, 'longitude': -79.9093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27242', 'place_name': 'Eagle Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.336, 'longitude': -79.631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27259', 'place_name': 'Highfalls', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.4921, 'longitude': -79.479, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '27281', 'place_name': 'Jackson Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.2259, 'longitude': -79.6685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27325', 'place_name': 'Robbins', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.4528, 'longitude': -79.582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27376', 'place_name': 'West End', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.2512, 'longitude': -79.536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28315', 'place_name': 'Aberdeen', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.1216, 'longitude': -79.445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28326', 'place_name': 'Cameron', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.3106, 'longitude': -79.3472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28327', 'place_name': 'Carthage', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.3061, 'longitude': -79.3969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28350', 'place_name': 'Lakeview', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.2438, 'longitude': -79.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28370', 'place_name': 'Pinehurst', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.2162, 'longitude': -79.4524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28373', 'place_name': 'Pinebluff', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.1007, 'longitude': -79.4663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28374', 'place_name': 'Pinehurst', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.1884, 'longitude': -79.4732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28387', 'place_name': 'Southern Pines', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.1697, 'longitude': -79.3957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28388', 'place_name': 'Southern Pines', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.2803, 'longitude': -79.4327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28394', 'place_name': 'Vass', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Moore', 'locality_code': '125', 'latitude': 35.2171, 'longitude': -79.2562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27803', 'place_name': 'Rocky Mount', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 35.9238, 'longitude': -77.835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27804', 'place_name': 'Rocky Mount', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 35.9904, 'longitude': -77.8468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27807', 'place_name': 'Bailey', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 35.8072, 'longitude': -78.0892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27815', 'place_name': 'Rocky Mount', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 35.8979, 'longitude': -77.7935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27816', 'place_name': 'Castalia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 36.0901, 'longitude': -78.0705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27856', 'place_name': 'Nashville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 35.9843, 'longitude': -77.9595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27868', 'place_name': 'Red Oak', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 36.0548, 'longitude': -77.9116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27878', 'place_name': 'Sharpsburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 35.8654, 'longitude': -77.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27882', 'place_name': 'Spring Hope', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 35.9302, 'longitude': -78.1085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27891', 'place_name': 'Whitakers', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Nash', 'locality_code': '127', 'latitude': 36.0758, 'longitude': -77.7167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28401', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.2257, 'longitude': -77.9447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28402', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.3405, 'longitude': -77.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28403', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.2237, 'longitude': -77.8862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28405', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.2651, 'longitude': -77.867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28406', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.0881, 'longitude': -77.8526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28407', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.0881, 'longitude': -77.8526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28408', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.2257, 'longitude': -77.9447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28409', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.1663, 'longitude': -77.8723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28410', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.0881, 'longitude': -77.8526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28411', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.3033, 'longitude': -77.8039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28412', 'place_name': 'Wilmington', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.1572, 'longitude': -77.9141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28428', 'place_name': 'Carolina Beach', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.0366, 'longitude': -77.8963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28429', 'place_name': 'Castle Hayne', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.3236, 'longitude': -77.9108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28449', 'place_name': 'Kure Beach', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 33.9927, 'longitude': -77.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28480', 'place_name': 'Wrightsville Beach', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'New Hanover', 'locality_code': '129', 'latitude': 34.2228, 'longitude': -77.7932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27820', 'place_name': 'Conway', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.4164, 'longitude': -77.2502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27831', 'place_name': 'Garysburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.4761, 'longitude': -77.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27832', 'place_name': 'Gaston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.5004, 'longitude': -77.645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27842', 'place_name': 'Henrico', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.5274, 'longitude': -77.8546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27845', 'place_name': 'Jackson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.3896, 'longitude': -77.4214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27853', 'place_name': 'Margarettsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.5245, 'longitude': -77.326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27862', 'place_name': 'Pendleton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.4937, 'longitude': -77.1911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27866', 'place_name': 'Pleasant Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.5212, 'longitude': -77.5192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27867', 'place_name': 'Potecasi', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.3632, 'longitude': -77.2391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27869', 'place_name': 'Rich Square', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.2773, 'longitude': -77.2969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27876', 'place_name': 'Seaboard', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.4886, 'longitude': -77.4113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27877', 'place_name': 'Severn', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.5152, 'longitude': -77.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27897', 'place_name': 'Woodland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Northampton', 'locality_code': '131', 'latitude': 36.325, 'longitude': -77.2107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28445', 'place_name': 'Holly Ridge', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.4954, 'longitude': -77.555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28460', 'place_name': 'Sneads Ferry', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.5426, 'longitude': -77.4038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28539', 'place_name': 'Hubert', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.6993, 'longitude': -77.2079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28540', 'place_name': 'Jacksonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.7375, 'longitude': -77.4628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28541', 'place_name': 'Jacksonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.6921, 'longitude': -77.3912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28542', 'place_name': 'Camp Lejeune', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.664, 'longitude': -77.4637, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28543', 'place_name': 'Tarawa Terrace', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.7354, 'longitude': -77.3831, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28544', 'place_name': 'Midway Park', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.727, 'longitude': -77.32, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28545', 'place_name': 'Mccutcheon Field', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.6921, 'longitude': -77.3912, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28546', 'place_name': 'Jacksonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.774, 'longitude': -77.3781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28547', 'place_name': 'Camp Lejeune', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.6909, 'longitude': -77.3614, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28574', 'place_name': 'Richlands', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.8624, 'longitude': -77.5863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28584', 'place_name': 'Swansboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Onslow', 'locality_code': '133', 'latitude': 34.6991, 'longitude': -77.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27231', 'place_name': 'Cedar Grove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 36.202, 'longitude': -79.1666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27243', 'place_name': 'Efland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 36.0912, 'longitude': -79.1884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27278', 'place_name': 'Hillsborough', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 36.0756, 'longitude': -79.0914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27510', 'place_name': 'Carrboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 35.9055, 'longitude': -79.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27514', 'place_name': 'Chapel Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 35.9203, 'longitude': -79.0372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27515', 'place_name': 'Chapel Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 35.9132, 'longitude': -79.0558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27516', 'place_name': 'Chapel Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 35.9162, 'longitude': -79.0999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27517', 'place_name': 'Chapel Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 35.9182, 'longitude': -79.0035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27599', 'place_name': 'Chapel Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Orange', 'locality_code': '135', 'latitude': 36.0525, 'longitude': -79.1077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28509', 'place_name': 'Alliance', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.1449, 'longitude': -76.8022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28510', 'place_name': 'Arapahoe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.0055, 'longitude': -76.8149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28515', 'place_name': 'Bayboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.1526, 'longitude': -76.7518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28529', 'place_name': 'Grantsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.0668, 'longitude': -76.871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28537', 'place_name': 'Hobucken', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.2518, 'longitude': -76.5696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28552', 'place_name': 'Lowland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.306, 'longitude': -76.5777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28556', 'place_name': 'Merritt', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.1224, 'longitude': -76.6719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28571', 'place_name': 'Oriental', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.0364, 'longitude': -76.7015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28583', 'place_name': 'Stonewall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.1371, 'longitude': -76.7406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28587', 'place_name': 'Vandemere', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pamlico', 'locality_code': '137', 'latitude': 35.1913, 'longitude': -76.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27906', 'place_name': 'Elizabeth City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pasquotank', 'locality_code': '139', 'latitude': 36.2854, 'longitude': -76.2133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27907', 'place_name': 'Elizabeth City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pasquotank', 'locality_code': '139', 'latitude': 36.285, 'longitude': -76.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27909', 'place_name': 'Elizabeth City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pasquotank', 'locality_code': '139', 'latitude': 36.2951, 'longitude': -76.2445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28421', 'place_name': 'Atkinson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pender', 'locality_code': '141', 'latitude': 34.5304, 'longitude': -78.1671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28425', 'place_name': 'Burgaw', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pender', 'locality_code': '141', 'latitude': 34.5487, 'longitude': -77.9403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28435', 'place_name': 'Currie', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pender', 'locality_code': '141', 'latitude': 34.4497, 'longitude': -78.0925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28443', 'place_name': 'Hampstead', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pender', 'locality_code': '141', 'latitude': 34.3879, 'longitude': -77.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28454', 'place_name': 'Maple Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pender', 'locality_code': '141', 'latitude': 34.6594, 'longitude': -77.7117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28457', 'place_name': 'Rocky Point', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pender', 'locality_code': '141', 'latitude': 34.4344, 'longitude': -77.9234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28478', 'place_name': 'Willard', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pender', 'locality_code': '141', 'latitude': 34.6845, 'longitude': -78.0234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27919', 'place_name': 'Belvidere', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Perquimans', 'locality_code': '143', 'latitude': 36.3096, 'longitude': -76.5436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27930', 'place_name': 'Hertford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Perquimans', 'locality_code': '143', 'latitude': 36.1902, 'longitude': -76.4661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27944', 'place_name': 'Hertford', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Perquimans', 'locality_code': '143', 'latitude': 36.1685, 'longitude': -76.3731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27985', 'place_name': 'Winfall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Perquimans', 'locality_code': '143', 'latitude': 36.2193, 'longitude': -76.4667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27343', 'place_name': 'Semora', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Person', 'locality_code': '145', 'latitude': 36.5114, 'longitude': -79.0942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27541', 'place_name': 'Hurdle Mills', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Person', 'locality_code': '145', 'latitude': 36.2518, 'longitude': -79.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27573', 'place_name': 'Roxboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Person', 'locality_code': '145', 'latitude': 36.4059, 'longitude': -78.9737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27583', 'place_name': 'Timberlake', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Person', 'locality_code': '145', 'latitude': 36.2918, 'longitude': -78.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27811', 'place_name': 'Bellarthur', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5847, 'longitude': -77.5134, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '27812', 'place_name': 'Bethel', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.7909, 'longitude': -77.3748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27827', 'place_name': 'Falkland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.6966, 'longitude': -77.5132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27828', 'place_name': 'Farmville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5806, 'longitude': -77.5793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27829', 'place_name': 'Fountain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.674, 'longitude': -77.64, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27833', 'place_name': 'Greenville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5804, 'longitude': -77.3926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27834', 'place_name': 'Greenville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.6192, 'longitude': -77.3975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27835', 'place_name': 'Greenville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5885, 'longitude': -77.3531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27836', 'place_name': 'Greenville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5804, 'longitude': -77.3926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27837', 'place_name': 'Grimesland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.558, 'longitude': -77.2566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27858', 'place_name': 'Greenville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5866, 'longitude': -77.3485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27879', 'place_name': 'Simpson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5752, 'longitude': -77.2786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27884', 'place_name': 'Stokes', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.7104, 'longitude': -77.2722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28513', 'place_name': 'Ayden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.4565, 'longitude': -77.4051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28530', 'place_name': 'Grifton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.3757, 'longitude': -77.4193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28590', 'place_name': 'Winterville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Pitt', 'locality_code': '147', 'latitude': 35.5336, 'longitude': -77.391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28722', 'place_name': 'Columbus', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Polk', 'locality_code': '149', 'latitude': 35.2532, 'longitude': -82.1971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28750', 'place_name': 'Lynn', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Polk', 'locality_code': '149', 'latitude': 35.2362, 'longitude': -82.2362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28756', 'place_name': 'Mill Spring', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Polk', 'locality_code': '149', 'latitude': 35.3338, 'longitude': -82.1557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28773', 'place_name': 'Saluda', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Polk', 'locality_code': '149', 'latitude': 35.2383, 'longitude': -82.3306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28782', 'place_name': 'Tryon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Polk', 'locality_code': '149', 'latitude': 35.2157, 'longitude': -82.2394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27203', 'place_name': 'Asheboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.7323, 'longitude': -79.7893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27204', 'place_name': 'Asheboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.7883, 'longitude': -79.7206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27205', 'place_name': 'Asheboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.6396, 'longitude': -79.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27230', 'place_name': 'Cedar Falls', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.8028, 'longitude': -79.8797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27248', 'place_name': 'Franklinville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.7917, 'longitude': -79.7132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27298', 'place_name': 'Liberty', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.8729, 'longitude': -79.5821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27316', 'place_name': 'Ramseur', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.7143, 'longitude': -79.6469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27317', 'place_name': 'Randleman', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.8488, 'longitude': -79.8018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27341', 'place_name': 'Seagrove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.5283, 'longitude': -79.6979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27350', 'place_name': 'Sophia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.8298, 'longitude': -79.8986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27355', 'place_name': 'Staley', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.796, 'longitude': -79.5514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27370', 'place_name': 'Trinity', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Randolph', 'locality_code': '151', 'latitude': 35.8429, 'longitude': -79.9902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28330', 'place_name': 'Cordova', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 34.9129, 'longitude': -79.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28338', 'place_name': 'Ellerbe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 35.0914, 'longitude': -79.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28345', 'place_name': 'Hamlet', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 34.8894, 'longitude': -79.7022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28347', 'place_name': 'Hoffman', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 35.0326, 'longitude': -79.56, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28363', 'place_name': 'Marston', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 34.9882, 'longitude': -79.5823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28367', 'place_name': 'Norman', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 35.1704, 'longitude': -79.7228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28379', 'place_name': 'Rockingham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 34.9336, 'longitude': -79.7666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28380', 'place_name': 'Rockingham', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Richmond', 'locality_code': '153', 'latitude': 34.9942, 'longitude': -79.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28271', 'place_name': 'Charlotte', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 35.216, 'longitude': -80.8358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28319', 'place_name': 'Barnesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.4088, 'longitude': -79.0467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28340', 'place_name': 'Fairmont', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.472, 'longitude': -79.1407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28357', 'place_name': 'Lumber Bridge', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.8762, 'longitude': -79.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28358', 'place_name': 'Lumberton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.6293, 'longitude': -79.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28359', 'place_name': 'Lumberton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.6077, 'longitude': -79.0144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28360', 'place_name': 'Lumberton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.6697, 'longitude': -79.1084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28362', 'place_name': 'Marietta', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.3791, 'longitude': -79.1279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28364', 'place_name': 'Maxton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.7334, 'longitude': -79.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28369', 'place_name': 'Orrum', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.4473, 'longitude': -79.031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28371', 'place_name': 'Parkton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.9006, 'longitude': -78.9969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28372', 'place_name': 'Pembroke', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.6902, 'longitude': -79.1834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28375', 'place_name': 'Proctorville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.4713, 'longitude': -79.0414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28377', 'place_name': 'Red Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.8083, 'longitude': -79.1636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28378', 'place_name': 'Rex', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.8543, 'longitude': -79.0642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28383', 'place_name': 'Rowland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.5887, 'longitude': -79.2618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28384', 'place_name': 'Saint Pauls', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.801, 'longitude': -78.9731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28386', 'place_name': 'Shannon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Robeson', 'locality_code': '155', 'latitude': 34.8988, 'longitude': -79.1806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27025', 'place_name': 'Madison', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.3695, 'longitude': -79.9654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27027', 'place_name': 'Mayodan', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.4277, 'longitude': -79.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27048', 'place_name': 'Stoneville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.4705, 'longitude': -79.9013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27288', 'place_name': 'Eden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.5, 'longitude': -79.759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27289', 'place_name': 'Eden', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.3921, 'longitude': -79.7731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27320', 'place_name': 'Reidsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.3432, 'longitude': -79.6642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27323', 'place_name': 'Reidsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.3921, 'longitude': -79.7731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27326', 'place_name': 'Ruffin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.4428, 'longitude': -79.5606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27375', 'place_name': 'Wentworth', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rockingham', 'locality_code': '157', 'latitude': 36.3921, 'longitude': -79.7731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27013', 'place_name': 'Cleveland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.7374, 'longitude': -80.7113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27054', 'place_name': 'Woodleaf', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.7901, 'longitude': -80.6051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28023', 'place_name': 'China Grove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.5669, 'longitude': -80.59, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28039', 'place_name': 'East Spencer', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6805, 'longitude': -80.4354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28041', 'place_name': 'Faith', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.5817, 'longitude': -80.4581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28071', 'place_name': 'Gold Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.5498, 'longitude': -80.3346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28072', 'place_name': 'Granite Quarry', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6109, 'longitude': -80.4361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28088', 'place_name': 'Landis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.5435, 'longitude': -80.6129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28125', 'place_name': 'Mount Ulla', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6389, 'longitude': -80.7239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28138', 'place_name': 'Rockwell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.5494, 'longitude': -80.4226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28144', 'place_name': 'Salisbury', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6515, 'longitude': -80.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28145', 'place_name': 'Salisbury', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6827, 'longitude': -80.4771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28146', 'place_name': 'Salisbury', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6187, 'longitude': -80.4022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28147', 'place_name': 'Salisbury', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6817, 'longitude': -80.5615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28159', 'place_name': 'Spencer', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rowan', 'locality_code': '159', 'latitude': 35.6917, 'longitude': -80.4327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28018', 'place_name': 'Bostic', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.4533, 'longitude': -81.8118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28019', 'place_name': 'Caroleen', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.281, 'longitude': -81.7962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28024', 'place_name': 'Cliffside', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.2416, 'longitude': -81.7755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28040', 'place_name': 'Ellenboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.3344, 'longitude': -81.7707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28043', 'place_name': 'Forest City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.325, 'longitude': -81.846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28074', 'place_name': 'Harris', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.2247, 'longitude': -81.8851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28076', 'place_name': 'Henrietta', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.2579, 'longitude': -81.7962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28139', 'place_name': 'Rutherfordton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.3706, 'longitude': -81.9781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28160', 'place_name': 'Spindale', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.3601, 'longitude': -81.9251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28167', 'place_name': 'Union Mills', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.4732, 'longitude': -81.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28720', 'place_name': 'Chimney Rock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.4369, 'longitude': -82.2417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28746', 'place_name': 'Lake Lure', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Rutherford', 'locality_code': '161', 'latitude': 35.4464, 'longitude': -82.1752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28318', 'place_name': 'Autryville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 35.0997, 'longitude': -78.6021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28328', 'place_name': 'Clinton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 35.0151, 'longitude': -78.326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28329', 'place_name': 'Clinton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 34.9979, 'longitude': -78.3233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28366', 'place_name': 'Newton Grove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 35.2301, 'longitude': -78.3594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28382', 'place_name': 'Roseboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 34.9639, 'longitude': -78.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28385', 'place_name': 'Salemburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 35.0515, 'longitude': -78.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28393', 'place_name': 'Turkey', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 34.9857, 'longitude': -78.2121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28441', 'place_name': 'Garland', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 34.7897, 'longitude': -78.4309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28444', 'place_name': 'Harrells', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 34.6769, 'longitude': -78.243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28447', 'place_name': 'Ivanhoe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Sampson', 'locality_code': '163', 'latitude': 34.6233, 'longitude': -78.2342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28343', 'place_name': 'Gibson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Scotland', 'locality_code': '165', 'latitude': 34.7549, 'longitude': -79.5839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28351', 'place_name': 'Laurel Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Scotland', 'locality_code': '165', 'latitude': 34.8238, 'longitude': -79.5491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28352', 'place_name': 'Laurinburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Scotland', 'locality_code': '165', 'latitude': 34.7599, 'longitude': -79.4673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28353', 'place_name': 'Laurinburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Scotland', 'locality_code': '165', 'latitude': 34.7818, 'longitude': -79.4824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28396', 'place_name': 'Wagram', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Scotland', 'locality_code': '165', 'latitude': 34.9044, 'longitude': -79.3959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28001', 'place_name': 'Albemarle', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.3573, 'longitude': -80.2044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28002', 'place_name': 'Albemarle', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.3501, 'longitude': -80.2001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28009', 'place_name': 'Badin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.406, 'longitude': -80.1167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28097', 'place_name': 'Locust', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.2704, 'longitude': -80.4211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28109', 'place_name': 'Misenheimer', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.4849, 'longitude': -80.2884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28127', 'place_name': 'New London', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.4285, 'longitude': -80.2057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28128', 'place_name': 'Norwood', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.2275, 'longitude': -80.1433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28129', 'place_name': 'Oakboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.246, 'longitude': -80.3413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28137', 'place_name': 'Richfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.4541, 'longitude': -80.2838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28163', 'place_name': 'Stanfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stanly', 'locality_code': '167', 'latitude': 35.2106, 'longitude': -80.4407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27016', 'place_name': 'Danbury', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.4559, 'longitude': -80.2194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27019', 'place_name': 'Germanton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.2725, 'longitude': -80.2254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27021', 'place_name': 'King', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.295, 'longitude': -80.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27022', 'place_name': 'Lawsonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.5132, 'longitude': -80.2103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27042', 'place_name': 'Pine Hall', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.3482, 'longitude': -80.0495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27043', 'place_name': 'Pinnacle', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.3339, 'longitude': -80.4391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27046', 'place_name': 'Sandy Ridge', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.49, 'longitude': -80.0859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27052', 'place_name': 'Walnut Cove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Stokes', 'locality_code': '169', 'latitude': 36.3189, 'longitude': -80.1484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27007', 'place_name': 'Ararat', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.3859, 'longitude': -80.5895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27017', 'place_name': 'Dobson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.3698, 'longitude': -80.7101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27024', 'place_name': 'Lowgap', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.503, 'longitude': -80.7889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27030', 'place_name': 'Mount Airy', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.5007, 'longitude': -80.6119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27031', 'place_name': 'White Plains', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.3994, 'longitude': -80.7081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27041', 'place_name': 'Pilot Mountain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.4109, 'longitude': -80.4921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27047', 'place_name': 'Siloam', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.3002, 'longitude': -80.5772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27049', 'place_name': 'Toast', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.5004, 'longitude': -80.6265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27053', 'place_name': 'Westfield', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.4674, 'longitude': -80.3677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28621', 'place_name': 'Elkin', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.2872, 'longitude': -80.8554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28676', 'place_name': 'State Road', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Surry', 'locality_code': '171', 'latitude': 36.3422, 'longitude': -80.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28702', 'place_name': 'Almond', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Swain', 'locality_code': '173', 'latitude': 35.3698, 'longitude': -83.5652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28713', 'place_name': 'Bryson City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Swain', 'locality_code': '173', 'latitude': 35.4241, 'longitude': -83.4392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28719', 'place_name': 'Cherokee', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Swain', 'locality_code': '173', 'latitude': 35.5094, 'longitude': -83.3144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28708', 'place_name': 'Balsam Grove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.2298, 'longitude': -82.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28712', 'place_name': 'Brevard', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.2208, 'longitude': -82.7404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28718', 'place_name': 'Cedar Mountain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.1508, 'longitude': -82.6374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28747', 'place_name': 'Lake Toxaway', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.1451, 'longitude': -82.9191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28766', 'place_name': 'Penrose', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.2524, 'longitude': -82.6222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28768', 'place_name': 'Pisgah Forest', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.2599, 'longitude': -82.6695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28772', 'place_name': 'Rosman', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.1437, 'longitude': -82.8212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28774', 'place_name': 'Sapphire', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Transylvania', 'locality_code': '175', 'latitude': 35.0666, 'longitude': -83.0019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27925', 'place_name': 'Columbia', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Tyrrell', 'locality_code': '177', 'latitude': 35.9057, 'longitude': -76.2345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28079', 'place_name': 'Indian Trail', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 35.0831, 'longitude': -80.6597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28103', 'place_name': 'Marshville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 35.0167, 'longitude': -80.3781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28108', 'place_name': 'Mineral Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 34.9379, 'longitude': -80.6687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28110', 'place_name': 'Monroe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 35.0178, 'longitude': -80.5372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28111', 'place_name': 'Monroe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 35.0112, 'longitude': -80.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28112', 'place_name': 'Monroe', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 34.8946, 'longitude': -80.554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28173', 'place_name': 'Waxhaw', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 34.9251, 'longitude': -80.7278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28174', 'place_name': 'Wingate', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Union', 'locality_code': '179', 'latitude': 34.9847, 'longitude': -80.4476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27536', 'place_name': 'Henderson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Vance', 'locality_code': '181', 'latitude': 36.3301, 'longitude': -78.3981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27537', 'place_name': 'Henderson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Vance', 'locality_code': '181', 'latitude': 36.36, 'longitude': -78.3906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27544', 'place_name': 'Kittrell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Vance', 'locality_code': '181', 'latitude': 36.2042, 'longitude': -78.4241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27553', 'place_name': 'Manson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Vance', 'locality_code': '181', 'latitude': 36.4603, 'longitude': -78.2952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27556', 'place_name': 'Middleburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Vance', 'locality_code': '181', 'latitude': 36.3996, 'longitude': -78.3225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27584', 'place_name': 'Townsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Vance', 'locality_code': '181', 'latitude': 36.4946, 'longitude': -78.4236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27502', 'place_name': 'Apex', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7225, 'longitude': -78.8408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27511', 'place_name': 'Cary', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7641, 'longitude': -78.7786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27512', 'place_name': 'Cary', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8084, 'longitude': -78.8395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27513', 'place_name': 'Cary', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7956, 'longitude': -78.7941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27518', 'place_name': 'Cary', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7299, 'longitude': -78.7735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27519', 'place_name': 'Cary', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8072, 'longitude': -78.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27523', 'place_name': 'Apex', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7225, 'longitude': -78.8408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27526', 'place_name': 'Fuquay Varina', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.58, 'longitude': -78.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27529', 'place_name': 'Garner', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.6813, 'longitude': -78.5975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27539', 'place_name': 'Apex', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7225, 'longitude': -78.8408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27540', 'place_name': 'Holly Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.6263, 'longitude': -78.8458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27545', 'place_name': 'Knightdale', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7789, 'longitude': -78.4898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27560', 'place_name': 'Morrisville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8344, 'longitude': -78.8466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27562', 'place_name': 'New Hill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.6809, 'longitude': -78.9365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27571', 'place_name': 'Rolesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.9156, 'longitude': -78.4658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27587', 'place_name': 'Wake Forest', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.9815, 'longitude': -78.5392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27588', 'place_name': 'Wake Forest', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.9731, 'longitude': -78.4508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27591', 'place_name': 'Wendell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.798, 'longitude': -78.3926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27592', 'place_name': 'Willow Spring', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.547, 'longitude': -78.6717, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '27597', 'place_name': 'Zebulon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8321, 'longitude': -78.3174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27601', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7727, 'longitude': -78.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27602', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7587, 'longitude': -78.6711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27603', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7076, 'longitude': -78.6563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27604', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8334, 'longitude': -78.5799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27605', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7908, 'longitude': -78.653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27606', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7645, 'longitude': -78.7112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27607', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8014, 'longitude': -78.6877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27608', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8077, 'longitude': -78.6463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27609', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.848, 'longitude': -78.6317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27610', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7667, 'longitude': -78.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27611', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27612', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.852, 'longitude': -78.6841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27613', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8949, 'longitude': -78.7051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27614', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.9457, 'longitude': -78.6433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27615', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8887, 'longitude': -78.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27616', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8673, 'longitude': -78.5381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27617', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.9034, 'longitude': -78.7447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27619', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8515, 'longitude': -78.6314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27620', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27621', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27622', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27623', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27624', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27625', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27626', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27627', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27628', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27629', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.8175, 'longitude': -78.5524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27634', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27635', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27636', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27640', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27650', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27656', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27658', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27661', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27668', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27675', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27676', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27690', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27695', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27697', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7721, 'longitude': -78.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27698', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27699', 'place_name': 'Raleigh', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wake', 'locality_code': '183', 'latitude': 35.7977, 'longitude': -78.6253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27551', 'place_name': 'Macon', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Warren', 'locality_code': '185', 'latitude': 36.507, 'longitude': -77.9975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27563', 'place_name': 'Norlina', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Warren', 'locality_code': '185', 'latitude': 36.4754, 'longitude': -78.1895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27570', 'place_name': 'Ridgeway', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Warren', 'locality_code': '185', 'latitude': 36.4357, 'longitude': -78.2367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27586', 'place_name': 'Vaughan', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Warren', 'locality_code': '185', 'latitude': 36.4265, 'longitude': -78.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27589', 'place_name': 'Warrenton', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Warren', 'locality_code': '185', 'latitude': 36.3539, 'longitude': -78.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27594', 'place_name': 'Wise', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Warren', 'locality_code': '185', 'latitude': 36.4865, 'longitude': -78.1708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27928', 'place_name': 'Creswell', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Washington', 'locality_code': '187', 'latitude': 35.8653, 'longitude': -76.4196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27962', 'place_name': 'Plymouth', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Washington', 'locality_code': '187', 'latitude': 35.8508, 'longitude': -76.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27970', 'place_name': 'Roper', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Washington', 'locality_code': '187', 'latitude': 35.8994, 'longitude': -76.5809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28605', 'place_name': 'Blowing Rock', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.1355, 'longitude': -81.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28607', 'place_name': 'Boone', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.2142, 'longitude': -81.666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28608', 'place_name': 'Boone', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.2168, 'longitude': -81.6746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28618', 'place_name': 'Deep Gap', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.2136, 'longitude': -81.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28679', 'place_name': 'Sugar Grove', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.2627, 'longitude': -81.8441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28691', 'place_name': 'Valle Crucis', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.2092, 'longitude': -81.7789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28692', 'place_name': 'Vilas', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.2574, 'longitude': -81.7652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28698', 'place_name': 'Zionville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Watauga', 'locality_code': '189', 'latitude': 36.3194, 'longitude': -81.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27530', 'place_name': 'Goldsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.3683, 'longitude': -78.0929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27531', 'place_name': 'Goldsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.343, 'longitude': -77.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27532', 'place_name': 'Goldsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.372, 'longitude': -78.0524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27533', 'place_name': 'Goldsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.372, 'longitude': -78.0524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27534', 'place_name': 'Goldsboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.3664, 'longitude': -77.9221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27830', 'place_name': 'Fremont', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.5553, 'longitude': -77.958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27863', 'place_name': 'Pikeville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.4929, 'longitude': -77.9578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28333', 'place_name': 'Dudley', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.2926, 'longitude': -78.0273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28365', 'place_name': 'Mount Olive', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.2109, 'longitude': -78.0983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28578', 'place_name': 'Seven Springs', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wayne', 'locality_code': '191', 'latitude': 35.2105, 'longitude': -77.9146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28606', 'place_name': 'Boomer', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.0552, 'longitude': -81.3137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28624', 'place_name': 'Ferguson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.1283, 'longitude': -81.3864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28635', 'place_name': 'Hays', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.31, 'longitude': -81.1161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28649', 'place_name': 'Mc Grady', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.3103, 'longitude': -81.1912, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '28651', 'place_name': 'Millers Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.2119, 'longitude': -81.2485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28654', 'place_name': 'Moravian Falls', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.0788, 'longitude': -81.1781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28656', 'place_name': 'North Wilkesboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.2384, 'longitude': -81.046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28659', 'place_name': 'North Wilkesboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.2017, 'longitude': -81.1286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28665', 'place_name': 'Purlear', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.1964, 'longitude': -81.3528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28669', 'place_name': 'Roaring River', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.1916, 'longitude': -81.0004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28670', 'place_name': 'Ronda', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.2059, 'longitude': -80.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28683', 'place_name': 'Thurmond', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.3562, 'longitude': -80.9317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28685', 'place_name': 'Traphill', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.3301, 'longitude': -81.0151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28697', 'place_name': 'Wilkesboro', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilkes', 'locality_code': '193', 'latitude': 36.1359, 'longitude': -81.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27813', 'place_name': 'Black Creek', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.6352, 'longitude': -77.933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27822', 'place_name': 'Elm City', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.811, 'longitude': -77.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27851', 'place_name': 'Lucama', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.6415, 'longitude': -78.0197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27873', 'place_name': 'Saratoga', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.6538, 'longitude': -77.7755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27880', 'place_name': 'Sims', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.7435, 'longitude': -78.0859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27883', 'place_name': 'Stantonsburg', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.594, 'longitude': -77.8378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27893', 'place_name': 'Wilson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.727, 'longitude': -77.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27894', 'place_name': 'Wilson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.7158, 'longitude': -77.9043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27895', 'place_name': 'Wilson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.7199, 'longitude': -77.9267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27896', 'place_name': 'Wilson', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Wilson', 'locality_code': '195', 'latitude': 35.7715, 'longitude': -77.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27011', 'place_name': 'Boonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yadkin', 'locality_code': '197', 'latitude': 36.234, 'longitude': -80.6357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27018', 'place_name': 'East Bend', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yadkin', 'locality_code': '197', 'latitude': 36.2032, 'longitude': -80.5284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27020', 'place_name': 'Hamptonville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yadkin', 'locality_code': '197', 'latitude': 36.1242, 'longitude': -80.8137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '27055', 'place_name': 'Yadkinville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yadkin', 'locality_code': '197', 'latitude': 36.1277, 'longitude': -80.653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28642', 'place_name': 'Jonesville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yadkin', 'locality_code': '197', 'latitude': 36.2286, 'longitude': -80.787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28714', 'place_name': 'Burnsville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yancey', 'locality_code': '199', 'latitude': 35.903, 'longitude': -82.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28740', 'place_name': 'Green Mountain', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yancey', 'locality_code': '199', 'latitude': 35.9937, 'longitude': -82.259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '28755', 'place_name': 'Micaville', 'state': 'North Carolina', 'state_ab': 'NC', 'county': 'Yancey', 'locality_code': '199', 'latitude': 35.9096, 'longitude': -82.2132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58639', 'place_name': 'Hettinger', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Adams', 'locality_code': '1', 'latitude': 46.0578, 'longitude': -102.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58649', 'place_name': 'Reeder', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Adams', 'locality_code': '1', 'latitude': 46.1116, 'longitude': -102.9405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58031', 'place_name': 'Fingal', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 46.7728, 'longitude': -97.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58049', 'place_name': 'Kathryn', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 46.7177, 'longitude': -97.9763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58062', 'place_name': 'Nome', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 46.6748, 'longitude': -97.7911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58063', 'place_name': 'Oriska', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 46.9433, 'longitude': -97.7853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58065', 'place_name': 'Pillsbury', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 47.1862, 'longitude': -97.7605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58072', 'place_name': 'Valley City', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 46.9268, 'longitude': -98.0033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58429', 'place_name': 'Dazey', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 47.1828, 'longitude': -98.1616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58461', 'place_name': 'Litchville', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 46.6536, 'longitude': -98.1943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58479', 'place_name': 'Rogers', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 47.0741, 'longitude': -98.2136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58480', 'place_name': 'Sanborn', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 46.9271, 'longitude': -98.2336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58492', 'place_name': 'Wimbledon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Barnes', 'locality_code': '3', 'latitude': 47.1438, 'longitude': -98.4329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58332', 'place_name': 'Esmond', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 48.0419, 'longitude': -99.7617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58335', 'place_name': 'Fort Totten', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 47.9811, 'longitude': -99.0264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58343', 'place_name': 'Knox', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 48.3388, 'longitude': -99.6713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58346', 'place_name': 'Leeds', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 48.2889, 'longitude': -99.4376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58348', 'place_name': 'Maddock', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 47.9625, 'longitude': -99.5301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58351', 'place_name': 'Minnewaukan', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 48.0698, 'longitude': -99.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58357', 'place_name': 'Oberon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 47.9487, 'longitude': -99.1401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58370', 'place_name': 'Saint Michael', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 47.985, 'longitude': -98.8721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58379', 'place_name': 'Tokio', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 47.9247, 'longitude': -98.8162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58381', 'place_name': 'Warwick', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 47.8913, 'longitude': -98.681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58386', 'place_name': 'York', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Benson', 'locality_code': '5', 'latitude': 48.2565, 'longitude': -99.6025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58627', 'place_name': 'Fairfield', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Billings', 'locality_code': '7', 'latitude': 47.2329, 'longitude': -103.3056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58645', 'place_name': 'Medora', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Billings', 'locality_code': '7', 'latitude': 46.9387, 'longitude': -103.5632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58318', 'place_name': 'Bottineau', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.8451, 'longitude': -100.4329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58384', 'place_name': 'Willow City', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.6062, 'longitude': -100.2968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58711', 'place_name': 'Antler', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.9585, 'longitude': -101.3338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58748', 'place_name': 'Kramer', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.6867, 'longitude': -100.6716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58750', 'place_name': 'Lansford', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.6254, 'longitude': -101.3858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58760', 'place_name': 'Maxbass', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.7722, 'longitude': -101.2563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58762', 'place_name': 'Newburg', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.6982, 'longitude': -100.9681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58783', 'place_name': 'Souris', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.8738, 'longitude': -100.7359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58793', 'place_name': 'Westhope', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bottineau', 'locality_code': '9', 'latitude': 48.9051, 'longitude': -101.0338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58623', 'place_name': 'Bowman', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bowman', 'locality_code': '11', 'latitude': 46.1733, 'longitude': -103.402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58651', 'place_name': 'Rhame', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bowman', 'locality_code': '11', 'latitude': 46.1664, 'longitude': -103.7079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58653', 'place_name': 'Scranton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Bowman', 'locality_code': '11', 'latitude': 46.0916, 'longitude': -103.1354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58721', 'place_name': 'Bowbells', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burke', 'locality_code': '13', 'latitude': 48.8378, 'longitude': -102.2839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58727', 'place_name': 'Columbus', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burke', 'locality_code': '13', 'latitude': 48.8434, 'longitude': -102.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58737', 'place_name': 'Flaxton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burke', 'locality_code': '13', 'latitude': 48.8772, 'longitude': -102.3823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58752', 'place_name': 'Lignite', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burke', 'locality_code': '13', 'latitude': 48.8481, 'longitude': -102.5542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58772', 'place_name': 'Portal', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burke', 'locality_code': '13', 'latitude': 48.9758, 'longitude': -102.548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58773', 'place_name': 'Powers Lake', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burke', 'locality_code': '13', 'latitude': 48.6551, 'longitude': -102.6795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58477', 'place_name': 'Regan', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 47.1527, 'longitude': -100.5224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58494', 'place_name': 'Wing', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 47.1519, 'longitude': -100.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58501', 'place_name': 'Bismarck', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8083, 'longitude': -100.7837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58502', 'place_name': 'Bismarck', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8887, 'longitude': -100.6819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58503', 'place_name': 'Bismarck', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8394, 'longitude': -100.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58504', 'place_name': 'Bismarck', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.7231, 'longitude': -100.678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58505', 'place_name': 'Bismarck', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8165, 'longitude': -100.7805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58506', 'place_name': 'Bismarck', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8083, 'longitude': -100.7837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58507', 'place_name': 'Bismarck', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8083, 'longitude': -100.7837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58521', 'place_name': 'Baldwin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.9543, 'longitude': -100.7615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58532', 'place_name': 'Driscoll', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8511, 'longitude': -100.1441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58558', 'place_name': 'Menoken', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8205, 'longitude': -100.5312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58560', 'place_name': 'Moffit', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.6757, 'longitude': -100.2975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58572', 'place_name': 'Sterling', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Burleigh', 'locality_code': '15', 'latitude': 46.8436, 'longitude': -100.2744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58002', 'place_name': 'Absaraka', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.9763, 'longitude': -97.4069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58004', 'place_name': 'Amenia', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.0194, 'longitude': -97.2048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58005', 'place_name': 'Argusville', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.1066, 'longitude': -96.9058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58006', 'place_name': 'Arthur', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.1048, 'longitude': -97.2097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58007', 'place_name': 'Ayr', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.0139, 'longitude': -97.4629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58011', 'place_name': 'Buffalo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.9264, 'longitude': -97.5352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58012', 'place_name': 'Casselton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8992, 'longitude': -97.2138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58021', 'place_name': 'Davenport', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.6968, 'longitude': -97.0871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58029', 'place_name': 'Erie', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.1128, 'longitude': -97.3849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58036', 'place_name': 'Gardner', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.1252, 'longitude': -96.9901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58038', 'place_name': 'Grandin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.2158, 'longitude': -97.0207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58042', 'place_name': 'Harwood', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.9565, 'longitude': -96.9654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58047', 'place_name': 'Horace', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.7101, 'longitude': -96.8851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58048', 'place_name': 'Hunter', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.1905, 'longitude': -97.217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58051', 'place_name': 'Kindred', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.6543, 'longitude': -97.0049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58052', 'place_name': 'Leonard', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.6593, 'longitude': -97.2725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58059', 'place_name': 'Mapleton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8614, 'longitude': -97.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58064', 'place_name': 'Page', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 47.1515, 'longitude': -97.5967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58071', 'place_name': 'Tower City', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.9119, 'longitude': -97.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58078', 'place_name': 'West Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8907, 'longitude': -96.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58079', 'place_name': 'Wheatland', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8326, 'longitude': -97.3461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58102', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.9209, 'longitude': -96.8318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58103', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8564, 'longitude': -96.8123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58104', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.7932, 'longitude': -96.8397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58105', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8954, 'longitude': -96.8078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58106', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58107', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58108', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58109', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8235, 'longitude': -96.8148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58121', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58122', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58124', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58125', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58126', 'place_name': 'Fargo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cass', 'locality_code': '17', 'latitude': 46.8772, 'longitude': -96.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58239', 'place_name': 'Hannah', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.9594, 'longitude': -98.7237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58249', 'place_name': 'Langdon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.7866, 'longitude': -98.3566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58255', 'place_name': 'Maida', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.9986, 'longitude': -98.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58260', 'place_name': 'Milton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.617, 'longitude': -98.0183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58269', 'place_name': 'Osnabrock', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.6689, 'longitude': -98.1512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58281', 'place_name': 'Wales', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.9216, 'longitude': -98.5596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58311', 'place_name': 'Alsen', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.6525, 'longitude': -98.5795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58323', 'place_name': 'Calvin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.851, 'longitude': -98.8808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58352', 'place_name': 'Munich', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.6694, 'longitude': -98.8355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58355', 'place_name': 'Nekoma', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.5772, 'longitude': -98.3704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58372', 'place_name': 'Sarles', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Cavalier', 'locality_code': '19', 'latitude': 48.9458, 'longitude': -98.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58436', 'place_name': 'Ellendale', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dickey', 'locality_code': '21', 'latitude': 46.0073, 'longitude': -98.5138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58439', 'place_name': 'Forbes', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dickey', 'locality_code': '21', 'latitude': 46.0109, 'longitude': -98.8124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58441', 'place_name': 'Fullerton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dickey', 'locality_code': '21', 'latitude': 46.1951, 'longitude': -98.3882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58474', 'place_name': 'Oakes', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dickey', 'locality_code': '21', 'latitude': 46.1095, 'longitude': -98.2257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58730', 'place_name': 'Crosby', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Divide', 'locality_code': '23', 'latitude': 48.8836, 'longitude': -103.274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58765', 'place_name': 'Noonan', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Divide', 'locality_code': '23', 'latitude': 48.8856, 'longitude': -103.0098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58833', 'place_name': 'Ambrose', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Divide', 'locality_code': '23', 'latitude': 48.8165, 'longitude': -103.4673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58844', 'place_name': 'Fortuna', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Divide', 'locality_code': '23', 'latitude': 48.8813, 'longitude': -103.7415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58625', 'place_name': 'Dodge', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dunn', 'locality_code': '25', 'latitude': 47.3049, 'longitude': -102.1985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58626', 'place_name': 'Dunn Center', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dunn', 'locality_code': '25', 'latitude': 47.3536, 'longitude': -102.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58636', 'place_name': 'Halliday', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dunn', 'locality_code': '25', 'latitude': 47.3517, 'longitude': -102.3368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58640', 'place_name': 'Killdeer', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dunn', 'locality_code': '25', 'latitude': 47.4109, 'longitude': -102.7762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58642', 'place_name': 'Manning', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dunn', 'locality_code': '25', 'latitude': 47.1258, 'longitude': -102.6806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58644', 'place_name': 'Marshall', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Dunn', 'locality_code': '25', 'latitude': 47.1381, 'longitude': -102.333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58356', 'place_name': 'New Rockford', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Eddy', 'locality_code': '27', 'latitude': 47.7174, 'longitude': -98.8987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58374', 'place_name': 'Sheyenne', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Eddy', 'locality_code': '27', 'latitude': 47.8184, 'longitude': -99.0583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58524', 'place_name': 'Braddock', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Emmons', 'locality_code': '29', 'latitude': 46.5603, 'longitude': -100.1075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58542', 'place_name': 'Hague', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Emmons', 'locality_code': '29', 'latitude': 46.0589, 'longitude': -99.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58544', 'place_name': 'Hazelton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Emmons', 'locality_code': '29', 'latitude': 46.4875, 'longitude': -100.2733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58549', 'place_name': 'Kintyre', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Emmons', 'locality_code': '29', 'latitude': 46.5736, 'longitude': -99.9705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58552', 'place_name': 'Linton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Emmons', 'locality_code': '29', 'latitude': 46.1855, 'longitude': -100.2331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58573', 'place_name': 'Strasburg', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Emmons', 'locality_code': '29', 'latitude': 46.0979, 'longitude': -100.2119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58421', 'place_name': 'Carrington', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Foster', 'locality_code': '31', 'latitude': 47.4573, 'longitude': -98.8933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58443', 'place_name': 'Glenfield', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Foster', 'locality_code': '31', 'latitude': 47.4569, 'longitude': -98.6916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58445', 'place_name': 'Grace City', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Foster', 'locality_code': '31', 'latitude': 47.5536, 'longitude': -98.8095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58464', 'place_name': 'Mchenry', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Foster', 'locality_code': '31', 'latitude': 47.5604, 'longitude': -98.5726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58621', 'place_name': 'Beach', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Golden Valley', 'locality_code': '33', 'latitude': 46.9324, 'longitude': -103.9843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58632', 'place_name': 'Golva', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Golden Valley', 'locality_code': '33', 'latitude': 46.7075, 'longitude': -103.9575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58654', 'place_name': 'Sentinel Butte', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Golden Valley', 'locality_code': '33', 'latitude': 46.8305, 'longitude': -103.8001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58201', 'place_name': 'Grand Forks', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.901, 'longitude': -97.0446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58202', 'place_name': 'Grand Forks', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9215, 'longitude': -97.0735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58203', 'place_name': 'Grand Forks', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9272, 'longitude': -97.0672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58204', 'place_name': 'Grand Forks Afb', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9679, 'longitude': -97.3675, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '58205', 'place_name': 'Grand Forks Afb', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9515, 'longitude': -97.379, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '58206', 'place_name': 'Grand Forks', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9253, 'longitude': -97.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58207', 'place_name': 'Grand Forks', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9253, 'longitude': -97.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58208', 'place_name': 'Grand Forks', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9253, 'longitude': -97.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58214', 'place_name': 'Arvilla', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9093, 'longitude': -97.4871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58228', 'place_name': 'Emerado', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9214, 'longitude': -97.263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58235', 'place_name': 'Gilby', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 48.0853, 'longitude': -97.4706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58244', 'place_name': 'Inkster', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 48.1514, 'longitude': -97.6443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58251', 'place_name': 'Larimore', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9115, 'longitude': -97.6264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58256', 'place_name': 'Manvel', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 48.0853, 'longitude': -97.1943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58258', 'place_name': 'Mekinock', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 48.0074, 'longitude': -97.4305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58266', 'place_name': 'Niagara', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.9848, 'longitude': -97.8334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58267', 'place_name': 'Northwood', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.7591, 'longitude': -97.6038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58275', 'place_name': 'Reynolds', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.7068, 'longitude': -97.2092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58278', 'place_name': 'Thompson', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grand Forks', 'locality_code': '35', 'latitude': 47.7766, 'longitude': -97.0962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58529', 'place_name': 'Carson', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grant', 'locality_code': '37', 'latitude': 46.4624, 'longitude': -101.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58533', 'place_name': 'Elgin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grant', 'locality_code': '37', 'latitude': 46.3679, 'longitude': -101.7558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58562', 'place_name': 'New Leipzig', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grant', 'locality_code': '37', 'latitude': 46.3823, 'longitude': -101.9619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58564', 'place_name': 'Raleigh', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grant', 'locality_code': '37', 'latitude': 46.3352, 'longitude': -101.2827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58569', 'place_name': 'Shields', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Grant', 'locality_code': '37', 'latitude': 46.1838, 'longitude': -101.2589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58416', 'place_name': 'Binford', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Griggs', 'locality_code': '39', 'latitude': 47.5739, 'longitude': -98.3546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58425', 'place_name': 'Cooperstown', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Griggs', 'locality_code': '39', 'latitude': 47.4527, 'longitude': -98.1533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58448', 'place_name': 'Hannaford', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Griggs', 'locality_code': '39', 'latitude': 47.3786, 'longitude': -98.3502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58452', 'place_name': 'Jessie', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Griggs', 'locality_code': '39', 'latitude': 47.5422, 'longitude': -98.2382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58484', 'place_name': 'Sutton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Griggs', 'locality_code': '39', 'latitude': 47.3854, 'longitude': -98.432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58646', 'place_name': 'Mott', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Hettinger', 'locality_code': '41', 'latitude': 46.3696, 'longitude': -102.327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58647', 'place_name': 'New England', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Hettinger', 'locality_code': '41', 'latitude': 46.5128, 'longitude': -102.8358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58650', 'place_name': 'Regent', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Hettinger', 'locality_code': '41', 'latitude': 46.4235, 'longitude': -102.5684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58428', 'place_name': 'Dawson', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Kidder', 'locality_code': '43', 'latitude': 46.8686, 'longitude': -99.7515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58475', 'place_name': 'Pettibone', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Kidder', 'locality_code': '43', 'latitude': 47.12, 'longitude': -99.5279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58478', 'place_name': 'Robinson', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Kidder', 'locality_code': '43', 'latitude': 47.1749, 'longitude': -99.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58482', 'place_name': 'Steele', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Kidder', 'locality_code': '43', 'latitude': 46.8524, 'longitude': -99.9336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58487', 'place_name': 'Tappen', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Kidder', 'locality_code': '43', 'latitude': 46.8336, 'longitude': -99.6019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58488', 'place_name': 'Tuttle', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Kidder', 'locality_code': '43', 'latitude': 47.1626, 'longitude': -99.9873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58415', 'place_name': 'Berlin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.3786, 'longitude': -98.4898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58431', 'place_name': 'Dickey', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.5426, 'longitude': -98.4682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58433', 'place_name': 'Edgeley', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.3591, 'longitude': -98.7157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58454', 'place_name': 'Jud', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.5511, 'longitude': -98.8667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58456', 'place_name': 'Kulm', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.3073, 'longitude': -98.9427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58458', 'place_name': 'Lamoure', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.3844, 'longitude': -98.3587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58466', 'place_name': 'Marion', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.5514, 'longitude': -98.369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58490', 'place_name': 'Verona', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'LaMoure', 'locality_code': '45', 'latitude': 46.3712, 'longitude': -98.0895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58440', 'place_name': 'Fredonia', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Logan', 'locality_code': '47', 'latitude': 46.3701, 'longitude': -99.1733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58442', 'place_name': 'Gackle', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Logan', 'locality_code': '47', 'latitude': 46.5913, 'longitude': -99.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58561', 'place_name': 'Napoleon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Logan', 'locality_code': '47', 'latitude': 46.4867, 'longitude': -99.7725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58710', 'place_name': 'Anamoose', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 47.8703, 'longitude': -100.2529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58712', 'place_name': 'Balfour', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 47.9685, 'longitude': -100.5209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58713', 'place_name': 'Bantry', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.5351, 'longitude': -100.5954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58731', 'place_name': 'Deering', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.4057, 'longitude': -101.0337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58736', 'place_name': 'Drake', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 47.9024, 'longitude': -100.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58741', 'place_name': 'Granville', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.2566, 'longitude': -100.8082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58744', 'place_name': 'Karlsruhe', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.1009, 'longitude': -100.5742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58768', 'place_name': 'Norwich', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.2491, 'longitude': -100.9712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58788', 'place_name': 'Towner', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.3636, 'longitude': -100.4854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58789', 'place_name': 'Upham', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.5816, 'longitude': -100.7323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58790', 'place_name': 'Velva', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 48.0675, 'longitude': -100.9346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58792', 'place_name': 'Voltaire', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McHenry', 'locality_code': '49', 'latitude': 47.986, 'longitude': -100.7988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58413', 'place_name': 'Ashley', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McIntosh', 'locality_code': '51', 'latitude': 46.0537, 'longitude': -99.3164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58460', 'place_name': 'Lehr', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McIntosh', 'locality_code': '51', 'latitude': 46.2586, 'longitude': -99.3491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58495', 'place_name': 'Wishek', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McIntosh', 'locality_code': '51', 'latitude': 46.1917, 'longitude': -99.6131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58581', 'place_name': 'Zeeland', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McIntosh', 'locality_code': '51', 'latitude': 46.0055, 'longitude': -99.7725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58634', 'place_name': 'Grassy Butte', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McKenzie', 'locality_code': '53', 'latitude': 47.4431, 'longitude': -103.2944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58757', 'place_name': 'Mandaree', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McKenzie', 'locality_code': '53', 'latitude': 47.7292, 'longitude': -102.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58831', 'place_name': 'Alexander', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McKenzie', 'locality_code': '53', 'latitude': 47.7947, 'longitude': -103.6546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58835', 'place_name': 'Arnegard', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McKenzie', 'locality_code': '53', 'latitude': 47.8088, 'longitude': -103.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58838', 'place_name': 'Cartwright', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McKenzie', 'locality_code': '53', 'latitude': 47.7992, 'longitude': -103.9487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58847', 'place_name': 'Keene', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McKenzie', 'locality_code': '53', 'latitude': 47.9405, 'longitude': -102.8906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58854', 'place_name': 'Watford City', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McKenzie', 'locality_code': '53', 'latitude': 47.8043, 'longitude': -103.2582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58531', 'place_name': 'Coleharbor', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.5442, 'longitude': -101.2238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58540', 'place_name': 'Garrison', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.6675, 'longitude': -101.6142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58559', 'place_name': 'Mercer', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.4858, 'longitude': -100.7171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58565', 'place_name': 'Riverdale', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.4975, 'longitude': -101.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58575', 'place_name': 'Turtle Lake', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.5414, 'longitude': -100.8814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58576', 'place_name': 'Underwood', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.4602, 'longitude': -101.1898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58577', 'place_name': 'Washburn', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.3114, 'longitude': -101.0116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58579', 'place_name': 'Wilton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.1709, 'longitude': -100.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58716', 'place_name': 'Benedict', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.7865, 'longitude': -101.0579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58723', 'place_name': 'Butte', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.8119, 'longitude': -100.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58759', 'place_name': 'Max', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.8156, 'longitude': -101.2932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58775', 'place_name': 'Roseglen', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.696, 'longitude': -101.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58778', 'place_name': 'Ruso', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'McLean', 'locality_code': '55', 'latitude': 47.7622, 'longitude': -100.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58523', 'place_name': 'Beulah', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mercer', 'locality_code': '57', 'latitude': 47.2707, 'longitude': -101.8075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58541', 'place_name': 'Golden Valley', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mercer', 'locality_code': '57', 'latitude': 47.2938, 'longitude': -102.0612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58545', 'place_name': 'Hazen', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mercer', 'locality_code': '57', 'latitude': 47.3271, 'longitude': -101.6107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58571', 'place_name': 'Stanton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mercer', 'locality_code': '57', 'latitude': 47.3128, 'longitude': -101.3899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58580', 'place_name': 'Zap', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mercer', 'locality_code': '57', 'latitude': 47.2897, 'longitude': -101.9256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58520', 'place_name': 'Almont', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Morton', 'locality_code': '59', 'latitude': 46.7046, 'longitude': -101.5221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58535', 'place_name': 'Flasher', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Morton', 'locality_code': '59', 'latitude': 46.5998, 'longitude': -101.3166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58554', 'place_name': 'Mandan', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Morton', 'locality_code': '59', 'latitude': 46.8306, 'longitude': -100.9092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58563', 'place_name': 'New Salem', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Morton', 'locality_code': '59', 'latitude': 46.806, 'longitude': -101.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58566', 'place_name': 'Saint Anthony', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Morton', 'locality_code': '59', 'latitude': 46.5888, 'longitude': -100.8972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58631', 'place_name': 'Glen Ullin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Morton', 'locality_code': '59', 'latitude': 46.8233, 'longitude': -101.8223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58638', 'place_name': 'Hebron', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Morton', 'locality_code': '59', 'latitude': 46.8936, 'longitude': -102.0367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58763', 'place_name': 'New Town', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mountrail', 'locality_code': '61', 'latitude': 47.9718, 'longitude': -102.4716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58769', 'place_name': 'Palermo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mountrail', 'locality_code': '61', 'latitude': 48.3396, 'longitude': -102.24, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58770', 'place_name': 'Parshall', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mountrail', 'locality_code': '61', 'latitude': 47.956, 'longitude': -102.1427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58771', 'place_name': 'Plaza', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mountrail', 'locality_code': '61', 'latitude': 48.0242, 'longitude': -101.9643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58776', 'place_name': 'Ross', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mountrail', 'locality_code': '61', 'latitude': 48.3111, 'longitude': -102.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58784', 'place_name': 'Stanley', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mountrail', 'locality_code': '61', 'latitude': 48.3458, 'longitude': -102.4185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58794', 'place_name': 'White Earth', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Mountrail', 'locality_code': '61', 'latitude': 48.2994, 'longitude': -102.7701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58212', 'place_name': 'Aneta', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 47.6993, 'longitude': -97.9814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58224', 'place_name': 'Dahlen', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 48.1599, 'longitude': -97.9573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58254', 'place_name': 'Mcville', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 47.7639, 'longitude': -98.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58259', 'place_name': 'Michigan', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 48.0204, 'longitude': -98.1186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58272', 'place_name': 'Petersburg', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 47.998, 'longitude': -97.984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58344', 'place_name': 'Lakota', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 47.972, 'longitude': -98.3246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58361', 'place_name': 'Pekin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 47.7696, 'longitude': -98.326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58380', 'place_name': 'Tolna', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Nelson', 'locality_code': '63', 'latitude': 47.8462, 'longitude': -98.4512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58530', 'place_name': 'Center', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Oliver', 'locality_code': '65', 'latitude': 47.1459, 'longitude': -101.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58216', 'place_name': 'Bathgate', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.8686, 'longitude': -97.4832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58220', 'place_name': 'Cavalier', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.7935, 'longitude': -97.7143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58222', 'place_name': 'Crystal', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.5924, 'longitude': -97.6738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58225', 'place_name': 'Drayton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.6104, 'longitude': -97.2156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58236', 'place_name': 'Glasston', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.7201, 'longitude': -97.4696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58238', 'place_name': 'Hamilton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.7942, 'longitude': -97.4693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58241', 'place_name': 'Hensel', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.7203, 'longitude': -97.6993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58262', 'place_name': 'Mountain', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.6931, 'longitude': -97.8841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58265', 'place_name': 'Neche', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.9796, 'longitude': -97.5427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58271', 'place_name': 'Pembina', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.859, 'longitude': -97.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58276', 'place_name': 'Saint Thomas', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.6252, 'longitude': -97.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58282', 'place_name': 'Walhalla', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pembina', 'locality_code': '67', 'latitude': 48.8808, 'longitude': -97.7974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58313', 'place_name': 'Balta', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pierce', 'locality_code': '69', 'latitude': 48.1667, 'longitude': -100.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58368', 'place_name': 'Rugby', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pierce', 'locality_code': '69', 'latitude': 48.2545, 'longitude': -99.9899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58385', 'place_name': 'Wolford', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Pierce', 'locality_code': '69', 'latitude': 48.4809, 'longitude': -99.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58301', 'place_name': 'Devils Lake', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.1132, 'longitude': -98.8616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58321', 'place_name': 'Brocket', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.2255, 'longitude': -98.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58325', 'place_name': 'Churchs Ferry', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.2862, 'longitude': -99.1412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58327', 'place_name': 'Crary', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.091, 'longitude': -98.5731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58330', 'place_name': 'Edmore', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.4308, 'longitude': -98.4458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58338', 'place_name': 'Hampden', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.5229, 'longitude': -98.6543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58345', 'place_name': 'Lawton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.3033, 'longitude': -98.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58362', 'place_name': 'Penn', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.2271, 'longitude': -99.0655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58377', 'place_name': 'Starkweather', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.4488, 'longitude': -98.8539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58382', 'place_name': 'Webster', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ramsey', 'locality_code': '71', 'latitude': 48.3229, 'longitude': -98.8739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58027', 'place_name': 'Enderlin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ransom', 'locality_code': '73', 'latitude': 46.6079, 'longitude': -97.6106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58033', 'place_name': 'Fort Ransom', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ransom', 'locality_code': '73', 'latitude': 46.4494, 'longitude': -97.9091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58054', 'place_name': 'Lisbon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ransom', 'locality_code': '73', 'latitude': 46.456, 'longitude': -97.6369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58057', 'place_name': 'Mcleod', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ransom', 'locality_code': '73', 'latitude': 46.4103, 'longitude': -97.3139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58068', 'place_name': 'Sheldon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ransom', 'locality_code': '73', 'latitude': 46.5548, 'longitude': -97.4543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58740', 'place_name': 'Glenburn', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Renville', 'locality_code': '75', 'latitude': 48.4718, 'longitude': -101.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58761', 'place_name': 'Mohall', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Renville', 'locality_code': '75', 'latitude': 48.7269, 'longitude': -101.6058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58782', 'place_name': 'Sherwood', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Renville', 'locality_code': '75', 'latitude': 48.9576, 'longitude': -101.697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58787', 'place_name': 'Tolley', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Renville', 'locality_code': '75', 'latitude': 48.7969, 'longitude': -101.8559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58001', 'place_name': 'Abercrombie', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.4479, 'longitude': -96.7278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58008', 'place_name': 'Barney', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.2496, 'longitude': -96.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58015', 'place_name': 'Christine', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.5736, 'longitude': -96.8017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58018', 'place_name': 'Colfax', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.4574, 'longitude': -96.8737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58030', 'place_name': 'Fairmount', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.0427, 'longitude': -96.6308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58041', 'place_name': 'Hankinson', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.0558, 'longitude': -96.8991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58053', 'place_name': 'Lidgerwood', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.0641, 'longitude': -97.1799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58058', 'place_name': 'Mantador', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.1599, 'longitude': -96.957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58061', 'place_name': 'Mooreton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.2686, 'longitude': -96.8762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58074', 'place_name': 'Wahpeton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.2652, 'longitude': -96.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58075', 'place_name': 'Wahpeton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.3366, 'longitude': -96.7921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58076', 'place_name': 'Wahpeton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.2718, 'longitude': -96.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58077', 'place_name': 'Walcott', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.5835, 'longitude': -97.0014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58081', 'place_name': 'Wyndmere', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Richland', 'locality_code': '77', 'latitude': 46.2891, 'longitude': -97.1289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58310', 'place_name': 'Agate', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Rolette', 'locality_code': '79', 'latitude': 48.6228, 'longitude': -99.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58316', 'place_name': 'Belcourt', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Rolette', 'locality_code': '79', 'latitude': 48.8379, 'longitude': -99.7688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58329', 'place_name': 'Dunseith', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Rolette', 'locality_code': '79', 'latitude': 48.8561, 'longitude': -100.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58353', 'place_name': 'Mylo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Rolette', 'locality_code': '79', 'latitude': 48.6329, 'longitude': -99.5957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58366', 'place_name': 'Rolette', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Rolette', 'locality_code': '79', 'latitude': 48.7009, 'longitude': -99.8785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58367', 'place_name': 'Rolla', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Rolette', 'locality_code': '79', 'latitude': 48.8594, 'longitude': -99.6134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58369', 'place_name': 'Saint John', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Rolette', 'locality_code': '79', 'latitude': 48.9366, 'longitude': -99.7648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58013', 'place_name': 'Cayuga', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 46.1326, 'longitude': -97.4059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58017', 'place_name': 'Cogswell', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 46.0659, 'longitude': -97.8207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58032', 'place_name': 'Forman', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 46.0721, 'longitude': -97.6986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58040', 'place_name': 'Gwinner', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 46.2258, 'longitude': -97.6626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58043', 'place_name': 'Havana', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 45.9644, 'longitude': -97.6094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58060', 'place_name': 'Milnor', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 46.2007, 'longitude': -97.4772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58067', 'place_name': 'Rutland', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 46.0738, 'longitude': -97.5483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58069', 'place_name': 'Stirum', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sargent', 'locality_code': '81', 'latitude': 46.2519, 'longitude': -97.8326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58430', 'place_name': 'Denhoff', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sheridan', 'locality_code': '83', 'latitude': 47.5709, 'longitude': -100.263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58444', 'place_name': 'Goodrich', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sheridan', 'locality_code': '83', 'latitude': 47.471, 'longitude': -100.119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58463', 'place_name': 'Mcclusky', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sheridan', 'locality_code': '83', 'latitude': 47.4896, 'longitude': -100.452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58758', 'place_name': 'Martin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sheridan', 'locality_code': '83', 'latitude': 47.7781, 'longitude': -100.1225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58528', 'place_name': 'Cannon Ball', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sioux', 'locality_code': '85', 'latitude': 46.3874, 'longitude': -100.5975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58538', 'place_name': 'Fort Yates', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sioux', 'locality_code': '85', 'latitude': 46.0905, 'longitude': -100.6516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58568', 'place_name': 'Selfridge', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sioux', 'locality_code': '85', 'latitude': 46.0351, 'longitude': -101.1502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58570', 'place_name': 'Solen', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Sioux', 'locality_code': '85', 'latitude': 46.3656, 'longitude': -100.7831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58620', 'place_name': 'Amidon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Slope', 'locality_code': '87', 'latitude': 46.456, 'longitude': -103.2647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58643', 'place_name': 'Marmarth', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Slope', 'locality_code': '87', 'latitude': 46.3254, 'longitude': -103.88, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58601', 'place_name': 'Dickinson', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.8057, 'longitude': -102.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58602', 'place_name': 'Dickinson', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.8792, 'longitude': -102.7896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58622', 'place_name': 'Belfield', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.8198, 'longitude': -103.1261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58630', 'place_name': 'Gladstone', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.8152, 'longitude': -102.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58641', 'place_name': 'Lefor', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.6684, 'longitude': -102.4986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58652', 'place_name': 'Richardton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.8426, 'longitude': -102.292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58655', 'place_name': 'South Heart', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.8127, 'longitude': -103.0162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58656', 'place_name': 'Taylor', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stark', 'locality_code': '89', 'latitude': 46.9284, 'longitude': -102.3756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58046', 'place_name': 'Hope', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Steele', 'locality_code': '91', 'latitude': 47.3237, 'longitude': -97.7134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58056', 'place_name': 'Luverne', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Steele', 'locality_code': '91', 'latitude': 47.2319, 'longitude': -97.9314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58230', 'place_name': 'Finley', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Steele', 'locality_code': '91', 'latitude': 47.5306, 'longitude': -97.7442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58277', 'place_name': 'Sharon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Steele', 'locality_code': '91', 'latitude': 47.6062, 'longitude': -97.9051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58401', 'place_name': 'Jamestown', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.921, 'longitude': -98.7455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58402', 'place_name': 'Jamestown', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.9788, 'longitude': -98.96, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58405', 'place_name': 'Jamestown', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.9133, 'longitude': -98.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58420', 'place_name': 'Buchanan', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 47.0051, 'longitude': -98.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58424', 'place_name': 'Cleveland', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.8931, 'longitude': -99.1288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58426', 'place_name': 'Courtenay', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 47.2272, 'longitude': -98.5489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58455', 'place_name': 'Kensal', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 47.2726, 'longitude': -98.7206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58467', 'place_name': 'Medina', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.892, 'longitude': -99.3106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58472', 'place_name': 'Montpelier', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.6816, 'longitude': -98.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58476', 'place_name': 'Pingree', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 47.2038, 'longitude': -99.0144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58481', 'place_name': 'Spiritwood', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.9865, 'longitude': -98.5219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58483', 'place_name': 'Streeter', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.695, 'longitude': -99.2971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58496', 'place_name': 'Woodworth', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 47.1636, 'longitude': -99.3406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58497', 'place_name': 'Ypsilanti', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Stutsman', 'locality_code': '93', 'latitude': 46.7719, 'longitude': -98.4876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58317', 'place_name': 'Bisbee', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Towner', 'locality_code': '95', 'latitude': 48.6258, 'longitude': -99.3779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58324', 'place_name': 'Cando', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Towner', 'locality_code': '95', 'latitude': 48.4867, 'longitude': -99.2099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58331', 'place_name': 'Egeland', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Towner', 'locality_code': '95', 'latitude': 48.6355, 'longitude': -99.1115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58339', 'place_name': 'Hansboro', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Towner', 'locality_code': '95', 'latitude': 48.9001, 'longitude': -99.4278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58363', 'place_name': 'Perth', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Towner', 'locality_code': '95', 'latitude': 48.7546, 'longitude': -99.4384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58365', 'place_name': 'Rocklake', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Towner', 'locality_code': '95', 'latitude': 48.8216, 'longitude': -99.1796, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '58009', 'place_name': 'Blanchard', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.3277, 'longitude': -97.2466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58016', 'place_name': 'Clifford', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.3569, 'longitude': -97.41, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58035', 'place_name': 'Galesburg', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.27, 'longitude': -97.4065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58045', 'place_name': 'Hillsboro', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.3835, 'longitude': -97.0603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58218', 'place_name': 'Buxton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.6163, 'longitude': -97.0893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58219', 'place_name': 'Caledonia', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.4776, 'longitude': -96.879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58223', 'place_name': 'Cummings', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.537, 'longitude': -96.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58240', 'place_name': 'Hatton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.638, 'longitude': -97.4325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58257', 'place_name': 'Mayville', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.5014, 'longitude': -97.3176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58274', 'place_name': 'Portland', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Traill', 'locality_code': '97', 'latitude': 47.5015, 'longitude': -97.3843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58210', 'place_name': 'Adams', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.4223, 'longitude': -98.0867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58227', 'place_name': 'Edinburg', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.4997, 'longitude': -97.8932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58229', 'place_name': 'Fairdale', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.4819, 'longitude': -98.2066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58231', 'place_name': 'Fordville', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.2212, 'longitude': -97.8022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58233', 'place_name': 'Forest River', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.2251, 'longitude': -97.4605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58237', 'place_name': 'Grafton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.4122, 'longitude': -97.4106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58243', 'place_name': 'Hoople', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.5198, 'longitude': -97.6183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58250', 'place_name': 'Lankin', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.2952, 'longitude': -98.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58261', 'place_name': 'Minto', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.26, 'longitude': -97.3144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58270', 'place_name': 'Park River', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.4039, 'longitude': -97.7439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58273', 'place_name': 'Pisek', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Walsh', 'locality_code': '99', 'latitude': 48.2971, 'longitude': -97.7029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58701', 'place_name': 'Minot', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.2291, 'longitude': -101.2985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58702', 'place_name': 'Minot', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.2325, 'longitude': -101.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58703', 'place_name': 'Minot', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.3306, 'longitude': -101.3156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58704', 'place_name': 'Minot Afb', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.4232, 'longitude': -101.3168, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '58705', 'place_name': 'Minot Afb', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.4223, 'longitude': -101.3339, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '58707', 'place_name': 'Minot', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.2453, 'longitude': -101.3012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58718', 'place_name': 'Berthold', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.3064, 'longitude': -101.6866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58722', 'place_name': 'Burlington', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.2735, 'longitude': -101.4282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58725', 'place_name': 'Carpio', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.4323, 'longitude': -101.7119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58733', 'place_name': 'Des Lacs', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.2557, 'longitude': -101.5672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58734', 'place_name': 'Donnybrook', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.49, 'longitude': -101.896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58735', 'place_name': 'Douglas', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 47.8659, 'longitude': -101.5112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58746', 'place_name': 'Kenmare', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.7182, 'longitude': -102.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58756', 'place_name': 'Makoti', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 47.9611, 'longitude': -101.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58779', 'place_name': 'Ryder', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 47.9788, 'longitude': -101.6683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58781', 'place_name': 'Sawyer', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.0858, 'longitude': -101.0674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58785', 'place_name': 'Surrey', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Ward', 'locality_code': '101', 'latitude': 48.2365, 'longitude': -101.1216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58341', 'place_name': 'Harvey', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Wells', 'locality_code': '103', 'latitude': 47.7035, 'longitude': -99.7478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58418', 'place_name': 'Bowdon', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Wells', 'locality_code': '103', 'latitude': 47.4343, 'longitude': -99.7015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58422', 'place_name': 'Cathay', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Wells', 'locality_code': '103', 'latitude': 47.6289, 'longitude': -99.4049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58423', 'place_name': 'Chaseley', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Wells', 'locality_code': '103', 'latitude': 47.449, 'longitude': -99.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58438', 'place_name': 'Fessenden', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Wells', 'locality_code': '103', 'latitude': 47.6286, 'longitude': -99.6434, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '58451', 'place_name': 'Hurdsfield', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Wells', 'locality_code': '103', 'latitude': 47.4387, 'longitude': -99.9416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58486', 'place_name': 'Sykeston', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Wells', 'locality_code': '103', 'latitude': 47.4369, 'longitude': -99.3975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58755', 'place_name': 'Mcgregor', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.595, 'longitude': -102.9288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58795', 'place_name': 'Wildrose', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.5678, 'longitude': -103.1536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58801', 'place_name': 'Williston', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.2257, 'longitude': -103.649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58802', 'place_name': 'Williston', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.1688, 'longitude': -103.6148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58803', 'place_name': 'Williston', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.1468, 'longitude': -103.6199, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '58830', 'place_name': 'Alamo', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.5817, 'longitude': -103.4699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58843', 'place_name': 'Epping', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.2764, 'longitude': -103.3763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58845', 'place_name': 'Grenora', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.5252, 'longitude': -103.9176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58849', 'place_name': 'Ray', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.3217, 'longitude': -103.1654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58852', 'place_name': 'Tioga', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.3646, 'longitude': -102.9576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58853', 'place_name': 'Trenton', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.0706, 'longitude': -103.8369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '58856', 'place_name': 'Zahl', 'state': 'North Dakota', 'state_ab': 'ND', 'county': 'Williams', 'locality_code': '105', 'latitude': 48.5787, 'longitude': -103.6599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68901', 'place_name': 'Hastings', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.5877, 'longitude': -98.3911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68902', 'place_name': 'Hastings', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.5896, 'longitude': -98.3972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68925', 'place_name': 'Ayr', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.4411, 'longitude': -98.439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68950', 'place_name': 'Holstein', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.4542, 'longitude': -98.6538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68955', 'place_name': 'Juniata', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.5867, 'longitude': -98.515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68956', 'place_name': 'Kenesaw', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.6165, 'longitude': -98.6572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68973', 'place_name': 'Roseland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.4591, 'longitude': -98.5551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68636', 'place_name': 'Elgin', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Antelope', 'locality_code': '3', 'latitude': 41.9732, 'longitude': -98.0751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68720', 'place_name': 'Brunswick', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Antelope', 'locality_code': '3', 'latitude': 42.3459, 'longitude': -98.0123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68726', 'place_name': 'Clearwater', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Antelope', 'locality_code': '3', 'latitude': 42.1266, 'longitude': -98.1868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68756', 'place_name': 'Neligh', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Antelope', 'locality_code': '3', 'latitude': 42.1389, 'longitude': -98.0151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68761', 'place_name': 'Oakdale', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Antelope', 'locality_code': '3', 'latitude': 42.0697, 'longitude': -97.9692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68764', 'place_name': 'Orchard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Antelope', 'locality_code': '3', 'latitude': 42.3399, 'longitude': -98.2409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68773', 'place_name': 'Royal', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Antelope', 'locality_code': '3', 'latitude': 42.3648, 'longitude': -98.1235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69121', 'place_name': 'Arthur', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Arthur', 'locality_code': '5', 'latitude': 41.574, 'longitude': -101.6931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69345', 'place_name': 'Harrisburg', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Banner', 'locality_code': '7', 'latitude': 41.5531, 'longitude': -103.7111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68821', 'place_name': 'Brewster', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Blaine', 'locality_code': '9', 'latitude': 41.9467, 'longitude': -99.8292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68833', 'place_name': 'Dunning', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Blaine', 'locality_code': '9', 'latitude': 41.8131, 'longitude': -100.0873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69157', 'place_name': 'Purdum', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Blaine', 'locality_code': '9', 'latitude': 42.065, 'longitude': -100.2585, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '68620', 'place_name': 'Albion', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boone', 'locality_code': '11', 'latitude': 41.7049, 'longitude': -97.9991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68627', 'place_name': 'Cedar Rapids', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boone', 'locality_code': '11', 'latitude': 41.5564, 'longitude': -98.1554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68652', 'place_name': 'Petersburg', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boone', 'locality_code': '11', 'latitude': 41.859, 'longitude': -98.0848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68655', 'place_name': 'Primrose', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boone', 'locality_code': '11', 'latitude': 41.6405, 'longitude': -98.2355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68660', 'place_name': 'Saint Edward', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boone', 'locality_code': '11', 'latitude': 41.5708, 'longitude': -97.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69301', 'place_name': 'Alliance', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Box Butte', 'locality_code': '13', 'latitude': 42.1149, 'longitude': -102.888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69348', 'place_name': 'Hemingford', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Box Butte', 'locality_code': '13', 'latitude': 42.3312, 'longitude': -103.0644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68719', 'place_name': 'Bristow', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boyd', 'locality_code': '15', 'latitude': 42.9484, 'longitude': -98.5721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68722', 'place_name': 'Butte', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boyd', 'locality_code': '15', 'latitude': 42.9124, 'longitude': -98.8459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68746', 'place_name': 'Lynch', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boyd', 'locality_code': '15', 'latitude': 42.8373, 'longitude': -98.4504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68755', 'place_name': 'Naper', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boyd', 'locality_code': '15', 'latitude': 42.9521, 'longitude': -99.071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68777', 'place_name': 'Spencer', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Boyd', 'locality_code': '15', 'latitude': 42.8849, 'longitude': -98.7059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69210', 'place_name': 'Ainsworth', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Brown', 'locality_code': '17', 'latitude': 42.5403, 'longitude': -99.8615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69214', 'place_name': 'Johnstown', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Brown', 'locality_code': '17', 'latitude': 42.5717, 'longitude': -100.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69217', 'place_name': 'Long Pine', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Brown', 'locality_code': '17', 'latitude': 42.5364, 'longitude': -99.7007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68812', 'place_name': 'Amherst', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.8495, 'longitude': -99.2609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68836', 'place_name': 'Elm Creek', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.7301, 'longitude': -99.3728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68840', 'place_name': 'Gibbon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.7444, 'longitude': -98.8543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68845', 'place_name': 'Kearney', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.7514, 'longitude': -99.1291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68847', 'place_name': 'Kearney', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.7136, 'longitude': -99.0779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68848', 'place_name': 'Kearney', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.6861, 'longitude': -99.0693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68849', 'place_name': 'Kearney', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.8497, 'longitude': -99.0741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68858', 'place_name': 'Miller', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.9422, 'longitude': -99.374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68861', 'place_name': 'Odessa', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.7017, 'longitude': -99.2568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68866', 'place_name': 'Pleasanton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.9818, 'longitude': -99.1283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68869', 'place_name': 'Ravenna', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 41.0233, 'longitude': -98.9041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68870', 'place_name': 'Riverdale', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.8524, 'longitude': -99.1611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68876', 'place_name': 'Shelton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Buffalo', 'locality_code': '19', 'latitude': 40.7717, 'longitude': -98.7435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68019', 'place_name': 'Craig', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Burt', 'locality_code': '21', 'latitude': 41.7715, 'longitude': -96.3924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68020', 'place_name': 'Decatur', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Burt', 'locality_code': '21', 'latitude': 41.9966, 'longitude': -96.2595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68038', 'place_name': 'Lyons', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Burt', 'locality_code': '21', 'latitude': 41.9442, 'longitude': -96.4661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68045', 'place_name': 'Oakland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Burt', 'locality_code': '21', 'latitude': 41.8384, 'longitude': -96.4671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68061', 'place_name': 'Tekamah', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Burt', 'locality_code': '21', 'latitude': 41.7819, 'longitude': -96.2281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68001', 'place_name': 'Abie', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.3479, 'longitude': -96.9563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68014', 'place_name': 'Bruno', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.2718, 'longitude': -96.9646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68036', 'place_name': 'Linwood', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.4129, 'longitude': -96.9399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68624', 'place_name': 'Bellwood', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.3474, 'longitude': -97.2747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68626', 'place_name': 'Brainard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.1832, 'longitude': -96.9882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68632', 'place_name': 'David City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.2528, 'longitude': -97.13, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68635', 'place_name': 'Dwight', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.0894, 'longitude': -96.9931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68658', 'place_name': 'Rising City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.2082, 'longitude': -97.3032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68667', 'place_name': 'Surprise', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.1086, 'longitude': -97.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68669', 'place_name': 'Ulysses', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Butler', 'locality_code': '23', 'latitude': 41.0791, 'longitude': -97.1984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68016', 'place_name': 'Cedar Creek', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 41.0425, 'longitude': -96.1044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68037', 'place_name': 'Louisville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.9967, 'longitude': -96.1948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68048', 'place_name': 'Plattsmouth', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.9992, 'longitude': -95.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68058', 'place_name': 'South Bend', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 41.0067, 'longitude': -96.2462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68304', 'place_name': 'Alvo', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.8992, 'longitude': -96.4036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68307', 'place_name': 'Avoca', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.8159, 'longitude': -96.0957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68347', 'place_name': 'Eagle', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.8169, 'longitude': -96.429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68349', 'place_name': 'Elmwood', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.8378, 'longitude': -96.2944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68366', 'place_name': 'Greenwood', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.9706, 'longitude': -96.4258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68403', 'place_name': 'Manley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.9207, 'longitude': -96.168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68407', 'place_name': 'Murdock', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.919, 'longitude': -96.2848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68409', 'place_name': 'Murray', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.92, 'longitude': -95.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68413', 'place_name': 'Nehawka', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.833, 'longitude': -95.993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68455', 'place_name': 'Union', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.8245, 'longitude': -95.9037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68463', 'place_name': 'Weeping Water', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cass', 'locality_code': '25', 'latitude': 40.8731, 'longitude': -96.1528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68717', 'place_name': 'Belden', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.4022, 'longitude': -97.1956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68727', 'place_name': 'Coleridge', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.5061, 'longitude': -97.2037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68736', 'place_name': 'Fordyce', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.7309, 'longitude': -97.3567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68739', 'place_name': 'Hartington', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.6235, 'longitude': -97.2837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68745', 'place_name': 'Laurel', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.427, 'longitude': -97.0874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68749', 'place_name': 'Magnet', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.455, 'longitude': -97.4701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68771', 'place_name': 'Randolph', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.3798, 'longitude': -97.3464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68774', 'place_name': 'Saint Helena', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.8046, 'longitude': -97.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68792', 'place_name': 'Wynot', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cedar', 'locality_code': '27', 'latitude': 42.7393, 'longitude': -97.1678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69023', 'place_name': 'Champion', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Chase', 'locality_code': '29', 'latitude': 40.46, 'longitude': -101.7485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69027', 'place_name': 'Enders', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Chase', 'locality_code': '29', 'latitude': 40.4655, 'longitude': -101.5222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69033', 'place_name': 'Imperial', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Chase', 'locality_code': '29', 'latitude': 40.5251, 'longitude': -101.6468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69045', 'place_name': 'Wauneta', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Chase', 'locality_code': '29', 'latitude': 40.4409, 'longitude': -101.3812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69135', 'place_name': 'Elsmere', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.2403, 'longitude': -100.2595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69201', 'place_name': 'Valentine', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.8062, 'longitude': -100.6215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69211', 'place_name': 'Cody', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.825, 'longitude': -101.2913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69212', 'place_name': 'Crookston', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.9255, 'longitude': -100.7735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69216', 'place_name': 'Kilgore', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.9146, 'longitude': -100.9884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69218', 'place_name': 'Merriman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.6419, 'longitude': -101.7583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69219', 'place_name': 'Nenzel', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.9278, 'longitude': -101.1029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69220', 'place_name': 'Sparks', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.9411, 'longitude': -100.256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69221', 'place_name': 'Wood Lake', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cherry', 'locality_code': '31', 'latitude': 42.6264, 'longitude': -100.2872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69131', 'place_name': 'Dalton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cheyenne', 'locality_code': '33', 'latitude': 41.4068, 'longitude': -102.9726, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69141', 'place_name': 'Gurley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cheyenne', 'locality_code': '33', 'latitude': 41.315, 'longitude': -102.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69149', 'place_name': 'Lodgepole', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cheyenne', 'locality_code': '33', 'latitude': 41.1697, 'longitude': -102.657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69156', 'place_name': 'Potter', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cheyenne', 'locality_code': '33', 'latitude': 41.2347, 'longitude': -103.3061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69160', 'place_name': 'Sidney', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cheyenne', 'locality_code': '33', 'latitude': 41.2205, 'longitude': -102.9959, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69162', 'place_name': 'Sidney', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cheyenne', 'locality_code': '33', 'latitude': 41.138, 'longitude': -102.9856, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '68452', 'place_name': 'Ong', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.3968, 'longitude': -97.861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68933', 'place_name': 'Clay Center', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.5113, 'longitude': -98.0386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68934', 'place_name': 'Deweese', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.354, 'longitude': -98.14, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68935', 'place_name': 'Edgar', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.3652, 'longitude': -97.9727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68938', 'place_name': 'Fairfield', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.4285, 'longitude': -98.1063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68941', 'place_name': 'Glenvil', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.4931, 'longitude': -98.2465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68944', 'place_name': 'Harvard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.6265, 'longitude': -98.0846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68954', 'place_name': 'Inland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.5899, 'longitude': -98.2234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68975', 'place_name': 'Saronville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.6021, 'longitude': -97.9388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68979', 'place_name': 'Sutton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.6056, 'longitude': -97.8592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68980', 'place_name': 'Trumbull', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Clay', 'locality_code': '35', 'latitude': 40.6795, 'longitude': -98.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68629', 'place_name': 'Clarkson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Colfax', 'locality_code': '37', 'latitude': 41.6961, 'longitude': -97.1051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68641', 'place_name': 'Howells', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Colfax', 'locality_code': '37', 'latitude': 41.725, 'longitude': -97.0028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68643', 'place_name': 'Leigh', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Colfax', 'locality_code': '37', 'latitude': 41.7053, 'longitude': -97.2381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68659', 'place_name': 'Rogers', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Colfax', 'locality_code': '37', 'latitude': 41.4653, 'longitude': -96.915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68661', 'place_name': 'Schuyler', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Colfax', 'locality_code': '37', 'latitude': 41.4591, 'longitude': -97.0628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68004', 'place_name': 'Bancroft', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cuming', 'locality_code': '39', 'latitude': 42.0267, 'longitude': -96.6171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68716', 'place_name': 'Beemer', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cuming', 'locality_code': '39', 'latitude': 41.9374, 'longitude': -96.815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68788', 'place_name': 'West Point', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cuming', 'locality_code': '39', 'latitude': 41.845, 'longitude': -96.7318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68791', 'place_name': 'Wisner', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Cuming', 'locality_code': '39', 'latitude': 41.998, 'longitude': -96.917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68813', 'place_name': 'Anselmo', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.6208, 'longitude': -99.8644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68814', 'place_name': 'Ansley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.3019, 'longitude': -99.3645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68822', 'place_name': 'Broken Bow', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.4126, 'longitude': -99.6355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68825', 'place_name': 'Callaway', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.2485, 'longitude': -99.9932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68828', 'place_name': 'Comstock', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.5606, 'longitude': -99.2504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68855', 'place_name': 'Mason City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.1853, 'longitude': -99.3049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68856', 'place_name': 'Merna', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.4435, 'longitude': -99.8036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68860', 'place_name': 'Oconto', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.1411, 'longitude': -99.7632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68874', 'place_name': 'Sargent', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.6508, 'longitude': -99.3816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68881', 'place_name': 'Westerville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.4193, 'longitude': -99.3844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69120', 'place_name': 'Arnold', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Custer', 'locality_code': '41', 'latitude': 41.4456, 'longitude': -100.1567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68030', 'place_name': 'Homer', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dakota', 'locality_code': '43', 'latitude': 42.3322, 'longitude': -96.4656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68731', 'place_name': 'Dakota City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dakota', 'locality_code': '43', 'latitude': 42.3807, 'longitude': -96.4536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68733', 'place_name': 'Emerson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dakota', 'locality_code': '43', 'latitude': 42.2852, 'longitude': -96.7159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68741', 'place_name': 'Hubbard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dakota', 'locality_code': '43', 'latitude': 42.3576, 'longitude': -96.6031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68743', 'place_name': 'Jackson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dakota', 'locality_code': '43', 'latitude': 42.4529, 'longitude': -96.5743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68776', 'place_name': 'South Sioux City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dakota', 'locality_code': '43', 'latitude': 42.4656, 'longitude': -96.4182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69337', 'place_name': 'Chadron', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawes', 'locality_code': '45', 'latitude': 42.8193, 'longitude': -102.9953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69339', 'place_name': 'Crawford', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawes', 'locality_code': '45', 'latitude': 42.6758, 'longitude': -103.4053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69354', 'place_name': 'Marsland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawes', 'locality_code': '45', 'latitude': 42.4439, 'longitude': -103.2985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69367', 'place_name': 'Whitney', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawes', 'locality_code': '45', 'latitude': 42.7559, 'longitude': -103.2396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68834', 'place_name': 'Eddyville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 41.0079, 'longitude': -99.681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68850', 'place_name': 'Lexington', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 40.785, 'longitude': -99.7515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68863', 'place_name': 'Overton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 40.7519, 'longitude': -99.5278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68878', 'place_name': 'Sumner', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 40.9504, 'longitude': -99.52, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69029', 'place_name': 'Farnam', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 40.7129, 'longitude': -100.2069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69130', 'place_name': 'Cozad', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 40.8619, 'longitude': -99.9921, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69138', 'place_name': 'Gothenburg', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 40.94, 'longitude': -100.1547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69171', 'place_name': 'Willow Island', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dawson', 'locality_code': '47', 'latitude': 40.8925, 'longitude': -100.0703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69122', 'place_name': 'Big Springs', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Deuel', 'locality_code': '49', 'latitude': 41.0696, 'longitude': -102.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69129', 'place_name': 'Chappell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Deuel', 'locality_code': '49', 'latitude': 41.0966, 'longitude': -102.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68710', 'place_name': 'Allen', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.4437, 'longitude': -96.8574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68728', 'place_name': 'Concord', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.382, 'longitude': -96.981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68732', 'place_name': 'Dixon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.4185, 'longitude': -96.9774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68751', 'place_name': 'Maskell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.6905, 'longitude': -96.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68757', 'place_name': 'Newcastle', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.6207, 'longitude': -96.8709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68770', 'place_name': 'Ponca', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.5693, 'longitude': -96.7128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68784', 'place_name': 'Wakefield', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.2733, 'longitude': -96.8776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68785', 'place_name': 'Waterbury', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dixon', 'locality_code': '51', 'latitude': 42.4604, 'longitude': -96.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68025', 'place_name': 'Fremont', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.4416, 'longitude': -96.4945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68026', 'place_name': 'Fremont', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.4333, 'longitude': -96.4981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68031', 'place_name': 'Hooper', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.6414, 'longitude': -96.5232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68044', 'place_name': 'Nickerson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.5491, 'longitude': -96.4441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68057', 'place_name': 'Scribner', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.663, 'longitude': -96.6441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68063', 'place_name': 'Uehling', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.7369, 'longitude': -96.5037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68072', 'place_name': 'Winslow', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.6102, 'longitude': -96.5033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68621', 'place_name': 'Ames', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.4613, 'longitude': -96.6463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68633', 'place_name': 'Dodge', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.7052, 'longitude': -96.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68649', 'place_name': 'North Bend', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.4689, 'longitude': -96.7813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68664', 'place_name': 'Snyder', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dodge', 'locality_code': '53', 'latitude': 41.7039, 'longitude': -96.7886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68007', 'place_name': 'Bennington', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.3623, 'longitude': -96.1575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68010', 'place_name': 'Boys Town', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2587, 'longitude': -96.133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68022', 'place_name': 'Elkhorn', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2756, 'longitude': -96.2431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68064', 'place_name': 'Valley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.3186, 'longitude': -96.3463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68069', 'place_name': 'Waterloo', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2702, 'longitude': -96.3063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68101', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68102', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.259, 'longitude': -95.9409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68103', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68104', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2919, 'longitude': -95.9999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68105', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2435, 'longitude': -95.9629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68106', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2403, 'longitude': -95.998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68107', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2068, 'longitude': -95.9559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68108', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2382, 'longitude': -95.9336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68109', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68110', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2933, 'longitude': -95.9361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68111', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2962, 'longitude': -95.965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68112', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.3296, 'longitude': -95.9597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68114', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2656, 'longitude': -96.0493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68116', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2879, 'longitude': -96.1495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68117', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2064, 'longitude': -95.9953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68118', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2606, 'longitude': -96.1661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68119', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68120', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68122', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.3333, 'longitude': -96.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68124', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2338, 'longitude': -96.0495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68127', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2074, 'longitude': -96.0612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68130', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2355, 'longitude': -96.1688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68131', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2647, 'longitude': -95.9639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68132', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2657, 'longitude': -95.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68134', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2949, 'longitude': -96.0546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68135', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2104, 'longitude': -96.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68137', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2075, 'longitude': -96.1147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68139', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68142', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.3359, 'longitude': -96.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68144', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2335, 'longitude': -96.1188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68145', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68152', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.3346, 'longitude': -96.0003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68154', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2642, 'longitude': -96.1206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68155', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68164', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2955, 'longitude': -96.1008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68172', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68175', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68176', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68178', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2657, 'longitude': -95.9477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68179', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68180', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68182', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68183', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68197', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2563, 'longitude': -95.9404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68198', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Douglas', 'locality_code': '55', 'latitude': 41.2586, 'longitude': -95.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69021', 'place_name': 'Benkelman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dundy', 'locality_code': '57', 'latitude': 40.098, 'longitude': -101.5344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69030', 'place_name': 'Haigler', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dundy', 'locality_code': '57', 'latitude': 40.0642, 'longitude': -101.9371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69037', 'place_name': 'Max', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dundy', 'locality_code': '57', 'latitude': 40.198, 'longitude': -101.4116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69041', 'place_name': 'Parks', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Dundy', 'locality_code': '57', 'latitude': 40.1398, 'longitude': -101.7399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68351', 'place_name': 'Exeter', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.6341, 'longitude': -97.4424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68354', 'place_name': 'Fairmont', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.6404, 'longitude': -97.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68361', 'place_name': 'Geneva', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.5277, 'longitude': -97.6096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68365', 'place_name': 'Grafton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.6402, 'longitude': -97.7403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68406', 'place_name': 'Milligan', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.4952, 'longitude': -97.3997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68416', 'place_name': 'Ohiowa', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.4065, 'longitude': -97.4427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68436', 'place_name': 'Shickley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.4077, 'longitude': -97.7143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68444', 'place_name': 'Strang', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Fillmore', 'locality_code': '59', 'latitude': 40.4156, 'longitude': -97.587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68929', 'place_name': 'Bloomington', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Franklin', 'locality_code': '61', 'latitude': 40.1383, 'longitude': -99.0094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68932', 'place_name': 'Campbell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Franklin', 'locality_code': '61', 'latitude': 40.2967, 'longitude': -98.737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68939', 'place_name': 'Franklin', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Franklin', 'locality_code': '61', 'latitude': 40.1052, 'longitude': -98.9469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68947', 'place_name': 'Hildreth', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Franklin', 'locality_code': '61', 'latitude': 40.3217, 'longitude': -99.0571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68960', 'place_name': 'Naponee', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Franklin', 'locality_code': '61', 'latitude': 40.1258, 'longitude': -99.1277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68972', 'place_name': 'Riverton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Franklin', 'locality_code': '61', 'latitude': 40.1016, 'longitude': -98.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68981', 'place_name': 'Upland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Franklin', 'locality_code': '61', 'latitude': 40.3171, 'longitude': -98.8966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69025', 'place_name': 'Curtis', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Frontier', 'locality_code': '63', 'latitude': 40.6131, 'longitude': -100.5104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69028', 'place_name': 'Eustis', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Frontier', 'locality_code': '63', 'latitude': 40.6625, 'longitude': -100.0296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69038', 'place_name': 'Maywood', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Frontier', 'locality_code': '63', 'latitude': 40.6575, 'longitude': -100.6221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69039', 'place_name': 'Moorefield', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Frontier', 'locality_code': '63', 'latitude': 40.5786, 'longitude': -100.3108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69042', 'place_name': 'Stockville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Frontier', 'locality_code': '63', 'latitude': 40.4948, 'longitude': -100.3849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68922', 'place_name': 'Arapahoe', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.3027, 'longitude': -99.8997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68926', 'place_name': 'Beaver City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.129, 'longitude': -99.8065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68936', 'place_name': 'Edison', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.2802, 'longitude': -99.786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68946', 'place_name': 'Hendley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.1063, 'longitude': -99.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68948', 'place_name': 'Holbrook', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.3019, 'longitude': -100.0136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68967', 'place_name': 'Oxford', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.256, 'longitude': -99.6302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69022', 'place_name': 'Cambridge', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.2808, 'longitude': -100.1676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69046', 'place_name': 'Wilsonville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Furnas', 'locality_code': '65', 'latitude': 40.1089, 'longitude': -100.1211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68301', 'place_name': 'Adams', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.4576, 'longitude': -96.5396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68309', 'place_name': 'Barneston', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.0483, 'longitude': -96.577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68310', 'place_name': 'Beatrice', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.2705, 'longitude': -96.7435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68318', 'place_name': 'Blue Springs', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.1407, 'longitude': -96.659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68328', 'place_name': 'Clatonia', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.4724, 'longitude': -96.8555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68331', 'place_name': 'Cortland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.4976, 'longitude': -96.7166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68357', 'place_name': 'Filley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.2946, 'longitude': -96.5301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68381', 'place_name': 'Liberty', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.0801, 'longitude': -96.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68415', 'place_name': 'Odell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.0451, 'longitude': -96.8019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68422', 'place_name': 'Pickrell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.3821, 'longitude': -96.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68458', 'place_name': 'Virginia', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.2309, 'longitude': -96.5121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68466', 'place_name': 'Wymore', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gage', 'locality_code': '67', 'latitude': 40.113, 'longitude': -96.6613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69147', 'place_name': 'Lewellen', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Garden', 'locality_code': '69', 'latitude': 41.3435, 'longitude': -102.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69148', 'place_name': 'Lisco', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Garden', 'locality_code': '69', 'latitude': 41.5114, 'longitude': -102.5498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69154', 'place_name': 'Oshkosh', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Garden', 'locality_code': '69', 'latitude': 41.405, 'longitude': -102.3444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69190', 'place_name': 'Oshkosh', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Garden', 'locality_code': '69', 'latitude': 41.405, 'longitude': -102.3444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68823', 'place_name': 'Burwell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Garfield', 'locality_code': '71', 'latitude': 41.808, 'longitude': -99.0995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68937', 'place_name': 'Elwood', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gosper', 'locality_code': '73', 'latitude': 40.5747, 'longitude': -99.8258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68976', 'place_name': 'Smithfield', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Gosper', 'locality_code': '73', 'latitude': 40.5832, 'longitude': -99.7285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69333', 'place_name': 'Ashby', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Grant', 'locality_code': '75', 'latitude': 41.9776, 'longitude': -101.9636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69350', 'place_name': 'Hyannis', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Grant', 'locality_code': '75', 'latitude': 42.007, 'longitude': -101.7483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69366', 'place_name': 'Whitman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Grant', 'locality_code': '75', 'latitude': 41.9584, 'longitude': -101.5216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68665', 'place_name': 'Spalding', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Greeley', 'locality_code': '77', 'latitude': 41.6874, 'longitude': -98.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68842', 'place_name': 'Greeley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Greeley', 'locality_code': '77', 'latitude': 41.5526, 'longitude': -98.53, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68875', 'place_name': 'Scotia', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Greeley', 'locality_code': '77', 'latitude': 41.4837, 'longitude': -98.6893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68882', 'place_name': 'Wolbach', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Greeley', 'locality_code': '77', 'latitude': 41.4244, 'longitude': -98.3995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68801', 'place_name': 'Grand Island', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hall', 'locality_code': '79', 'latitude': 40.9219, 'longitude': -98.3411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68802', 'place_name': 'Grand Island', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hall', 'locality_code': '79', 'latitude': 40.8725, 'longitude': -98.5021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68803', 'place_name': 'Grand Island', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hall', 'locality_code': '79', 'latitude': 40.9286, 'longitude': -98.3873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68810', 'place_name': 'Alda', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hall', 'locality_code': '79', 'latitude': 40.8711, 'longitude': -98.4681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68824', 'place_name': 'Cairo', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hall', 'locality_code': '79', 'latitude': 41.0002, 'longitude': -98.6165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68832', 'place_name': 'Doniphan', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hall', 'locality_code': '79', 'latitude': 40.77, 'longitude': -98.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68883', 'place_name': 'Wood River', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hall', 'locality_code': '79', 'latitude': 40.8106, 'longitude': -98.6065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68818', 'place_name': 'Aurora', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hamilton', 'locality_code': '81', 'latitude': 40.8528, 'longitude': -98.0201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68841', 'place_name': 'Giltner', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hamilton', 'locality_code': '81', 'latitude': 40.7654, 'longitude': -98.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68843', 'place_name': 'Hampton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hamilton', 'locality_code': '81', 'latitude': 40.9236, 'longitude': -97.8841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68846', 'place_name': 'Hordville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hamilton', 'locality_code': '81', 'latitude': 41.0813, 'longitude': -97.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68854', 'place_name': 'Marquette', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hamilton', 'locality_code': '81', 'latitude': 41.01, 'longitude': -98, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68865', 'place_name': 'Phillips', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hamilton', 'locality_code': '81', 'latitude': 40.8982, 'longitude': -98.2129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68920', 'place_name': 'Alma', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Harlan', 'locality_code': '83', 'latitude': 40.1189, 'longitude': -99.3601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68966', 'place_name': 'Orleans', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Harlan', 'locality_code': '83', 'latitude': 40.1484, 'longitude': -99.4572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68969', 'place_name': 'Ragan', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Harlan', 'locality_code': '83', 'latitude': 40.3103, 'longitude': -99.2898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68971', 'place_name': 'Republican City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Harlan', 'locality_code': '83', 'latitude': 40.1034, 'longitude': -99.2322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68977', 'place_name': 'Stamford', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Harlan', 'locality_code': '83', 'latitude': 40.1163, 'longitude': -99.5814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69032', 'place_name': 'Hayes Center', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hayes', 'locality_code': '85', 'latitude': 40.5173, 'longitude': -101.0252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69024', 'place_name': 'Culbertson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hitchcock', 'locality_code': '87', 'latitude': 40.2237, 'longitude': -100.85, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69040', 'place_name': 'Palisade', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hitchcock', 'locality_code': '87', 'latitude': 40.3387, 'longitude': -101.1295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69043', 'place_name': 'Stratton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hitchcock', 'locality_code': '87', 'latitude': 40.1445, 'longitude': -101.2183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69044', 'place_name': 'Trenton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hitchcock', 'locality_code': '87', 'latitude': 40.1681, 'longitude': -101.0201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68711', 'place_name': 'Amelia', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.1809, 'longitude': -99.008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68713', 'place_name': 'Atkinson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.5483, 'longitude': -98.9761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68725', 'place_name': 'Chambers', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.1916, 'longitude': -98.7378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68734', 'place_name': 'Emmet', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.4747, 'longitude': -98.8238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68735', 'place_name': 'Ewing', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.1851, 'longitude': -98.3981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68742', 'place_name': 'Inman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.3761, 'longitude': -98.5384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68763', 'place_name': 'Oneill', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.4857, 'longitude': -98.6456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68766', 'place_name': 'Page', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.4119, 'longitude': -98.3964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68780', 'place_name': 'Stuart', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Holt', 'locality_code': '89', 'latitude': 42.5713, 'longitude': -99.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69152', 'place_name': 'Mullen', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Hooker', 'locality_code': '91', 'latitude': 42.0163, 'longitude': -101.0542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68820', 'place_name': 'Boelus', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Howard', 'locality_code': '93', 'latitude': 41.1003, 'longitude': -98.6976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68831', 'place_name': 'Dannebrog', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Howard', 'locality_code': '93', 'latitude': 41.1192, 'longitude': -98.5546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68835', 'place_name': 'Elba', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Howard', 'locality_code': '93', 'latitude': 41.2864, 'longitude': -98.5756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68838', 'place_name': 'Farwell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Howard', 'locality_code': '93', 'latitude': 41.2204, 'longitude': -98.6481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68872', 'place_name': 'Saint Libory', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Howard', 'locality_code': '93', 'latitude': 41.0867, 'longitude': -98.3589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68873', 'place_name': 'Saint Paul', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Howard', 'locality_code': '93', 'latitude': 41.2242, 'longitude': -98.444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68338', 'place_name': 'Daykin', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Jefferson', 'locality_code': '95', 'latitude': 40.3192, 'longitude': -97.3043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68342', 'place_name': 'Diller', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Jefferson', 'locality_code': '95', 'latitude': 40.1192, 'longitude': -96.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68350', 'place_name': 'Endicott', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Jefferson', 'locality_code': '95', 'latitude': 40.0496, 'longitude': -97.0813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68352', 'place_name': 'Fairbury', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Jefferson', 'locality_code': '95', 'latitude': 40.1488, 'longitude': -97.1839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68377', 'place_name': 'Jansen', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Jefferson', 'locality_code': '95', 'latitude': 40.2074, 'longitude': -97.0244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68424', 'place_name': 'Plymouth', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Jefferson', 'locality_code': '95', 'latitude': 40.3039, 'longitude': -97.0012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68440', 'place_name': 'Steele City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Jefferson', 'locality_code': '95', 'latitude': 40.0378, 'longitude': -97.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68329', 'place_name': 'Cook', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Johnson', 'locality_code': '97', 'latitude': 40.4986, 'longitude': -96.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68332', 'place_name': 'Crab Orchard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Johnson', 'locality_code': '97', 'latitude': 40.3166, 'longitude': -96.4116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68348', 'place_name': 'Elk Creek', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Johnson', 'locality_code': '97', 'latitude': 40.2977, 'longitude': -96.1421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68443', 'place_name': 'Sterling', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Johnson', 'locality_code': '97', 'latitude': 40.4637, 'longitude': -96.3867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68450', 'place_name': 'Tecumseh', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Johnson', 'locality_code': '97', 'latitude': 40.3697, 'longitude': -96.205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68924', 'place_name': 'Axtell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Kearney', 'locality_code': '99', 'latitude': 40.5269, 'longitude': -99.1169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68945', 'place_name': 'Heartwell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Kearney', 'locality_code': '99', 'latitude': 40.5716, 'longitude': -98.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68959', 'place_name': 'Minden', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Kearney', 'locality_code': '99', 'latitude': 40.5091, 'longitude': -98.9383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68982', 'place_name': 'Wilcox', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Kearney', 'locality_code': '99', 'latitude': 40.3735, 'longitude': -99.1539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69127', 'place_name': 'Brule', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keith', 'locality_code': '101', 'latitude': 41.1002, 'longitude': -101.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69144', 'place_name': 'Keystone', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keith', 'locality_code': '101', 'latitude': 41.2621, 'longitude': -101.6282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69146', 'place_name': 'Lemoyne', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keith', 'locality_code': '101', 'latitude': 41.3236, 'longitude': -101.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69153', 'place_name': 'Ogallala', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keith', 'locality_code': '101', 'latitude': 41.1275, 'longitude': -101.7107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69155', 'place_name': 'Paxton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keith', 'locality_code': '101', 'latitude': 41.1268, 'longitude': -101.3585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68753', 'place_name': 'Mills', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keya Paha', 'locality_code': '103', 'latitude': 42.9225, 'longitude': -99.4466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68759', 'place_name': 'Newport', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keya Paha', 'locality_code': '103', 'latitude': 42.6001, 'longitude': -99.3359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68778', 'place_name': 'Springview', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Keya Paha', 'locality_code': '103', 'latitude': 42.8488, 'longitude': -99.8061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69128', 'place_name': 'Bushnell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Kimball', 'locality_code': '105', 'latitude': 41.2139, 'longitude': -103.9075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69133', 'place_name': 'Dix', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Kimball', 'locality_code': '105', 'latitude': 41.227, 'longitude': -103.4796, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69145', 'place_name': 'Kimball', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Kimball', 'locality_code': '105', 'latitude': 41.2321, 'longitude': -103.6602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68718', 'place_name': 'Bloomfield', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.5978, 'longitude': -97.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68724', 'place_name': 'Center', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.5973, 'longitude': -97.867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68729', 'place_name': 'Creighton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.4681, 'longitude': -97.8932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68730', 'place_name': 'Crofton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.737, 'longitude': -97.5406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68760', 'place_name': 'Niobrara', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.7391, 'longitude': -97.9248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68783', 'place_name': 'Verdigre', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.6101, 'longitude': -98.0793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68786', 'place_name': 'Wausa', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.4973, 'longitude': -97.5576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68789', 'place_name': 'Winnetoon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Knox', 'locality_code': '107', 'latitude': 42.5334, 'longitude': -98.005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68317', 'place_name': 'Bennet', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.68, 'longitude': -96.5064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68336', 'place_name': 'Davey', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.9639, 'longitude': -96.688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68339', 'place_name': 'Denton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7378, 'longitude': -96.8445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68358', 'place_name': 'Firth', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.5586, 'longitude': -96.614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68368', 'place_name': 'Hallam', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.5739, 'longitude': -96.7998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68372', 'place_name': 'Hickman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.6119, 'longitude': -96.6247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68402', 'place_name': 'Malcolm', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.9091, 'longitude': -96.86, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68404', 'place_name': 'Martell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.6514, 'longitude': -96.7442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68419', 'place_name': 'Panama', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.5998, 'longitude': -96.5129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68428', 'place_name': 'Raymond', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.9342, 'longitude': -96.7866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68430', 'place_name': 'Roca', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.6702, 'longitude': -96.6391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68438', 'place_name': 'Sprague', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.6267, 'longitude': -96.7456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68461', 'place_name': 'Walton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7975, 'longitude': -96.5359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68462', 'place_name': 'Waverly', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.9222, 'longitude': -96.526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68501', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8651, 'longitude': -96.8231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68502', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7893, 'longitude': -96.6938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68503', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8233, 'longitude': -96.6766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68504', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8392, 'longitude': -96.6532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68505', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8247, 'longitude': -96.6252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68506', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7848, 'longitude': -96.6431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68507', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8473, 'longitude': -96.6289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68508', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8145, 'longitude': -96.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68509', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7845, 'longitude': -96.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68510', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8063, 'longitude': -96.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68512', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7565, 'longitude': -96.6946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68514', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.9401, 'longitude': -96.6621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68516', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7568, 'longitude': -96.6523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68517', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.9317, 'longitude': -96.6045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68520', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7744, 'longitude': -96.5693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68521', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.851, 'longitude': -96.711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68522', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7934, 'longitude': -96.7479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68523', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7408, 'longitude': -96.7583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68524', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8529, 'longitude': -96.7943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68526', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7314, 'longitude': -96.5878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68527', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8347, 'longitude': -96.5401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68528', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8195, 'longitude': -96.7545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68529', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8798, 'longitude': -96.7798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68531', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.9008, 'longitude': -96.7201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68532', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7922, 'longitude': -96.8551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68542', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7845, 'longitude': -96.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68544', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7845, 'longitude': -96.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68583', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.7845, 'longitude': -96.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68588', 'place_name': 'Lincoln', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lancaster', 'locality_code': '109', 'latitude': 40.8206, 'longitude': -96.6928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69101', 'place_name': 'North Platte', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 41.1326, 'longitude': -100.7746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69103', 'place_name': 'North Platte', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 41.0464, 'longitude': -100.7469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69123', 'place_name': 'Brady', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 41.0515, 'longitude': -100.3736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69132', 'place_name': 'Dickens', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 40.8041, 'longitude': -101.0149, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69143', 'place_name': 'Hershey', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 41.2102, 'longitude': -101.0392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69151', 'place_name': 'Maxwell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 41.0588, 'longitude': -100.527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69165', 'place_name': 'Sutherland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 41.1557, 'longitude': -101.136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69169', 'place_name': 'Wallace', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 40.8304, 'longitude': -101.1738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69170', 'place_name': 'Wellfleet', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Lincoln', 'locality_code': '111', 'latitude': 40.7988, 'longitude': -100.7119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69163', 'place_name': 'Stapleton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Logan', 'locality_code': '113', 'latitude': 41.4888, 'longitude': -100.4831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68879', 'place_name': 'Taylor', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Loup', 'locality_code': '115', 'latitude': 41.9141, 'longitude': -99.4543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69167', 'place_name': 'Tryon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'McPherson', 'locality_code': '117', 'latitude': 41.5732, 'longitude': -101.0175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68701', 'place_name': 'Norfolk', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Madison', 'locality_code': '119', 'latitude': 42.0329, 'longitude': -97.4229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68702', 'place_name': 'Norfolk', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Madison', 'locality_code': '119', 'latitude': 42.0283, 'longitude': -97.417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68715', 'place_name': 'Battle Creek', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Madison', 'locality_code': '119', 'latitude': 41.9943, 'longitude': -97.5982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68748', 'place_name': 'Madison', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Madison', 'locality_code': '119', 'latitude': 41.8308, 'longitude': -97.472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68752', 'place_name': 'Meadow Grove', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Madison', 'locality_code': '119', 'latitude': 42.0102, 'longitude': -97.7334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68758', 'place_name': 'Newman Grove', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Madison', 'locality_code': '119', 'latitude': 41.7498, 'longitude': -97.774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68781', 'place_name': 'Tilden', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Madison', 'locality_code': '119', 'latitude': 42.0496, 'longitude': -97.8223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68628', 'place_name': 'Clarks', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Merrick', 'locality_code': '121', 'latitude': 41.2328, 'longitude': -97.8461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68663', 'place_name': 'Silver Creek', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Merrick', 'locality_code': '121', 'latitude': 41.319, 'longitude': -97.6671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68816', 'place_name': 'Archer', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Merrick', 'locality_code': '121', 'latitude': 41.1782, 'longitude': -98.1182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68826', 'place_name': 'Central City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Merrick', 'locality_code': '121', 'latitude': 41.1213, 'longitude': -98.0017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68827', 'place_name': 'Chapman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Merrick', 'locality_code': '121', 'latitude': 40.9856, 'longitude': -98.2217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68864', 'place_name': 'Palmer', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Merrick', 'locality_code': '121', 'latitude': 41.1788, 'longitude': -98.2411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69125', 'place_name': 'Broadwater', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Morrill', 'locality_code': '123', 'latitude': 41.5825, 'longitude': -102.8225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69331', 'place_name': 'Angora', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Morrill', 'locality_code': '123', 'latitude': 41.8934, 'longitude': -103.085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69334', 'place_name': 'Bayard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Morrill', 'locality_code': '123', 'latitude': 41.7579, 'longitude': -103.3019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69336', 'place_name': 'Bridgeport', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Morrill', 'locality_code': '123', 'latitude': 41.6766, 'longitude': -103.0701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68623', 'place_name': 'Belgrade', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nance', 'locality_code': '125', 'latitude': 41.4611, 'longitude': -98.0866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68638', 'place_name': 'Fullerton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nance', 'locality_code': '125', 'latitude': 41.3633, 'longitude': -97.9692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68640', 'place_name': 'Genoa', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nance', 'locality_code': '125', 'latitude': 41.4468, 'longitude': -97.764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68305', 'place_name': 'Auburn', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nemaha', 'locality_code': '127', 'latitude': 40.3789, 'longitude': -95.8526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68320', 'place_name': 'Brock', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nemaha', 'locality_code': '127', 'latitude': 40.4772, 'longitude': -95.9801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68321', 'place_name': 'Brownville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nemaha', 'locality_code': '127', 'latitude': 40.3994, 'longitude': -95.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68378', 'place_name': 'Johnson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nemaha', 'locality_code': '127', 'latitude': 40.4016, 'longitude': -95.9883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68379', 'place_name': 'Julian', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nemaha', 'locality_code': '127', 'latitude': 40.5199, 'longitude': -95.8674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68414', 'place_name': 'Nemaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nemaha', 'locality_code': '127', 'latitude': 40.3198, 'longitude': -95.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68421', 'place_name': 'Peru', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nemaha', 'locality_code': '127', 'latitude': 40.4766, 'longitude': -95.7312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68943', 'place_name': 'Hardy', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nuckolls', 'locality_code': '129', 'latitude': 40.0285, 'longitude': -97.9271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68957', 'place_name': 'Lawrence', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nuckolls', 'locality_code': '129', 'latitude': 40.2767, 'longitude': -98.2402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68961', 'place_name': 'Nelson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nuckolls', 'locality_code': '129', 'latitude': 40.2011, 'longitude': -98.0684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68964', 'place_name': 'Oak', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nuckolls', 'locality_code': '129', 'latitude': 40.2378, 'longitude': -97.903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68974', 'place_name': 'Ruskin', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nuckolls', 'locality_code': '129', 'latitude': 40.1383, 'longitude': -97.872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68978', 'place_name': 'Superior', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Nuckolls', 'locality_code': '129', 'latitude': 40.0315, 'longitude': -98.0779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68324', 'place_name': 'Burr', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.5601, 'longitude': -96.2384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68344', 'place_name': 'Douglas', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.5838, 'longitude': -96.397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68346', 'place_name': 'Dunbar', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.6592, 'longitude': -96.0136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68382', 'place_name': 'Lorton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.5973, 'longitude': -96.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68410', 'place_name': 'Nebraska City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.6747, 'longitude': -95.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68417', 'place_name': 'Otoe', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.7355, 'longitude': -96.1329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68418', 'place_name': 'Palmyra', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.705, 'longitude': -96.3999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68446', 'place_name': 'Syracuse', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.6614, 'longitude': -96.1824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68448', 'place_name': 'Talmage', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.5586, 'longitude': -96.0138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68454', 'place_name': 'Unadilla', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Otoe', 'locality_code': '131', 'latitude': 40.6917, 'longitude': -96.2825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68323', 'place_name': 'Burchard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pawnee', 'locality_code': '133', 'latitude': 40.1475, 'longitude': -96.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68345', 'place_name': 'Du Bois', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pawnee', 'locality_code': '133', 'latitude': 40.0375, 'longitude': -96.0575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68380', 'place_name': 'Lewiston', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pawnee', 'locality_code': '133', 'latitude': 40.2309, 'longitude': -96.4049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68420', 'place_name': 'Pawnee City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pawnee', 'locality_code': '133', 'latitude': 40.1093, 'longitude': -96.1509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68441', 'place_name': 'Steinauer', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pawnee', 'locality_code': '133', 'latitude': 40.2169, 'longitude': -96.2302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68447', 'place_name': 'Table Rock', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pawnee', 'locality_code': '133', 'latitude': 40.1874, 'longitude': -96.0818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69134', 'place_name': 'Elsie', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Perkins', 'locality_code': '135', 'latitude': 40.8596, 'longitude': -101.37, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69140', 'place_name': 'Grant', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Perkins', 'locality_code': '135', 'latitude': 40.8511, 'longitude': -101.7196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69150', 'place_name': 'Madrid', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Perkins', 'locality_code': '135', 'latitude': 40.8544, 'longitude': -101.5371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69168', 'place_name': 'Venango', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Perkins', 'locality_code': '135', 'latitude': 40.8073, 'longitude': -101.9839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68923', 'place_name': 'Atlanta', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Phelps', 'locality_code': '137', 'latitude': 40.3667, 'longitude': -99.4732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68927', 'place_name': 'Bertrand', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Phelps', 'locality_code': '137', 'latitude': 40.5608, 'longitude': -99.5759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68940', 'place_name': 'Funk', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Phelps', 'locality_code': '137', 'latitude': 40.502, 'longitude': -99.245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68949', 'place_name': 'Holdrege', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Phelps', 'locality_code': '137', 'latitude': 40.4475, 'longitude': -99.3672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68958', 'place_name': 'Loomis', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Phelps', 'locality_code': '137', 'latitude': 40.4792, 'longitude': -99.4979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68738', 'place_name': 'Hadar', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pierce', 'locality_code': '139', 'latitude': 42.105, 'longitude': -97.4492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68747', 'place_name': 'Mclean', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pierce', 'locality_code': '139', 'latitude': 42.3921, 'longitude': -97.4751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68765', 'place_name': 'Osmond', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pierce', 'locality_code': '139', 'latitude': 42.3539, 'longitude': -97.582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68767', 'place_name': 'Pierce', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pierce', 'locality_code': '139', 'latitude': 42.1943, 'longitude': -97.5256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68769', 'place_name': 'Plainview', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Pierce', 'locality_code': '139', 'latitude': 42.3467, 'longitude': -97.7786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68601', 'place_name': 'Columbus', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.4297, 'longitude': -97.3684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68602', 'place_name': 'Columbus', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.4297, 'longitude': -97.3684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68631', 'place_name': 'Creston', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.7067, 'longitude': -97.3625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68634', 'place_name': 'Duncan', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.3895, 'longitude': -97.4948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68642', 'place_name': 'Humphrey', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.6702, 'longitude': -97.4986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68644', 'place_name': 'Lindsay', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.6926, 'longitude': -97.6711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68647', 'place_name': 'Monroe', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.4783, 'longitude': -97.6061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68653', 'place_name': 'Platte Center', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Platte', 'locality_code': '141', 'latitude': 41.5375, 'longitude': -97.4884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68651', 'place_name': 'Osceola', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Polk', 'locality_code': '143', 'latitude': 41.1966, 'longitude': -97.5571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68654', 'place_name': 'Polk', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Polk', 'locality_code': '143', 'latitude': 41.0767, 'longitude': -97.7839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68662', 'place_name': 'Shelby', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Polk', 'locality_code': '143', 'latitude': 41.1922, 'longitude': -97.4253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68666', 'place_name': 'Stromsburg', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Polk', 'locality_code': '143', 'latitude': 41.1118, 'longitude': -97.5742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69001', 'place_name': 'Mc Cook', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Red Willow', 'locality_code': '145', 'latitude': 40.2049, 'longitude': -100.6279, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69020', 'place_name': 'Bartley', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Red Willow', 'locality_code': '145', 'latitude': 40.2581, 'longitude': -100.2908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69026', 'place_name': 'Danbury', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Red Willow', 'locality_code': '145', 'latitude': 40.0377, 'longitude': -100.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69034', 'place_name': 'Indianola', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Red Willow', 'locality_code': '145', 'latitude': 40.2357, 'longitude': -100.4298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69036', 'place_name': 'Lebanon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Red Willow', 'locality_code': '145', 'latitude': 40.0506, 'longitude': -100.2763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68337', 'place_name': 'Dawson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.1377, 'longitude': -95.8341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68355', 'place_name': 'Falls City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.0742, 'longitude': -95.5931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68376', 'place_name': 'Humboldt', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.1566, 'longitude': -95.9311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68431', 'place_name': 'Rulo', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.0536, 'longitude': -95.4292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68433', 'place_name': 'Salem', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.062, 'longitude': -95.7273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68437', 'place_name': 'Shubert', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.2325, 'longitude': -95.6895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68442', 'place_name': 'Stella', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.2303, 'longitude': -95.768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68457', 'place_name': 'Verdon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Richardson', 'locality_code': '147', 'latitude': 40.1425, 'longitude': -95.7162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68714', 'place_name': 'Bassett', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Rock', 'locality_code': '149', 'latitude': 42.5763, 'longitude': -99.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68333', 'place_name': 'Crete', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.6193, 'longitude': -96.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68341', 'place_name': 'De Witt', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.3944, 'longitude': -96.9338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68343', 'place_name': 'Dorchester', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.6499, 'longitude': -97.1056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68359', 'place_name': 'Friend', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.6368, 'longitude': -97.2739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68445', 'place_name': 'Swanton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.3844, 'longitude': -97.0806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68453', 'place_name': 'Tobias', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.4262, 'longitude': -97.3184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68464', 'place_name': 'Western', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.4152, 'longitude': -97.1976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68465', 'place_name': 'Wilber', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saline', 'locality_code': '151', 'latitude': 40.4821, 'longitude': -96.9757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68005', 'place_name': 'Bellevue', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1497, 'longitude': -95.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68028', 'place_name': 'Gretna', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1345, 'longitude': -96.2458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68046', 'place_name': 'Papillion', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1523, 'longitude': -96.0371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68056', 'place_name': 'St Columbans', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.0927, 'longitude': -96.0905, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '68059', 'place_name': 'Springfield', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.0765, 'longitude': -96.1438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68113', 'place_name': 'Offutt Afb', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.2563, 'longitude': -95.9404, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '68123', 'place_name': 'Bellevue', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1156, 'longitude': -95.9393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68128', 'place_name': 'La Vista', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1814, 'longitude': -96.0658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68133', 'place_name': 'Papillion', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1416, 'longitude': -96.0131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68136', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1683, 'longitude': -96.2096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68138', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1549, 'longitude': -96.1376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68147', 'place_name': 'Bellevue', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.1758, 'longitude': -95.9553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68157', 'place_name': 'Omaha', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sarpy', 'locality_code': '153', 'latitude': 41.181, 'longitude': -95.9909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68003', 'place_name': 'Ashland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.0541, 'longitude': -96.3904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68015', 'place_name': 'Cedar Bluffs', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.3835, 'longitude': -96.5691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68017', 'place_name': 'Ceresco', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.0681, 'longitude': -96.6398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68018', 'place_name': 'Colon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.2883, 'longitude': -96.6141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68033', 'place_name': 'Ithaca', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.1748, 'longitude': -96.5298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68040', 'place_name': 'Malmo', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.2984, 'longitude': -96.7327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68041', 'place_name': 'Mead', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.2393, 'longitude': -96.4961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68042', 'place_name': 'Memphis', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.0946, 'longitude': -96.4306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68050', 'place_name': 'Prague', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.3036, 'longitude': -96.8301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68065', 'place_name': 'Valparaiso', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.0843, 'longitude': -96.8091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68066', 'place_name': 'Wahoo', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.2117, 'longitude': -96.6219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68070', 'place_name': 'Weston', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.1811, 'longitude': -96.7691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68073', 'place_name': 'Yutan', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.234, 'longitude': -96.3932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68648', 'place_name': 'Morse Bluff', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Saunders', 'locality_code': '155', 'latitude': 41.4178, 'longitude': -96.7862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69341', 'place_name': 'Gering', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.822, 'longitude': -103.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69352', 'place_name': 'Lyman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.8918, 'longitude': -104.0066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69353', 'place_name': 'Mcgrew', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.7469, 'longitude': -103.4164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69355', 'place_name': 'Melbeta', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.7816, 'longitude': -103.5177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69356', 'place_name': 'Minatare', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.8493, 'longitude': -103.489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69357', 'place_name': 'Mitchell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.9459, 'longitude': -103.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69358', 'place_name': 'Morrill', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.9681, 'longitude': -103.9182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69361', 'place_name': 'Scottsbluff', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.872, 'longitude': -103.6619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69363', 'place_name': 'Scottsbluff', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Scotts Bluff', 'locality_code': '157', 'latitude': 41.8666, 'longitude': -103.6672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68313', 'place_name': 'Beaver Crossing', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.7887, 'longitude': -97.2914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68314', 'place_name': 'Bee', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 41.0007, 'longitude': -97.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68330', 'place_name': 'Cordova', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.7185, 'longitude': -97.3407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68360', 'place_name': 'Garland', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.9412, 'longitude': -96.9702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68364', 'place_name': 'Goehner', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.8322, 'longitude': -97.2212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68405', 'place_name': 'Milford', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.7632, 'longitude': -97.0576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68423', 'place_name': 'Pleasant Dale', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.8133, 'longitude': -96.9513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68434', 'place_name': 'Seward', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.9066, 'longitude': -97.0966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68439', 'place_name': 'Staplehurst', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.9845, 'longitude': -97.1859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68456', 'place_name': 'Utica', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Seward', 'locality_code': '159', 'latitude': 40.9168, 'longitude': -97.3344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69335', 'place_name': 'Bingham', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sheridan', 'locality_code': '161', 'latitude': 42.0211, 'longitude': -102.0885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69340', 'place_name': 'Ellsworth', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sheridan', 'locality_code': '161', 'latitude': 42.0586, 'longitude': -102.2807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69343', 'place_name': 'Gordon', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sheridan', 'locality_code': '161', 'latitude': 42.8068, 'longitude': -102.2049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69347', 'place_name': 'Hay Springs', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sheridan', 'locality_code': '161', 'latitude': 42.6401, 'longitude': -102.6756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69351', 'place_name': 'Lakeside', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sheridan', 'locality_code': '161', 'latitude': 42.0496, 'longitude': -102.4437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69360', 'place_name': 'Rushville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sheridan', 'locality_code': '161', 'latitude': 42.7379, 'longitude': -102.4657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69365', 'place_name': 'Whiteclay', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sheridan', 'locality_code': '161', 'latitude': 42.9969, 'longitude': -102.5546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68817', 'place_name': 'Ashton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sherman', 'locality_code': '163', 'latitude': 41.2672, 'longitude': -98.8034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68844', 'place_name': 'Hazard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sherman', 'locality_code': '163', 'latitude': 41.0934, 'longitude': -99.0719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68852', 'place_name': 'Litchfield', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sherman', 'locality_code': '163', 'latitude': 41.1686, 'longitude': -99.1415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68853', 'place_name': 'Loup City', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sherman', 'locality_code': '163', 'latitude': 41.2845, 'longitude': -98.9751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68871', 'place_name': 'Rockville', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sherman', 'locality_code': '163', 'latitude': 41.1108, 'longitude': -98.8578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69346', 'place_name': 'Harrison', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Sioux', 'locality_code': '165', 'latitude': 42.6872, 'longitude': -103.8827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68768', 'place_name': 'Pilger', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Stanton', 'locality_code': '167', 'latitude': 41.9761, 'longitude': -97.0779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68779', 'place_name': 'Stanton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Stanton', 'locality_code': '167', 'latitude': 41.9076, 'longitude': -97.214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68303', 'place_name': 'Alexandria', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.2614, 'longitude': -97.4039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68315', 'place_name': 'Belvidere', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.251, 'longitude': -97.5554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68322', 'place_name': 'Bruning', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.3302, 'longitude': -97.5573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68325', 'place_name': 'Byron', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.0269, 'longitude': -97.7612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68326', 'place_name': 'Carleton', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.3005, 'longitude': -97.6719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68327', 'place_name': 'Chester', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.029, 'longitude': -97.6197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68335', 'place_name': 'Davenport', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.3108, 'longitude': -97.805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68340', 'place_name': 'Deshler', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.1387, 'longitude': -97.73, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68362', 'place_name': 'Gilead', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.147, 'longitude': -97.4271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68370', 'place_name': 'Hebron', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.1728, 'longitude': -97.6052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68375', 'place_name': 'Hubbell', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.0456, 'longitude': -97.4735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68429', 'place_name': 'Reynolds', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thayer', 'locality_code': '169', 'latitude': 40.0598, 'longitude': -97.3806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69142', 'place_name': 'Halsey', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thomas', 'locality_code': '171', 'latitude': 41.9291, 'longitude': -100.2955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '69161', 'place_name': 'Seneca', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thomas', 'locality_code': '171', 'latitude': 42.0433, 'longitude': -100.8329, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '69166', 'place_name': 'Thedford', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thomas', 'locality_code': '171', 'latitude': 41.9794, 'longitude': -100.5574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68039', 'place_name': 'Macy', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thurston', 'locality_code': '173', 'latitude': 42.1177, 'longitude': -96.3589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68047', 'place_name': 'Pender', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thurston', 'locality_code': '173', 'latitude': 42.1177, 'longitude': -96.7189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68055', 'place_name': 'Rosalie', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thurston', 'locality_code': '173', 'latitude': 42.0574, 'longitude': -96.4929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68062', 'place_name': 'Thurston', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thurston', 'locality_code': '173', 'latitude': 42.1882, 'longitude': -96.6904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68067', 'place_name': 'Walthill', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thurston', 'locality_code': '173', 'latitude': 42.1485, 'longitude': -96.4803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68071', 'place_name': 'Winnebago', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Thurston', 'locality_code': '173', 'latitude': 42.2339, 'longitude': -96.4685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68815', 'place_name': 'Arcadia', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Valley', 'locality_code': '175', 'latitude': 41.4293, 'longitude': -99.1205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68837', 'place_name': 'Elyria', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Valley', 'locality_code': '175', 'latitude': 41.6808, 'longitude': -99.0062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68859', 'place_name': 'North Loup', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Valley', 'locality_code': '175', 'latitude': 41.4972, 'longitude': -98.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68862', 'place_name': 'Ord', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Valley', 'locality_code': '175', 'latitude': 41.5962, 'longitude': -98.9418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68002', 'place_name': 'Arlington', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Washington', 'locality_code': '177', 'latitude': 41.4417, 'longitude': -96.307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68008', 'place_name': 'Blair', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Washington', 'locality_code': '177', 'latitude': 41.5454, 'longitude': -96.1617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68009', 'place_name': 'Blair', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Washington', 'locality_code': '177', 'latitude': 41.5383, 'longitude': -96.1823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68023', 'place_name': 'Fort Calhoun', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Washington', 'locality_code': '177', 'latitude': 41.4373, 'longitude': -96.0324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68029', 'place_name': 'Herman', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Washington', 'locality_code': '177', 'latitude': 41.6524, 'longitude': -96.2869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68034', 'place_name': 'Kennard', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Washington', 'locality_code': '177', 'latitude': 41.4526, 'longitude': -96.1903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68068', 'place_name': 'Washington', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Washington', 'locality_code': '177', 'latitude': 41.3975, 'longitude': -96.2081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68723', 'place_name': 'Carroll', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Wayne', 'locality_code': '179', 'latitude': 42.277, 'longitude': -97.1926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68740', 'place_name': 'Hoskins', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Wayne', 'locality_code': '179', 'latitude': 42.1408, 'longitude': -97.3084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68787', 'place_name': 'Wayne', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Wayne', 'locality_code': '179', 'latitude': 42.2304, 'longitude': -97.0186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68790', 'place_name': 'Winside', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Wayne', 'locality_code': '179', 'latitude': 42.1678, 'longitude': -97.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68928', 'place_name': 'Bladen', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Webster', 'locality_code': '181', 'latitude': 40.299, 'longitude': -98.6046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68930', 'place_name': 'Blue Hill', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Webster', 'locality_code': '181', 'latitude': 40.311, 'longitude': -98.427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68942', 'place_name': 'Guide Rock', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Webster', 'locality_code': '181', 'latitude': 40.0812, 'longitude': -98.3391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68952', 'place_name': 'Inavale', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Webster', 'locality_code': '181', 'latitude': 40.0959, 'longitude': -98.6612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68970', 'place_name': 'Red Cloud', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Webster', 'locality_code': '181', 'latitude': 40.0952, 'longitude': -98.5187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68622', 'place_name': 'Bartlett', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Wheeler', 'locality_code': '183', 'latitude': 41.8697, 'longitude': -98.5567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68637', 'place_name': 'Ericson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'Wheeler', 'locality_code': '183', 'latitude': 41.7828, 'longitude': -98.6453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68316', 'place_name': 'Benedict', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'York', 'locality_code': '185', 'latitude': 41.0033, 'longitude': -97.6029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68319', 'place_name': 'Bradshaw', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'York', 'locality_code': '185', 'latitude': 40.9207, 'longitude': -97.7607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68367', 'place_name': 'Gresham', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'York', 'locality_code': '185', 'latitude': 41.021, 'longitude': -97.4079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68371', 'place_name': 'Henderson', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'York', 'locality_code': '185', 'latitude': 40.7814, 'longitude': -97.7979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68401', 'place_name': 'Mc Cool Junction', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'York', 'locality_code': '185', 'latitude': 40.7442, 'longitude': -97.5937, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '68460', 'place_name': 'Waco', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'York', 'locality_code': '185', 'latitude': 40.9198, 'longitude': -97.4534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '68467', 'place_name': 'York', 'state': 'Nebraska', 'state_ab': 'NE', 'county': 'York', 'locality_code': '185', 'latitude': 40.8667, 'longitude': -97.5825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3218', 'place_name': 'Barnstead', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.3349, 'longitude': -71.2887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3220', 'place_name': 'Belmont', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.4512, 'longitude': -71.489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3225', 'place_name': 'Center Barnstead', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.3566, 'longitude': -71.2424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3226', 'place_name': 'Center Harbor', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.7107, 'longitude': -71.4797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3237', 'place_name': 'Gilmanton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.4175, 'longitude': -71.4121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3246', 'place_name': 'Laconia', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.5727, 'longitude': -71.4781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3247', 'place_name': 'Laconia', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.589, 'longitude': -71.4455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3249', 'place_name': 'Gilford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.5475, 'longitude': -71.4072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3252', 'place_name': 'Lochmere', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.4686, 'longitude': -71.5371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3253', 'place_name': 'Meredith', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.6311, 'longitude': -71.4997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3256', 'place_name': 'New Hampton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.6184, 'longitude': -71.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3269', 'place_name': 'Sanbornton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.5496, 'longitude': -71.6003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3276', 'place_name': 'Tilton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.4603, 'longitude': -71.5774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3289', 'place_name': 'Winnisquam', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.4964, 'longitude': -71.5197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3298', 'place_name': 'Tilton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.5249, 'longitude': -71.4458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3299', 'place_name': 'Tilton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.5249, 'longitude': -71.4458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3809', 'place_name': 'Alton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.463, 'longitude': -71.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3810', 'place_name': 'Alton Bay', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.4845, 'longitude': -71.2489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3837', 'place_name': 'Gilmanton Iron Works', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Belknap', 'locality_code': '1', 'latitude': 43.4466, 'longitude': -71.2995, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '3227', 'place_name': 'Center Sandwich', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.8162, 'longitude': -71.4506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3254', 'place_name': 'Moultonborough', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.7281, 'longitude': -71.3922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3259', 'place_name': 'North Sandwich', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.8452, 'longitude': -71.385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3812', 'place_name': 'Bartlett', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 44.0802, 'longitude': -71.292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3813', 'place_name': 'Center Conway', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.9878, 'longitude': -71.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3814', 'place_name': 'Center Ossipee', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.7682, 'longitude': -71.1349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3816', 'place_name': 'Center Tuftonboro', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.6849, 'longitude': -71.2551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3817', 'place_name': 'Chocorua', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.8909, 'longitude': -71.2407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3818', 'place_name': 'Conway', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.9742, 'longitude': -71.1503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3830', 'place_name': 'East Wakefield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.6142, 'longitude': -71.0051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3832', 'place_name': 'Eaton Center', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.9092, 'longitude': -71.0837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3836', 'place_name': 'Freedom', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.8172, 'longitude': -71.0628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3838', 'place_name': 'Glen', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 44.1018, 'longitude': -71.1925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3845', 'place_name': 'Intervale', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 44.0955, 'longitude': -71.1194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3846', 'place_name': 'Jackson', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 44.167, 'longitude': -71.1878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3847', 'place_name': 'Kearsarge', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 44.0753, 'longitude': -71.1176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3849', 'place_name': 'Madison', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.9152, 'longitude': -71.1254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3850', 'place_name': 'Melvin Village', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.7077, 'longitude': -71.3017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3853', 'place_name': 'Mirror Lake', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.6366, 'longitude': -71.2729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3860', 'place_name': 'North Conway', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 44.0336, 'longitude': -71.1238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3861', 'place_name': 'Lee', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.1192, 'longitude': -70.9969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3864', 'place_name': 'Ossipee', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.6945, 'longitude': -71.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3872', 'place_name': 'Sanbornville', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.5513, 'longitude': -71.02, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3875', 'place_name': 'Silver Lake', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.879, 'longitude': -71.1905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3882', 'place_name': 'Effingham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.7012, 'longitude': -70.9834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3883', 'place_name': 'South Tamworth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.8077, 'longitude': -71.308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3886', 'place_name': 'Tamworth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.862, 'longitude': -71.2645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3890', 'place_name': 'West Ossipee', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.8118, 'longitude': -71.1946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3894', 'place_name': 'Wolfeboro', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.595, 'longitude': -71.1908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3896', 'place_name': 'Wolfeboro Falls', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.5892, 'longitude': -71.2189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3897', 'place_name': 'Wonalancet', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Carroll', 'locality_code': '3', 'latitude': 43.9073, 'longitude': -71.3506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3431', 'place_name': 'Keene', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.9627, 'longitude': -72.2955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3435', 'place_name': 'Keene', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.9337, 'longitude': -72.2781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3441', 'place_name': 'Ashuelot', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.7851, 'longitude': -72.4349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3443', 'place_name': 'Chesterfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8839, 'longitude': -72.4548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3444', 'place_name': 'Dublin', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8972, 'longitude': -72.0505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3445', 'place_name': 'Sullivan', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.9982, 'longitude': -72.2019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3446', 'place_name': 'Swanzey', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8411, 'longitude': -72.3301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3447', 'place_name': 'Fitzwilliam', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.7611, 'longitude': -72.145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3448', 'place_name': 'Gilsum', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 43.0399, 'longitude': -72.2719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3450', 'place_name': 'Harrisville', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.9399, 'longitude': -72.0972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3451', 'place_name': 'Hinsdale', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8027, 'longitude': -72.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3452', 'place_name': 'Jaffrey', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8178, 'longitude': -72.0275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3455', 'place_name': 'Marlborough', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8988, 'longitude': -72.2013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3456', 'place_name': 'Marlow', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 43.1326, 'longitude': -72.2109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3457', 'place_name': 'Nelson', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.9906, 'longitude': -72.1309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3461', 'place_name': 'Rindge', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.7544, 'longitude': -72.019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3462', 'place_name': 'Spofford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.912, 'longitude': -72.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3464', 'place_name': 'Stoddard', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 43.0739, 'longitude': -72.1088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3465', 'place_name': 'Troy', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.827, 'longitude': -72.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3466', 'place_name': 'West Chesterfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8956, 'longitude': -72.5097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3467', 'place_name': 'Westmoreland', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.969, 'longitude': -72.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3469', 'place_name': 'West Swanzey', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.8734, 'longitude': -72.3151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3470', 'place_name': 'Winchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 42.7788, 'longitude': -72.344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3602', 'place_name': 'Alstead', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 43.1265, 'longitude': -72.3281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3604', 'place_name': 'Drewsville', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 43.1281, 'longitude': -72.392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3608', 'place_name': 'Walpole', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 43.0765, 'longitude': -72.4155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3609', 'place_name': 'North Walpole', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Cheshire', 'locality_code': '5', 'latitude': 43.1428, 'longitude': -72.4483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3570', 'place_name': 'Berlin', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.4811, 'longitude': -71.1892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3575', 'place_name': 'Bretton Woods', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.2581, 'longitude': -71.4412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3576', 'place_name': 'Colebrook', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.9078, 'longitude': -71.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3579', 'place_name': 'Errol', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.8003, 'longitude': -71.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3581', 'place_name': 'Gorham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.4048, 'longitude': -71.1548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3582', 'place_name': 'Groveton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.5984, 'longitude': -71.5064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3583', 'place_name': 'Jefferson', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.3999, 'longitude': -71.4518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3584', 'place_name': 'Lancaster', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.4921, 'longitude': -71.5591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3588', 'place_name': 'Milan', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.587, 'longitude': -71.181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3589', 'place_name': 'Mount Washington', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.6956, 'longitude': -71.3874, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '3590', 'place_name': 'North Stratford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.7149, 'longitude': -71.5644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3592', 'place_name': 'Pittsburg', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 45.0866, 'longitude': -71.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3593', 'place_name': 'Randolph', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.3753, 'longitude': -71.2798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3595', 'place_name': 'Twin Mountain', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.2689, 'longitude': -71.5471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3597', 'place_name': 'West Stewartstown', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.6956, 'longitude': -71.3874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3598', 'place_name': 'Whitefield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Coos', 'locality_code': '7', 'latitude': 44.3681, 'longitude': -71.6035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3215', 'place_name': 'Waterville Valley', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.9501, 'longitude': -71.4995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3217', 'place_name': 'Ashland', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.7034, 'longitude': -71.6121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3222', 'place_name': 'Bristol', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.612, 'longitude': -71.7507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3223', 'place_name': 'Campton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.8418, 'longitude': -71.6652, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '3238', 'place_name': 'Glencliff', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.9828, 'longitude': -71.8934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3240', 'place_name': 'Grafton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.5727, 'longitude': -71.9634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3241', 'place_name': 'Hebron', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.7186, 'longitude': -71.827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3245', 'place_name': 'Holderness', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.7378, 'longitude': -71.6044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3251', 'place_name': 'Lincoln', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.0582, 'longitude': -71.6727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3258', 'place_name': 'Chichester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.244, 'longitude': -71.4105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3262', 'place_name': 'North Woodstock', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.0354, 'longitude': -71.6863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3264', 'place_name': 'Plymouth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.757, 'longitude': -71.6881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3266', 'place_name': 'Rumney', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.8044, 'longitude': -71.848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3279', 'place_name': 'Warren', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.9447, 'longitude': -71.8901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3282', 'place_name': 'Wentworth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.8685, 'longitude': -71.9097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3285', 'place_name': 'Thornton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.905, 'longitude': -71.647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3293', 'place_name': 'Woodstock', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.9776, 'longitude': -71.6851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3561', 'place_name': 'Littleton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.3112, 'longitude': -71.7768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3574', 'place_name': 'Bethlehem', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.2808, 'longitude': -71.6829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3580', 'place_name': 'Franconia', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.2053, 'longitude': -71.7518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3585', 'place_name': 'Lisbon', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.2148, 'longitude': -71.8966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3586', 'place_name': 'Sugar Hill', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.2203, 'longitude': -71.7964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3740', 'place_name': 'Bath', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.1808, 'longitude': -71.9828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3741', 'place_name': 'Canaan', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.6601, 'longitude': -72.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3748', 'place_name': 'Enfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.6256, 'longitude': -72.127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3749', 'place_name': 'Enfield Center', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.5796, 'longitude': -72.0854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3750', 'place_name': 'Etna', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.7113, 'longitude': -72.2125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3755', 'place_name': 'Hanover', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.7045, 'longitude': -72.285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3756', 'place_name': 'Lebanon', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.6423, 'longitude': -72.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3765', 'place_name': 'Haverhill', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.0394, 'longitude': -72.0573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3766', 'place_name': 'Lebanon', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.6447, 'longitude': -72.2428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3768', 'place_name': 'Lyme', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.7913, 'longitude': -72.162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3769', 'place_name': 'Lyme Center', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.7863, 'longitude': -72.1205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3771', 'place_name': 'Monroe', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.2734, 'longitude': -72.025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3774', 'place_name': 'North Haverhill', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.0978, 'longitude': -72.0191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3777', 'place_name': 'Orford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.8941, 'longitude': -72.0978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3779', 'place_name': 'Piermont', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.9906, 'longitude': -72.0813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3780', 'place_name': 'Pike', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.0255, 'longitude': -72.0096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3784', 'place_name': 'West Lebanon', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 43.644, 'longitude': -72.3007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3785', 'place_name': 'Woodsville', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Grafton', 'locality_code': '9', 'latitude': 44.1523, 'longitude': -72.0373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3031', 'place_name': 'Amherst', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8569, 'longitude': -71.6075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3033', 'place_name': 'Brookline', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7384, 'longitude': -71.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3043', 'place_name': 'Francestown', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.992, 'longitude': -71.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3045', 'place_name': 'Goffstown', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 43.0201, 'longitude': -71.5697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3047', 'place_name': 'Greenfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9493, 'longitude': -71.8728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3048', 'place_name': 'Greenville', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7482, 'longitude': -71.7619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3049', 'place_name': 'Hollis', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7485, 'longitude': -71.5772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3051', 'place_name': 'Hudson', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.769, 'longitude': -71.4121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3052', 'place_name': 'Litchfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.843, 'longitude': -71.455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3054', 'place_name': 'Merrimack', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8667, 'longitude': -71.5128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3055', 'place_name': 'Milford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8285, 'longitude': -71.6606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3057', 'place_name': 'Mont Vernon', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8976, 'longitude': -71.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3060', 'place_name': 'Nashua', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7564, 'longitude': -71.4667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3061', 'place_name': 'Nashua', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7654, 'longitude': -71.4676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3062', 'place_name': 'Nashua', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7235, 'longitude': -71.4893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3063', 'place_name': 'Nashua', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7717, 'longitude': -71.5132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3064', 'place_name': 'Nashua', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.779, 'longitude': -71.4748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3070', 'place_name': 'New Boston', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9722, 'longitude': -71.6864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3071', 'place_name': 'New Ipswich', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7511, 'longitude': -71.8703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3076', 'place_name': 'Pelham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.7288, 'longitude': -71.3046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3082', 'place_name': 'Lyndeborough', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8954, 'longitude': -71.7744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3084', 'place_name': 'Temple', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.82, 'longitude': -71.8523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3086', 'place_name': 'Wilton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8368, 'longitude': -71.7541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3101', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9929, 'longitude': -71.4633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3102', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9944, 'longitude': -71.4884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3103', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9656, 'longitude': -71.4493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3104', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 43.0073, 'longitude': -71.4482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3105', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9956, 'longitude': -71.4548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3108', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9956, 'longitude': -71.4548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3109', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9713, 'longitude': -71.4135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3110', 'place_name': 'Bedford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9403, 'longitude': -71.5213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3111', 'place_name': 'Manchester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9956, 'longitude': -71.4548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3244', 'place_name': 'Hillsborough', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 43.1141, 'longitude': -71.8992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3281', 'place_name': 'Weare', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 43.0714, 'longitude': -71.7038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3440', 'place_name': 'Antrim', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 43.0595, 'longitude': -71.9387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3442', 'place_name': 'Bennington', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 43.0103, 'longitude': -71.9153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3449', 'place_name': 'Hancock', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.9768, 'longitude': -71.9819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3458', 'place_name': 'Peterborough', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8856, 'longitude': -71.947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3468', 'place_name': 'West Peterborough', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Hillsborough', 'locality_code': '11', 'latitude': 42.8908, 'longitude': -71.9334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3046', 'place_name': 'Dunbarton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.1025, 'longitude': -71.6169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3106', 'place_name': 'Hooksett', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.0617, 'longitude': -71.4444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3216', 'place_name': 'Andover', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.4287, 'longitude': -71.783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3221', 'place_name': 'Bradford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.2517, 'longitude': -71.9617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3224', 'place_name': 'Canterbury', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.357, 'longitude': -71.557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3229', 'place_name': 'Contoocook', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.1978, 'longitude': -71.6968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3230', 'place_name': 'Danbury', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.5115, 'longitude': -71.8691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3231', 'place_name': 'East Andover', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.4595, 'longitude': -71.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3233', 'place_name': 'Elkins', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.4209, 'longitude': -71.9373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3234', 'place_name': 'Epsom', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.2174, 'longitude': -71.3546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3235', 'place_name': 'Franklin', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.4426, 'longitude': -71.6491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3242', 'place_name': 'Henniker', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.1791, 'longitude': -71.8159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3243', 'place_name': 'Hill', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.5274, 'longitude': -71.7292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3255', 'place_name': 'Newbury', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.3217, 'longitude': -72.0118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3257', 'place_name': 'New London', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.4145, 'longitude': -71.9857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3260', 'place_name': 'North Sutton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.3653, 'longitude': -71.9341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3263', 'place_name': 'Pittsfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.2874, 'longitude': -71.333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3268', 'place_name': 'Salisbury', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.4067, 'longitude': -71.7045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3272', 'place_name': 'South Newbury', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.2956, 'longitude': -71.9967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3273', 'place_name': 'South Sutton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.3042, 'longitude': -71.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3275', 'place_name': 'Suncook', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.1604, 'longitude': -71.4179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3278', 'place_name': 'Warner', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.3035, 'longitude': -71.8353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3287', 'place_name': 'Wilmot', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.4485, 'longitude': -71.9158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3301', 'place_name': 'Concord', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.2185, 'longitude': -71.5277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3302', 'place_name': 'Concord', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.3103, 'longitude': -71.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3303', 'place_name': 'Concord', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.2817, 'longitude': -71.6595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3304', 'place_name': 'Bow', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.1388, 'longitude': -71.5448, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '3305', 'place_name': 'Concord', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.2134, 'longitude': -71.5172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3307', 'place_name': 'Loudon', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Merrimack', 'locality_code': '13', 'latitude': 43.3193, 'longitude': -71.467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3032', 'place_name': 'Auburn', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9925, 'longitude': -71.3449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3034', 'place_name': 'Candia', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0585, 'longitude': -71.3049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3036', 'place_name': 'Chester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9678, 'longitude': -71.245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3037', 'place_name': 'Deerfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.1378, 'longitude': -71.2513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3038', 'place_name': 'Derry', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8874, 'longitude': -71.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3040', 'place_name': 'East Candia', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0481, 'longitude': -71.2487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3041', 'place_name': 'East Derry', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8945, 'longitude': -71.2912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3042', 'place_name': 'Epping', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0411, 'longitude': -71.0764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3044', 'place_name': 'Fremont', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.984, 'longitude': -71.1218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3053', 'place_name': 'Londonderry', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8656, 'longitude': -71.3772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3073', 'place_name': 'North Salem', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.837, 'longitude': -71.2206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3077', 'place_name': 'Raymond', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0325, 'longitude': -71.1912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3079', 'place_name': 'Salem', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.7846, 'longitude': -71.2176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3087', 'place_name': 'Windham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8051, 'longitude': -71.3067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3261', 'place_name': 'Northwood', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.207, 'longitude': -71.2004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3290', 'place_name': 'Nottingham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.1196, 'longitude': -71.111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3291', 'place_name': 'West Nottingham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.1823, 'longitude': -71.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3801', 'place_name': 'Portsmouth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0729, 'longitude': -70.8052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3802', 'place_name': 'Portsmouth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0718, 'longitude': -70.7626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3803', 'place_name': 'Portsmouth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0718, 'longitude': -70.7626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3804', 'place_name': 'Portsmouth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0718, 'longitude': -70.7626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3811', 'place_name': 'Atkinson', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.837, 'longitude': -71.1603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3819', 'place_name': 'Danville', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9234, 'longitude': -71.121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3826', 'place_name': 'East Hampstead', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8877, 'longitude': -71.128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3827', 'place_name': 'East Kingston', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.907, 'longitude': -70.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3833', 'place_name': 'Exeter', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9815, 'longitude': -70.9478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3840', 'place_name': 'Greenland', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0353, 'longitude': -70.8475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3841', 'place_name': 'Hampstead', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.882, 'longitude': -71.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3842', 'place_name': 'Hampton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9359, 'longitude': -70.8243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3843', 'place_name': 'Hampton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0059, 'longitude': -71.0132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3844', 'place_name': 'Hampton Falls', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9263, 'longitude': -70.8876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3848', 'place_name': 'Kingston', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9133, 'longitude': -71.0639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3854', 'place_name': 'New Castle', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0681, 'longitude': -70.7199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3856', 'place_name': 'Newfields', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0374, 'longitude': -70.9782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3857', 'place_name': 'Newmarket', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0726, 'longitude': -70.9553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3858', 'place_name': 'Newton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8678, 'longitude': -71.042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3859', 'place_name': 'Newton Junction', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8619, 'longitude': -71.04, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3862', 'place_name': 'North Hampton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9776, 'longitude': -70.8267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3865', 'place_name': 'Plaistow', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8356, 'longitude': -71.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3870', 'place_name': 'Rye', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0095, 'longitude': -70.7652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3871', 'place_name': 'Rye Beach', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9806, 'longitude': -70.7719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3873', 'place_name': 'Sandown', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.9308, 'longitude': -71.1861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3874', 'place_name': 'Seabrook', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 42.8854, 'longitude': -70.8646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3885', 'place_name': 'Stratham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Rockingham', 'locality_code': '15', 'latitude': 43.0194, 'longitude': -70.8997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3815', 'place_name': 'Center Strafford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.2629, 'longitude': -71.1071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3820', 'place_name': 'Dover', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.1888, 'longitude': -70.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3821', 'place_name': 'Dover', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.1979, 'longitude': -70.8737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3822', 'place_name': 'Dover', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.1979, 'longitude': -70.8737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3823', 'place_name': 'Madbury', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.1729, 'longitude': -70.9412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3824', 'place_name': 'Durham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.1174, 'longitude': -70.9197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3825', 'place_name': 'Barrington', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.2027, 'longitude': -71.0377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3835', 'place_name': 'Farmington', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.3884, 'longitude': -71.0647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3839', 'place_name': 'Rochester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.262, 'longitude': -70.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3851', 'place_name': 'Milton', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.4229, 'longitude': -71.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3852', 'place_name': 'Milton Mills', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.5025, 'longitude': -70.9697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3855', 'place_name': 'New Durham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.443, 'longitude': -71.1408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3866', 'place_name': 'Rochester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.3045, 'longitude': -70.9756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3867', 'place_name': 'Rochester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.3045, 'longitude': -70.9756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3868', 'place_name': 'Rochester', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.32, 'longitude': -70.9413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3869', 'place_name': 'Rollinsford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.2269, 'longitude': -70.8332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3878', 'place_name': 'Somersworth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.2525, 'longitude': -70.8756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3884', 'place_name': 'Strafford', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.2506, 'longitude': -71.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3887', 'place_name': 'Union', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Strafford', 'locality_code': '17', 'latitude': 43.4861, 'longitude': -71.063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3280', 'place_name': 'Washington', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.1747, 'longitude': -72.0824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3284', 'place_name': 'Springfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.4938, 'longitude': -72.047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3601', 'place_name': 'Acworth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.196, 'longitude': -72.3001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3603', 'place_name': 'Charlestown', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.2573, 'longitude': -72.4064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3605', 'place_name': 'Lempster', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.2136, 'longitude': -72.1968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3607', 'place_name': 'South Acworth', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.1956, 'longitude': -72.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3743', 'place_name': 'Claremont', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.3679, 'longitude': -72.3422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3745', 'place_name': 'Cornish', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.4963, 'longitude': -72.3394, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '3746', 'place_name': 'Cornish Flat', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.4973, 'longitude': -72.2795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3751', 'place_name': 'Georges Mills', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.4317, 'longitude': -72.0673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3752', 'place_name': 'Goshen', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.3026, 'longitude': -72.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3753', 'place_name': 'Grantham', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.5103, 'longitude': -72.1334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3754', 'place_name': 'Guild', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.3767, 'longitude': -72.1381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3770', 'place_name': 'Meriden', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.5299, 'longitude': -72.2756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3773', 'place_name': 'Newport', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.3532, 'longitude': -72.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3781', 'place_name': 'Plainfield', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.5519, 'longitude': -72.2704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '3782', 'place_name': 'Sunapee', 'state': 'New Hampshire', 'state_ab': 'NH', 'county': 'Sullivan', 'locality_code': '19', 'latitude': 43.3868, 'longitude': -72.095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8037', 'place_name': 'Hammonton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.638, 'longitude': -74.7728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8201', 'place_name': 'Absecon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4218, 'longitude': -74.4949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8203', 'place_name': 'Brigantine', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4101, 'longitude': -74.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8205', 'place_name': 'Absecon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4745, 'longitude': -74.4575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8213', 'place_name': 'Cologne', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5092, 'longitude': -74.6086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8215', 'place_name': 'Egg Harbor City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5331, 'longitude': -74.6177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8217', 'place_name': 'Elwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5737, 'longitude': -74.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8220', 'place_name': 'Leeds Point', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4921, 'longitude': -74.429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8221', 'place_name': 'Linwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3469, 'longitude': -74.5807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8225', 'place_name': 'Northfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3703, 'longitude': -74.5552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8231', 'place_name': 'Oceanville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4712, 'longitude': -74.4604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8232', 'place_name': 'Pleasantville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3876, 'longitude': -74.5149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8234', 'place_name': 'Egg Harbor Township', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3741, 'longitude': -74.6118, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '8240', 'place_name': 'Pomona', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4877, 'longitude': -74.5543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8241', 'place_name': 'Port Republic', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5272, 'longitude': -74.4903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8244', 'place_name': 'Somers Point', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3223, 'longitude': -74.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8310', 'place_name': 'Buena', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.537, 'longitude': -74.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8317', 'place_name': 'Dorothy', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4031, 'longitude': -74.8316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8319', 'place_name': 'Estell Manor', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3783, 'longitude': -74.8165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8326', 'place_name': 'Landisville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5239, 'longitude': -74.9377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8330', 'place_name': 'Mays Landing', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.432, 'longitude': -74.6962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8340', 'place_name': 'Milmay', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.4451, 'longitude': -74.8667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8341', 'place_name': 'Minotola', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5155, 'longitude': -74.9467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8342', 'place_name': 'Mizpah', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5021, 'longitude': -74.8335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8346', 'place_name': 'Newtonville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.5645, 'longitude': -74.859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8350', 'place_name': 'Richland', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.485, 'longitude': -74.8776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8401', 'place_name': 'Atlantic City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3664, 'longitude': -74.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8402', 'place_name': 'Margate City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3286, 'longitude': -74.509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8403', 'place_name': 'Longport', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3194, 'longitude': -74.5356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8404', 'place_name': 'Atlantic City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3643, 'longitude': -74.4229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8405', 'place_name': 'Atlantic City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.3643, 'longitude': -74.4229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8406', 'place_name': 'Ventnor City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Atlantic', 'locality_code': '1', 'latitude': 39.346, 'longitude': -74.4723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7010', 'place_name': 'Cliffside Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8222, 'longitude': -73.988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7020', 'place_name': 'Edgewater', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8317, 'longitude': -73.9738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7022', 'place_name': 'Fairview', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.817, 'longitude': -74, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7024', 'place_name': 'Fort Lee', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8503, 'longitude': -73.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7026', 'place_name': 'Garfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8789, 'longitude': -74.1081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7031', 'place_name': 'North Arlington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.7898, 'longitude': -74.1343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7057', 'place_name': 'Wallington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8536, 'longitude': -74.1079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7070', 'place_name': 'Rutherford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8292, 'longitude': -74.1121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7071', 'place_name': 'Lyndhurst', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8094, 'longitude': -74.1245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7072', 'place_name': 'Carlstadt', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8403, 'longitude': -74.0925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7073', 'place_name': 'East Rutherford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8385, 'longitude': -74.1041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7074', 'place_name': 'Moonachie', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8394, 'longitude': -74.0566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7075', 'place_name': 'Wood Ridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8493, 'longitude': -74.0878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7401', 'place_name': 'Allendale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0327, 'longitude': -74.1342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7407', 'place_name': 'Elmwood Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9069, 'longitude': -74.1209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7410', 'place_name': 'Fair Lawn', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9343, 'longitude': -74.1166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7417', 'place_name': 'Franklin Lakes', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0081, 'longitude': -74.2113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7423', 'place_name': 'Ho Ho Kus', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0004, 'longitude': -74.1025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7430', 'place_name': 'Mahwah', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0817, 'longitude': -74.1861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7432', 'place_name': 'Midland Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9957, 'longitude': -74.1409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7436', 'place_name': 'Oakland', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0294, 'longitude': -74.2338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7446', 'place_name': 'Ramsey', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0577, 'longitude': -74.1445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7450', 'place_name': 'Ridgewood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.982, 'longitude': -74.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7451', 'place_name': 'Ridgewood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9793, 'longitude': -74.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7452', 'place_name': 'Glen Rock', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9602, 'longitude': -74.1254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7458', 'place_name': 'Saddle River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0443, 'longitude': -74.0981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7463', 'place_name': 'Waldwick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.013, 'longitude': -74.1243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7481', 'place_name': 'Wyckoff', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9978, 'longitude': -74.166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7495', 'place_name': 'Mahwah', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.1039, 'longitude': -74.1644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7601', 'place_name': 'Hackensack', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8882, 'longitude': -74.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7602', 'place_name': 'Hackensack', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8859, 'longitude': -74.0435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7603', 'place_name': 'Bogota', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8744, 'longitude': -74.0281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7604', 'place_name': 'Hasbrouck Heights', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8623, 'longitude': -74.0756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7605', 'place_name': 'Leonia', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8629, 'longitude': -73.9879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7606', 'place_name': 'South Hackensack', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8634, 'longitude': -74.0456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7607', 'place_name': 'Maywood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9024, 'longitude': -74.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7608', 'place_name': 'Teterboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.864, 'longitude': -74.0556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7620', 'place_name': 'Alpine', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9511, 'longitude': -73.9308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7621', 'place_name': 'Bergenfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9238, 'longitude': -73.9989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7624', 'place_name': 'Closter', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9721, 'longitude': -73.959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7626', 'place_name': 'Cresskill', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9418, 'longitude': -73.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7627', 'place_name': 'Demarest', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9548, 'longitude': -73.9602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7628', 'place_name': 'Dumont', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9447, 'longitude': -73.9921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7630', 'place_name': 'Emerson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9755, 'longitude': -74.0285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7631', 'place_name': 'Englewood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8943, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7632', 'place_name': 'Englewood Cliffs', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.882, 'longitude': -73.9544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7640', 'place_name': 'Harrington Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9918, 'longitude': -73.98, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7641', 'place_name': 'Haworth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9608, 'longitude': -73.9874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7642', 'place_name': 'Hillsdale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0069, 'longitude': -74.0426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7643', 'place_name': 'Little Ferry', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8493, 'longitude': -74.0405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7644', 'place_name': 'Lodi', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8764, 'longitude': -74.0838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7645', 'place_name': 'Montvale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0495, 'longitude': -74.0384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7646', 'place_name': 'New Milford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9331, 'longitude': -74.0195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7647', 'place_name': 'Northvale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0086, 'longitude': -73.9389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7648', 'place_name': 'Norwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9952, 'longitude': -73.9582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7649', 'place_name': 'Oradell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9535, 'longitude': -74.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7650', 'place_name': 'Palisades Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8462, 'longitude': -73.9954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7652', 'place_name': 'Paramus', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9477, 'longitude': -74.0672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7653', 'place_name': 'Paramus', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9481, 'longitude': -74.0832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7656', 'place_name': 'Park Ridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0343, 'longitude': -74.0396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7657', 'place_name': 'Ridgefield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8326, 'longitude': -74.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7660', 'place_name': 'Ridgefield Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8562, 'longitude': -74.023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7661', 'place_name': 'River Edge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9265, 'longitude': -74.0392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7662', 'place_name': 'Rochelle Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9057, 'longitude': -74.079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7663', 'place_name': 'Saddle Brook', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9031, 'longitude': -74.0955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7666', 'place_name': 'Teaneck', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8915, 'longitude': -74.0119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7670', 'place_name': 'Tenafly', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9216, 'longitude': -73.9659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7675', 'place_name': 'Westwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0092, 'longitude': -74.0041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7676', 'place_name': 'Township Of Washington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.9883, 'longitude': -74.0635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7677', 'place_name': 'Woodcliff Lake', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 41.0234, 'longitude': -74.0603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7699', 'place_name': 'Teterboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Bergen', 'locality_code': '3', 'latitude': 40.8463, 'longitude': -74.0611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8010', 'place_name': 'Beverly', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0565, 'longitude': -74.9114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8011', 'place_name': 'Birmingham', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.976, 'longitude': -74.7114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8015', 'place_name': 'Browns Mills', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9597, 'longitude': -74.5655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8016', 'place_name': 'Burlington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.068, 'longitude': -74.8454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8019', 'place_name': 'Chatsworth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.8019, 'longitude': -74.5256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8022', 'place_name': 'Columbus', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0642, 'longitude': -74.6899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8036', 'place_name': 'Hainesport', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9872, 'longitude': -74.8293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8041', 'place_name': 'Jobstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0387, 'longitude': -74.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8042', 'place_name': 'Juliustown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0123, 'longitude': -74.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8046', 'place_name': 'Willingboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.029, 'longitude': -74.8835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8048', 'place_name': 'Lumberton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9651, 'longitude': -74.8067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8052', 'place_name': 'Maple Shade', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9511, 'longitude': -74.9946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8053', 'place_name': 'Marlton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.8845, 'longitude': -74.9067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8054', 'place_name': 'Mount Laurel', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9478, 'longitude': -74.9036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8055', 'place_name': 'Medford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.8637, 'longitude': -74.8223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8057', 'place_name': 'Moorestown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9683, 'longitude': -74.9533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8060', 'place_name': 'Mount Holly', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0086, 'longitude': -74.7896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8064', 'place_name': 'New Lisbon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9582, 'longitude': -74.6279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8065', 'place_name': 'Palmyra', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0037, 'longitude': -75.0257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8068', 'place_name': 'Pemberton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.9712, 'longitude': -74.6676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8073', 'place_name': 'Rancocas', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0095, 'longitude': -74.8668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8075', 'place_name': 'Riverside', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0293, 'longitude': -74.9497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8076', 'place_name': 'Riverton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0115, 'longitude': -75.0149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8077', 'place_name': 'Riverton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.002, 'longitude': -74.9952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8088', 'place_name': 'Vincentown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.8604, 'longitude': -74.6693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8224', 'place_name': 'New Gretna', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 39.5923, 'longitude': -74.451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8505', 'place_name': 'Bordentown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.1431, 'longitude': -74.7032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8511', 'place_name': 'Cookstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.0481, 'longitude': -74.5595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8515', 'place_name': 'Chesterfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.1151, 'longitude': -74.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8518', 'place_name': 'Florence', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.118, 'longitude': -74.8055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8554', 'place_name': 'Roebling', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.1154, 'longitude': -74.7772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8562', 'place_name': 'Wrightstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.072, 'longitude': -74.5731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8640', 'place_name': 'Joint Base Mdl', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.2171, 'longitude': -74.7429, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '8641', 'place_name': 'Joint Base Mdl', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Burlington', 'locality_code': '5', 'latitude': 40.2171, 'longitude': -74.7429, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '8002', 'place_name': 'Cherry Hill', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9308, 'longitude': -75.0175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8003', 'place_name': 'Cherry Hill', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8805, 'longitude': -74.9706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8004', 'place_name': 'Atco', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.76, 'longitude': -74.8665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8007', 'place_name': 'Barrington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8651, 'longitude': -75.0564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8009', 'place_name': 'Berlin', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.7788, 'longitude': -74.9308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8012', 'place_name': 'Blackwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.7901, 'longitude': -75.0367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8018', 'place_name': 'Cedar Brook', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.7154, 'longitude': -74.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8021', 'place_name': 'Clementon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8036, 'longitude': -75.0058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8026', 'place_name': 'Gibbsboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8365, 'longitude': -74.971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8029', 'place_name': 'Glendora', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8404, 'longitude': -75.0697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8030', 'place_name': 'Gloucester City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8911, 'longitude': -75.117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8031', 'place_name': 'Bellmawr', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8689, 'longitude': -75.0944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8033', 'place_name': 'Haddonfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8954, 'longitude': -75.0417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8034', 'place_name': 'Cherry Hill', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9074, 'longitude': -75.0008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8035', 'place_name': 'Haddon Heights', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8788, 'longitude': -75.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8043', 'place_name': 'Voorhees', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8504, 'longitude': -74.9646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8045', 'place_name': 'Lawnside', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8676, 'longitude': -75.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8049', 'place_name': 'Magnolia', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8538, 'longitude': -75.0393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8059', 'place_name': 'Mount Ephraim', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8827, 'longitude': -75.0929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8078', 'place_name': 'Runnemede', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8508, 'longitude': -75.0742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8081', 'place_name': 'Sicklerville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.7354, 'longitude': -74.9864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8083', 'place_name': 'Somerdale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.84, 'longitude': -75.0309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8084', 'place_name': 'Stratford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8288, 'longitude': -75.0147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8089', 'place_name': 'Waterford Works', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.7215, 'longitude': -74.8609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8091', 'place_name': 'West Berlin', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8051, 'longitude': -74.9255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8095', 'place_name': 'Winslow', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.6549, 'longitude': -74.8685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8099', 'place_name': 'Bellmawr', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.8676, 'longitude': -75.0946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8101', 'place_name': 'Camden', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9259, 'longitude': -75.1196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8102', 'place_name': 'Camden', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9512, 'longitude': -75.1186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8103', 'place_name': 'Camden', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9351, 'longitude': -75.1117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8104', 'place_name': 'Camden', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9186, 'longitude': -75.1078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8105', 'place_name': 'Camden', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9484, 'longitude': -75.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8106', 'place_name': 'Audubon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.891, 'longitude': -75.0724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8107', 'place_name': 'Oaklyn', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.908, 'longitude': -75.0849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8108', 'place_name': 'Collingswood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9157, 'longitude': -75.0634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8109', 'place_name': 'Merchantville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9519, 'longitude': -75.0482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8110', 'place_name': 'Pennsauken', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Camden', 'locality_code': '7', 'latitude': 39.9723, 'longitude': -75.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8202', 'place_name': 'Avalon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.0951, 'longitude': -74.7262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8204', 'place_name': 'Cape May', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 38.9711, 'longitude': -74.9214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8210', 'place_name': 'Cape May Court House', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.1378, 'longitude': -74.7806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8212', 'place_name': 'Cape May Point', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 38.9372, 'longitude': -74.9654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8214', 'place_name': 'Dennisville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.1932, 'longitude': -74.8252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8218', 'place_name': 'Goshen', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.1415, 'longitude': -74.8529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8219', 'place_name': 'Green Creek', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.0462, 'longitude': -74.9013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8223', 'place_name': 'Marmora', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.2586, 'longitude': -74.6593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8226', 'place_name': 'Ocean City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.2709, 'longitude': -74.5875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8230', 'place_name': 'Ocean View', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.2154, 'longitude': -74.7075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8242', 'place_name': 'Rio Grande', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.0196, 'longitude': -74.8756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8243', 'place_name': 'Sea Isle City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.154, 'longitude': -74.7005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8245', 'place_name': 'South Dennis', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.1, 'longitude': -74.8487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8246', 'place_name': 'South Seaville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.179, 'longitude': -74.7599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8247', 'place_name': 'Stone Harbor', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.0533, 'longitude': -74.762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8248', 'place_name': 'Strathmere', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.1992, 'longitude': -74.6554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8250', 'place_name': 'Tuckahoe', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.2901, 'longitude': -74.7538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8251', 'place_name': 'Villas', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.0219, 'longitude': -74.9354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8252', 'place_name': 'Whitesboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.0421, 'longitude': -74.8618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8260', 'place_name': 'Wildwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 38.9949, 'longitude': -74.838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8270', 'place_name': 'Woodbine', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cape May', 'locality_code': '9', 'latitude': 39.2716, 'longitude': -74.7968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8302', 'place_name': 'Bridgeton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.3762, 'longitude': -75.1617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8311', 'place_name': 'Cedarville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.337, 'longitude': -75.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8313', 'place_name': 'Deerfield Street', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.5293, 'longitude': -75.2249, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '8314', 'place_name': 'Delmont', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2023, 'longitude': -74.9705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8315', 'place_name': 'Dividing Creek', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2732, 'longitude': -75.095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8316', 'place_name': 'Dorchester', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2679, 'longitude': -74.9791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8320', 'place_name': 'Fairton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.3799, 'longitude': -75.2217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8321', 'place_name': 'Fortescue', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2189, 'longitude': -75.1403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8323', 'place_name': 'Greenwich', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.4055, 'longitude': -75.3209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8324', 'place_name': 'Heislerville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.224, 'longitude': -74.9942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8327', 'place_name': 'Leesburg', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2568, 'longitude': -74.9874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8329', 'place_name': 'Mauricetown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2853, 'longitude': -74.9983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8332', 'place_name': 'Millville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.3673, 'longitude': -75.0293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8345', 'place_name': 'Newport', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2832, 'longitude': -75.1716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8348', 'place_name': 'Port Elizabeth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.3131, 'longitude': -74.9807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8349', 'place_name': 'Port Norris', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.2563, 'longitude': -75.0506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8352', 'place_name': 'Rosenhayn', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.4782, 'longitude': -75.1313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8353', 'place_name': 'Shiloh', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.4594, 'longitude': -75.297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8360', 'place_name': 'Vineland', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.4818, 'longitude': -75.0091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8361', 'place_name': 'Vineland', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.4655, 'longitude': -74.9653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8362', 'place_name': 'Vineland', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Cumberland', 'locality_code': '11', 'latitude': 39.4862, 'longitude': -75.0257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7003', 'place_name': 'Bloomfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8035, 'longitude': -74.1891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7004', 'place_name': 'Fairfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8822, 'longitude': -74.296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7006', 'place_name': 'Caldwell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8545, 'longitude': -74.2789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7007', 'place_name': 'Caldwell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8398, 'longitude': -74.2765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7009', 'place_name': 'Cedar Grove', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8534, 'longitude': -74.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7017', 'place_name': 'East Orange', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7696, 'longitude': -74.2077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7018', 'place_name': 'East Orange', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7558, 'longitude': -74.2198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7019', 'place_name': 'East Orange', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7673, 'longitude': -74.2049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7021', 'place_name': 'Essex Fells', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8279, 'longitude': -74.2797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7028', 'place_name': 'Glen Ridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.804, 'longitude': -74.2055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7039', 'place_name': 'Livingston', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7896, 'longitude': -74.3202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7040', 'place_name': 'Maplewood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7279, 'longitude': -74.2656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7041', 'place_name': 'Millburn', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7228, 'longitude': -74.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7042', 'place_name': 'Montclair', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8131, 'longitude': -74.2165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7043', 'place_name': 'Montclair', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.843, 'longitude': -74.2011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7044', 'place_name': 'Verona', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8319, 'longitude': -74.2428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7050', 'place_name': 'Orange', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7692, 'longitude': -74.2355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7051', 'place_name': 'Orange', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7918, 'longitude': -74.2452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7052', 'place_name': 'West Orange', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7859, 'longitude': -74.2568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7068', 'place_name': 'Roseland', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8203, 'longitude': -74.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7078', 'place_name': 'Short Hills', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7368, 'longitude': -74.3271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7079', 'place_name': 'South Orange', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7465, 'longitude': -74.2575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7101', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7361, 'longitude': -74.2251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7102', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.732, 'longitude': -74.1765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7103', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.737, 'longitude': -74.1964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7104', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7664, 'longitude': -74.1695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7105', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7271, 'longitude': -74.1563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7106', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7415, 'longitude': -74.233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7107', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7607, 'longitude': -74.1882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7108', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7236, 'longitude': -74.2015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7109', 'place_name': 'Belleville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7946, 'longitude': -74.1631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7110', 'place_name': 'Nutley', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.8185, 'longitude': -74.1589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7111', 'place_name': 'Irvington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7261, 'longitude': -74.2313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7112', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7107, 'longitude': -74.2131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7114', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7082, 'longitude': -74.1891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7175', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7357, 'longitude': -74.1724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7184', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7918, 'longitude': -74.2452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7188', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7357, 'longitude': -74.1724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7189', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7918, 'longitude': -74.2452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7191', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7918, 'longitude': -74.2452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7192', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7357, 'longitude': -74.1724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7193', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7357, 'longitude': -74.1724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7195', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7357, 'longitude': -74.1724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7198', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7918, 'longitude': -74.2452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7199', 'place_name': 'Newark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Essex', 'locality_code': '13', 'latitude': 40.7357, 'longitude': -74.1724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8014', 'place_name': 'Bridgeport', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8016, 'longitude': -75.3478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8020', 'place_name': 'Clarksboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7992, 'longitude': -75.2237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8025', 'place_name': 'Ewan', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7015, 'longitude': -75.1629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8027', 'place_name': 'Gibbstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8231, 'longitude': -75.2751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8028', 'place_name': 'Glassboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7068, 'longitude': -75.1172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8032', 'place_name': 'Grenloch', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7788, 'longitude': -75.0601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8039', 'place_name': 'Harrisonville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.6931, 'longitude': -75.2711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8051', 'place_name': 'Mantua', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.787, 'longitude': -75.1785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8056', 'place_name': 'Mickleton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7857, 'longitude': -75.2498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8061', 'place_name': 'Mount Royal', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8097, 'longitude': -75.2082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8062', 'place_name': 'Mullica Hill', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7252, 'longitude': -75.2065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8063', 'place_name': 'National Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8664, 'longitude': -75.1794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8066', 'place_name': 'Paulsboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8312, 'longitude': -75.2242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8071', 'place_name': 'Pitman', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7312, 'longitude': -75.1297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8074', 'place_name': 'Richwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7206, 'longitude': -75.1681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8080', 'place_name': 'Sewell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7473, 'longitude': -75.0899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8085', 'place_name': 'Swedesboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7529, 'longitude': -75.3362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8086', 'place_name': 'Thorofare', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8457, 'longitude': -75.1943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8090', 'place_name': 'Wenonah', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7993, 'longitude': -75.1536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8093', 'place_name': 'Westville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8605, 'longitude': -75.1323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8094', 'place_name': 'Williamstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.665, 'longitude': -74.971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8096', 'place_name': 'Deptford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.7539, 'longitude': -74.996, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '8097', 'place_name': 'Woodbury Heights', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.8142, 'longitude': -75.153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8312', 'place_name': 'Clayton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.659, 'longitude': -75.0942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8322', 'place_name': 'Franklinville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.6156, 'longitude': -75.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8328', 'place_name': 'Malaga', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.5755, 'longitude': -75.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8343', 'place_name': 'Monroeville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.6442, 'longitude': -75.1568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8344', 'place_name': 'Newfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Gloucester', 'locality_code': '15', 'latitude': 39.5553, 'longitude': -75.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7002', 'place_name': 'Bayonne', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.6664, 'longitude': -74.1192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7029', 'place_name': 'Harrison', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7445, 'longitude': -74.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7030', 'place_name': 'Hoboken', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7445, 'longitude': -74.0329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7032', 'place_name': 'Kearny', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7647, 'longitude': -74.1471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7047', 'place_name': 'North Bergen', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7939, 'longitude': -74.0258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7086', 'place_name': 'Weehawken', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7681, 'longitude': -74.0208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7087', 'place_name': 'Union City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7674, 'longitude': -74.0323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7093', 'place_name': 'West New York', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7888, 'longitude': -74.0115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7094', 'place_name': 'Secaucus', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.791, 'longitude': -74.0634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7096', 'place_name': 'Secaucus', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7328, 'longitude': -74.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7097', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7328, 'longitude': -74.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7099', 'place_name': 'Kearny', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7328, 'longitude': -74.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7302', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7221, 'longitude': -74.0469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7303', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7328, 'longitude': -74.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7304', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.718, 'longitude': -74.0754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7305', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.702, 'longitude': -74.089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7306', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7321, 'longitude': -74.066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7307', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7482, 'longitude': -74.0498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7308', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7328, 'longitude': -74.0755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7310', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7324, 'longitude': -74.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7311', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7323, 'longitude': -74.0754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7395', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7279, 'longitude': -74.078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7399', 'place_name': 'Jersey City', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hudson', 'locality_code': '17', 'latitude': 40.7323, 'longitude': -74.0754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7830', 'place_name': 'Califon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.7162, 'longitude': -74.8152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '7979', 'place_name': 'Pottersville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.7026, 'longitude': -74.7276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8530', 'place_name': 'Lambertville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.3731, 'longitude': -74.9266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8551', 'place_name': 'Ringoes', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.4459, 'longitude': -74.8288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8556', 'place_name': 'Rosemont', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.42, 'longitude': -74.9886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8557', 'place_name': 'Sergeantsville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.4459, 'longitude': -74.9435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8559', 'place_name': 'Stockton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.4397, 'longitude': -74.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8801', 'place_name': 'Annandale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6287, 'longitude': -74.8855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8803', 'place_name': 'Baptistown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5218, 'longitude': -75.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8804', 'place_name': 'Bloomsbury', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6437, 'longitude': -75.0966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8809', 'place_name': 'Clinton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6412, 'longitude': -74.9088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8822', 'place_name': 'Flemington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.518, 'longitude': -74.8453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8825', 'place_name': 'Frenchtown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5208, 'longitude': -75.0325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8826', 'place_name': 'Glen Gardner', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.7134, 'longitude': -74.9162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8827', 'place_name': 'Hampton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6774, 'longitude': -74.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8829', 'place_name': 'High Bridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6684, 'longitude': -74.8937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8833', 'place_name': 'Lebanon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6466, 'longitude': -74.829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8834', 'place_name': 'Little York', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5637, 'longitude': -74.9494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8848', 'place_name': 'Milford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5929, 'longitude': -75.1025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8858', 'place_name': 'Oldwick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6726, 'longitude': -74.7474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8867', 'place_name': 'Pittstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5992, 'longitude': -74.9576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8868', 'place_name': 'Quakertown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5655, 'longitude': -74.9389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8870', 'place_name': 'Readington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5687, 'longitude': -74.7377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8885', 'place_name': 'Stanton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5764, 'longitude': -74.8311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8887', 'place_name': 'Three Bridges', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.5206, 'longitude': -74.7946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8888', 'place_name': 'Whitehouse', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6194, 'longitude': -74.7406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8889', 'place_name': 'Whitehouse Station', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Hunterdon', 'locality_code': '19', 'latitude': 40.6156, 'longitude': -74.7724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8520', 'place_name': 'Hightstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2669, 'longitude': -74.525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8525', 'place_name': 'Hopewell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3902, 'longitude': -74.771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '8534', 'place_name': 'Pennington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3339, 'longitude': -74.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08540', 'place_name': 'Princeton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3666, 'longitude': -74.6408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08541', 'place_name': 'Princeton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3487, 'longitude': -74.659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08542', 'place_name': 'Princeton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3535, 'longitude': -74.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08543', 'place_name': 'Princeton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08544', 'place_name': 'Princeton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3492, 'longitude': -74.6528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08550', 'place_name': 'Princeton Junction', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2669, 'longitude': -74.6511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08560', 'place_name': 'Titusville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.3077, 'longitude': -74.8655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08561', 'place_name': 'Windsor', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2423, 'longitude': -74.5787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08601', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08602', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08603', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08604', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08605', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08606', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08607', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08608', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2204, 'longitude': -74.7622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08609', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2248, 'longitude': -74.741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08610', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2016, 'longitude': -74.705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08611', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2171, 'longitude': -74.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08618', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2377, 'longitude': -74.7821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08619', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2418, 'longitude': -74.6962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08620', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.167, 'longitude': -74.6488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08625', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08628', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2655, 'longitude': -74.8168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08629', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2196, 'longitude': -74.7334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08638', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.251, 'longitude': -74.7627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08644', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2171, 'longitude': -74.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08645', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08646', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08647', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08648', 'place_name': 'Lawrence Township', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2171, 'longitude': -74.7429, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '08650', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08666', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08690', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2336, 'longitude': -74.6576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08691', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2197, 'longitude': -74.5939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08695', 'place_name': 'Trenton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Mercer', 'locality_code': '21', 'latitude': 40.2805, 'longitude': -74.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07001', 'place_name': 'Avenel', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5826, 'longitude': -74.2785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07008', 'place_name': 'Carteret', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5823, 'longitude': -74.2313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07064', 'place_name': 'Port Reading', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5709, 'longitude': -74.2466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07067', 'place_name': 'Colonia', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5937, 'longitude': -74.3164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07077', 'place_name': 'Sewaren', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5542, 'longitude': -74.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07080', 'place_name': 'South Plainfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5839, 'longitude': -74.4147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07095', 'place_name': 'Woodbridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.556, 'longitude': -74.2845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08512', 'place_name': 'Cranbury', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.3039, 'longitude': -74.5065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08536', 'place_name': 'Plainsboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.3324, 'longitude': -74.5688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08810', 'place_name': 'Dayton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.3825, 'longitude': -74.5111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08812', 'place_name': 'Dunellen', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5897, 'longitude': -74.4639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08816', 'place_name': 'East Brunswick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4284, 'longitude': -74.4064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08817', 'place_name': 'Edison', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5171, 'longitude': -74.3973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08818', 'place_name': 'Edison', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.43, 'longitude': -74.4173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08820', 'place_name': 'Edison', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.578, 'longitude': -74.3589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08824', 'place_name': 'Kendall Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4208, 'longitude': -74.5529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08828', 'place_name': 'Helmetta', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.3777, 'longitude': -74.4204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08830', 'place_name': 'Iselin', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5716, 'longitude': -74.3167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08831', 'place_name': 'Monroe Township', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.3192, 'longitude': -74.4285, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '08832', 'place_name': 'Keasbey', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5192, 'longitude': -74.3021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08837', 'place_name': 'Edison', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5325, 'longitude': -74.3375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08840', 'place_name': 'Metuchen', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5449, 'longitude': -74.3517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08846', 'place_name': 'Middlesex', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5759, 'longitude': -74.5008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08850', 'place_name': 'Milltown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4493, 'longitude': -74.439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08852', 'place_name': 'Monmouth Junction', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.3869, 'longitude': -74.5558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08854', 'place_name': 'Piscataway', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5515, 'longitude': -74.459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08855', 'place_name': 'Piscataway', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.43, 'longitude': -74.4173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08857', 'place_name': 'Old Bridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.398, 'longitude': -74.3236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08859', 'place_name': 'Parlin', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4587, 'longitude': -74.305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08861', 'place_name': 'Perth Amboy', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5176, 'longitude': -74.2754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08862', 'place_name': 'Perth Amboy', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.43, 'longitude': -74.4173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08863', 'place_name': 'Fords', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5393, 'longitude': -74.3117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08871', 'place_name': 'Sayreville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.43, 'longitude': -74.4173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08872', 'place_name': 'Sayreville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.46, 'longitude': -74.3478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08879', 'place_name': 'South Amboy', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.464, 'longitude': -74.2742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08882', 'place_name': 'South River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4444, 'longitude': -74.3801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08884', 'place_name': 'Spotswood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.3847, 'longitude': -74.3894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08899', 'place_name': 'Edison', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5203, 'longitude': -74.4205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08901', 'place_name': 'New Brunswick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4891, 'longitude': -74.4482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08902', 'place_name': 'North Brunswick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4538, 'longitude': -74.4823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08903', 'place_name': 'New Brunswick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.5139, 'longitude': -74.4451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08904', 'place_name': 'Highland Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4991, 'longitude': -74.4266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08906', 'place_name': 'New Brunswick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4862, 'longitude': -74.4518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08933', 'place_name': 'New Brunswick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.4862, 'longitude': -74.4518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08989', 'place_name': 'New Brunswick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Middlesex', 'locality_code': '23', 'latitude': 40.43, 'longitude': -74.4173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07701', 'place_name': 'Red Bank', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3584, 'longitude': -74.0681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07702', 'place_name': 'Shrewsbury', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3282, 'longitude': -74.0589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07703', 'place_name': 'Fort Monmouth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3177, 'longitude': -74.039, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '07704', 'place_name': 'Fair Haven', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3599, 'longitude': -74.0389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07710', 'place_name': 'Adelphia', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2182, 'longitude': -74.2563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07711', 'place_name': 'Allenhurst', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2367, 'longitude': -74.0067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07712', 'place_name': 'Asbury Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2507, 'longitude': -74.0486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07715', 'place_name': 'Belmar', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1784, 'longitude': -74.0218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07716', 'place_name': 'Atlantic Highlands', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4015, 'longitude': -74.0309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07717', 'place_name': 'Avon By The Sea', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1918, 'longitude': -74.0167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07718', 'place_name': 'Belford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4173, 'longitude': -74.0889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07719', 'place_name': 'Belmar', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1688, 'longitude': -74.072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07720', 'place_name': 'Bradley Beach', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2023, 'longitude': -74.0132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07721', 'place_name': 'Cliffwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4353, 'longitude': -74.2358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07722', 'place_name': 'Colts Neck', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3012, 'longitude': -74.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07723', 'place_name': 'Deal', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2506, 'longitude': -74.002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07724', 'place_name': 'Eatontown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3028, 'longitude': -74.0698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07726', 'place_name': 'Englishtown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2825, 'longitude': -74.3424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07727', 'place_name': 'Farmingdale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2043, 'longitude': -74.1779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07728', 'place_name': 'Freehold', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2458, 'longitude': -74.2768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07730', 'place_name': 'Hazlet', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4226, 'longitude': -74.1799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07731', 'place_name': 'Howell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1481, 'longitude': -74.2137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07732', 'place_name': 'Highlands', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4037, 'longitude': -73.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07733', 'place_name': 'Holmdel', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3859, 'longitude': -74.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07734', 'place_name': 'Keansburg', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4414, 'longitude': -74.1306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07735', 'place_name': 'Keyport', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4332, 'longitude': -74.1996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07737', 'place_name': 'Leonardo', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4177, 'longitude': -74.0623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07738', 'place_name': 'Lincroft', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3369, 'longitude': -74.1205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07739', 'place_name': 'Little Silver', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3354, 'longitude': -74.0413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07740', 'place_name': 'Long Branch', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2992, 'longitude': -73.9912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07746', 'place_name': 'Marlboro', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3182, 'longitude': -74.2639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07747', 'place_name': 'Matawan', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4109, 'longitude': -74.238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07748', 'place_name': 'Middletown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3944, 'longitude': -74.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07750', 'place_name': 'Monmouth Beach', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.333, 'longitude': -73.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07751', 'place_name': 'Morganville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3529, 'longitude': -74.2779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07752', 'place_name': 'Navesink', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4023, 'longitude': -74.0273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07753', 'place_name': 'Neptune', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2096, 'longitude': -74.0714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07754', 'place_name': 'Neptune', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2001, 'longitude': -74.0279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07755', 'place_name': 'Oakhurst', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2648, 'longitude': -74.0184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07756', 'place_name': 'Ocean Grove', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2116, 'longitude': -74.0093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07757', 'place_name': 'Oceanport', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3157, 'longitude': -74.0164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07758', 'place_name': 'Port Monmouth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.4289, 'longitude': -74.1083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07760', 'place_name': 'Rumson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3707, 'longitude': -74.0084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07762', 'place_name': 'Spring Lake', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1542, 'longitude': -74.0379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07763', 'place_name': 'Tennent', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2796, 'longitude': -74.3343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07764', 'place_name': 'West Long Branch', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2878, 'longitude': -74.0162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07765', 'place_name': 'Wickatunk', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3501, 'longitude': -74.2479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07799', 'place_name': 'Eatontown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.3027, 'longitude': -74.2493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08501', 'place_name': 'Allentown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1589, 'longitude': -74.5909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08510', 'place_name': 'Millstone Township', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.147, 'longitude': -74.609, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '08514', 'place_name': 'Cream Ridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1399, 'longitude': -74.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08526', 'place_name': 'Imlaystown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1623, 'longitude': -74.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08535', 'place_name': 'Millstone Township', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2739, 'longitude': -74.7162, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '08555', 'place_name': 'Roosevelt', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.2214, 'longitude': -74.4747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08720', 'place_name': 'Allenwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1389, 'longitude': -74.1122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08730', 'place_name': 'Brielle', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1077, 'longitude': -74.0635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08736', 'place_name': 'Manasquan', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1217, 'longitude': -74.0611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08750', 'place_name': 'Sea Girt', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Monmouth', 'locality_code': '25', 'latitude': 40.1345, 'longitude': -74.0436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07005', 'place_name': 'Boonton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9115, 'longitude': -74.414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07034', 'place_name': 'Lake Hiawatha', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8825, 'longitude': -74.383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07035', 'place_name': 'Lincoln Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9208, 'longitude': -74.2995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07045', 'place_name': 'Montville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9049, 'longitude': -74.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07046', 'place_name': 'Mountain Lakes', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8904, 'longitude': -74.4415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07054', 'place_name': 'Parsippany', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8621, 'longitude': -74.4117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07058', 'place_name': 'Pine Brook', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8742, 'longitude': -74.35, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07082', 'place_name': 'Towaco', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9277, 'longitude': -74.3428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07405', 'place_name': 'Butler', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9988, 'longitude': -74.4261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07440', 'place_name': 'Pequannock', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9473, 'longitude': -74.296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07444', 'place_name': 'Pompton Plains', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9655, 'longitude': -74.3016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07457', 'place_name': 'Riverdale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9931, 'longitude': -74.3088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07801', 'place_name': 'Dover', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9176, 'longitude': -74.5467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07802', 'place_name': 'Dover', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8673, 'longitude': -74.5783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07803', 'place_name': 'Mine Hill', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8771, 'longitude': -74.5845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07806', 'place_name': 'Picatinny Arsenal', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8673, 'longitude': -74.5783, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '07828', 'place_name': 'Budd Lake', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8731, 'longitude': -74.7426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07834', 'place_name': 'Denville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8897, 'longitude': -74.4844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07836', 'place_name': 'Flanders', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8453, 'longitude': -74.7019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07842', 'place_name': 'Hibernia', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.944, 'longitude': -74.4927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07845', 'place_name': 'Ironia', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8229, 'longitude': -74.6257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07847', 'place_name': 'Kenvil', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8819, 'longitude': -74.621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07849', 'place_name': 'Lake Hopatcong', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9506, 'longitude': -74.6129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07850', 'place_name': 'Landing', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9087, 'longitude': -74.6554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07852', 'place_name': 'Ledgewood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.878, 'longitude': -74.6554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07853', 'place_name': 'Long Valley', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7878, 'longitude': -74.787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07856', 'place_name': 'Mount Arlington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9283, 'longitude': -74.6363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07857', 'place_name': 'Netcong', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8985, 'longitude': -74.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07866', 'place_name': 'Rockaway', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9229, 'longitude': -74.5094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07869', 'place_name': 'Randolph', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8456, 'longitude': -74.5725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07870', 'place_name': 'Schooleys Mountain', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7993, 'longitude': -74.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07876', 'place_name': 'Succasunna', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8539, 'longitude': -74.6536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07878', 'place_name': 'Mount Tabor', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8711, 'longitude': -74.4777, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '07885', 'place_name': 'Wharton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.9139, 'longitude': -74.5863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07926', 'place_name': 'Brookside', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8004, 'longitude': -74.5718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07927', 'place_name': 'Cedar Knolls', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8223, 'longitude': -74.4569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07928', 'place_name': 'Chatham', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7305, 'longitude': -74.4017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07930', 'place_name': 'Chester', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7892, 'longitude': -74.6776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07932', 'place_name': 'Florham Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7757, 'longitude': -74.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07933', 'place_name': 'Gillette', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.6877, 'longitude': -74.4681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07935', 'place_name': 'Green Village', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7416, 'longitude': -74.4517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07936', 'place_name': 'East Hanover', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8192, 'longitude': -74.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07940', 'place_name': 'Madison', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7599, 'longitude': -74.4179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07945', 'place_name': 'Mendham', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7789, 'longitude': -74.6, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07946', 'place_name': 'Millington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.6727, 'longitude': -74.5183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07950', 'place_name': 'Morris Plains', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8445, 'longitude': -74.4824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07960', 'place_name': 'Morristown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7952, 'longitude': -74.4873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07961', 'place_name': 'Convent Station', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7968, 'longitude': -74.4815, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '07962', 'place_name': 'Morristown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8673, 'longitude': -74.5783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07963', 'place_name': 'Morristown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7968, 'longitude': -74.4815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07970', 'place_name': 'Mount Freedom', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8055, 'longitude': -74.5738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07976', 'place_name': 'New Vernon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.7347, 'longitude': -74.4845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07980', 'place_name': 'Stirling', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.6774, 'longitude': -74.4968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07981', 'place_name': 'Whippany', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8219, 'longitude': -74.42, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07999', 'place_name': 'Whippany', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Morris', 'locality_code': '27', 'latitude': 40.8673, 'longitude': -74.5783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08005', 'place_name': 'Barnegat', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.7552, 'longitude': -74.247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08006', 'place_name': 'Barnegat Light', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.7512, 'longitude': -74.1146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08008', 'place_name': 'Beach Haven', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.6411, 'longitude': -74.1922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08050', 'place_name': 'Manahawkin', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.705, 'longitude': -74.2604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08087', 'place_name': 'Tuckerton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.5881, 'longitude': -74.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08092', 'place_name': 'West Creek', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.6627, 'longitude': -74.2885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08527', 'place_name': 'Jackson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.121, 'longitude': -74.3017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08533', 'place_name': 'New Egypt', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0713, 'longitude': -74.5067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08701', 'place_name': 'Lakewood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.085, 'longitude': -74.2042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08721', 'place_name': 'Bayville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9093, 'longitude': -74.1549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08722', 'place_name': 'Beachwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9302, 'longitude': -74.1961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08723', 'place_name': 'Brick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0389, 'longitude': -74.1109, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '08724', 'place_name': 'Brick', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0874, 'longitude': -74.1152, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '08731', 'place_name': 'Forked River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.8444, 'longitude': -74.1973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08732', 'place_name': 'Island Heights', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9432, 'longitude': -74.1468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08733', 'place_name': 'Lakehurst', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0263, 'longitude': -74.3254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08734', 'place_name': 'Lanoka Harbor', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.862, 'longitude': -74.1668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08735', 'place_name': 'Lavallette', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9775, 'longitude': -74.0704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08738', 'place_name': 'Mantoloking', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0261, 'longitude': -74.0562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08739', 'place_name': 'Normandy Beach', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0026, 'longitude': -74.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08740', 'place_name': 'Ocean Gate', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.926, 'longitude': -74.1351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08741', 'place_name': 'Pine Beach', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9347, 'longitude': -74.168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08742', 'place_name': 'Point Pleasant Beach', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0806, 'longitude': -74.0595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08751', 'place_name': 'Seaside Heights', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9466, 'longitude': -74.0765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08752', 'place_name': 'Seaside Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9222, 'longitude': -74.0795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08753', 'place_name': 'Toms River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9771, 'longitude': -74.1565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08754', 'place_name': 'Toms River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 40.0008, 'longitude': -74.2493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08755', 'place_name': 'Toms River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9999, 'longitude': -74.2228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08756', 'place_name': 'Toms River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.788, 'longitude': -74.1911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08757', 'place_name': 'Toms River', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9715, 'longitude': -74.2512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08758', 'place_name': 'Waretown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.7896, 'longitude': -74.1954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08759', 'place_name': 'Manchester Township', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Ocean', 'locality_code': '29', 'latitude': 39.9515, 'longitude': -74.1521, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '07011', 'place_name': 'Clifton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.8789, 'longitude': -74.1425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07012', 'place_name': 'Clifton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.8488, 'longitude': -74.1612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07013', 'place_name': 'Clifton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.8693, 'longitude': -74.1711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07014', 'place_name': 'Clifton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.8344, 'longitude': -74.1377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07015', 'place_name': 'Clifton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.8584, 'longitude': -74.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07055', 'place_name': 'Passaic', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.8601, 'longitude': -74.1283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07403', 'place_name': 'Bloomingdale', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0128, 'longitude': -74.3338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07420', 'place_name': 'Haskell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0301, 'longitude': -74.2965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07421', 'place_name': 'Hewitt', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.1709, 'longitude': -74.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07424', 'place_name': 'Little Falls', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.8835, 'longitude': -74.2144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07435', 'place_name': 'Newfoundland', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0647, 'longitude': -74.4359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07438', 'place_name': 'Oak Ridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0302, 'longitude': -74.5198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07442', 'place_name': 'Pompton Lakes', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9993, 'longitude': -74.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07456', 'place_name': 'Ringwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0928, 'longitude': -74.2659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07465', 'place_name': 'Wanaque', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0544, 'longitude': -74.279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07470', 'place_name': 'Wayne', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9471, 'longitude': -74.2466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07474', 'place_name': 'Wayne', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9481, 'longitude': -74.245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07480', 'place_name': 'West Milford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0915, 'longitude': -74.375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07501', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9143, 'longitude': -74.1671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07502', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9199, 'longitude': -74.1932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07503', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.897, 'longitude': -74.1573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07504', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9122, 'longitude': -74.1452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07505', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9166, 'longitude': -74.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07506', 'place_name': 'Hawthorne', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9564, 'longitude': -74.1569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07507', 'place_name': 'Hawthorne', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9493, 'longitude': -74.1538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07508', 'place_name': 'Haledon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9457, 'longitude': -74.1826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07509', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9168, 'longitude': -74.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07510', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9168, 'longitude': -74.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07511', 'place_name': 'Totowa', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0114, 'longitude': -74.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07512', 'place_name': 'Totowa', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9048, 'longitude': -74.2168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07513', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.907, 'longitude': -74.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07514', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9248, 'longitude': -74.1467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07522', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9252, 'longitude': -74.1781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07524', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9309, 'longitude': -74.1555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07533', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0114, 'longitude': -74.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07538', 'place_name': 'Haledon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 40.9357, 'longitude': -74.1863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07543', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0114, 'longitude': -74.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07544', 'place_name': 'Paterson', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Passaic', 'locality_code': '31', 'latitude': 41.0114, 'longitude': -74.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08001', 'place_name': 'Alloway', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.5591, 'longitude': -75.3506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08023', 'place_name': 'Deepwater', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.6815, 'longitude': -75.4934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08038', 'place_name': 'Hancocks Bridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.4716, 'longitude': -75.4902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08067', 'place_name': 'Pedricktown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.7435, 'longitude': -75.412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08069', 'place_name': 'Penns Grove', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.6994, 'longitude': -75.4495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08070', 'place_name': 'Pennsville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.6491, 'longitude': -75.5155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08072', 'place_name': 'Quinton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.5459, 'longitude': -75.4124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08079', 'place_name': 'Salem', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.5591, 'longitude': -75.4521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08098', 'place_name': 'Woodstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.6457, 'longitude': -75.3248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08318', 'place_name': 'Elmer', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.5691, 'longitude': -75.163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08347', 'place_name': 'Norma', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Salem', 'locality_code': '33', 'latitude': 39.4998, 'longitude': -75.082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07059', 'place_name': 'Warren', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6318, 'longitude': -74.5105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07920', 'place_name': 'Basking Ridge', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6789, 'longitude': -74.5605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07921', 'place_name': 'Bedminster', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6571, 'longitude': -74.6432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07924', 'place_name': 'Bernardsville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.7225, 'longitude': -74.5778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07931', 'place_name': 'Far Hills', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6996, 'longitude': -74.6536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07934', 'place_name': 'Gladstone', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.7219, 'longitude': -74.6707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07938', 'place_name': 'Liberty Corner', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6554, 'longitude': -74.5862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07939', 'place_name': 'Lyons', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6674, 'longitude': -74.5539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07977', 'place_name': 'Peapack', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.7079, 'longitude': -74.6541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07978', 'place_name': 'Pluckemin', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6425, 'longitude': -74.6396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08502', 'place_name': 'Belle Mead', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.4483, 'longitude': -74.6557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08504', 'place_name': 'Blawenburg', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.4076, 'longitude': -74.7027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08528', 'place_name': 'Kingston', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.3828, 'longitude': -74.6096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08553', 'place_name': 'Rocky Hill', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.401, 'longitude': -74.64, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08558', 'place_name': 'Skillman', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.4173, 'longitude': -74.6938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08805', 'place_name': 'Bound Brook', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5681, 'longitude': -74.5397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08807', 'place_name': 'Bridgewater', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5904, 'longitude': -74.6267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08821', 'place_name': 'Flagtown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.517, 'longitude': -74.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08823', 'place_name': 'Franklin Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.4421, 'longitude': -74.5369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08835', 'place_name': 'Manville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5399, 'longitude': -74.5934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08836', 'place_name': 'Martinsville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.6, 'longitude': -74.5572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08844', 'place_name': 'Hillsborough', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.4775, 'longitude': -74.6272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08853', 'place_name': 'Neshanic Station', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5293, 'longitude': -74.7401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08869', 'place_name': 'Raritan', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5711, 'longitude': -74.6377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08873', 'place_name': 'Somerset', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5007, 'longitude': -74.5013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08875', 'place_name': 'Somerset', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.4976, 'longitude': -74.4885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08876', 'place_name': 'Somerville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.588, 'longitude': -74.6874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08880', 'place_name': 'South Bound Brook', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5523, 'longitude': -74.5311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08890', 'place_name': 'Zarephath', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Somerset', 'locality_code': '35', 'latitude': 40.5361, 'longitude': -74.5789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07416', 'place_name': 'Franklin', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1164, 'longitude': -74.5865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07418', 'place_name': 'Glenwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.2356, 'longitude': -74.4885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07419', 'place_name': 'Hamburg', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1467, 'longitude': -74.5874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07422', 'place_name': 'Highland Lakes', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1826, 'longitude': -74.4564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07428', 'place_name': 'Mc Afee', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.2065, 'longitude': -74.5381, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '07439', 'place_name': 'Ogdensburg', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.0767, 'longitude': -74.5982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07460', 'place_name': 'Stockholm', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.0992, 'longitude': -74.5283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07461', 'place_name': 'Sussex', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.2292, 'longitude': -74.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07462', 'place_name': 'Vernon', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.185, 'longitude': -74.5332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07821', 'place_name': 'Andover', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 40.9614, 'longitude': -74.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07822', 'place_name': 'Augusta', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1451, 'longitude': -74.6848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07826', 'place_name': 'Branchville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1705, 'longitude': -74.75, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07827', 'place_name': 'Montague', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.3023, 'longitude': -74.754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07837', 'place_name': 'Glasser', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1283, 'longitude': -74.679, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '07839', 'place_name': 'Greendell', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 40.974, 'longitude': -74.821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07843', 'place_name': 'Hopatcong', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 40.939, 'longitude': -74.6616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07848', 'place_name': 'Lafayette', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.0761, 'longitude': -74.6912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07851', 'place_name': 'Layton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.2299, 'longitude': -74.8466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07855', 'place_name': 'Middleville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.0559, 'longitude': -74.8629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07860', 'place_name': 'Newton', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.0695, 'longitude': -74.8069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07871', 'place_name': 'Sparta', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.0277, 'longitude': -74.6407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07874', 'place_name': 'Stanhope', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 40.9217, 'longitude': -74.7004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07875', 'place_name': 'Stillwater', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.0439, 'longitude': -74.872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07877', 'place_name': 'Swartswood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1029, 'longitude': -74.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07879', 'place_name': 'Tranquility', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 40.9559, 'longitude': -74.7881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07881', 'place_name': 'Wallpack Center', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1256, 'longitude': -74.9177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07890', 'place_name': 'Branchville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Sussex', 'locality_code': '37', 'latitude': 41.1465, 'longitude': -74.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07016', 'place_name': 'Cranford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6554, 'longitude': -74.3057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07023', 'place_name': 'Fanwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6419, 'longitude': -74.3868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07027', 'place_name': 'Garwood', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6512, 'longitude': -74.3239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07033', 'place_name': 'Kenilworth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6759, 'longitude': -74.2944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07036', 'place_name': 'Linden', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6354, 'longitude': -74.2556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07060', 'place_name': 'Plainfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6152, 'longitude': -74.415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07061', 'place_name': 'Plainfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6657, 'longitude': -74.2997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07062', 'place_name': 'Plainfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6323, 'longitude': -74.3997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07063', 'place_name': 'Plainfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6048, 'longitude': -74.4427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07065', 'place_name': 'Rahway', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6087, 'longitude': -74.2819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07066', 'place_name': 'Clark', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6203, 'longitude': -74.3106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07069', 'place_name': 'Watchung', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6378, 'longitude': -74.4514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07076', 'place_name': 'Scotch Plains', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6379, 'longitude': -74.3682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07081', 'place_name': 'Springfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.7015, 'longitude': -74.3227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07083', 'place_name': 'Union', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6952, 'longitude': -74.2677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07088', 'place_name': 'Vauxhall', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.7179, 'longitude': -74.2829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07090', 'place_name': 'Westfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6479, 'longitude': -74.3451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07091', 'place_name': 'Westfield', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6657, 'longitude': -74.2997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07092', 'place_name': 'Mountainside', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6785, 'longitude': -74.3588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07201', 'place_name': 'Elizabeth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6717, 'longitude': -74.2043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07202', 'place_name': 'Elizabeth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6565, 'longitude': -74.2215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07203', 'place_name': 'Roselle', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.653, 'longitude': -74.261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07204', 'place_name': 'Roselle Park', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6651, 'longitude': -74.267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07205', 'place_name': 'Hillside', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6968, 'longitude': -74.2281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07206', 'place_name': 'Elizabethport', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6501, 'longitude': -74.1871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07207', 'place_name': 'Elizabeth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.664, 'longitude': -74.2107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07208', 'place_name': 'Elizabeth', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6747, 'longitude': -74.2239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07901', 'place_name': 'Summit', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.7149, 'longitude': -74.3642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07902', 'place_name': 'Summit', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.7156, 'longitude': -74.3647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07922', 'place_name': 'Berkeley Heights', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.6752, 'longitude': -74.4346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07974', 'place_name': 'New Providence', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Union', 'locality_code': '39', 'latitude': 40.7004, 'longitude': -74.4023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07820', 'place_name': 'Allamuchy', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.9218, 'longitude': -74.8102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07823', 'place_name': 'Belvidere', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.8308, 'longitude': -75.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07825', 'place_name': 'Blairstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.9674, 'longitude': -74.9651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07829', 'place_name': 'Buttzville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.8434, 'longitude': -74.9859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07831', 'place_name': 'Changewater', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.7394, 'longitude': -74.9448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07832', 'place_name': 'Columbia', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.9388, 'longitude': -75.055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07833', 'place_name': 'Delaware', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.8929, 'longitude': -75.0646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07838', 'place_name': 'Great Meadows', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.852, 'longitude': -74.9418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07840', 'place_name': 'Hackettstown', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.8529, 'longitude': -74.8343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07844', 'place_name': 'Hope', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.9197, 'longitude': -74.9846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07846', 'place_name': 'Johnsonburg', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.9645, 'longitude': -74.8785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07863', 'place_name': 'Oxford', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.8105, 'longitude': -75.0019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07865', 'place_name': 'Port Murray', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.7906, 'longitude': -74.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07880', 'place_name': 'Vienna', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.8648, 'longitude': -74.897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '07882', 'place_name': 'Washington', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.7582, 'longitude': -74.9914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08802', 'place_name': 'Asbury', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.695, 'longitude': -75.0281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08808', 'place_name': 'Broadway', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.732, 'longitude': -75.0516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08865', 'place_name': 'Phillipsburg', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.7079, 'longitude': -75.1507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '08886', 'place_name': 'Stewartsville', 'state': 'New Jersey', 'state_ab': 'NJ', 'county': 'Warren', 'locality_code': '41', 'latitude': 40.6937, 'longitude': -75.111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87008', 'place_name': 'Cedar Crest', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1285, 'longitude': -106.3617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87022', 'place_name': 'Isleta', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 34.9073, 'longitude': -106.6892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87047', 'place_name': 'Sandia Park', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1683, 'longitude': -106.3238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87059', 'place_name': 'Tijeras', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0446, 'longitude': -106.3062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87101', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1996, 'longitude': -106.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87102', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0818, 'longitude': -106.6482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87103', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87104', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1038, 'longitude': -106.6712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87105', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0448, 'longitude': -106.6893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87106', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.079, 'longitude': -106.6169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87107', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1347, 'longitude': -106.6427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87108', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0726, 'longitude': -106.5749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87109', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1506, 'longitude': -106.569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87110', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1104, 'longitude': -106.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87111', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1347, 'longitude': -106.5222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87112', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.101, 'longitude': -106.5183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87113', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1759, 'longitude': -106.6015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87114', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1868, 'longitude': -106.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87115', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0549, 'longitude': -106.5461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87116', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0561, 'longitude': -106.5506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87117', 'place_name': 'Kirtland Afb', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0203, 'longitude': -106.5503, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '87119', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87120', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1421, 'longitude': -106.7041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87121', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0512, 'longitude': -106.7269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87122', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.1787, 'longitude': -106.5102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87123', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0717, 'longitude': -106.509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87125', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87131', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87151', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.023, 'longitude': -106.8556, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '87153', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87154', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87158', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0845, 'longitude': -106.6511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87174', 'place_name': 'Rio Rancho', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87176', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87181', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87184', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87185', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87187', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87190', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87191', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87192', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87193', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87194', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87195', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87196', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87197', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0845, 'longitude': -106.6511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87198', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0845, 'longitude': -106.6511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87199', 'place_name': 'Albuquerque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Bernalillo', 'locality_code': '1', 'latitude': 35.0443, 'longitude': -106.6729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87820', 'place_name': 'Aragon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Catron', 'locality_code': '3', 'latitude': 33.8859, 'longitude': -108.5466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87821', 'place_name': 'Datil', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Catron', 'locality_code': '3', 'latitude': 34.0427, 'longitude': -108.0183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87824', 'place_name': 'Luna', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Catron', 'locality_code': '3', 'latitude': 33.8189, 'longitude': -108.9545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87827', 'place_name': 'Pie Town', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Catron', 'locality_code': '3', 'latitude': 34.3243, 'longitude': -108.3682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87829', 'place_name': 'Quemado', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Catron', 'locality_code': '3', 'latitude': 34.2652, 'longitude': -108.7578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87830', 'place_name': 'Reserve', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Catron', 'locality_code': '3', 'latitude': 33.7131, 'longitude': -108.7578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88039', 'place_name': 'Glenwood', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Catron', 'locality_code': '3', 'latitude': 33.3048, 'longitude': -108.7743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88201', 'place_name': 'Roswell', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Chaves', 'locality_code': '5', 'latitude': 33.6397, 'longitude': -104.3748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88202', 'place_name': 'Roswell', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Chaves', 'locality_code': '5', 'latitude': 33.3038, 'longitude': -104.4318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88203', 'place_name': 'Roswell', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Chaves', 'locality_code': '5', 'latitude': 33.3718, 'longitude': -104.5284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88230', 'place_name': 'Dexter', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Chaves', 'locality_code': '5', 'latitude': 33.191, 'longitude': -104.3833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88232', 'place_name': 'Hagerman', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Chaves', 'locality_code': '5', 'latitude': 33.1076, 'longitude': -104.3298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88253', 'place_name': 'Lake Arthur', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Chaves', 'locality_code': '5', 'latitude': 32.9982, 'longitude': -104.3666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87005', 'place_name': 'Bluewater', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.255, 'longitude': -107.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87007', 'place_name': 'Casa Blanca', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.0456, 'longitude': -107.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87014', 'place_name': 'Cubero', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.0859, 'longitude': -107.5181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87020', 'place_name': 'Grants', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.1476, 'longitude': -107.8526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87021', 'place_name': 'Milan', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.1698, 'longitude': -107.8909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87026', 'place_name': 'Laguna', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 34.9625, 'longitude': -107.2325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87038', 'place_name': 'New Laguna', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.0409, 'longitude': -107.422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87040', 'place_name': 'Paguate', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.1387, 'longitude': -107.3789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87049', 'place_name': 'San Fidel', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.0823, 'longitude': -107.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87051', 'place_name': 'San Rafael', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 35.1125, 'longitude': -107.8826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87315', 'place_name': 'Fence Lake', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 34.7344, 'longitude': -108.6934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87357', 'place_name': 'Pinehill', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Cibola', 'locality_code': '6', 'latitude': 34.9992, 'longitude': -108.4112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87710', 'place_name': 'Angel Fire', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.3849, 'longitude': -105.2439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87714', 'place_name': 'Cimarron', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.4574, 'longitude': -105.0697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87718', 'place_name': 'Eagle Nest', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.5326, 'longitude': -105.2756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87728', 'place_name': 'Maxwell', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.5434, 'longitude': -104.564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87729', 'place_name': 'Miami', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.35, 'longitude': -104.7931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87740', 'place_name': 'Raton', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.8952, 'longitude': -104.4349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87747', 'place_name': 'Springer', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.3767, 'longitude': -104.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87749', 'place_name': 'Ute Park', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Colfax', 'locality_code': '7', 'latitude': 36.5581, 'longitude': -105.115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88101', 'place_name': 'Clovis', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.4126, 'longitude': -103.2214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88102', 'place_name': 'Clovis', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.4048, 'longitude': -103.2052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88103', 'place_name': 'Cannon Afb', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.3841, 'longitude': -103.3154, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88112', 'place_name': 'Broadview', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.804, 'longitude': -103.1292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88120', 'place_name': 'Grady', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.8107, 'longitude': -103.298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88124', 'place_name': 'Melrose', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.4479, 'longitude': -103.6325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88133', 'place_name': 'Saint Vrain', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.4756, 'longitude': -103.4669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88135', 'place_name': 'Texico', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Curry', 'locality_code': '9', 'latitude': 34.3958, 'longitude': -103.0615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88119', 'place_name': 'Fort Sumner', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'DeBaca', 'locality_code': '11', 'latitude': 34.46, 'longitude': -104.2317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88134', 'place_name': 'Taiban', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'DeBaca', 'locality_code': '11', 'latitude': 34.3271, 'longitude': -104.0159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88136', 'place_name': 'Yeso', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'DeBaca', 'locality_code': '11', 'latitude': 34.455, 'longitude': -104.7452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87936', 'place_name': 'Garfield', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.7557, 'longitude': -107.2704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87937', 'place_name': 'Hatch', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.6583, 'longitude': -107.159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87940', 'place_name': 'Rincon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.6597, 'longitude': -107.0643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87941', 'place_name': 'Salem', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.7093, 'longitude': -107.2157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88001', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.2901, 'longitude': -106.7539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88002', 'place_name': 'White Sands Missile Range', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.3839, 'longitude': -106.4937, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88003', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.2738, 'longitude': -106.7472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88004', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.4181, 'longitude': -106.8201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88005', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.3161, 'longitude': -106.7991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88006', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.3052, 'longitude': -106.7863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88007', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.3224, 'longitude': -106.8041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88008', 'place_name': 'Santa Teresa', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 31.8394, 'longitude': -106.6821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88011', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.3244, 'longitude': -106.6683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88012', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.5835, 'longitude': -106.7714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88013', 'place_name': 'Las Cruces', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.5835, 'longitude': -106.7714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88021', 'place_name': 'Anthony', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.004, 'longitude': -106.6058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88024', 'place_name': 'Berino', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.0682, 'longitude': -106.631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88027', 'place_name': 'Chamberino', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.0401, 'longitude': -106.6856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88032', 'place_name': 'Dona Ana', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.3895, 'longitude': -106.8139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88033', 'place_name': 'Fairacres', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.2984, 'longitude': -106.8812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88044', 'place_name': 'La Mesa', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.1383, 'longitude': -106.7999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88046', 'place_name': 'Mesilla', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.268, 'longitude': -106.8059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88047', 'place_name': 'Mesilla Park', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.21, 'longitude': -106.7147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88048', 'place_name': 'Mesquite', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.146, 'longitude': -106.6676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88052', 'place_name': 'Organ', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.4259, 'longitude': -106.6136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88054', 'place_name': 'Radium Springs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.4888, 'longitude': -106.9146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88058', 'place_name': 'San Miguel', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.1554, 'longitude': -106.735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88063', 'place_name': 'Sunland Park', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 31.8186, 'longitude': -106.5997, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88072', 'place_name': 'Vado', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Doña Ana', 'locality_code': '13', 'latitude': 32.1187, 'longitude': -106.649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88210', 'place_name': 'Artesia', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.8384, 'longitude': -104.4074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88211', 'place_name': 'Artesia', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.7536, 'longitude': -104.3281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88220', 'place_name': 'Carlsbad', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.4119, 'longitude': -104.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88221', 'place_name': 'Carlsbad', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.342, 'longitude': -104.2937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88250', 'place_name': 'Hope', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.8156, 'longitude': -104.7299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88254', 'place_name': 'Lakewood', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.6362, 'longitude': -104.365, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88255', 'place_name': 'Loco Hills', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.819, 'longitude': -103.9777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88256', 'place_name': 'Loving', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.274, 'longitude': -104.0914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88263', 'place_name': 'Malaga', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.1813, 'longitude': -104.0668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88268', 'place_name': 'Whites City', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Eddy', 'locality_code': '15', 'latitude': 32.1757, 'longitude': -104.3766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88022', 'place_name': 'Arenas Valley', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.7839, 'longitude': -108.1854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88023', 'place_name': 'Bayard', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.7617, 'longitude': -108.1306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88025', 'place_name': 'Buckhorn', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 33.0633, 'longitude': -108.6956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88026', 'place_name': 'Santa Clara', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.7795, 'longitude': -108.1503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88028', 'place_name': 'Cliff', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.9623, 'longitude': -108.6112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88034', 'place_name': 'Faywood', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.5642, 'longitude': -108.0242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88036', 'place_name': 'Fort Bayard', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.7574, 'longitude': -108.0075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88038', 'place_name': 'Gila', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.9659, 'longitude': -108.5767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88040', 'place_name': 'Hachita', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 31.8904, 'longitude': -108.3316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88041', 'place_name': 'Hanover', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.8045, 'longitude': -107.9545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88043', 'place_name': 'Hurley', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.648, 'longitude': -108.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88049', 'place_name': 'Mimbres', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.909, 'longitude': -108.0332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88051', 'place_name': 'Mule Creek', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 33.1071, 'longitude': -108.9032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88053', 'place_name': 'Pinos Altos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.8614, 'longitude': -108.2192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88055', 'place_name': 'Redrock', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.6862, 'longitude': -108.7381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88061', 'place_name': 'Silver City', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.79, 'longitude': -108.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88062', 'place_name': 'Silver City', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.7282, 'longitude': -108.1379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88065', 'place_name': 'Tyrone', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Grant', 'locality_code': '17', 'latitude': 32.7098, 'longitude': -108.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87711', 'place_name': 'Anton Chico', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Guadalupe', 'locality_code': '19', 'latitude': 35.2001, 'longitude': -105.1422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87724', 'place_name': 'La Loma', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Guadalupe', 'locality_code': '19', 'latitude': 35.1734, 'longitude': -105.0775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88353', 'place_name': 'Vaughn', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Guadalupe', 'locality_code': '19', 'latitude': 34.6241, 'longitude': -105.1926, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88417', 'place_name': 'Cuervo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Guadalupe', 'locality_code': '19', 'latitude': 35.0312, 'longitude': -104.4086, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88431', 'place_name': 'Newkirk', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Guadalupe', 'locality_code': '19', 'latitude': 35.0847, 'longitude': -104.2433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88435', 'place_name': 'Santa Rosa', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Guadalupe', 'locality_code': '19', 'latitude': 34.8526, 'longitude': -104.5899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87730', 'place_name': 'Mills', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Harding', 'locality_code': '21', 'latitude': 36.1281, 'longitude': -104.2277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87733', 'place_name': 'Mosquero', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Harding', 'locality_code': '21', 'latitude': 35.8041, 'longitude': -103.9021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87743', 'place_name': 'Roy', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Harding', 'locality_code': '21', 'latitude': 35.9522, 'longitude': -104.1497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87746', 'place_name': 'Solano', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Harding', 'locality_code': '21', 'latitude': 35.8484, 'longitude': -104.0675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88009', 'place_name': 'Playas', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Hidalgo', 'locality_code': '23', 'latitude': 32.055, 'longitude': -108.6291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88020', 'place_name': 'Animas', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Hidalgo', 'locality_code': '23', 'latitude': 32.053, 'longitude': -108.9069, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88045', 'place_name': 'Lordsburg', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Hidalgo', 'locality_code': '23', 'latitude': 32.316, 'longitude': -108.723, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88056', 'place_name': 'Rodeo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Hidalgo', 'locality_code': '23', 'latitude': 31.8358, 'longitude': -109.0322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88114', 'place_name': 'Crossroads', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 33.5272, 'longitude': -103.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88213', 'place_name': 'Caprock', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 33.3939, 'longitude': -103.639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88231', 'place_name': 'Eunice', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.4392, 'longitude': -103.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88240', 'place_name': 'Hobbs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.7222, 'longitude': -103.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88241', 'place_name': 'Hobbs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.7475, 'longitude': -103.2165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88242', 'place_name': 'Hobbs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.8105, 'longitude': -103.1587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88244', 'place_name': 'Hobbs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.7026, 'longitude': -103.136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88252', 'place_name': 'Jal', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.1128, 'longitude': -103.1997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88260', 'place_name': 'Lovington', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.9512, 'longitude': -103.3488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88262', 'place_name': 'Mcdonald', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 33.1407, 'longitude': -103.3174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88264', 'place_name': 'Maljamar', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.8562, 'longitude': -103.7627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88265', 'place_name': 'Monument', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 32.5874, 'longitude': -103.2703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88267', 'place_name': 'Tatum', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lea', 'locality_code': '25', 'latitude': 33.26, 'longitude': -103.314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88301', 'place_name': 'Carrizozo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.6496, 'longitude': -105.8696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88312', 'place_name': 'Alto', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.4314, 'longitude': -105.6776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88316', 'place_name': 'Capitan', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.5602, 'longitude': -105.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88318', 'place_name': 'Corona', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 34.1693, 'longitude': -105.5339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88323', 'place_name': 'Fort Stanton', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.4959, 'longitude': -105.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88324', 'place_name': 'Glencoe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3898, 'longitude': -105.4391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88336', 'place_name': 'Hondo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3876, 'longitude': -105.2708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88338', 'place_name': 'Lincoln', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.4869, 'longitude': -105.382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88341', 'place_name': 'Nogal', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.4996, 'longitude': -105.7036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88343', 'place_name': 'Picacho', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3518, 'longitude': -105.145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88345', 'place_name': 'Ruidoso', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3474, 'longitude': -105.651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88346', 'place_name': 'Ruidoso Downs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3577, 'longitude': -105.5383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88348', 'place_name': 'San Patricio', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3877, 'longitude': -105.3498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88351', 'place_name': 'Tinnie', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3706, 'longitude': -105.2264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88355', 'place_name': 'Ruidoso', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Lincoln', 'locality_code': '27', 'latitude': 33.3305, 'longitude': -105.6933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87544', 'place_name': 'Los Alamos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Los Alamos', 'locality_code': '28', 'latitude': 35.8663, 'longitude': -106.2676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87545', 'place_name': 'Los Alamos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Los Alamos', 'locality_code': '28', 'latitude': 35.8639, 'longitude': -106.2953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87547', 'place_name': 'White Rock', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Los Alamos', 'locality_code': '28', 'latitude': 35.8275, 'longitude': -106.2039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88029', 'place_name': 'Columbus', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Luna', 'locality_code': '29', 'latitude': 31.8276, 'longitude': -107.64, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88030', 'place_name': 'Deming', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Luna', 'locality_code': '29', 'latitude': 32.2318, 'longitude': -107.7466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88031', 'place_name': 'Deming', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Luna', 'locality_code': '29', 'latitude': 32.2398, 'longitude': -107.7404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87045', 'place_name': 'Prewitt', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.3547, 'longitude': -108.1038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87301', 'place_name': 'Gallup', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.5065, 'longitude': -108.7414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87302', 'place_name': 'Gallup', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.5281, 'longitude': -108.7426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87305', 'place_name': 'Gallup', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.4499, 'longitude': -108.7705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87310', 'place_name': 'Brimhall', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.8005, 'longitude': -108.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87311', 'place_name': 'Church Rock', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.5339, 'longitude': -108.5998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87312', 'place_name': 'Continental Divide', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.4226, 'longitude': -108.323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87313', 'place_name': 'Crownpoint', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.7206, 'longitude': -108.0271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87316', 'place_name': 'Fort Wingate', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.5191, 'longitude': -108.4864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87317', 'place_name': 'Gamerco', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.5763, 'longitude': -108.7626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87319', 'place_name': 'Mentmore', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.5042, 'longitude': -108.8317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87320', 'place_name': 'Mexican Springs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.7837, 'longitude': -108.819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87321', 'place_name': 'Ramah', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.1324, 'longitude': -108.492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87322', 'place_name': 'Rehoboth', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.5289, 'longitude': -108.6548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87323', 'place_name': 'Thoreau', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.3976, 'longitude': -108.1604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87325', 'place_name': 'Tohatchi', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 36.0021, 'longitude': -108.6229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87326', 'place_name': 'Vanderwagen', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.3509, 'longitude': -108.6985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87327', 'place_name': 'Zuni', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.0684, 'longitude': -108.8336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87328', 'place_name': 'Navajo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.8942, 'longitude': -109.0226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87347', 'place_name': 'Jamestown', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.4809, 'longitude': -108.1767, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '87365', 'place_name': 'Smith Lake', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.4809, 'longitude': -108.1767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87375', 'place_name': 'Yatahey', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'McKinley', 'locality_code': '31', 'latitude': 35.4809, 'longitude': -108.1767, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '87712', 'place_name': 'Buena Vista', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 35.9136, 'longitude': -105.2492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87713', 'place_name': 'Chacon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 36.1388, 'longitude': -105.3854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87715', 'place_name': 'Cleveland', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 35.9898, 'longitude': -105.4326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87722', 'place_name': 'Guadalupita', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 36.1375, 'longitude': -105.2386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87723', 'place_name': 'Holman', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 36.0384, 'longitude': -105.3836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87732', 'place_name': 'Mora', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 35.9742, 'longitude': -105.33, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87734', 'place_name': 'Ocate', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 36.1037, 'longitude': -105.066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87735', 'place_name': 'Ojo Feliz', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 36.0578, 'longitude': -105.1183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87736', 'place_name': 'Rainsville', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 35.9786, 'longitude': -105.2092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87750', 'place_name': 'Valmora', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 35.8164, 'longitude': -104.9231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87752', 'place_name': 'Wagon Mound', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 35.9814, 'longitude': -104.691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87753', 'place_name': 'Watrous', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Mora', 'locality_code': '33', 'latitude': 35.7906, 'longitude': -104.9817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88081', 'place_name': 'Chaparral', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.2239, 'longitude': -106.2631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88310', 'place_name': 'Alamogordo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.8932, 'longitude': -105.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88311', 'place_name': 'Alamogordo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.8995, 'longitude': -105.9603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88314', 'place_name': 'Bent', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 33.148, 'longitude': -105.8635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88317', 'place_name': 'Cloudcroft', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.8897, 'longitude': -105.6744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88325', 'place_name': 'High Rolls Mountain Park', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.9396, 'longitude': -105.8189, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88330', 'place_name': 'Holloman Air Force Base', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.8366, 'longitude': -106.0774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88337', 'place_name': 'La Luz', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.9774, 'longitude': -105.9534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88339', 'place_name': 'Mayhill', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.907, 'longitude': -105.5181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88340', 'place_name': 'Mescalero', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 33.2164, 'longitude': -105.7743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88342', 'place_name': 'Orogrande', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.3712, 'longitude': -106.0844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88344', 'place_name': 'Pinon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.6396, 'longitude': -105.4157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88347', 'place_name': 'Sacramento', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.8052, 'longitude': -105.6211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88349', 'place_name': 'Sunspot', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.8672, 'longitude': -105.7811, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88350', 'place_name': 'Timberon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.6295, 'longitude': -105.6945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88352', 'place_name': 'Tularosa', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 33.065, 'longitude': -106.0108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88354', 'place_name': 'Weed', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Otero', 'locality_code': '35', 'latitude': 32.8052, 'longitude': -105.5063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88121', 'place_name': 'House', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 34.6952, 'longitude': -103.9203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88401', 'place_name': 'Tucumcari', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 35.168, 'longitude': -103.7179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88411', 'place_name': 'Bard', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 35.1303, 'longitude': -103.1605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88426', 'place_name': 'Logan', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 35.3681, 'longitude': -103.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88427', 'place_name': 'Mcalister', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 34.6923, 'longitude': -103.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88430', 'place_name': 'Nara Visa', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 35.618, 'longitude': -103.1317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88433', 'place_name': 'Quay', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 34.9167, 'longitude': -103.7782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88434', 'place_name': 'San Jon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Quay', 'locality_code': '37', 'latitude': 35.1198, 'longitude': -103.2846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87012', 'place_name': 'Coyote', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.1018, 'longitude': -106.6692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87017', 'place_name': 'Gallina', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.3202, 'longitude': -106.7687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87029', 'place_name': 'Lindrith', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.3249, 'longitude': -107.0495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87064', 'place_name': 'Youngsville', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.1875, 'longitude': -106.5564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87510', 'place_name': 'Abiquiu', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.1769, 'longitude': -106.2449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87511', 'place_name': 'Alcalde', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.0889, 'longitude': -106.0536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87515', 'place_name': 'Canjilon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.4795, 'longitude': -106.4378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87516', 'place_name': 'Canones', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.1814, 'longitude': -106.4376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87518', 'place_name': 'Cebolla', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.4654, 'longitude': -106.5785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87520', 'place_name': 'Chama', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.8962, 'longitude': -106.5829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87522', 'place_name': 'Chimayo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.0039, 'longitude': -105.947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87523', 'place_name': 'Cordova', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.0072, 'longitude': -105.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87527', 'place_name': 'Dixon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.179, 'longitude': -105.8615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87528', 'place_name': 'Dulce', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.8598, 'longitude': -107.0602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87530', 'place_name': 'El Rito', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.3647, 'longitude': -106.2192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87531', 'place_name': 'Embudo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.2153, 'longitude': -105.8901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87532', 'place_name': 'Espanola', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 35.9872, 'longitude': -106.0717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87533', 'place_name': 'Espanola', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 35.9866, 'longitude': -106.0654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87537', 'place_name': 'Hernandez', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.0738, 'longitude': -106.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87539', 'place_name': 'La Madera', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.4654, 'longitude': -106.5785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87548', 'place_name': 'Medanales', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.1756, 'longitude': -106.1834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87551', 'place_name': 'Los Ojos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.7292, 'longitude': -106.57, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87554', 'place_name': 'Petaca', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.5084, 'longitude': -106.0106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87566', 'place_name': 'Ohkay Owingeh', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.0508, 'longitude': -106.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87575', 'place_name': 'Tierra Amarilla', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.6805, 'longitude': -106.557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87578', 'place_name': 'Truchas', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.0444, 'longitude': -105.8129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87581', 'place_name': 'Vallecitos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.5286, 'longitude': -106.1448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87582', 'place_name': 'Velarde', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Rio Arriba', 'locality_code': '39', 'latitude': 36.1589, 'longitude': -105.9747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88113', 'place_name': 'Causey', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.7781, 'longitude': -103.0865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88115', 'place_name': 'Dora', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.9387, 'longitude': -103.3366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88116', 'place_name': 'Elida', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.9405, 'longitude': -103.6323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88118', 'place_name': 'Floyd', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 34.252, 'longitude': -103.5827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88122', 'place_name': 'Kenna', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.8423, 'longitude': -103.7719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88123', 'place_name': 'Lingo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.7176, 'longitude': -103.1451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88125', 'place_name': 'Milnesand', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.605, 'longitude': -103.2782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88126', 'place_name': 'Pep', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.8362, 'longitude': -103.3355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88130', 'place_name': 'Portales', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 34.1799, 'longitude': -103.3363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88132', 'place_name': 'Rogers', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Roosevelt', 'locality_code': '41', 'latitude': 33.9216, 'longitude': -103.1898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87001', 'place_name': 'Algodones', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.389, 'longitude': -106.3517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87004', 'place_name': 'Bernalillo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.3285, 'longitude': -106.5309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87013', 'place_name': 'Cuba', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 36.0482, 'longitude': -107.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87018', 'place_name': 'Counselor', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 36.2092, 'longitude': -107.4578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87024', 'place_name': 'Jemez Pueblo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.6243, 'longitude': -106.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87025', 'place_name': 'Jemez Springs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.8927, 'longitude': -106.7714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87027', 'place_name': 'La Jara', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 36.1194, 'longitude': -106.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87041', 'place_name': 'Pena Blanca', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.5709, 'longitude': -106.3381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87043', 'place_name': 'Placitas', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.3092, 'longitude': -106.5293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87044', 'place_name': 'Ponderosa', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.66, 'longitude': -106.6675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87046', 'place_name': 'Regina', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 36.1842, 'longitude': -106.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87048', 'place_name': 'Corrales', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.2339, 'longitude': -106.62, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87052', 'place_name': 'Santo Domingo Pueblo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.5269, 'longitude': -106.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87053', 'place_name': 'San Ysidro', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.5634, 'longitude': -106.7706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87072', 'place_name': 'Cochiti Pueblo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.6089, 'longitude': -106.3518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87083', 'place_name': 'Cochiti Lake', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.6485, 'longitude': -106.3428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87124', 'place_name': 'Rio Rancho', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.2493, 'longitude': -106.6818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87144', 'place_name': 'Rio Rancho', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sandoval', 'locality_code': '43', 'latitude': 35.324, 'longitude': -106.7099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87037', 'place_name': 'Nageezi', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.1598, 'longitude': -107.7664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87364', 'place_name': 'Sheep Springs', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.142, 'longitude': -108.7064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87401', 'place_name': 'Farmington', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.7412, 'longitude': -108.1797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87402', 'place_name': 'Farmington', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.7685, 'longitude': -108.1478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87410', 'place_name': 'Aztec', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.8205, 'longitude': -108.011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87412', 'place_name': 'Blanco', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.7242, 'longitude': -107.8253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87413', 'place_name': 'Bloomfield', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.6955, 'longitude': -107.9784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87415', 'place_name': 'Flora Vista', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.8028, 'longitude': -108.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87416', 'place_name': 'Fruitland', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.6933, 'longitude': -108.4218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87417', 'place_name': 'Kirtland', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.741, 'longitude': -108.351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87418', 'place_name': 'La Plata', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.9576, 'longitude': -108.1792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87419', 'place_name': 'Navajo Dam', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.8689, 'longitude': -107.6528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87420', 'place_name': 'Shiprock', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.656, 'longitude': -108.7355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87421', 'place_name': 'Waterflow', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.7637, 'longitude': -108.5186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87455', 'place_name': 'Newcomb', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.2847, 'longitude': -108.7059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87461', 'place_name': 'Sanostee', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.4247, 'longitude': -108.8743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87499', 'place_name': 'Farmington', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Juan', 'locality_code': '45', 'latitude': 36.7745, 'longitude': -108.0692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87538', 'place_name': 'Ilfeld', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.4212, 'longitude': -105.5589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87552', 'place_name': 'Pecos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.571, 'longitude': -105.6701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87560', 'place_name': 'Ribera', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.3344, 'longitude': -105.4652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87562', 'place_name': 'Rowe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.4917, 'longitude': -105.6753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87565', 'place_name': 'San Jose', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.4569, 'longitude': -105.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87569', 'place_name': 'Serafina', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.3975, 'longitude': -105.3236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87573', 'place_name': 'Tererro', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.7727, 'longitude': -105.6713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87583', 'place_name': 'Villanueva', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.2667, 'longitude': -105.3608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87701', 'place_name': 'Las Vegas', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.5949, 'longitude': -105.2272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87731', 'place_name': 'Montezuma', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.6523, 'longitude': -105.2764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87742', 'place_name': 'Rociada', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.8226, 'longitude': -105.3147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87745', 'place_name': 'Sapello', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.762, 'longitude': -105.1077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88416', 'place_name': 'Conchas Dam', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.3786, 'longitude': -104.2052, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88421', 'place_name': 'Garita', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.3502, 'longitude': -104.4419, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88439', 'place_name': 'Trementina', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'San Miguel', 'locality_code': '47', 'latitude': 35.4563, 'longitude': -104.6796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87010', 'place_name': 'Cerrillos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.423, 'longitude': -106.1317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87015', 'place_name': 'Edgewood', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.0776, 'longitude': -106.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87056', 'place_name': 'Stanley', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.1295, 'longitude': -106.0283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87501', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.6975, 'longitude': -105.9821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87502', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.687, 'longitude': -105.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87503', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.687, 'longitude': -105.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87504', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.687, 'longitude': -105.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87505', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.6219, 'longitude': -105.8688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87506', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.8195, 'longitude': -105.9886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87507', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.6567, 'longitude': -106.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87508', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.5335, 'longitude': -105.926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87509', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.5212, 'longitude': -105.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87535', 'place_name': 'Glorieta', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.5288, 'longitude': -105.7477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87540', 'place_name': 'Lamy', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.4311, 'longitude': -105.9409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87567', 'place_name': 'Santa Cruz', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.986, 'longitude': -106.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87574', 'place_name': 'Tesuque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.7874, 'longitude': -105.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87592', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.5212, 'longitude': -105.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87594', 'place_name': 'Santa Fe', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Santa Fe', 'locality_code': '49', 'latitude': 35.5212, 'longitude': -105.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87654', 'place_name': 'Spaceport City', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 32.9903, 'longitude': -106.9697, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '87901', 'place_name': 'Truth Or Consequences', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 33.1606, 'longitude': -107.2669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87930', 'place_name': 'Arrey', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 32.8487, 'longitude': -107.3192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87931', 'place_name': 'Caballo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 32.9641, 'longitude': -107.4102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87933', 'place_name': 'Derry', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 32.7881, 'longitude': -107.2822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87935', 'place_name': 'Elephant Butte', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 33.209, 'longitude': -107.2212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87939', 'place_name': 'Monticello', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 33.397, 'longitude': -107.4509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87942', 'place_name': 'Williamsburg', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 33.1171, 'longitude': -107.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87943', 'place_name': 'Winston', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 33.3061, 'longitude': -107.6675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88042', 'place_name': 'Hillsboro', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Sierra', 'locality_code': '51', 'latitude': 32.9239, 'longitude': -107.6276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87011', 'place_name': 'Claunch', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.0646, 'longitude': -105.9496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87028', 'place_name': 'La Joya', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.3813, 'longitude': -106.815, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '87062', 'place_name': 'Veguita', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.485, 'longitude': -106.7591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87801', 'place_name': 'Socorro', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.0479, 'longitude': -106.8907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87823', 'place_name': 'Lemitar', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.156, 'longitude': -106.9044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87825', 'place_name': 'Magdalena', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.1114, 'longitude': -107.2409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87828', 'place_name': 'Polvadera', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.2059, 'longitude': -106.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87831', 'place_name': 'San Acacia', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 34.2283, 'longitude': -106.9049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87832', 'place_name': 'San Antonio', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Socorro', 'locality_code': '53', 'latitude': 33.819, 'longitude': -106.8285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87512', 'place_name': 'Amalia', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.942, 'longitude': -105.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87513', 'place_name': 'Arroyo Hondo', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.5796, 'longitude': -105.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87514', 'place_name': 'Arroyo Seco', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.52, 'longitude': -105.534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87517', 'place_name': 'Carson', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.3645, 'longitude': -105.7653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87519', 'place_name': 'Cerro', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.7539, 'longitude': -105.6128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87521', 'place_name': 'Chamisal', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.1311, 'longitude': -105.7385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87524', 'place_name': 'Costilla', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.9324, 'longitude': -105.6723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87525', 'place_name': 'Taos Ski Valley', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.596, 'longitude': -105.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87529', 'place_name': 'El Prado', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.4317, 'longitude': -105.5747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87543', 'place_name': 'Llano', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.14, 'longitude': -105.6817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87549', 'place_name': 'Ojo Caliente', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.3313, 'longitude': -106.0028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87553', 'place_name': 'Penasco', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.1763, 'longitude': -105.7105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87556', 'place_name': 'Questa', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.7039, 'longitude': -105.595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87557', 'place_name': 'Ranchos De Taos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.3357, 'longitude': -105.6086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87558', 'place_name': 'Red River', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.6659, 'longitude': -105.4694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87564', 'place_name': 'San Cristobal', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.6116, 'longitude': -105.636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87571', 'place_name': 'Taos', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.3953, 'longitude': -105.5847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87576', 'place_name': 'Trampas', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.1311, 'longitude': -105.7589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87577', 'place_name': 'Tres Piedras', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.647, 'longitude': -105.9672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87579', 'place_name': 'Vadito', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.1338, 'longitude': -105.5712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87580', 'place_name': 'Valdez', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Taos', 'locality_code': '55', 'latitude': 36.5701, 'longitude': -105.5658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87009', 'place_name': 'Cedarvale', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.3706, 'longitude': -105.702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87016', 'place_name': 'Estancia', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.77, 'longitude': -106.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87032', 'place_name': 'Mcintosh', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.8648, 'longitude': -106.0517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87035', 'place_name': 'Moriarty', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.9889, 'longitude': -106.0609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87036', 'place_name': 'Mountainair', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.5158, 'longitude': -106.2577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87061', 'place_name': 'Torreon', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.6948, 'longitude': -106.3247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87063', 'place_name': 'Willard', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.5754, 'longitude': -106.0307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87070', 'place_name': 'Clines Corners', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 35.0095, 'longitude': -105.6692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88321', 'place_name': 'Encino', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Torrance', 'locality_code': '57', 'latitude': 34.615, 'longitude': -105.4839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88410', 'place_name': 'Amistad', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 35.8983, 'longitude': -103.213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88414', 'place_name': 'Capulin', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 36.7785, 'longitude': -103.9986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88415', 'place_name': 'Clayton', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 36.4414, 'longitude': -103.1888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88418', 'place_name': 'Des Moines', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 36.7291, 'longitude': -103.8739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88419', 'place_name': 'Folsom', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 36.869, 'longitude': -103.8399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88422', 'place_name': 'Gladstone', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 36.3048, 'longitude': -103.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88424', 'place_name': 'Grenville', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 36.3698, 'longitude': -103.5055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88436', 'place_name': 'Sedan', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Union', 'locality_code': '59', 'latitude': 36.226, 'longitude': -103.1449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87002', 'place_name': 'Belen', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.6511, 'longitude': -106.6952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87006', 'place_name': 'Bosque', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.4996, 'longitude': -106.8038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87023', 'place_name': 'Jarales', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.592, 'longitude': -106.7611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87031', 'place_name': 'Los Lunas', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.7806, 'longitude': -106.7115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87034', 'place_name': 'Pueblo Of Acoma', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.8964, 'longitude': -107.5817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87042', 'place_name': 'Peralta', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.8332, 'longitude': -106.6872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87060', 'place_name': 'Tome', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.7426, 'longitude': -106.7328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '87068', 'place_name': 'Bosque Farms', 'state': 'New Mexico', 'state_ab': 'NM', 'county': 'Valencia', 'locality_code': '61', 'latitude': 34.8764, 'longitude': -106.6975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89406', 'place_name': 'Fallon', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Churchill', 'locality_code': '1', 'latitude': 39.4703, 'longitude': -118.7861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89407', 'place_name': 'Fallon', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Churchill', 'locality_code': '1', 'latitude': 39.4735, 'longitude': -118.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89496', 'place_name': 'Fallon', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Churchill', 'locality_code': '1', 'latitude': 39.4735, 'longitude': -118.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88901', 'place_name': 'The Lakes', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.3225, 'longitude': -114.8197, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '88905', 'place_name': 'The Lakes', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9279, 'longitude': -114.9721, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89002', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0008, 'longitude': -114.9588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89004', 'place_name': 'Blue Diamond', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0464, 'longitude': -115.4039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89005', 'place_name': 'Boulder City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9727, 'longitude': -114.8344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89006', 'place_name': 'Boulder City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9279, 'longitude': -114.9721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89007', 'place_name': 'Bunkerville', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.7684, 'longitude': -114.1281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89009', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9279, 'longitude': -114.9721, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89011', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1065, 'longitude': -114.9192, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89012', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0119, 'longitude': -115.0433, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89014', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0564, 'longitude': -115.078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89015', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0357, 'longitude': -114.9718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89016', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9279, 'longitude': -114.9721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89018', 'place_name': 'Indian Springs', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.5697, 'longitude': -115.6706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89019', 'place_name': 'Jean', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.7368, 'longitude': -115.5405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89021', 'place_name': 'Logandale', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.5935, 'longitude': -114.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89024', 'place_name': 'Mesquite', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.8101, 'longitude': -114.0722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89025', 'place_name': 'Moapa', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.6916, 'longitude': -114.6514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89026', 'place_name': 'Jean', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.7789, 'longitude': -115.3239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89027', 'place_name': 'Mesquite', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.8113, 'longitude': -114.1235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89028', 'place_name': 'Laughlin', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.1604, 'longitude': -114.7464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89029', 'place_name': 'Laughlin', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.1321, 'longitude': -114.6368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89030', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2115, 'longitude': -115.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89031', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2589, 'longitude': -115.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89032', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.218, 'longitude': -115.1709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89033', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2845, 'longitude': -115.1345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89034', 'place_name': 'Mesquite', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.809, 'longitude': -114.0591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89036', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1989, 'longitude': -115.1175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89037', 'place_name': 'Coyote Springs', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1579, 'longitude': -114.934, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89039', 'place_name': 'Cal Nev Ari', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.2522, 'longitude': -114.8714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89040', 'place_name': 'Overton', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.5703, 'longitude': -114.4732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89046', 'place_name': 'Searchlight', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.5132, 'longitude': -114.8866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89052', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9878, 'longitude': -115.1167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89053', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9279, 'longitude': -114.9721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89054', 'place_name': 'Sloan', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.935, 'longitude': -115.2058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89067', 'place_name': 'Moapa', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.6591, 'longitude': -114.6656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89070', 'place_name': 'Indian Springs', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.5697, 'longitude': -115.6706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89074', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0384, 'longitude': -115.0857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89077', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0397, 'longitude': -114.9819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89081', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2583, 'longitude': -115.1068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89084', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2815, 'longitude': -115.1482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89085', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.3097, 'longitude': -115.1981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89086', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2809, 'longitude': -115.1349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89087', 'place_name': 'North Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2204, 'longitude': -115.1458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89101', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1721, 'longitude': -115.1224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89102', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1433, 'longitude': -115.2004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89103', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1149, 'longitude': -115.2161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89104', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.152, 'longitude': -115.1092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89105', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.086, 'longitude': -115.1471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89106', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1847, 'longitude': -115.1617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89107', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1705, 'longitude': -115.2176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89108', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2044, 'longitude': -115.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89109', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.126, 'longitude': -115.1454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89110', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.173, 'longitude': -115.0669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89111', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89112', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1578, 'longitude': -115.0256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89113', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0854, 'longitude': -115.2566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89114', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0113, 'longitude': -115.1015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89115', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2158, 'longitude': -115.0671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89116', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89117', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1302, 'longitude': -115.2755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89118', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0811, 'longitude': -115.2169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89119', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1008, 'longitude': -115.1365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89120', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0914, 'longitude': -115.0885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89121', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1232, 'longitude': -115.0902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89122', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1205, 'longitude': -115.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89123', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0383, 'longitude': -115.1462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89124', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.4257, 'longitude': -115.4809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89125', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2235, 'longitude': -115.2655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89126', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89127', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89128', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1968, 'longitude': -115.2644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89129', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.245, 'longitude': -115.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89130', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2471, 'longitude': -115.221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89131', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2956, 'longitude': -115.2419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89132', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.019, 'longitude': -115.1519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89133', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89134', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2092, 'longitude': -115.2941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89135', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1378, 'longitude': -115.3261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89136', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1753, 'longitude': -115.1364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89137', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89138', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1666, 'longitude': -115.3613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89139', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0129, 'longitude': -115.2118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89140', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.086, 'longitude': -115.1471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89141', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0104, 'longitude': -115.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89142', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.148, 'longitude': -115.0404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89143', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.3223, 'longitude': -115.2932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89144', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1781, 'longitude': -115.3183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89145', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1693, 'longitude': -115.2828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89146', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1424, 'longitude': -115.2242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89147', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1128, 'longitude': -115.2801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89148', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0588, 'longitude': -115.3104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89149', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2765, 'longitude': -115.2885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89150', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89151', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89152', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89153', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89154', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89155', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89156', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2034, 'longitude': -115.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89157', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89158', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89159', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89160', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89161', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.0004, 'longitude': -115.3639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89162', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1725, 'longitude': -115.1414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89163', 'place_name': 'The Lakes', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89164', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89165', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.3302, 'longitude': -115.3257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89166', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.3265, 'longitude': -115.3398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89169', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.1234, 'longitude': -115.1429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89170', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89173', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89177', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89178', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9977, 'longitude': -115.2861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89179', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2542, 'longitude': -115.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89180', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89183', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 35.9959, 'longitude': -115.1576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89185', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89191', 'place_name': 'Nellis Afb', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.2395, 'longitude': -115.0257, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89193', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89195', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89199', 'place_name': 'Las Vegas', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Clark', 'locality_code': '3', 'latitude': 36.175, 'longitude': -115.1372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89410', 'place_name': 'Gardnerville', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 38.8703, 'longitude': -119.6115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89411', 'place_name': 'Genoa', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 39.0341, 'longitude': -119.8228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89413', 'place_name': 'Glenbrook', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 39.0509, 'longitude': -119.9428, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89423', 'place_name': 'Minden', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 39.0218, 'longitude': -119.7314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89448', 'place_name': 'Zephyr Cove', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 39.0204, 'longitude': -119.9114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89449', 'place_name': 'Stateline', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 38.9643, 'longitude': -119.9068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89460', 'place_name': 'Gardnerville', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 38.9166, 'longitude': -119.7272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89705', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Douglas', 'locality_code': '5', 'latitude': 39.0554, 'longitude': -119.8059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89801', 'place_name': 'Elko', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.9056, 'longitude': -115.5344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89802', 'place_name': 'Elko', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.8324, 'longitude': -115.7631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89803', 'place_name': 'Elko', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.8324, 'longitude': -115.7631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89815', 'place_name': 'Spring Creek', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.7519, 'longitude': -115.5956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89822', 'place_name': 'Carlin', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.7172, 'longitude': -116.1082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89823', 'place_name': 'Deeth', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.0655, 'longitude': -115.2748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89825', 'place_name': 'Jackpot', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.8882, 'longitude': -114.7233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89826', 'place_name': 'Jarbidge', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.8873, 'longitude': -115.3813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89828', 'place_name': 'Lamoille', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.7505, 'longitude': -115.3631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89830', 'place_name': 'Montello', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.2613, 'longitude': -114.1942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89831', 'place_name': 'Mountain City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.8385, 'longitude': -115.9654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89832', 'place_name': 'Owyhee', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.9477, 'longitude': -116.0987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89833', 'place_name': 'Ruby Valley', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.3995, 'longitude': -115.2312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89834', 'place_name': 'Tuscarora', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.3141, 'longitude': -116.2218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89835', 'place_name': 'Wells', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 41.1116, 'longitude': -114.9645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89883', 'place_name': 'West Wendover', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Elko', 'locality_code': '7', 'latitude': 40.7391, 'longitude': -114.0733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89010', 'place_name': 'Dyer', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Esmeralda', 'locality_code': '9', 'latitude': 37.7776, 'longitude': -118.084, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89013', 'place_name': 'Goldfield', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Esmeralda', 'locality_code': '9', 'latitude': 37.7085, 'longitude': -117.2356, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89047', 'place_name': 'Silverpeak', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Esmeralda', 'locality_code': '9', 'latitude': 37.7225, 'longitude': -117.7965, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89316', 'place_name': 'Eureka', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Eureka', 'locality_code': '11', 'latitude': 39.5897, 'longitude': -115.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89821', 'place_name': 'Crescent Valley', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Eureka', 'locality_code': '11', 'latitude': 40.4138, 'longitude': -116.5813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89404', 'place_name': 'Denio', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 41.9899, 'longitude': -118.6343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89414', 'place_name': 'Golconda', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 40.9532, 'longitude': -117.4893, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89421', 'place_name': 'Mc Dermitt', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 41.9708, 'longitude': -117.6737, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89425', 'place_name': 'Orovada', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 41.6654, 'longitude': -117.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89426', 'place_name': 'Paradise Valley', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 41.5057, 'longitude': -117.5728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89438', 'place_name': 'Valmy', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 40.7927, 'longitude': -117.1268, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89445', 'place_name': 'Winnemucca', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 40.9664, 'longitude': -117.7467, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89446', 'place_name': 'Winnemucca', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Humboldt', 'locality_code': '13', 'latitude': 41.0764, 'longitude': -117.7602, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89310', 'place_name': 'Austin', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lander', 'locality_code': '15', 'latitude': 39.508, 'longitude': -117.0811, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89820', 'place_name': 'Battle Mountain', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lander', 'locality_code': '15', 'latitude': 40.622, 'longitude': -116.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89001', 'place_name': 'Alamo', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lincoln', 'locality_code': '17', 'latitude': 37.3259, 'longitude': -115.308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89008', 'place_name': 'Caliente', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lincoln', 'locality_code': '17', 'latitude': 37.6128, 'longitude': -114.5097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89017', 'place_name': 'Hiko', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lincoln', 'locality_code': '17', 'latitude': 37.5926, 'longitude': -115.2262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89042', 'place_name': 'Panaca', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lincoln', 'locality_code': '17', 'latitude': 37.7905, 'longitude': -114.3894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89043', 'place_name': 'Pioche', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lincoln', 'locality_code': '17', 'latitude': 37.8981, 'longitude': -114.3968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89044', 'place_name': 'Henderson', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lincoln', 'locality_code': '17', 'latitude': 35.9025, 'longitude': -115.1789, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89403', 'place_name': 'Dayton', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lyon', 'locality_code': '19', 'latitude': 39.2806, 'longitude': -119.5287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89408', 'place_name': 'Fernley', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lyon', 'locality_code': '19', 'latitude': 39.6019, 'longitude': -119.235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89428', 'place_name': 'Silver City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lyon', 'locality_code': '19', 'latitude': 39.2652, 'longitude': -119.6388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89429', 'place_name': 'Silver Springs', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lyon', 'locality_code': '19', 'latitude': 39.38, 'longitude': -119.2705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89430', 'place_name': 'Smith', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lyon', 'locality_code': '19', 'latitude': 38.7733, 'longitude': -119.3029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89444', 'place_name': 'Wellington', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lyon', 'locality_code': '19', 'latitude': 38.8447, 'longitude': -119.3523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89447', 'place_name': 'Yerington', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Lyon', 'locality_code': '19', 'latitude': 38.9866, 'longitude': -119.1596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89415', 'place_name': 'Hawthorne', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Mineral', 'locality_code': '21', 'latitude': 38.5347, 'longitude': -118.6411, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89420', 'place_name': 'Luning', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Mineral', 'locality_code': '21', 'latitude': 38.5063, 'longitude': -118.1815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89422', 'place_name': 'Mina', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Mineral', 'locality_code': '21', 'latitude': 38.387, 'longitude': -118.1096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89427', 'place_name': 'Schurz', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Mineral', 'locality_code': '21', 'latitude': 38.9575, 'longitude': -118.7756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89003', 'place_name': 'Beatty', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 36.8199, 'longitude': -116.6094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89020', 'place_name': 'Amargosa Valley', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 36.539, 'longitude': -116.5496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89022', 'place_name': 'Manhattan', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 38.5388, 'longitude': -117.0734, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89023', 'place_name': 'Mercury', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 36.6605, 'longitude': -115.9945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89041', 'place_name': 'Pahrump', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 36.2083, 'longitude': -115.9839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89045', 'place_name': 'Round Mountain', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 38.711, 'longitude': -117.0676, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89048', 'place_name': 'Pahrump', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 36.1661, 'longitude': -116.0038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89049', 'place_name': 'Tonopah', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 38.0672, 'longitude': -117.2301, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89060', 'place_name': 'Pahrump', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 36.2645, 'longitude': -116.0393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89061', 'place_name': 'Pahrump', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 36.1184, 'longitude': -115.9407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89409', 'place_name': 'Gabbs', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Nye', 'locality_code': '23', 'latitude': 38.8688, 'longitude': -117.9221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89418', 'place_name': 'Imlay', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Pershing', 'locality_code': '27', 'latitude': 40.5484, 'longitude': -118.0344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89419', 'place_name': 'Lovelock', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Pershing', 'locality_code': '27', 'latitude': 40.1819, 'longitude': -118.4689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89440', 'place_name': 'Virginia City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Storey', 'locality_code': '29', 'latitude': 39.2965, 'longitude': -119.6587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89402', 'place_name': 'Crystal Bay', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.226, 'longitude': -120.0041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89405', 'place_name': 'Empire', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 40.6132, 'longitude': -119.3485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89412', 'place_name': 'Gerlach', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 40.6525, 'longitude': -119.3565, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89424', 'place_name': 'Nixon', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.8272, 'longitude': -119.3605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89431', 'place_name': 'Sparks', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5473, 'longitude': -119.7556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89432', 'place_name': 'Sparks', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5349, 'longitude': -119.7527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89433', 'place_name': 'Sun Valley', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5955, 'longitude': -119.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89434', 'place_name': 'Sparks', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5502, 'longitude': -119.7178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89435', 'place_name': 'Sparks', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5349, 'longitude': -119.7527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89436', 'place_name': 'Sparks', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.6269, 'longitude': -119.7081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89437', 'place_name': 'Sparks', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.6269, 'longitude': -119.7081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89439', 'place_name': 'Verdi', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5165, 'longitude': -119.9833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89441', 'place_name': 'Sparks', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.6582, 'longitude': -119.6954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89442', 'place_name': 'Wadsworth', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.6481, 'longitude': -119.2918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89450', 'place_name': 'Incline Village', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.2564, 'longitude': -119.9464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89451', 'place_name': 'Incline Village', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.2564, 'longitude': -119.9521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89452', 'place_name': 'Incline Village', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.2591, 'longitude': -119.9566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89501', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5268, 'longitude': -119.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89502', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.4972, 'longitude': -119.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89503', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5354, 'longitude': -119.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89504', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5296, 'longitude': -119.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89505', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5224, 'longitude': -119.8353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89506', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.6412, 'longitude': -119.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89507', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5423, 'longitude': -119.8164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89508', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.6781, 'longitude': -119.9383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89509', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.498, 'longitude': -119.8239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89510', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.7699, 'longitude': -119.6027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89511', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.4151, 'longitude': -119.7668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89512', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5483, 'longitude': -119.7957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89513', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.53, 'longitude': -119.81, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89515', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5296, 'longitude': -119.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89519', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.4814, 'longitude': -119.8591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89520', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5296, 'longitude': -119.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89521', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.3809, 'longitude': -119.6859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89523', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5249, 'longitude': -119.9031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89533', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5439, 'longitude': -119.9061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89555', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5246, 'longitude': -119.8125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89557', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5296, 'longitude': -119.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89570', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5296, 'longitude': -119.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89595', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5296, 'longitude': -119.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89599', 'place_name': 'Reno', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.5296, 'longitude': -119.8138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89704', 'place_name': 'Washoe Valley', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Washoe', 'locality_code': '31', 'latitude': 39.2669, 'longitude': -119.8174, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89301', 'place_name': 'Ely', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'White Pine', 'locality_code': '33', 'latitude': 39.2474, 'longitude': -114.8886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89311', 'place_name': 'Baker', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'White Pine', 'locality_code': '33', 'latitude': 38.9559, 'longitude': -114.2438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89314', 'place_name': 'Duckwater', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'White Pine', 'locality_code': '33', 'latitude': 38.9324, 'longitude': -115.7145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89315', 'place_name': 'Ely', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'White Pine', 'locality_code': '33', 'latitude': 39.3326, 'longitude': -114.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89317', 'place_name': 'Lund', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'White Pine', 'locality_code': '33', 'latitude': 38.8641, 'longitude': -115.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89318', 'place_name': 'Mc Gill', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'White Pine', 'locality_code': '33', 'latitude': 39.4034, 'longitude': -114.7791, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '89319', 'place_name': 'Ruth', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'White Pine', 'locality_code': '33', 'latitude': 39.2783, 'longitude': -114.9892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89701', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1507, 'longitude': -119.7459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89702', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1355, 'longitude': -119.7588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89703', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1704, 'longitude': -119.7782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89706', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.2025, 'longitude': -119.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89711', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1678, 'longitude': -119.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89712', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1678, 'longitude': -119.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89713', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1678, 'longitude': -119.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89714', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1678, 'longitude': -119.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '89721', 'place_name': 'Carson City', 'state': 'Nevada', 'state_ab': 'NV', 'county': 'Carson City (city)', 'locality_code': '510', 'latitude': 39.1678, 'longitude': -119.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12007', 'place_name': 'Alcove', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.4561, 'longitude': -73.9277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12009', 'place_name': 'Altamont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.7063, 'longitude': -74.0193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12023', 'place_name': 'Berne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6108, 'longitude': -74.1466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12041', 'place_name': 'Clarksville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.5759, 'longitude': -73.964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12045', 'place_name': 'Coeymans', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.4757, 'longitude': -73.7977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12046', 'place_name': 'Coeymans Hollow', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.4865, 'longitude': -73.9206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12047', 'place_name': 'Cohoes', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.7754, 'longitude': -73.7124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12054', 'place_name': 'Delmar', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6158, 'longitude': -73.8373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12055', 'place_name': 'Dormansville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6149, 'longitude': -73.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12059', 'place_name': 'East Berne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6191, 'longitude': -74.0555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12067', 'place_name': 'Feura Bush', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.555, 'longitude': -73.9237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12077', 'place_name': 'Glenmont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.5971, 'longitude': -73.7959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12084', 'place_name': 'Guilderland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6973, 'longitude': -73.8975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12085', 'place_name': 'Guilderland Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.702, 'longitude': -73.9662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12107', 'place_name': 'Knox', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.66, 'longitude': -74.1168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12110', 'place_name': 'Latham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.7462, 'longitude': -73.763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12120', 'place_name': 'Medusa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.4515, 'longitude': -74.1315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12128', 'place_name': 'Newtonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.725, 'longitude': -73.7643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12143', 'place_name': 'Ravena', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.4754, 'longitude': -73.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12147', 'place_name': 'Rensselaerville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.5133, 'longitude': -74.1474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12158', 'place_name': 'Selkirk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.5486, 'longitude': -73.8129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12159', 'place_name': 'Slingerlands', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6485, 'longitude': -73.8711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12161', 'place_name': 'South Bethlehem', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.5317, 'longitude': -73.8473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12183', 'place_name': 'Troy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.746, 'longitude': -73.6943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12186', 'place_name': 'Voorheesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6431, 'longitude': -73.9448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12189', 'place_name': 'Watervliet', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.7298, 'longitude': -73.7123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12193', 'place_name': 'Westerlo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.5156, 'longitude': -74.0394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12201', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12202', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6413, 'longitude': -73.7641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12203', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.7003, 'longitude': -73.8575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12204', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6847, 'longitude': -73.7354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12205', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.7198, 'longitude': -73.8207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12206', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6683, 'longitude': -73.7744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12207', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12208', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.656, 'longitude': -73.7964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12209', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6417, 'longitude': -73.7854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12210', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6568, 'longitude': -73.7605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12211', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.713, 'longitude': -73.7739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12212', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.7168, 'longitude': -73.8104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12214', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12220', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12222', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6853, 'longitude': -73.8253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12223', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12224', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12225', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12226', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12227', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12228', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12229', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12230', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12231', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12232', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12233', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12234', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12235', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12236', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12237', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12238', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12239', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12240', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12241', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12242', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12243', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12244', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12245', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12246', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6471, 'longitude': -73.7503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12247', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12248', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12249', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12250', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12252', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12255', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12256', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12257', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12260', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12261', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12288', 'place_name': 'Albany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.6526, 'longitude': -73.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12469', 'place_name': 'Preston Hollow', 'state': 'New York', 'state_ab': 'NY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.4563, 'longitude': -74.242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14029', 'place_name': 'Centerville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.4743, 'longitude': -78.2474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14707', 'place_name': 'Allentown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.0737, 'longitude': -78.0594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14708', 'place_name': 'Alma', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.0126, 'longitude': -78.0578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14709', 'place_name': 'Angelica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.3263, 'longitude': -77.9947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14711', 'place_name': 'Belfast', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.32, 'longitude': -78.0943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14714', 'place_name': 'Black Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.2855, 'longitude': -78.2312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14715', 'place_name': 'Bolivar', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.0704, 'longitude': -78.1448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14717', 'place_name': 'Caneadea', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.364, 'longitude': -78.184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14721', 'place_name': 'Ceres', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.0137, 'longitude': -78.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14727', 'place_name': 'Cuba', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.1882, 'longitude': -78.2751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14735', 'place_name': 'Fillmore', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.4508, 'longitude': -78.1043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14739', 'place_name': 'Friendship', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.1907, 'longitude': -78.1359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14744', 'place_name': 'Houghton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.4228, 'longitude': -78.2063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14745', 'place_name': 'Hume', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.4777, 'longitude': -78.1403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14754', 'place_name': 'Little Genesee', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.0319, 'longitude': -78.2097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14774', 'place_name': 'Richburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.0884, 'longitude': -78.1533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14777', 'place_name': 'Rushford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.3923, 'longitude': -78.2536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14786', 'place_name': 'West Clarksville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.1227, 'longitude': -78.2213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14802', 'place_name': 'Alfred', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.2534, 'longitude': -77.7893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14803', 'place_name': 'Alfred Station', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.2558, 'longitude': -77.7781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14804', 'place_name': 'Almond', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.316, 'longitude': -77.778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14806', 'place_name': 'Andover', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.1575, 'longitude': -77.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14813', 'place_name': 'Belmont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.2334, 'longitude': -78.011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14822', 'place_name': 'Canaseraga', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.4585, 'longitude': -77.7954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14880', 'place_name': 'Scio', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.1697, 'longitude': -77.99, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14884', 'place_name': 'Swain', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.4773, 'longitude': -77.889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14895', 'place_name': 'Wellsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.1108, 'longitude': -77.9419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14897', 'place_name': 'Whitesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Allegany', 'locality_code': '3', 'latitude': 42.0456, 'longitude': -77.8106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10451', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8222, 'longitude': -73.9217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10452', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8376, 'longitude': -73.9216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10453', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.852, 'longitude': -73.9129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10454', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8085, 'longitude': -73.9198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10455', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8153, 'longitude': -73.9072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10456', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8316, 'longitude': -73.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10457', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8486, 'longitude': -73.8999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10458', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8633, 'longitude': -73.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10459', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8247, 'longitude': -73.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10460', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8409, 'longitude': -73.8794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10461', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8465, 'longitude': -73.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10462', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8434, 'longitude': -73.8602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10463', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8798, 'longitude': -73.9067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10464', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8469, 'longitude': -73.7874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10465', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8261, 'longitude': -73.8196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10466', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8904, 'longitude': -73.8503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10467', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8737, 'longitude': -73.8712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10468', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8662, 'longitude': -73.9003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10469', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8702, 'longitude': -73.8495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10470', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.9, 'longitude': -73.8622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10471', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.9011, 'longitude': -73.9053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10472', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8295, 'longitude': -73.8716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10473', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8194, 'longitude': -73.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10474', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8139, 'longitude': -73.8841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10475', 'place_name': 'Bronx', 'state': 'New York', 'state_ab': 'NY', 'county': 'Bronx', 'locality_code': '5', 'latitude': 40.8729, 'longitude': -73.8278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13737', 'place_name': 'Bible School Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0805, 'longitude': -76.0973, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13744', 'place_name': 'Castle Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.2568, 'longitude': -75.9087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13745', 'place_name': 'Chenango Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1738, 'longitude': -75.8728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13746', 'place_name': 'Chenango Forks', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.2778, 'longitude': -75.8462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13748', 'place_name': 'Conklin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0454, 'longitude': -75.8076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13749', 'place_name': 'Corbettsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0156, 'longitude': -75.7905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13754', 'place_name': 'Deposit', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0666, 'longitude': -75.4287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13760', 'place_name': 'Endicott', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1506, 'longitude': -76.0551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13761', 'place_name': 'Endicott', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0984, 'longitude': -76.0494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13762', 'place_name': 'Endwell', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1129, 'longitude': -76.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13763', 'place_name': 'Endicott', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0984, 'longitude': -76.0494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13777', 'place_name': 'Glen Aubrey', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.2573, 'longitude': -75.9805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13787', 'place_name': 'Harpursville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1823, 'longitude': -75.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13790', 'place_name': 'Johnson City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1267, 'longitude': -75.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13794', 'place_name': 'Killawog', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.4006, 'longitude': -76.0208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13795', 'place_name': 'Kirkwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0695, 'longitude': -75.7967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13797', 'place_name': 'Lisle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.3409, 'longitude': -76.0302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13802', 'place_name': 'Maine', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.2538, 'longitude': -76.0464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13813', 'place_name': 'Nineveh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1625, 'longitude': -75.5484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13826', 'place_name': 'Ouaquaga', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1262, 'longitude': -75.6471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13833', 'place_name': 'Port Crane', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1958, 'longitude': -75.7591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13848', 'place_name': 'Tunnel', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.2147, 'longitude': -75.7277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13850', 'place_name': 'Vestal', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0771, 'longitude': -76.0118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13851', 'place_name': 'Vestal', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0851, 'longitude': -76.0538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13862', 'place_name': 'Whitney Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.3384, 'longitude': -75.9522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13865', 'place_name': 'Windsor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0759, 'longitude': -75.6405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13901', 'place_name': 'Binghamton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1463, 'longitude': -75.8865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13902', 'place_name': 'Binghamton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1054, 'longitude': -75.8876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13903', 'place_name': 'Binghamton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.0811, 'longitude': -75.8977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13904', 'place_name': 'Binghamton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1171, 'longitude': -75.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13905', 'place_name': 'Binghamton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Broome', 'locality_code': '7', 'latitude': 42.1151, 'longitude': -75.9309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14041', 'place_name': 'Dayton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4086, 'longitude': -78.9844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14042', 'place_name': 'Delevan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4926, 'longitude': -78.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14060', 'place_name': 'Farmersville Station', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4276, 'longitude': -78.3608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14065', 'place_name': 'Freedom', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4897, 'longitude': -78.3501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14070', 'place_name': 'Gowanda', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4712, 'longitude': -78.9339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14101', 'place_name': 'Machias', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4083, 'longitude': -78.5059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14129', 'place_name': 'Perrysburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4723, 'longitude': -78.9981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14133', 'place_name': 'Sandusky', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4891, 'longitude': -78.367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14138', 'place_name': 'South Dayton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.3718, 'longitude': -79.0501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14168', 'place_name': 'Versailles', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.5189, 'longitude': -78.9959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14171', 'place_name': 'West Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.4315, 'longitude': -78.628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14173', 'place_name': 'Yorkshire', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.5247, 'longitude': -78.4755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14706', 'place_name': 'Allegany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.0918, 'longitude': -78.4999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14719', 'place_name': 'Cattaraugus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.3333, 'longitude': -78.8885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14726', 'place_name': 'Conewango Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.2625, 'longitude': -79.022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14729', 'place_name': 'East Otto', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.3971, 'longitude': -78.7432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14730', 'place_name': 'East Randolph', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.1747, 'longitude': -78.9473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14731', 'place_name': 'Ellicottville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.2959, 'longitude': -78.6606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14737', 'place_name': 'Franklinville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.3388, 'longitude': -78.44, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14741', 'place_name': 'Great Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.2083, 'longitude': -78.6208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14743', 'place_name': 'Hinsdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.1979, 'longitude': -78.4159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14748', 'place_name': 'Kill Buck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.145, 'longitude': -78.6466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14751', 'place_name': 'Leon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.2983, 'longitude': -79.0062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14753', 'place_name': 'Limestone', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.0639, 'longitude': -78.632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14755', 'place_name': 'Little Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.2541, 'longitude': -78.8093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14760', 'place_name': 'Olean', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.0821, 'longitude': -78.426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14766', 'place_name': 'Otto', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.3575, 'longitude': -78.8073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14770', 'place_name': 'Portville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.0273, 'longitude': -78.3314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14772', 'place_name': 'Randolph', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.1631, 'longitude': -78.96, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14778', 'place_name': 'Saint Bonaventure', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.0803, 'longitude': -78.475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14779', 'place_name': 'Salamanca', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.1604, 'longitude': -78.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14783', 'place_name': 'Steamburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.082, 'longitude': -78.9177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14788', 'place_name': 'Westons Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cattaraugus', 'locality_code': '9', 'latitude': 42.0621, 'longitude': -78.378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13021', 'place_name': 'Auburn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.93, 'longitude': -76.5626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13022', 'place_name': 'Auburn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.9317, 'longitude': -76.5661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13024', 'place_name': 'Auburn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.9317, 'longitude': -76.5661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13026', 'place_name': 'Aurora', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.7472, 'longitude': -76.6775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13033', 'place_name': 'Cato', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 43.1794, 'longitude': -76.5648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13034', 'place_name': 'Cayuga', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.9142, 'longitude': -76.7024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13071', 'place_name': 'Genoa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.6746, 'longitude': -76.5418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13081', 'place_name': 'King Ferry', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.6635, 'longitude': -76.6216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13092', 'place_name': 'Locke', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.6558, 'longitude': -76.4154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13111', 'place_name': 'Martville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 43.2661, 'longitude': -76.6289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13113', 'place_name': 'Meridian', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 43.1656, 'longitude': -76.5369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13117', 'place_name': 'Montezuma', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 43.0101, 'longitude': -76.7033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13118', 'place_name': 'Moravia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.7355, 'longitude': -76.399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13139', 'place_name': 'Poplar Ridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.7421, 'longitude': -76.6285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13140', 'place_name': 'Port Byron', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 43.0427, 'longitude': -76.6449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13147', 'place_name': 'Scipio Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.7708, 'longitude': -76.5862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13156', 'place_name': 'Sterling', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 43.3296, 'longitude': -76.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13160', 'place_name': 'Union Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 42.8335, 'longitude': -76.674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13166', 'place_name': 'Weedsport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cayuga', 'locality_code': '11', 'latitude': 43.0489, 'longitude': -76.5425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14048', 'place_name': 'Dunkirk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.4877, 'longitude': -79.3283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14062', 'place_name': 'Forestville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.4482, 'longitude': -79.1607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14063', 'place_name': 'Fredonia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.4333, 'longitude': -79.3339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14081', 'place_name': 'Irving', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.5739, 'longitude': -79.0596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14135', 'place_name': 'Sheridan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.489, 'longitude': -79.239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14136', 'place_name': 'Silver Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.5357, 'longitude': -79.1628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14166', 'place_name': 'Van Buren Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.4511, 'longitude': -79.4154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14701', 'place_name': 'Jamestown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.0928, 'longitude': -79.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14702', 'place_name': 'Jamestown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.097, 'longitude': -79.2353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14710', 'place_name': 'Ashville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1084, 'longitude': -79.4056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14712', 'place_name': 'Bemus Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1513, 'longitude': -79.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14716', 'place_name': 'Brocton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.394, 'longitude': -79.4344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14718', 'place_name': 'Cassadaga', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.3504, 'longitude': -79.2993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14720', 'place_name': 'Celoron', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1095, 'longitude': -79.2831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14722', 'place_name': 'Chautauqua', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.2098, 'longitude': -79.4667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14723', 'place_name': 'Cherry Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.3127, 'longitude': -79.1203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14724', 'place_name': 'Clymer', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.0557, 'longitude': -79.6685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14728', 'place_name': 'Dewittville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.2394, 'longitude': -79.4193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14732', 'place_name': 'Ellington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.2291, 'longitude': -79.1135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14733', 'place_name': 'Falconer', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1239, 'longitude': -79.1895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14736', 'place_name': 'Findley Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1204, 'longitude': -79.7349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14738', 'place_name': 'Frewsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.0528, 'longitude': -79.1318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14740', 'place_name': 'Gerry', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.2147, 'longitude': -79.1649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14742', 'place_name': 'Greenhurst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1205, 'longitude': -79.3096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14747', 'place_name': 'Kennedy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1508, 'longitude': -79.0964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14750', 'place_name': 'Lakewood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.0973, 'longitude': -79.3291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14752', 'place_name': 'Lily Dale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.3524, 'longitude': -79.3235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14756', 'place_name': 'Maple Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1967, 'longitude': -79.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14757', 'place_name': 'Mayville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.2409, 'longitude': -79.4963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14758', 'place_name': 'Niobe', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.0126, 'longitude': -79.4495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14767', 'place_name': 'Panama', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.057, 'longitude': -79.4815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14769', 'place_name': 'Portland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.3858, 'longitude': -79.4589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14775', 'place_name': 'Ripley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.2482, 'longitude': -79.7121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14781', 'place_name': 'Sherman', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1631, 'longitude': -79.5857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14782', 'place_name': 'Sinclairville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.2455, 'longitude': -79.2673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14784', 'place_name': 'Stockton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.3182, 'longitude': -79.3758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14785', 'place_name': 'Stow', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.1557, 'longitude': -79.4122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14787', 'place_name': 'Westfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chautauqua', 'locality_code': '13', 'latitude': 42.322, 'longitude': -79.5726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14814', 'place_name': 'Big Flats', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.1455, 'longitude': -76.9527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14816', 'place_name': 'Breesport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.1939, 'longitude': -76.7361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14825', 'place_name': 'Chemung', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.0392, 'longitude': -76.6202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14838', 'place_name': 'Erin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.1859, 'longitude': -76.6819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14845', 'place_name': 'Horseheads', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.1805, 'longitude': -76.8345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14861', 'place_name': 'Lowman', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.0694, 'longitude': -76.693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14864', 'place_name': 'Millport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.2581, 'longitude': -76.8392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14871', 'place_name': 'Pine City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.0419, 'longitude': -76.8815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14872', 'place_name': 'Pine Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.2348, 'longitude': -76.8652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14889', 'place_name': 'Van Etten', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.2085, 'longitude': -76.5717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14894', 'place_name': 'Wellsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.0273, 'longitude': -76.7723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14901', 'place_name': 'Elmira', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.1008, 'longitude': -76.812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14902', 'place_name': 'Elmira', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.1473, 'longitude': -76.7509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14903', 'place_name': 'Elmira', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.1198, 'longitude': -76.8877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14904', 'place_name': 'Elmira', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.0729, 'longitude': -76.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14905', 'place_name': 'Elmira', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chemung', 'locality_code': '15', 'latitude': 42.0869, 'longitude': -76.8397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13124', 'place_name': 'North Pitcher', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6372, 'longitude': -75.8164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13136', 'place_name': 'Pitcher', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.5969, 'longitude': -75.8465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13155', 'place_name': 'South Otselic', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6626, 'longitude': -75.7669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13332', 'place_name': 'Earlville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.7197, 'longitude': -75.5589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13411', 'place_name': 'New Berlin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6224, 'longitude': -75.3474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13460', 'place_name': 'Sherburne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6859, 'longitude': -75.483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13464', 'place_name': 'Smyrna', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6896, 'longitude': -75.6121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13730', 'place_name': 'Afton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.2417, 'longitude': -75.5366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13733', 'place_name': 'Bainbridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.312, 'longitude': -75.4894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13758', 'place_name': 'East Pharsalia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.5835, 'longitude': -75.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13778', 'place_name': 'Greene', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.3401, 'longitude': -75.7342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13780', 'place_name': 'Guilford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.4269, 'longitude': -75.4823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13801', 'place_name': 'Mc Donough', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.5068, 'longitude': -75.7623, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13809', 'place_name': 'Mount Upton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.4081, 'longitude': -75.4003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13814', 'place_name': 'North Norwich', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6036, 'longitude': -75.5282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13815', 'place_name': 'Norwich', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.5414, 'longitude': -75.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13830', 'place_name': 'Oxford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.4379, 'longitude': -75.5673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13832', 'place_name': 'Plymouth', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6336, 'longitude': -75.6172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13841', 'place_name': 'Smithville Flats', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.3989, 'longitude': -75.8237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13843', 'place_name': 'South New Berlin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.5295, 'longitude': -75.3852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13844', 'place_name': 'South Plymouth', 'state': 'New York', 'state_ab': 'NY', 'county': 'Chenango', 'locality_code': '17', 'latitude': 42.6053, 'longitude': -75.633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12901', 'place_name': 'Plattsburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.6927, 'longitude': -73.466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12903', 'place_name': 'Plattsburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.6854, 'longitude': -73.4474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12910', 'place_name': 'Altona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.8816, 'longitude': -73.6408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12911', 'place_name': 'Keeseville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.505, 'longitude': -73.4801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12912', 'place_name': 'Au Sable Forks', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.4499, 'longitude': -73.6857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12918', 'place_name': 'Cadyville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.6862, 'longitude': -73.6702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12919', 'place_name': 'Champlain', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.9773, 'longitude': -73.4466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12921', 'place_name': 'Chazy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.8884, 'longitude': -73.4501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12923', 'place_name': 'Churubusco', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.9432, 'longitude': -73.9355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12924', 'place_name': 'Keeseville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.4777, 'longitude': -73.5843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12929', 'place_name': 'Dannemora', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.72, 'longitude': -73.7192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12933', 'place_name': 'Ellenburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.8939, 'longitude': -73.8365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12934', 'place_name': 'Ellenburg Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.8444, 'longitude': -73.8685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12935', 'place_name': 'Ellenburg Depot', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.9163, 'longitude': -73.7876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12952', 'place_name': 'Lyon Mountain', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.7255, 'longitude': -73.9195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12955', 'place_name': 'Lyon Mountain', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.8043, 'longitude': -73.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12958', 'place_name': 'Mooers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.9592, 'longitude': -73.5834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12959', 'place_name': 'Mooers Forks', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.9602, 'longitude': -73.673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12962', 'place_name': 'Morrisonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.6894, 'longitude': -73.5772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12972', 'place_name': 'Peru', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.5851, 'longitude': -73.5293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12978', 'place_name': 'Redford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.6164, 'longitude': -73.8087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12979', 'place_name': 'Rouses Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.9884, 'longitude': -73.3691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12981', 'place_name': 'Saranac', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.7032, 'longitude': -73.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12985', 'place_name': 'Schuyler Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.6287, 'longitude': -73.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12992', 'place_name': 'West Chazy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Clinton', 'locality_code': '19', 'latitude': 44.797, 'longitude': -73.5112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12017', 'place_name': 'Austerlitz', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.3223, 'longitude': -73.455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12029', 'place_name': 'Canaan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.4132, 'longitude': -73.4159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12037', 'place_name': 'Chatham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.3496, 'longitude': -73.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12050', 'place_name': 'Columbiaville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.3172, 'longitude': -73.7486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12060', 'place_name': 'East Chatham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.433, 'longitude': -73.4903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12075', 'place_name': 'Ghent', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.3036, 'longitude': -73.6486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12106', 'place_name': 'Kinderhook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.3767, 'longitude': -73.7183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12115', 'place_name': 'Malden Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.4725, 'longitude': -73.5807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12125', 'place_name': 'New Lebanon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.4759, 'longitude': -73.3773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12130', 'place_name': 'Niverville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.44, 'longitude': -73.6663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12132', 'place_name': 'North Chatham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.4705, 'longitude': -73.63, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12136', 'place_name': 'Old Chatham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.4357, 'longitude': -73.5545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12165', 'place_name': 'Spencertown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.3091, 'longitude': -73.5008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12172', 'place_name': 'Stottville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.2857, 'longitude': -73.7335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12173', 'place_name': 'Stuyvesant', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.3596, 'longitude': -73.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12174', 'place_name': 'Stuyvesant Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.344, 'longitude': -73.7348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12184', 'place_name': 'Valatie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.4321, 'longitude': -73.6683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12195', 'place_name': 'West Lebanon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.4862, 'longitude': -73.4662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12502', 'place_name': 'Ancram', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.0851, 'longitude': -73.6424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12503', 'place_name': 'Ancramdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.0381, 'longitude': -73.5819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12513', 'place_name': 'Claverack', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.2251, 'longitude': -73.7346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12516', 'place_name': 'Copake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.1113, 'longitude': -73.5526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12517', 'place_name': 'Copake Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.1367, 'longitude': -73.5108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12521', 'place_name': 'Craryville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.176, 'longitude': -73.6571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12523', 'place_name': 'Elizaville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.0902, 'longitude': -73.7818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12526', 'place_name': 'Germantown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.1219, 'longitude': -73.8625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12529', 'place_name': 'Hillsdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.1868, 'longitude': -73.5483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12530', 'place_name': 'Hollowville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.2054, 'longitude': -73.6912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12534', 'place_name': 'Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.247, 'longitude': -73.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12541', 'place_name': 'Livingston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.1421, 'longitude': -73.7574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12544', 'place_name': 'Mellenville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.2596, 'longitude': -73.668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12565', 'place_name': 'Philmont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Columbia', 'locality_code': '21', 'latitude': 42.2485, 'longitude': -73.6463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13040', 'place_name': 'Cincinnatus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.5385, 'longitude': -75.903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13045', 'place_name': 'Cortland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.5952, 'longitude': -76.1857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13056', 'place_name': 'East Homer', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.6772, 'longitude': -76.1052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13077', 'place_name': 'Homer', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.6726, 'longitude': -76.1878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13087', 'place_name': 'Little York', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.707, 'longitude': -76.1561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13101', 'place_name': 'Mc Graw', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.5948, 'longitude': -76.082, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13141', 'place_name': 'Preble', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.795, 'longitude': -76.2141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13158', 'place_name': 'Truxton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.7085, 'longitude': -76.0189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13738', 'place_name': 'Blodgett Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.5673, 'longitude': -76.1238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13784', 'place_name': 'Harford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.4262, 'longitude': -76.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13803', 'place_name': 'Marathon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.4527, 'longitude': -76.0395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13863', 'place_name': 'Willet', 'state': 'New York', 'state_ab': 'NY', 'county': 'Cortland', 'locality_code': '23', 'latitude': 42.452, 'longitude': -75.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12167', 'place_name': 'Stamford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.4174, 'longitude': -74.6098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12406', 'place_name': 'Arkville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.1417, 'longitude': -74.5721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12421', 'place_name': 'Denver', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2522, 'longitude': -74.5407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12430', 'place_name': 'Fleischmanns', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.1772, 'longitude': -74.5473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12434', 'place_name': 'Grand Gorge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.362, 'longitude': -74.494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12438', 'place_name': 'Halcottsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2079, 'longitude': -74.6012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12455', 'place_name': 'Margaretville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.1852, 'longitude': -74.6178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12459', 'place_name': 'New Kingston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2094, 'longitude': -74.6837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12474', 'place_name': 'Roxbury', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2957, 'longitude': -74.5631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13731', 'place_name': 'Andes', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.1569, 'longitude': -74.7887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13739', 'place_name': 'Bloomville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.3522, 'longitude': -74.8071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13740', 'place_name': 'Bovina Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2709, 'longitude': -74.7661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13750', 'place_name': 'Davenport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.4711, 'longitude': -74.8357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13751', 'place_name': 'Davenport Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.4508, 'longitude': -74.9013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13752', 'place_name': 'Delancey', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2884, 'longitude': -75.1051, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13753', 'place_name': 'Delhi', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2937, 'longitude': -74.9207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13755', 'place_name': 'Downsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.0716, 'longitude': -75.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13756', 'place_name': 'East Branch', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.0039, 'longitude': -75.1226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13757', 'place_name': 'East Meredith', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.4101, 'longitude': -74.8987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13774', 'place_name': 'Fishs Eddy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 41.9654, 'longitude': -75.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13775', 'place_name': 'Franklin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.3421, 'longitude': -75.1485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13782', 'place_name': 'Hamden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.1787, 'longitude': -74.9984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13783', 'place_name': 'Hancock', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 41.9914, 'longitude': -75.2647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13786', 'place_name': 'Harpersfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.4499, 'longitude': -74.6871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13788', 'place_name': 'Hobart', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.3594, 'longitude': -74.6759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13804', 'place_name': 'Masonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2102, 'longitude': -75.3739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13806', 'place_name': 'Meridale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.3734, 'longitude': -74.965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13838', 'place_name': 'Sidney', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.3074, 'longitude': -75.3908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13839', 'place_name': 'Sidney Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2441, 'longitude': -75.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13842', 'place_name': 'South Kortright', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.377, 'longitude': -74.7259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13846', 'place_name': 'Treadwell', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.363, 'longitude': -75.0588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13847', 'place_name': 'Trout Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.2037, 'longitude': -75.2793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13856', 'place_name': 'Walton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.1756, 'longitude': -75.1532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13860', 'place_name': 'West Davenport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Delaware', 'locality_code': '25', 'latitude': 42.4459, 'longitude': -74.9632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12501', 'place_name': 'Amenia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.8447, 'longitude': -73.5542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12504', 'place_name': 'Annandale On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 42.0129, 'longitude': -73.9082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12506', 'place_name': 'Bangall', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.8756, 'longitude': -73.6912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12507', 'place_name': 'Barrytown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 42.0005, 'longitude': -73.9199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12508', 'place_name': 'Beacon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5097, 'longitude': -73.9634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12510', 'place_name': 'Billings', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.6712, 'longitude': -73.7632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12511', 'place_name': 'Castle Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5462, 'longitude': -73.9596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12512', 'place_name': 'Chelsea', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5528, 'longitude': -73.9682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12514', 'place_name': 'Clinton Corners', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.8693, 'longitude': -73.7659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12522', 'place_name': 'Dover Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7351, 'longitude': -73.587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12524', 'place_name': 'Fishkill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5404, 'longitude': -73.8979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12527', 'place_name': 'Glenham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5202, 'longitude': -73.9333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12531', 'place_name': 'Holmes', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5325, 'longitude': -73.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12533', 'place_name': 'Hopewell Junction', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5603, 'longitude': -73.7939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12537', 'place_name': 'Hughsonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5824, 'longitude': -73.9363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12538', 'place_name': 'Hyde Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7887, 'longitude': -73.9063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12540', 'place_name': 'Lagrangeville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.6615, 'longitude': -73.745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12545', 'place_name': 'Millbrook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7803, 'longitude': -73.6885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12546', 'place_name': 'Millerton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.9536, 'longitude': -73.5287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12564', 'place_name': 'Pawling', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5749, 'longitude': -73.5948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12567', 'place_name': 'Pine Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.9896, 'longitude': -73.6602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12569', 'place_name': 'Pleasant Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.747, 'longitude': -73.8143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12570', 'place_name': 'Poughquag', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.6194, 'longitude': -73.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12571', 'place_name': 'Red Hook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 42.0064, 'longitude': -73.8546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12572', 'place_name': 'Rhinebeck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.9272, 'longitude': -73.8888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12574', 'place_name': 'Rhinecliff', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.9151, 'longitude': -73.9517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12578', 'place_name': 'Salt Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.805, 'longitude': -73.8013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12580', 'place_name': 'Staatsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.8502, 'longitude': -73.8988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12581', 'place_name': 'Stanfordville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.8877, 'longitude': -73.6945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12582', 'place_name': 'Stormville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.5512, 'longitude': -73.7255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12583', 'place_name': 'Tivoli', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 42.0579, 'longitude': -73.9025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12585', 'place_name': 'Verbank', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7227, 'longitude': -73.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12590', 'place_name': 'Wappingers Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.595, 'longitude': -73.8876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12592', 'place_name': 'Wassaic', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7759, 'longitude': -73.5544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12594', 'place_name': 'Wingdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.6538, 'longitude': -73.5556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12601', 'place_name': 'Poughkeepsie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7035, 'longitude': -73.9117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12602', 'place_name': 'Poughkeepsie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7599, 'longitude': -73.7437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12603', 'place_name': 'Poughkeepsie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.6907, 'longitude': -73.8621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12604', 'place_name': 'Poughkeepsie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Dutchess', 'locality_code': '27', 'latitude': 41.7599, 'longitude': -73.7437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14001', 'place_name': 'Akron', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.0249, 'longitude': -78.5084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14004', 'place_name': 'Alden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8984, 'longitude': -78.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14006', 'place_name': 'Angola', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6366, 'longitude': -79.0497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14010', 'place_name': 'Athol Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14025', 'place_name': 'Boston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6314, 'longitude': -78.7391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14026', 'place_name': 'Bowmansville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.941, 'longitude': -78.688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14027', 'place_name': 'Brant', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5707, 'longitude': -79.0308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14030', 'place_name': 'Chaffee', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5605, 'longitude': -78.5025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14031', 'place_name': 'Clarence', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.981, 'longitude': -78.6162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14032', 'place_name': 'Clarence Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.0362, 'longitude': -78.639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14033', 'place_name': 'Colden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6551, 'longitude': -78.6921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14034', 'place_name': 'Collins', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5001, 'longitude': -78.893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14035', 'place_name': 'Collins Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.4906, 'longitude': -78.8499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14038', 'place_name': 'Crittenden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9473, 'longitude': -78.4744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14043', 'place_name': 'Depew', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.905, 'longitude': -78.7041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14047', 'place_name': 'Derby', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6974, 'longitude': -78.9834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14051', 'place_name': 'East Amherst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.0429, 'longitude': -78.6988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14052', 'place_name': 'East Aurora', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7701, 'longitude': -78.602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14055', 'place_name': 'East Concord', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5466, 'longitude': -78.611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14057', 'place_name': 'Eden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6506, 'longitude': -78.8781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14059', 'place_name': 'Elma', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.834, 'longitude': -78.6343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14061', 'place_name': 'Farnham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5946, 'longitude': -79.084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14068', 'place_name': 'Getzville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.024, 'longitude': -78.7532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14069', 'place_name': 'Glenwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6001, 'longitude': -78.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14072', 'place_name': 'Grand Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.0183, 'longitude': -78.9591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14075', 'place_name': 'Hamburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7334, 'longitude': -78.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14080', 'place_name': 'Holland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6396, 'longitude': -78.5439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14085', 'place_name': 'Lake View', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7215, 'longitude': -78.9327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14086', 'place_name': 'Lancaster', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9017, 'longitude': -78.6631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14091', 'place_name': 'Lawtons', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5404, 'longitude': -78.9212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14102', 'place_name': 'Marilla', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8332, 'longitude': -78.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14110', 'place_name': 'North Boston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.6856, 'longitude': -78.7767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14111', 'place_name': 'North Collins', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5896, 'longitude': -78.9107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14112', 'place_name': 'North Evans', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.697, 'longitude': -78.9414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14127', 'place_name': 'Orchard Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7639, 'longitude': -78.7518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14134', 'place_name': 'Sardinia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.5323, 'longitude': -78.5172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14139', 'place_name': 'South Wales', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7063, 'longitude': -78.5452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14140', 'place_name': 'Spring Brook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8072, 'longitude': -78.6676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14141', 'place_name': 'Springville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.52, 'longitude': -78.6847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14150', 'place_name': 'Tonawanda', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.0028, 'longitude': -78.8547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14151', 'place_name': 'Tonawanda', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.0203, 'longitude': -78.8803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14169', 'place_name': 'Wales Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.53, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14170', 'place_name': 'West Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7053, 'longitude': -78.6779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14201', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8967, 'longitude': -78.8846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14202', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.887, 'longitude': -78.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14203', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8939, 'longitude': -78.8681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14204', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.884, 'longitude': -78.8597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14205', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8864, 'longitude': -78.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14206', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8811, 'longitude': -78.8104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14207', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9491, 'longitude': -78.8978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14208', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9154, 'longitude': -78.8505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14209', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.913, 'longitude': -78.8656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14210', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8614, 'longitude': -78.8205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14211', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9082, 'longitude': -78.8225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14212', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8946, 'longitude': -78.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14213', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9167, 'longitude': -78.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14214', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9414, 'longitude': -78.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14215', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9335, 'longitude': -78.8115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14216', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9499, 'longitude': -78.8599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14217', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9719, 'longitude': -78.8769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14218', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8146, 'longitude': -78.8078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14219', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7863, 'longitude': -78.8264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14220', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8441, 'longitude': -78.8182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14221', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9685, 'longitude': -78.7492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14222', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9164, 'longitude': -78.8763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14223', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9731, 'longitude': -78.845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14224', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8371, 'longitude': -78.7484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14225', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9255, 'longitude': -78.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14226', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9744, 'longitude': -78.7949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14227', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8853, 'longitude': -78.7462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14228', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 43.0408, 'longitude': -78.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14231', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14233', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14240', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14241', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.9383, 'longitude': -78.7441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14260', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14261', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14263', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14264', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8856, 'longitude': -78.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14265', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14267', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14269', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14270', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14272', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.7684, 'longitude': -78.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14273', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.755, 'longitude': -78.7849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14276', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8864, 'longitude': -78.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14280', 'place_name': 'Buffalo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Erie', 'locality_code': '29', 'latitude': 42.8864, 'longitude': -78.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12851', 'place_name': 'Minerva', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.7811, 'longitude': -73.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12852', 'place_name': 'Newcomb', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.946, 'longitude': -74.1299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12855', 'place_name': 'North Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.9869, 'longitude': -73.7121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12857', 'place_name': 'Olmstedville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.7799, 'longitude': -73.9335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12858', 'place_name': 'Paradox', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.8914, 'longitude': -73.645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12870', 'place_name': 'Schroon Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.8412, 'longitude': -73.7674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12872', 'place_name': 'Severance', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.8759, 'longitude': -73.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12879', 'place_name': 'Newcomb', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.9697, 'longitude': -74.1662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12883', 'place_name': 'Ticonderoga', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.8463, 'longitude': -73.4426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12913', 'place_name': 'Bloomingdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.3985, 'longitude': -74.0829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12928', 'place_name': 'Crown Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 43.9526, 'longitude': -73.4665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12932', 'place_name': 'Elizabethtown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.2245, 'longitude': -73.6011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12936', 'place_name': 'Essex', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.2807, 'longitude': -73.3731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12941', 'place_name': 'Jay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.3734, 'longitude': -73.7247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12942', 'place_name': 'Keene', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.2555, 'longitude': -73.7915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12943', 'place_name': 'Keene Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.2024, 'longitude': -73.7731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12944', 'place_name': 'Keeseville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.4999, 'longitude': -73.4745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12946', 'place_name': 'Lake Placid', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.2796, 'longitude': -73.982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12950', 'place_name': 'Lewis', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.3075, 'longitude': -73.5491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12956', 'place_name': 'Mineville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.0876, 'longitude': -73.5236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12960', 'place_name': 'Moriah', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.0438, 'longitude': -73.5079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12961', 'place_name': 'Moriah Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.0612, 'longitude': -73.5098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12964', 'place_name': 'New Russia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.1595, 'longitude': -73.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12974', 'place_name': 'Port Henry', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.0465, 'longitude': -73.4705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12975', 'place_name': 'Port Kent', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.5264, 'longitude': -73.4092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12977', 'place_name': 'Ray Brook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.2802, 'longitude': -74.0795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12987', 'place_name': 'Upper Jay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.3364, 'longitude': -73.7757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12993', 'place_name': 'Westport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.205, 'longitude': -73.4702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12996', 'place_name': 'Willsboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.3604, 'longitude': -73.3963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12997', 'place_name': 'Wilmington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.3755, 'longitude': -73.8431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12998', 'place_name': 'Witherbee', 'state': 'New York', 'state_ab': 'NY', 'county': 'Essex', 'locality_code': '31', 'latitude': 44.0827, 'longitude': -73.5306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12914', 'place_name': 'Bombay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.9479, 'longitude': -74.5947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12915', 'place_name': 'Brainardsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.8578, 'longitude': -74.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12916', 'place_name': 'Brushton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.8282, 'longitude': -74.5223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12917', 'place_name': 'Burke', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.9177, 'longitude': -74.1731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12920', 'place_name': 'Chateaugay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.9088, 'longitude': -74.0741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12926', 'place_name': 'Constable', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.9417, 'longitude': -74.3297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12930', 'place_name': 'Dickinson Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.7233, 'longitude': -74.5523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12937', 'place_name': 'Fort Covington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.9731, 'longitude': -74.4929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12939', 'place_name': 'Gabriels', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.432, 'longitude': -74.181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12945', 'place_name': 'Lake Clear', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.3375, 'longitude': -74.2381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12953', 'place_name': 'Malone', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.8482, 'longitude': -74.2928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12957', 'place_name': 'Moira', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.8504, 'longitude': -74.5603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12966', 'place_name': 'North Bangor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.8532, 'longitude': -74.4191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12969', 'place_name': 'Owls Head', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.7308, 'longitude': -74.1342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12970', 'place_name': 'Paul Smiths', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.445, 'longitude': -74.2664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12976', 'place_name': 'Rainbow Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.467, 'longitude': -74.1729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12980', 'place_name': 'Saint Regis Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.6578, 'longitude': -74.5155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12983', 'place_name': 'Saranac Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.3243, 'longitude': -74.133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12986', 'place_name': 'Tupper Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.232, 'longitude': -74.4905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12989', 'place_name': 'Vermontville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.4601, 'longitude': -74.0573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12995', 'place_name': 'Whippleville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.8057, 'longitude': -74.2523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13655', 'place_name': 'Hogansburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Franklin', 'locality_code': '33', 'latitude': 44.9825, 'longitude': -74.6626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12025', 'place_name': 'Broadalbin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Fulton', 'locality_code': '35', 'latitude': 43.0727, 'longitude': -74.1684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12032', 'place_name': 'Caroga Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Fulton', 'locality_code': '35', 'latitude': 43.1922, 'longitude': -74.5169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12078', 'place_name': 'Gloversville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Fulton', 'locality_code': '35', 'latitude': 43.0616, 'longitude': -74.3375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12095', 'place_name': 'Johnstown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Fulton', 'locality_code': '35', 'latitude': 43.0069, 'longitude': -74.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12117', 'place_name': 'Mayfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Fulton', 'locality_code': '35', 'latitude': 43.1411, 'longitude': -74.2444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12134', 'place_name': 'Northville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Fulton', 'locality_code': '35', 'latitude': 43.2662, 'longitude': -74.2288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13470', 'place_name': 'Stratford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Fulton', 'locality_code': '35', 'latitude': 43.1791, 'longitude': -74.6768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14005', 'place_name': 'Alexander', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9159, 'longitude': -78.2589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14013', 'place_name': 'Basom', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 43.0807, 'longitude': -78.3951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14020', 'place_name': 'Batavia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 43.0003, 'longitude': -78.1929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14021', 'place_name': 'Batavia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9981, 'longitude': -78.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14036', 'place_name': 'Corfu', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9777, 'longitude': -78.3929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14040', 'place_name': 'Darien Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.8948, 'longitude': -78.3878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14054', 'place_name': 'East Bethany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9166, 'longitude': -78.1342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14056', 'place_name': 'East Pembroke', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9912, 'longitude': -78.3122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14058', 'place_name': 'Elba', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 43.0897, 'longitude': -78.1704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14125', 'place_name': 'Oakfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 43.0717, 'longitude': -78.2702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14143', 'place_name': 'Stafford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9829, 'longitude': -78.0898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14416', 'place_name': 'Bergen', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 43.0869, 'longitude': -77.9603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14422', 'place_name': 'Byron', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 43.0738, 'longitude': -78.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14482', 'place_name': 'Le Roy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9774, 'longitude': -77.9851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14486', 'place_name': 'Linwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.8943, 'longitude': -77.9216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14525', 'place_name': 'Pavilion', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 42.9102, 'longitude': -78.0269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14557', 'place_name': 'South Byron', 'state': 'New York', 'state_ab': 'NY', 'county': 'Genesee', 'locality_code': '37', 'latitude': 43.0416, 'longitude': -78.0573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12015', 'place_name': 'Athens', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2736, 'longitude': -73.8152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12042', 'place_name': 'Climax', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3659, 'longitude': -73.851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12051', 'place_name': 'Coxsackie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3501, 'longitude': -73.8199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12058', 'place_name': 'Earlton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3527, 'longitude': -73.9062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12083', 'place_name': 'Greenville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.4113, 'longitude': -74.0222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12087', 'place_name': 'Hannacroix', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.429, 'longitude': -73.8093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12124', 'place_name': 'New Baltimore', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.4442, 'longitude': -73.7882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12176', 'place_name': 'Surprise', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3851, 'longitude': -73.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12192', 'place_name': 'West Coxsackie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.4029, 'longitude': -73.8283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12405', 'place_name': 'Acra', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3304, 'longitude': -74.0857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12407', 'place_name': 'Ashland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3037, 'longitude': -74.3335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12413', 'place_name': 'Cairo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3096, 'longitude': -74.0115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12414', 'place_name': 'Catskill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2276, 'longitude': -73.8985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12418', 'place_name': 'Cornwallville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3629, 'longitude': -74.1631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12422', 'place_name': 'Durham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.402, 'longitude': -74.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12423', 'place_name': 'East Durham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.386, 'longitude': -74.1117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12424', 'place_name': 'East Jewett', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2469, 'longitude': -74.1353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12427', 'place_name': 'Elka Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.1643, 'longitude': -74.1245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12431', 'place_name': 'Freehold', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3815, 'longitude': -74.0623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12436', 'place_name': 'Haines Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.1955, 'longitude': -74.1023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12439', 'place_name': 'Hensonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2898, 'longitude': -74.2165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12442', 'place_name': 'Hunter', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2333, 'longitude': -74.2416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12444', 'place_name': 'Jewett', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2694, 'longitude': -74.2793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12450', 'place_name': 'Lanesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.1332, 'longitude': -74.2443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12451', 'place_name': 'Leeds', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3045, 'longitude': -73.9457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12452', 'place_name': 'Lexington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2404, 'longitude': -74.3654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12454', 'place_name': 'Maplecrest', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2995, 'longitude': -74.1655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12460', 'place_name': 'Oak Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.4098, 'longitude': -74.1524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12463', 'place_name': 'Palenville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.1729, 'longitude': -74.0167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12468', 'place_name': 'Prattsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2979, 'longitude': -74.3895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12470', 'place_name': 'Purling', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2959, 'longitude': -74.0773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12473', 'place_name': 'Round Top', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2678, 'longitude': -74.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12482', 'place_name': 'South Cairo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2681, 'longitude': -73.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12485', 'place_name': 'Tannersville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.1956, 'longitude': -74.1338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12492', 'place_name': 'West Kill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.2046, 'longitude': -74.362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12496', 'place_name': 'Windham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Greene', 'locality_code': '39', 'latitude': 42.3175, 'longitude': -74.262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12108', 'place_name': 'Lake Pleasant', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.6676, 'longitude': -74.4569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12139', 'place_name': 'Piseco', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.4481, 'longitude': -74.5263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12164', 'place_name': 'Speculator', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.5042, 'longitude': -74.3667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12190', 'place_name': 'Wells', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.4012, 'longitude': -74.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12812', 'place_name': 'Blue Mountain Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.8553, 'longitude': -74.4435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12842', 'place_name': 'Indian Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.7606, 'longitude': -74.2766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12847', 'place_name': 'Long Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.9477, 'longitude': -74.4662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12864', 'place_name': 'Sabael', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.7284, 'longitude': -74.3057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13353', 'place_name': 'Hoffmeister', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.3915, 'longitude': -74.74, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13360', 'place_name': 'Inlet', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.748, 'longitude': -74.7846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13436', 'place_name': 'Raquette Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Hamilton', 'locality_code': '41', 'latitude': 43.8131, 'longitude': -74.6574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13324', 'place_name': 'Cold Brook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.3024, 'longitude': -74.9977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13329', 'place_name': 'Dolgeville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.1042, 'longitude': -74.7643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13331', 'place_name': 'Eagle Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.8167, 'longitude': -74.8862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13340', 'place_name': 'Frankfort', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.044, 'longitude': -75.1072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13350', 'place_name': 'Herkimer', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.0307, 'longitude': -74.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13357', 'place_name': 'Ilion', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.0064, 'longitude': -75.0484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13361', 'place_name': 'Jordanville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 42.9148, 'longitude': -74.9515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13365', 'place_name': 'Little Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.0474, 'longitude': -74.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13406', 'place_name': 'Middleville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.1369, 'longitude': -74.924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13407', 'place_name': 'Mohawk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 42.99, 'longitude': -74.9853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13416', 'place_name': 'Newport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.18, 'longitude': -74.9861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13420', 'place_name': 'Old Forge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.7435, 'longitude': -74.8935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13431', 'place_name': 'Poland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.2115, 'longitude': -75.0731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13454', 'place_name': 'Salisbury Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.1625, 'longitude': -74.7809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13472', 'place_name': 'Thendara', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 43.7001, 'longitude': -75.0018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13475', 'place_name': 'Van Hornesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 42.8951, 'longitude': -74.8276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13491', 'place_name': 'West Winfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Herkimer', 'locality_code': '43', 'latitude': 42.8826, 'longitude': -75.1835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13601', 'place_name': 'Watertown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.9743, 'longitude': -75.9122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13602', 'place_name': 'Fort Drum', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0354, 'longitude': -75.754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13603', 'place_name': 'Watertown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.9087, 'longitude': -75.8967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13605', 'place_name': 'Adams', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.8062, 'longitude': -76.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13606', 'place_name': 'Adams Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.8631, 'longitude': -76.0041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13607', 'place_name': 'Alexandria Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.3359, 'longitude': -75.9177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13608', 'place_name': 'Antwerp', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.2358, 'longitude': -75.6005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13611', 'place_name': 'Belleville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.778, 'longitude': -76.1259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13612', 'place_name': 'Black River', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0042, 'longitude': -75.7958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13615', 'place_name': 'Brownville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.007, 'longitude': -75.9841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13616', 'place_name': 'Calcium', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0265, 'longitude': -75.8499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13618', 'place_name': 'Cape Vincent', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.1244, 'longitude': -76.3164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13619', 'place_name': 'Carthage', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.9791, 'longitude': -75.6013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13622', 'place_name': 'Chaumont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0848, 'longitude': -76.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13624', 'place_name': 'Clayton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.1442, 'longitude': -76.062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13628', 'place_name': 'Deferiet', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0356, 'longitude': -75.6838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13632', 'place_name': 'Depauville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.1395, 'longitude': -76.0616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13634', 'place_name': 'Dexter', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0069, 'longitude': -76.065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13636', 'place_name': 'Ellisburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.7434, 'longitude': -76.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13637', 'place_name': 'Evans Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0817, 'longitude': -75.8305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13638', 'place_name': 'Felts Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0204, 'longitude': -75.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13640', 'place_name': 'Wellesley Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.3213, 'longitude': -76.0172, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13641', 'place_name': 'Fishers Landing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.2752, 'longitude': -76.0049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13643', 'place_name': 'Great Bend', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0342, 'longitude': -75.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13650', 'place_name': 'Henderson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.8467, 'longitude': -76.2352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13651', 'place_name': 'Henderson Harbor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.8708, 'longitude': -76.1809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13656', 'place_name': 'La Fargeville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.1987, 'longitude': -75.9569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13657', 'place_name': 'Limerick', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0292, 'longitude': -76.043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13659', 'place_name': 'Lorraine', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.7568, 'longitude': -75.9053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13661', 'place_name': 'Mannsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.7179, 'longitude': -76.082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13665', 'place_name': 'Natural Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.063, 'longitude': -75.5039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13671', 'place_name': 'Oxbow', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.2873, 'longitude': -75.623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13673', 'place_name': 'Philadelphia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.1589, 'longitude': -75.7099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13674', 'place_name': 'Pierrepont Manor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.7334, 'longitude': -76.0543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13675', 'place_name': 'Plessis', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.2774, 'longitude': -75.8496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13679', 'place_name': 'Redwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.3211, 'longitude': -75.815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13682', 'place_name': 'Rodman', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.8622, 'longitude': -75.8719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13685', 'place_name': 'Sackets Harbor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 43.9398, 'longitude': -76.105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13691', 'place_name': 'Theresa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.2113, 'longitude': -75.8014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13692', 'place_name': 'Thousand Island Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.2898, 'longitude': -76.0262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13693', 'place_name': 'Three Mile Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Jefferson', 'locality_code': '45', 'latitude': 44.0551, 'longitude': -76.2689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11201', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.694, 'longitude': -73.9903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11202', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11203', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6505, 'longitude': -73.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11204', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6179, 'longitude': -73.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11205', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6924, 'longitude': -73.9666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11206', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.7012, 'longitude': -73.9436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11207', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6705, 'longitude': -73.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11208', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6762, 'longitude': -73.8736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11209', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6251, 'longitude': -74.0303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11210', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6281, 'longitude': -73.9467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11211', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.7095, 'longitude': -73.9563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11212', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6625, 'longitude': -73.9145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11213', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.67, 'longitude': -73.9367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11214', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6016, 'longitude': -73.9968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11215', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6669, 'longitude': -73.9828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11216', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6794, 'longitude': -73.9496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11217', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6816, 'longitude': -73.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11218', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6424, 'longitude': -73.9758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11219', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6336, 'longitude': -73.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11220', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6412, 'longitude': -74.0133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11221', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6907, 'longitude': -73.9274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11222', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.7272, 'longitude': -73.9498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11223', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.5979, 'longitude': -73.9743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11224', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.5767, 'longitude': -73.9884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11225', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6628, 'longitude': -73.9546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11226', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6467, 'longitude': -73.957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11228', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6174, 'longitude': -74.0121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11229', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6011, 'longitude': -73.9475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11230', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6225, 'longitude': -73.965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11231', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6794, 'longitude': -74.0014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11232', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6521, 'longitude': -74.0018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11233', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6784, 'longitude': -73.9211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11234', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6205, 'longitude': -73.9239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11235', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.5839, 'longitude': -73.9536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11236', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6407, 'longitude': -73.9028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11237', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.7006, 'longitude': -73.918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11238', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.679, 'longitude': -73.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11239', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6497, 'longitude': -73.8824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11241', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11242', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11243', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11245', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11247', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11249', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11251', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11252', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11256', 'place_name': 'Brooklyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Kings', 'locality_code': '47', 'latitude': 40.6451, 'longitude': -73.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13305', 'place_name': 'Beaver Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.887, 'longitude': -75.4274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13312', 'place_name': 'Brantingham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.6887, 'longitude': -75.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13325', 'place_name': 'Constableville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.563, 'longitude': -75.4584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13327', 'place_name': 'Croghan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.9095, 'longitude': -75.3542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13343', 'place_name': 'Glenfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.7323, 'longitude': -75.3669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13345', 'place_name': 'Greig', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.6886, 'longitude': -75.3302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13367', 'place_name': 'Lowville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.7893, 'longitude': -75.4156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13368', 'place_name': 'Lyons Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.6262, 'longitude': -75.3553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13404', 'place_name': 'Martinsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.7376, 'longitude': -75.4696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13433', 'place_name': 'Port Leyden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.5802, 'longitude': -75.3263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13473', 'place_name': 'Turin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.6441, 'longitude': -75.4132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13489', 'place_name': 'West Leyden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.4597, 'longitude': -75.5127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13620', 'place_name': 'Castorland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.8843, 'longitude': -75.4604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13626', 'place_name': 'Copenhagen', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.8801, 'longitude': -75.6839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13627', 'place_name': 'Deer River', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.9298, 'longitude': -75.5891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13631', 'place_name': 'Denmark', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 43.8998, 'longitude': -75.5824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13648', 'place_name': 'Harrisville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Lewis', 'locality_code': '49', 'latitude': 44.1613, 'longitude': -75.3252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14414', 'place_name': 'Avon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.903, 'longitude': -77.7274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14423', 'place_name': 'Caledonia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.9567, 'longitude': -77.8493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14435', 'place_name': 'Conesus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.7216, 'longitude': -77.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14437', 'place_name': 'Dansville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.57, 'longitude': -77.7109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14454', 'place_name': 'Geneseo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.7938, 'longitude': -77.7996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14462', 'place_name': 'Groveland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.676, 'longitude': -77.7573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14466', 'place_name': 'Hemlock', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.78, 'longitude': -77.582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14480', 'place_name': 'Lakeville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.8296, 'longitude': -77.7149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14481', 'place_name': 'Leicester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.7739, 'longitude': -77.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14485', 'place_name': 'Lima', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.9012, 'longitude': -77.6083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14487', 'place_name': 'Livonia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.8135, 'longitude': -77.6635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14488', 'place_name': 'Livonia Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.8215, 'longitude': -77.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14510', 'place_name': 'Mount Morris', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.6835, 'longitude': -77.8664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14517', 'place_name': 'Nunda', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.5867, 'longitude': -77.918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14533', 'place_name': 'Piffard', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.8435, 'longitude': -77.8962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14539', 'place_name': 'Retsof', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.8343, 'longitude': -77.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14545', 'place_name': 'Scottsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.6649, 'longitude': -77.701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14556', 'place_name': 'Sonyea', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.679, 'longitude': -77.8272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14558', 'place_name': 'South Lima', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.8554, 'longitude': -77.6876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14560', 'place_name': 'Springwater', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.6776, 'longitude': -77.5775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14592', 'place_name': 'York', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.8757, 'longitude': -77.8835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14836', 'place_name': 'Dalton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.5449, 'longitude': -77.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14846', 'place_name': 'Hunt', 'state': 'New York', 'state_ab': 'NY', 'county': 'Livingston', 'locality_code': '51', 'latitude': 42.5388, 'longitude': -77.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13032', 'place_name': 'Canastota', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 43.0878, 'longitude': -75.7602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13035', 'place_name': 'Cazenovia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.938, 'longitude': -75.8392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13037', 'place_name': 'Chittenango', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 43.0552, 'longitude': -75.8768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13043', 'place_name': 'Clockville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 43.042, 'longitude': -75.7408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13052', 'place_name': 'De Ruyter', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.7494, 'longitude': -75.8582, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13061', 'place_name': 'Erieville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8562, 'longitude': -75.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13072', 'place_name': 'Georgetown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.7631, 'longitude': -75.7443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13122', 'place_name': 'New Woodstock', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8441, 'longitude': -75.8635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13134', 'place_name': 'Peterboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.9686, 'longitude': -75.6794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13163', 'place_name': 'Wampsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 43.0753, 'longitude': -75.7069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13310', 'place_name': 'Bouckville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.894, 'longitude': -75.5678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13314', 'place_name': 'Brookfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8128, 'longitude': -75.3177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13334', 'place_name': 'Eaton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8484, 'longitude': -75.6314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13346', 'place_name': 'Hamilton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8231, 'longitude': -75.5434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13355', 'place_name': 'Hubbardsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8237, 'longitude': -75.4367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13364', 'place_name': 'Leonardsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8087, 'longitude': -75.2527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13402', 'place_name': 'Madison', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8969, 'longitude': -75.5076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13408', 'place_name': 'Morrisville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.9108, 'longitude': -75.6487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13409', 'place_name': 'Munnsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.9863, 'longitude': -75.594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13418', 'place_name': 'North Brookfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8501, 'longitude': -75.3815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13421', 'place_name': 'Oneida', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 43.0862, 'longitude': -75.6508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13465', 'place_name': 'Solsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.9106, 'longitude': -75.5177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13484', 'place_name': 'West Eaton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Madison', 'locality_code': '53', 'latitude': 42.8545, 'longitude': -75.656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14410', 'place_name': 'Adams Basin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1953, 'longitude': -77.8559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14420', 'place_name': 'Brockport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2128, 'longitude': -77.9368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14428', 'place_name': 'Churchville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.0749, 'longitude': -77.835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14430', 'place_name': 'Clarkson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2331, 'longitude': -77.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14445', 'place_name': 'East Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1128, 'longitude': -77.4906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14450', 'place_name': 'Fairport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.0892, 'longitude': -77.436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14464', 'place_name': 'Hamlin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.3076, 'longitude': -77.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14467', 'place_name': 'Henrietta', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.0483, 'longitude': -77.6122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14468', 'place_name': 'Hilton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2923, 'longitude': -77.7905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14472', 'place_name': 'Honeoye Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 42.9695, 'longitude': -77.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14506', 'place_name': 'Mendon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 42.9953, 'longitude': -77.5001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14511', 'place_name': 'Mumford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 42.9928, 'longitude': -77.8603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14514', 'place_name': 'North Chili', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1186, 'longitude': -77.8005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14515', 'place_name': 'North Greece', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2578, 'longitude': -77.7351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14526', 'place_name': 'Penfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1396, 'longitude': -77.456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14534', 'place_name': 'Pittsford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.0695, 'longitude': -77.5141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14543', 'place_name': 'Rush', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 42.9966, 'longitude': -77.6665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14546', 'place_name': 'Scottsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.0246, 'longitude': -77.7743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14559', 'place_name': 'Spencerport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1895, 'longitude': -77.8043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14580', 'place_name': 'Webster', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2196, 'longitude': -77.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14586', 'place_name': 'West Henrietta', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.0397, 'longitude': -77.6871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14602', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14603', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1616, 'longitude': -77.6068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14604', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1577, 'longitude': -77.608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14605', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1698, 'longitude': -77.6007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14606', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1685, 'longitude': -77.6845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14607', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1501, 'longitude': -77.589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14608', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1521, 'longitude': -77.6258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14609', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.174, 'longitude': -77.5637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14610', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1452, 'longitude': -77.5495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14611', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1484, 'longitude': -77.6394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14612', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2566, 'longitude': -77.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14613', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1831, 'longitude': -77.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14614', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1558, 'longitude': -77.6142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14615', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2058, 'longitude': -77.6521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14616', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2346, 'longitude': -77.6577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14617', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2203, 'longitude': -77.5994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14618', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1122, 'longitude': -77.5618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14619', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1367, 'longitude': -77.6481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14620', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1317, 'longitude': -77.6062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14621', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1834, 'longitude': -77.6043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14622', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.214, 'longitude': -77.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14623', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.0834, 'longitude': -77.6344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14624', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1216, 'longitude': -77.7311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14625', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1522, 'longitude': -77.5057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14626', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.2126, 'longitude': -77.704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14627', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1275, 'longitude': -77.6277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14638', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14639', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14642', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14643', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1548, 'longitude': -77.6156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14644', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14646', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14647', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1548, 'longitude': -77.6156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14649', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14650', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1548, 'longitude': -77.6156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14651', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.1548, 'longitude': -77.6156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14652', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14653', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14692', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14694', 'place_name': 'Rochester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Monroe', 'locality_code': '55', 'latitude': 43.286, 'longitude': -77.6843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12010', 'place_name': 'Amsterdam', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9387, 'longitude': -74.1882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12016', 'place_name': 'Auriesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9295, 'longitude': -74.3165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12066', 'place_name': 'Esperance', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.7717, 'longitude': -74.2882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12068', 'place_name': 'Fonda', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9571, 'longitude': -74.4021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12069', 'place_name': 'Fort Hunter', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9423, 'longitude': -74.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12070', 'place_name': 'Fort Johnson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9765, 'longitude': -74.2484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12072', 'place_name': 'Fultonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9036, 'longitude': -74.3598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12086', 'place_name': 'Hagaman', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9695, 'longitude': -74.1556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12166', 'place_name': 'Sprakers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.8484, 'longitude': -74.4536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12177', 'place_name': 'Tribes Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9554, 'longitude': -74.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13317', 'place_name': 'Canajoharie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.8671, 'longitude': -74.5956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13339', 'place_name': 'Fort Plain', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9372, 'longitude': -74.6433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13410', 'place_name': 'Nelliston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9379, 'longitude': -74.6117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13428', 'place_name': 'Palatine Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 42.9221, 'longitude': -74.5708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13452', 'place_name': 'Saint Johnsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Montgomery', 'locality_code': '57', 'latitude': 43.017, 'longitude': -74.646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11001', 'place_name': 'Floral Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7236, 'longitude': -73.7058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11002', 'place_name': 'Floral Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7237, 'longitude': -73.7049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11003', 'place_name': 'Elmont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6976, 'longitude': -73.7049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11010', 'place_name': 'Franklin Square', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.701, 'longitude': -73.6758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11020', 'place_name': 'Great Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7742, 'longitude': -73.7189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11021', 'place_name': 'Great Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7867, 'longitude': -73.727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11022', 'place_name': 'Great Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11023', 'place_name': 'Great Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7993, 'longitude': -73.7343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11024', 'place_name': 'Great Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8171, 'longitude': -73.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11026', 'place_name': 'Great Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11027', 'place_name': 'Great Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8007, 'longitude': -73.7285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11030', 'place_name': 'Manhasset', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7934, 'longitude': -73.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11040', 'place_name': 'New Hyde Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7294, 'longitude': -73.6828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11042', 'place_name': 'New Hyde Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7602, 'longitude': -73.695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11050', 'place_name': 'Port Washington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.835, 'longitude': -73.6964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11051', 'place_name': 'Port Washington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11052', 'place_name': 'Port Washington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11053', 'place_name': 'Port Washington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11054', 'place_name': 'Port Washington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11055', 'place_name': 'Port Washington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11096', 'place_name': 'Inwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6205, 'longitude': -73.7474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11501', 'place_name': 'Mineola', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7469, 'longitude': -73.6398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11507', 'place_name': 'Albertson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7703, 'longitude': -73.6514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11509', 'place_name': 'Atlantic Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.5887, 'longitude': -73.7255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11510', 'place_name': 'Baldwin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6548, 'longitude': -73.6097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11514', 'place_name': 'Carle Place', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7512, 'longitude': -73.6119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11516', 'place_name': 'Cedarhurst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6236, 'longitude': -73.7264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11518', 'place_name': 'East Rockaway', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6404, 'longitude': -73.6674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11520', 'place_name': 'Freeport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6536, 'longitude': -73.5866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11530', 'place_name': 'Garden City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7245, 'longitude': -73.6487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11531', 'place_name': 'Garden City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7268, 'longitude': -73.6343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11542', 'place_name': 'Glen Cove', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.865, 'longitude': -73.6277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11545', 'place_name': 'Glen Head', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8281, 'longitude': -73.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11547', 'place_name': 'Glenwood Landing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8307, 'longitude': -73.6387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11548', 'place_name': 'Greenvale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8125, 'longitude': -73.6261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11549', 'place_name': 'Hempstead', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7172, 'longitude': -73.6027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11550', 'place_name': 'Hempstead', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7049, 'longitude': -73.6176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11551', 'place_name': 'Hempstead', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7062, 'longitude': -73.6187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11552', 'place_name': 'West Hempstead', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6929, 'longitude': -73.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11553', 'place_name': 'Uniondale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.702, 'longitude': -73.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11554', 'place_name': 'East Meadow', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7149, 'longitude': -73.5561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11555', 'place_name': 'Uniondale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7004, 'longitude': -73.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11556', 'place_name': 'Uniondale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11557', 'place_name': 'Hewlett', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6404, 'longitude': -73.6957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11558', 'place_name': 'Island Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.604, 'longitude': -73.6554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11559', 'place_name': 'Lawrence', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.614, 'longitude': -73.733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11560', 'place_name': 'Locust Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8817, 'longitude': -73.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11561', 'place_name': 'Long Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.5877, 'longitude': -73.6595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11563', 'place_name': 'Lynbrook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6571, 'longitude': -73.6741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11565', 'place_name': 'Malverne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.675, 'longitude': -73.6731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11566', 'place_name': 'Merrick', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6685, 'longitude': -73.5536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11568', 'place_name': 'Old Westbury', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7882, 'longitude': -73.5875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11569', 'place_name': 'Point Lookout', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.5905, 'longitude': -73.5808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11570', 'place_name': 'Rockville Centre', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6637, 'longitude': -73.638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11571', 'place_name': 'Rockville Centre', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6587, 'longitude': -73.6412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11572', 'place_name': 'Oceanside', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6362, 'longitude': -73.6375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11575', 'place_name': 'Roosevelt', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6802, 'longitude': -73.5867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11576', 'place_name': 'Roslyn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7984, 'longitude': -73.6477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11577', 'place_name': 'Roslyn Heights', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7845, 'longitude': -73.6403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11579', 'place_name': 'Sea Cliff', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.846, 'longitude': -73.6436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11580', 'place_name': 'Valley Stream', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6742, 'longitude': -73.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11581', 'place_name': 'Valley Stream', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6523, 'longitude': -73.7118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11582', 'place_name': 'Valley Stream', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6643, 'longitude': -73.7085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11590', 'place_name': 'Westbury', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7557, 'longitude': -73.5723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11596', 'place_name': 'Williston Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7592, 'longitude': -73.6449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11598', 'place_name': 'Woodmere', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6326, 'longitude': -73.7141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11599', 'place_name': 'Garden City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7268, 'longitude': -73.6343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11709', 'place_name': 'Bayville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.9074, 'longitude': -73.5601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11710', 'place_name': 'Bellmore', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6729, 'longitude': -73.5365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11714', 'place_name': 'Bethpage', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.74, 'longitude': -73.4857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11732', 'place_name': 'East Norwich', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8472, 'longitude': -73.5349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11735', 'place_name': 'Farmingdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7315, 'longitude': -73.4327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11737', 'place_name': 'Farmingdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7326, 'longitude': -73.4454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11753', 'place_name': 'Jericho', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7881, 'longitude': -73.5331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11756', 'place_name': 'Levittown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7254, 'longitude': -73.5166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11758', 'place_name': 'Massapequa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6682, 'longitude': -73.4588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11762', 'place_name': 'Massapequa Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6807, 'longitude': -73.4444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11765', 'place_name': 'Mill Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8857, 'longitude': -73.5526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11771', 'place_name': 'Oyster Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.866, 'longitude': -73.5272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11773', 'place_name': 'Syosset', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8262, 'longitude': -73.5021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11783', 'place_name': 'Seaford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.6795, 'longitude': -73.491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11791', 'place_name': 'Syosset', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8146, 'longitude': -73.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11793', 'place_name': 'Wantagh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.685, 'longitude': -73.5103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11797', 'place_name': 'Woodbury', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.8154, 'longitude': -73.4716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11801', 'place_name': 'Hicksville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7623, 'longitude': -73.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11802', 'place_name': 'Hicksville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7684, 'longitude': -73.5251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11803', 'place_name': 'Plainview', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7781, 'longitude': -73.4816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11804', 'place_name': 'Old Bethpage', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.765, 'longitude': -73.4575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11815', 'place_name': 'Hicksville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7548, 'longitude': -73.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11819', 'place_name': 'Hicksville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.7684, 'longitude': -73.5251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11853', 'place_name': 'Jericho', 'state': 'New York', 'state_ab': 'NY', 'county': 'Nassau', 'locality_code': '59', 'latitude': 40.792, 'longitude': -73.5398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10001', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7484, 'longitude': -73.9967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10002', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7152, 'longitude': -73.9877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10003', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7313, 'longitude': -73.9892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10004', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10005', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7056, 'longitude': -74.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10006', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7085, 'longitude': -74.0135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10007', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7139, 'longitude': -74.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10008', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10009', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7262, 'longitude': -73.9796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10010', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7375, 'longitude': -73.9813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10011', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7402, 'longitude': -73.9996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10012', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7255, 'longitude': -73.9983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10013', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7185, 'longitude': -74.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10014', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7339, 'longitude': -74.0054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10016', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7443, 'longitude': -73.9781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10017', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7517, 'longitude': -73.9707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10018', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7547, 'longitude': -73.9925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10019', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7651, 'longitude': -73.9858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10020', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7354, 'longitude': -73.9968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10021', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7685, 'longitude': -73.9588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10022', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7571, 'longitude': -73.9657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10023', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7764, 'longitude': -73.9827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10024', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7864, 'longitude': -73.9764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10025', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7975, 'longitude': -73.9683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10026', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8019, 'longitude': -73.9531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10027', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8116, 'longitude': -73.955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10028', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7763, 'longitude': -73.9529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10029', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7918, 'longitude': -73.9447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10030', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8183, 'longitude': -73.9426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10031', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8246, 'longitude': -73.9507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10032', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8382, 'longitude': -73.942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10033', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8496, 'longitude': -73.9356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10034', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8662, 'longitude': -73.9221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10035', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8011, 'longitude': -73.9371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10036', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7597, 'longitude': -73.9918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10037', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8135, 'longitude': -73.9381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10038', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7101, 'longitude': -74.0013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10039', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8265, 'longitude': -73.9383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10040', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8583, 'longitude': -73.9296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10041', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7038, 'longitude': -74.0098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10043', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10044', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7618, 'longitude': -73.9505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10045', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7086, 'longitude': -74.0087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10055', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10060', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10065', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7651, 'longitude': -73.9638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10069', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.778, 'longitude': -73.9884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10075', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '10080', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10081', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10087', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10090', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10101', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10102', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10103', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7603, 'longitude': -73.9762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10104', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7609, 'longitude': -73.9799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10105', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7628, 'longitude': -73.9785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10106', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7652, 'longitude': -73.9804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10107', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7664, 'longitude': -73.9827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10108', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10109', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10110', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.754, 'longitude': -73.9808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10111', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7592, 'longitude': -73.9778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10112', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7593, 'longitude': -73.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10113', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10114', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10115', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.8111, 'longitude': -73.9642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10116', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10117', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10118', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.749, 'longitude': -73.9865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10119', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10120', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7506, 'longitude': -73.9894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10121', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7496, 'longitude': -73.9919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10122', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7518, 'longitude': -73.9922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10123', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7515, 'longitude': -73.9905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10124', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10125', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10126', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10128', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7816, 'longitude': -73.9511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10129', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10130', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10131', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10132', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10133', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10138', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10150', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10151', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7634, 'longitude': -73.974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10152', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7589, 'longitude': -73.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10153', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7641, 'longitude': -73.9735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10154', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7583, 'longitude': -73.9735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10155', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7611, 'longitude': -73.968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10156', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10157', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10158', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7494, 'longitude': -73.9758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10159', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10160', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10161', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10162', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7699, 'longitude': -73.9511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10163', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10164', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10165', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7524, 'longitude': -73.9791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10166', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7546, 'longitude': -73.9762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10167', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7549, 'longitude': -73.975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10168', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7519, 'longitude': -73.9768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10169', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7547, 'longitude': -73.9766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10170', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7526, 'longitude': -73.9755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10171', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7564, 'longitude': -73.9748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10172', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7558, 'longitude': -73.9753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10173', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7543, 'longitude': -73.9796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10174', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7517, 'longitude': -73.9752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10175', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7543, 'longitude': -73.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10176', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7556, 'longitude': -73.9789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10177', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7553, 'longitude': -73.9761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10178', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7514, 'longitude': -73.9785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10179', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10185', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10199', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7503, 'longitude': -74.0006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10203', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10211', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10212', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10213', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10242', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10249', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10256', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10258', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10259', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10260', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10261', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10265', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10268', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10269', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10270', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7069, 'longitude': -74.0082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10271', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7089, 'longitude': -74.0111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10272', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10273', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10274', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10275', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10276', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10277', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7808, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10278', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7152, 'longitude': -74.0038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10279', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7127, 'longitude': -74.0078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10280', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7105, 'longitude': -74.0163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10281', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7146, 'longitude': -74.015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10282', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7166, 'longitude': -74.0146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10285', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7143, 'longitude': -74.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10286', 'place_name': 'New York', 'state': 'New York', 'state_ab': 'NY', 'county': 'New York', 'locality_code': '61', 'latitude': 40.7142, 'longitude': -74.0119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14008', 'place_name': 'Appleton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.3105, 'longitude': -78.6372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14012', 'place_name': 'Barker', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.3368, 'longitude': -78.542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14028', 'place_name': 'Burt', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.3221, 'longitude': -78.7141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14067', 'place_name': 'Gasport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.2106, 'longitude': -78.5745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14092', 'place_name': 'Lewiston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.1722, 'longitude': -79.0215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14094', 'place_name': 'Lockport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.16, 'longitude': -78.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14095', 'place_name': 'Lockport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.1706, 'longitude': -78.6903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14105', 'place_name': 'Middleport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.2183, 'longitude': -78.4841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14107', 'place_name': 'Model City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.1851, 'longitude': -78.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14108', 'place_name': 'Newfane', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.2724, 'longitude': -78.707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14109', 'place_name': 'Niagara University', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.138, 'longitude': -79.0342, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '14120', 'place_name': 'North Tonawanda', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.0498, 'longitude': -78.851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14126', 'place_name': 'Olcott', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.3378, 'longitude': -78.7148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14131', 'place_name': 'Ransomville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.2286, 'longitude': -78.8982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14132', 'place_name': 'Sanborn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.1419, 'longitude': -78.8785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14144', 'place_name': 'Stella Niagara', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.1995, 'longitude': -79.0425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14172', 'place_name': 'Wilson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.2968, 'longitude': -78.8244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14174', 'place_name': 'Youngstown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.2461, 'longitude': -79.0245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14301', 'place_name': 'Niagara Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.0955, 'longitude': -79.0414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14302', 'place_name': 'Niagara Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.0945, 'longitude': -79.0567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14303', 'place_name': 'Niagara Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.0878, 'longitude': -79.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14304', 'place_name': 'Niagara Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.0908, 'longitude': -78.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14305', 'place_name': 'Niagara Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Niagara', 'locality_code': '63', 'latitude': 43.1146, 'longitude': -79.0378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13054', 'place_name': 'Durhamville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1579, 'longitude': -75.6714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13123', 'place_name': 'North Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2364, 'longitude': -75.7769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13157', 'place_name': 'Sylvan Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1965, 'longitude': -75.7305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13162', 'place_name': 'Verona Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1885, 'longitude': -75.7126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13301', 'place_name': 'Alder Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.4157, 'longitude': -75.2137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13303', 'place_name': 'Ava', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3445, 'longitude': -75.4509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13304', 'place_name': 'Barneveld', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2237, 'longitude': -75.1612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13308', 'place_name': 'Blossvale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2303, 'longitude': -75.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13309', 'place_name': 'Boonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.4786, 'longitude': -75.344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13313', 'place_name': 'Bridgewater', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.8792, 'longitude': -75.2672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13316', 'place_name': 'Camden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3392, 'longitude': -75.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13318', 'place_name': 'Cassville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.9069, 'longitude': -75.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13319', 'place_name': 'Chadwicks', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0226, 'longitude': -75.2656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13321', 'place_name': 'Clark Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0923, 'longitude': -75.3796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13322', 'place_name': 'Clayville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.9801, 'longitude': -75.251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13323', 'place_name': 'Clinton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0586, 'longitude': -75.3808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13328', 'place_name': 'Deansboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.9818, 'longitude': -75.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13338', 'place_name': 'Forestport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.4737, 'longitude': -75.1787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13341', 'place_name': 'Franklin Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0361, 'longitude': -75.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13352', 'place_name': 'Hinckley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3126, 'longitude': -75.1169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13354', 'place_name': 'Holland Patent', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2484, 'longitude': -75.2535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13362', 'place_name': 'Knoxboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.9803, 'longitude': -75.5186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13363', 'place_name': 'Lee Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3148, 'longitude': -75.5055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13401', 'place_name': 'Mc Connellsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2672, 'longitude': -75.6882, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13403', 'place_name': 'Marcy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1639, 'longitude': -75.2783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13413', 'place_name': 'New Hartford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0654, 'longitude': -75.2906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13417', 'place_name': 'New York Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1, 'longitude': -75.2937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13424', 'place_name': 'Oriskany', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1524, 'longitude': -75.3434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13425', 'place_name': 'Oriskany Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.9576, 'longitude': -75.4838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13435', 'place_name': 'Prospect', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3052, 'longitude': -75.1502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13438', 'place_name': 'Remsen', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3385, 'longitude': -75.1616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13440', 'place_name': 'Rome', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2193, 'longitude': -75.4498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13441', 'place_name': 'Rome', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2264, 'longitude': -75.4083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13442', 'place_name': 'Rome', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2128, 'longitude': -75.4557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13449', 'place_name': 'Rome', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2393, 'longitude': -75.478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13455', 'place_name': 'Sangerfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.9162, 'longitude': -75.3545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13456', 'place_name': 'Sauquoit', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0073, 'longitude': -75.2626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13461', 'place_name': 'Sherrill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0704, 'longitude': -75.599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13469', 'place_name': 'Stittville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.2229, 'longitude': -75.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13471', 'place_name': 'Taberg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3366, 'longitude': -75.6027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13476', 'place_name': 'Vernon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0945, 'longitude': -75.5627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13477', 'place_name': 'Vernon Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0443, 'longitude': -75.521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13478', 'place_name': 'Verona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1473, 'longitude': -75.5724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13479', 'place_name': 'Washington Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0538, 'longitude': -75.2716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13480', 'place_name': 'Waterville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 42.9332, 'longitude': -75.3815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13483', 'place_name': 'Westdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.4117, 'longitude': -75.8226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13486', 'place_name': 'Westernville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.3294, 'longitude': -75.3151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13490', 'place_name': 'Westmoreland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1017, 'longitude': -75.4533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13492', 'place_name': 'Whitesboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1158, 'longitude': -75.3095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13494', 'place_name': 'Woodgate', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.5249, 'longitude': -75.1428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13495', 'place_name': 'Yorkville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1116, 'longitude': -75.2756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13501', 'place_name': 'Utica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.0871, 'longitude': -75.2315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13502', 'place_name': 'Utica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1067, 'longitude': -75.2314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13503', 'place_name': 'Utica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1019, 'longitude': -75.2312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13504', 'place_name': 'Utica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1009, 'longitude': -75.2327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13505', 'place_name': 'Utica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1009, 'longitude': -75.2327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13599', 'place_name': 'Utica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oneida', 'locality_code': '65', 'latitude': 43.1009, 'longitude': -75.2327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13020', 'place_name': 'Apulia Station', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.8187, 'longitude': -76.0724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13027', 'place_name': 'Baldwinsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.162, 'longitude': -76.3237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13029', 'place_name': 'Brewerton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.2252, 'longitude': -76.1351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13030', 'place_name': 'Bridgeport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.159, 'longitude': -75.97, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13031', 'place_name': 'Camillus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0417, 'longitude': -76.2807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13039', 'place_name': 'Cicero', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1707, 'longitude': -76.0962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13041', 'place_name': 'Clay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1737, 'longitude': -76.1707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13051', 'place_name': 'Delphi Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.8765, 'longitude': -75.9135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13057', 'place_name': 'East Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0734, 'longitude': -76.0558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13060', 'place_name': 'Elbridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0252, 'longitude': -76.4352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13063', 'place_name': 'Fabius', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.8531, 'longitude': -75.9836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13066', 'place_name': 'Fayetteville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0268, 'longitude': -76.0145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13078', 'place_name': 'Jamesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.983, 'longitude': -76.0766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13080', 'place_name': 'Jordan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0651, 'longitude': -76.4598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13082', 'place_name': 'Kirkville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0981, 'longitude': -75.955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13084', 'place_name': 'La Fayette', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.891, 'longitude': -76.1061, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '13088', 'place_name': 'Liverpool', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1099, 'longitude': -76.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13089', 'place_name': 'Liverpool', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0214, 'longitude': -76.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13090', 'place_name': 'Liverpool', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1528, 'longitude': -76.2235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13104', 'place_name': 'Manlius', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.9904, 'longitude': -75.9703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13108', 'place_name': 'Marcellus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.9821, 'longitude': -76.3323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13110', 'place_name': 'Marietta', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.8974, 'longitude': -76.2806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13112', 'place_name': 'Memphis', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0934, 'longitude': -76.403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13116', 'place_name': 'Minoa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0772, 'longitude': -76.0098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13119', 'place_name': 'Mottville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.9745, 'longitude': -76.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13120', 'place_name': 'Nedrow', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.9559, 'longitude': -76.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13137', 'place_name': 'Plainville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1577, 'longitude': -76.447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13138', 'place_name': 'Pompey', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.899, 'longitude': -76.016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13152', 'place_name': 'Skaneateles', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.9258, 'longitude': -76.4052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13153', 'place_name': 'Skaneateles Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.9931, 'longitude': -76.456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13159', 'place_name': 'Tully', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.807, 'longitude': -76.1394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13164', 'place_name': 'Warners', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0932, 'longitude': -76.2904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13201', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0481, 'longitude': -76.1474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13202', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.041, 'longitude': -76.1489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13203', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0607, 'longitude': -76.1369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13204', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0444, 'longitude': -76.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13205', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0123, 'longitude': -76.1452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13206', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0677, 'longitude': -76.1102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13207', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0195, 'longitude': -76.165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13208', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.073, 'longitude': -76.1486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13209', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0847, 'longitude': -76.2405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13210', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0354, 'longitude': -76.1282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13211', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1036, 'longitude': -76.1195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13212', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1226, 'longitude': -76.1284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13214', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0397, 'longitude': -76.0722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13215', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 42.9722, 'longitude': -76.2276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13217', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0214, 'longitude': -76.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13218', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0214, 'longitude': -76.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13219', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0409, 'longitude': -76.2262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13220', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.1234, 'longitude': -76.1282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13221', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0481, 'longitude': -76.1474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13224', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0421, 'longitude': -76.1046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13225', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0214, 'longitude': -76.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13235', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0559, 'longitude': -76.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13244', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0377, 'longitude': -76.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13250', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0214, 'longitude': -76.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13251', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0214, 'longitude': -76.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13252', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.051, 'longitude': -76.1567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13261', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0481, 'longitude': -76.1474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13290', 'place_name': 'Syracuse', 'state': 'New York', 'state_ab': 'NY', 'county': 'Onondaga', 'locality_code': '67', 'latitude': 43.0676, 'longitude': -76.1714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14424', 'place_name': 'Canandaigua', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.8689, 'longitude': -77.2846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14425', 'place_name': 'Farmington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.958, 'longitude': -77.3083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14432', 'place_name': 'Clifton Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.9632, 'longitude': -77.144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14443', 'place_name': 'East Bloomfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.901, 'longitude': -77.4233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14453', 'place_name': 'Fishers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 43.0109, 'longitude': -77.4705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14456', 'place_name': 'Geneva', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.8637, 'longitude': -76.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14461', 'place_name': 'Gorham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.799, 'longitude': -77.1316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14463', 'place_name': 'Hall', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.7966, 'longitude': -77.0639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14469', 'place_name': 'Bloomfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.8851, 'longitude': -77.46, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '14471', 'place_name': 'Honeoye', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.7901, 'longitude': -77.5169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14475', 'place_name': 'Ionia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.938, 'longitude': -77.5009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14504', 'place_name': 'Manchester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.9689, 'longitude': -77.2332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14512', 'place_name': 'Naples', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.6404, 'longitude': -77.3901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14518', 'place_name': 'Oaks Corners', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.9319, 'longitude': -77.0118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14532', 'place_name': 'Phelps', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.9582, 'longitude': -77.0473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14537', 'place_name': 'Port Gibson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 43.0345, 'longitude': -77.1575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14547', 'place_name': 'Seneca Castle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.887, 'longitude': -77.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14548', 'place_name': 'Shortsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.9761, 'longitude': -77.2439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14561', 'place_name': 'Stanley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.8303, 'longitude': -77.1207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14564', 'place_name': 'Victor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.9866, 'longitude': -77.418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14585', 'place_name': 'West Bloomfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ontario', 'locality_code': '69', 'latitude': 42.9063, 'longitude': -77.5531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10910', 'place_name': 'Arden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.2745, 'longitude': -74.1529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10912', 'place_name': 'Bellvale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.2504, 'longitude': -74.3107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10914', 'place_name': 'Blooming Grove', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4093, 'longitude': -74.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10915', 'place_name': 'Bullville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5443, 'longitude': -74.3615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10916', 'place_name': 'Campbell Hall', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.443, 'longitude': -74.2505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10917', 'place_name': 'Central Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3268, 'longitude': -74.122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10918', 'place_name': 'Chester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3554, 'longitude': -74.2651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10919', 'place_name': 'Circleville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5244, 'longitude': -74.385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10921', 'place_name': 'Florida', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3295, 'longitude': -74.3528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10922', 'place_name': 'Fort Montgomery', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3346, 'longitude': -73.9917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10924', 'place_name': 'Goshen', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3946, 'longitude': -74.3302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10925', 'place_name': 'Greenwood Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.2101, 'longitude': -74.3033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10926', 'place_name': 'Harriman', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3005, 'longitude': -74.1249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10928', 'place_name': 'Highland Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3582, 'longitude': -73.9746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10930', 'place_name': 'Highland Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3536, 'longitude': -74.1197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10932', 'place_name': 'Howells', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4795, 'longitude': -74.4652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10933', 'place_name': 'Johnson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3653, 'longitude': -74.5109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10940', 'place_name': 'Middletown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4512, 'longitude': -74.4701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10941', 'place_name': 'Middletown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4886, 'longitude': -74.345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10949', 'place_name': 'Monroe', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3274, 'longitude': -74.1911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10950', 'place_name': 'Monroe', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3286, 'longitude': -74.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10953', 'place_name': 'Mountainville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4009, 'longitude': -74.0785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10958', 'place_name': 'New Hampton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3627, 'longitude': -74.4435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10959', 'place_name': 'New Milford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.2345, 'longitude': -74.4138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10963', 'place_name': 'Otisville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4818, 'longitude': -74.5294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10969', 'place_name': 'Pine Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.2926, 'longitude': -74.4888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10973', 'place_name': 'Slate Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.376, 'longitude': -74.4847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10975', 'place_name': 'Southfields', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.248, 'longitude': -74.1762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10979', 'place_name': 'Sterling Forest', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.1823, 'longitude': -74.3184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10981', 'place_name': 'Sugar Loaf', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3232, 'longitude': -74.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10985', 'place_name': 'Thompson Ridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.575, 'longitude': -74.3225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10987', 'place_name': 'Tuxedo Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.1925, 'longitude': -74.2159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10988', 'place_name': 'Unionville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.302, 'longitude': -74.5615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10990', 'place_name': 'Warwick', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.2656, 'longitude': -74.3604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10992', 'place_name': 'Washingtonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4237, 'longitude': -74.1601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10996', 'place_name': 'West Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3945, 'longitude': -73.9737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10997', 'place_name': 'West Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3915, 'longitude': -73.956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10998', 'place_name': 'Westtown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3214, 'longitude': -74.5529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12518', 'place_name': 'Cornwall', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4162, 'longitude': -74.0395, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '12520', 'place_name': 'Cornwall On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.433, 'longitude': -74.0061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12543', 'place_name': 'Maybrook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4886, 'longitude': -74.2163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12549', 'place_name': 'Montgomery', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5333, 'longitude': -74.2534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12550', 'place_name': 'Newburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5372, 'longitude': -74.0526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12551', 'place_name': 'Newburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5034, 'longitude': -74.0104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12552', 'place_name': 'Newburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5034, 'longitude': -74.0104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12553', 'place_name': 'New Windsor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4724, 'longitude': -74.0566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12555', 'place_name': 'Newburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5034, 'longitude': -74.0104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12566', 'place_name': 'Pine Bush', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.6178, 'longitude': -74.3263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12575', 'place_name': 'Rock Tavern', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4575, 'longitude': -74.1659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12577', 'place_name': 'Salisbury Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4497, 'longitude': -74.1214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12584', 'place_name': 'Vails Gate', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4641, 'longitude': -74.0591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12586', 'place_name': 'Walden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.5596, 'longitude': -74.1764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12729', 'place_name': 'Cuddebackville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4776, 'longitude': -74.5976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12746', 'place_name': 'Huguenot', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4179, 'longitude': -74.631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12771', 'place_name': 'Port Jervis', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.3786, 'longitude': -74.6691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12780', 'place_name': 'Sparrow Bush', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orange', 'locality_code': '71', 'latitude': 41.4443, 'longitude': -74.7213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14098', 'place_name': 'Lyndonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.3233, 'longitude': -78.3811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14103', 'place_name': 'Medina', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.2184, 'longitude': -78.3874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14411', 'place_name': 'Albion', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.2398, 'longitude': -78.2068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14429', 'place_name': 'Clarendon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.1934, 'longitude': -78.0647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14452', 'place_name': 'Fancher', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.2448, 'longitude': -78.0911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14470', 'place_name': 'Holley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.2159, 'longitude': -78.0731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14476', 'place_name': 'Kendall', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.3284, 'longitude': -78.0304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14477', 'place_name': 'Kent', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.3341, 'longitude': -78.1355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14479', 'place_name': 'Knowlesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.2363, 'longitude': -78.3138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14508', 'place_name': 'Morton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.3281, 'longitude': -77.9953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14571', 'place_name': 'Waterport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Orleans', 'locality_code': '73', 'latitude': 43.3326, 'longitude': -78.243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13028', 'place_name': 'Bernhards Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.2717, 'longitude': -75.9373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13036', 'place_name': 'Central Square', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.309, 'longitude': -76.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13042', 'place_name': 'Cleveland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.2432, 'longitude': -75.8537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13044', 'place_name': 'Constantia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.2728, 'longitude': -76.0042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13064', 'place_name': 'Fair Haven', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4313, 'longitude': -76.2004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13069', 'place_name': 'Fulton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.3211, 'longitude': -76.4034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13074', 'place_name': 'Hannibal', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.3111, 'longitude': -76.546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13076', 'place_name': 'Hastings', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.3527, 'longitude': -76.1477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13083', 'place_name': 'Lacona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.6429, 'longitude': -76.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13093', 'place_name': 'Lycoming', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4987, 'longitude': -76.3858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13103', 'place_name': 'Mallory', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.3237, 'longitude': -76.1166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13107', 'place_name': 'Maple View', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4578, 'longitude': -76.1534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13114', 'place_name': 'Mexico', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4605, 'longitude': -76.2446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13115', 'place_name': 'Minetto', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.3977, 'longitude': -76.4824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13121', 'place_name': 'New Haven', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4834, 'longitude': -76.315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13126', 'place_name': 'Oswego', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4394, 'longitude': -76.4613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13131', 'place_name': 'Parish', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4153, 'longitude': -76.1, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13132', 'place_name': 'Pennellville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.2609, 'longitude': -76.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13135', 'place_name': 'Phoenix', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.2468, 'longitude': -76.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13142', 'place_name': 'Pulaski', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.5562, 'longitude': -76.1252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13144', 'place_name': 'Richland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.5776, 'longitude': -76.0029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13145', 'place_name': 'Sandy Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.6517, 'longitude': -76.1264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13167', 'place_name': 'West Monroe', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.2882, 'longitude': -76.0797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13302', 'place_name': 'Altmar', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.497, 'longitude': -75.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13426', 'place_name': 'Orwell', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.5628, 'longitude': -75.9968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13437', 'place_name': 'Redfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.5658, 'longitude': -75.8242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13493', 'place_name': 'Williamstown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Oswego', 'locality_code': '75', 'latitude': 43.4106, 'longitude': -75.9044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12064', 'place_name': 'East Worcester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.6321, 'longitude': -74.6674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12116', 'place_name': 'Maryland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.5371, 'longitude': -74.903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12155', 'place_name': 'Schenevus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.59, 'longitude': -74.8149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12197', 'place_name': 'Worcester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.6049, 'longitude': -74.7299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13315', 'place_name': 'Burlington Flats', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.7516, 'longitude': -75.169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13320', 'place_name': 'Cherry Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.7823, 'longitude': -74.7444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13326', 'place_name': 'Cooperstown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.7005, 'longitude': -74.9243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13333', 'place_name': 'East Springfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.8336, 'longitude': -74.8233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13335', 'place_name': 'Edmeston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.6979, 'longitude': -75.2438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13337', 'place_name': 'Fly Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.7252, 'longitude': -74.9869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13342', 'place_name': 'Garrattsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.6315, 'longitude': -75.1866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13348', 'place_name': 'Hartwick', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.695, 'longitude': -75.055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13415', 'place_name': 'New Lisbon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.5904, 'longitude': -75.1957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13439', 'place_name': 'Richfield Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.8402, 'longitude': -74.9716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13450', 'place_name': 'Roseboom', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.708, 'longitude': -74.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13457', 'place_name': 'Schuyler Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.7758, 'longitude': -75.0485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13468', 'place_name': 'Springfield Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.8388, 'longitude': -74.859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13482', 'place_name': 'West Burlington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.7043, 'longitude': -75.1849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13485', 'place_name': 'West Edmeston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.7868, 'longitude': -75.3149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13488', 'place_name': 'Westford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.6809, 'longitude': -74.7653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13747', 'place_name': 'Colliersville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.5051, 'longitude': -74.9821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13776', 'place_name': 'Gilbertsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.4715, 'longitude': -75.3257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13796', 'place_name': 'Laurens', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.5383, 'longitude': -75.1279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13807', 'place_name': 'Milford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.6148, 'longitude': -74.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13808', 'place_name': 'Morris', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.5478, 'longitude': -75.2448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13810', 'place_name': 'Mount Vision', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.6068, 'longitude': -75.1264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13820', 'place_name': 'Oneonta', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.4625, 'longitude': -75.0491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13825', 'place_name': 'Otego', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.4133, 'longitude': -75.2079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13834', 'place_name': 'Portlandville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.5304, 'longitude': -74.9671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13849', 'place_name': 'Unadilla', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.3252, 'longitude': -75.3366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13859', 'place_name': 'Wells Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.3709, 'longitude': -75.2486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13861', 'place_name': 'West Oneonta', 'state': 'New York', 'state_ab': 'NY', 'county': 'Otsego', 'locality_code': '77', 'latitude': 42.5011, 'longitude': -75.1409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10509', 'place_name': 'Brewster', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.4097, 'longitude': -73.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10512', 'place_name': 'Carmel', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.4432, 'longitude': -73.6815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10516', 'place_name': 'Cold Spring', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.4414, 'longitude': -73.9335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10524', 'place_name': 'Garrison', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.3621, 'longitude': -73.92, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10537', 'place_name': 'Lake Peekskill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.3374, 'longitude': -73.8838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10541', 'place_name': 'Mahopac', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.3717, 'longitude': -73.7508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10542', 'place_name': 'Mahopac Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.3726, 'longitude': -73.7601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10579', 'place_name': 'Putnam Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.3728, 'longitude': -73.8502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12563', 'place_name': 'Patterson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Putnam', 'locality_code': '79', 'latitude': 41.4888, 'longitude': -73.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11004', 'place_name': 'Glen Oaks', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7481, 'longitude': -73.7114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11005', 'place_name': 'Floral Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7571, 'longitude': -73.7182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11101', 'place_name': 'Long Island City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7446, 'longitude': -73.9345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11102', 'place_name': 'Astoria', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7706, 'longitude': -73.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11103', 'place_name': 'Astoria', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7627, 'longitude': -73.9149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11104', 'place_name': 'Sunnyside', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7436, 'longitude': -73.9216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11105', 'place_name': 'Astoria', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7763, 'longitude': -73.911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11106', 'place_name': 'Astoria', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7608, 'longitude': -73.9295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11109', 'place_name': 'Long Island City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7454, 'longitude': -73.9575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11120', 'place_name': 'Long Island City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7448, 'longitude': -73.9487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11351', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7817, 'longitude': -73.8317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11352', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11354', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7667, 'longitude': -73.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11355', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7536, 'longitude': -73.8226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11356', 'place_name': 'College Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7855, 'longitude': -73.845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11357', 'place_name': 'Whitestone', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7851, 'longitude': -73.8096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11358', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7606, 'longitude': -73.7968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11359', 'place_name': 'Bayside', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7928, 'longitude': -73.7767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11360', 'place_name': 'Bayside', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7807, 'longitude': -73.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11361', 'place_name': 'Bayside', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7627, 'longitude': -73.7745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11362', 'place_name': 'Little Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7591, 'longitude': -73.7326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11363', 'place_name': 'Little Neck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7722, 'longitude': -73.7454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11364', 'place_name': 'Oakland Gardens', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7428, 'longitude': -73.7588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11365', 'place_name': 'Fresh Meadows', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7374, 'longitude': -73.7951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11366', 'place_name': 'Fresh Meadows', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7272, 'longitude': -73.7949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11367', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.728, 'longitude': -73.8195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11368', 'place_name': 'Corona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7453, 'longitude': -73.8611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11369', 'place_name': 'East Elmhurst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7613, 'longitude': -73.8739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11370', 'place_name': 'East Elmhurst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7611, 'longitude': -73.8916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11371', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7721, 'longitude': -73.8735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11372', 'place_name': 'Jackson Heights', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7513, 'longitude': -73.883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11373', 'place_name': 'Elmhurst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7351, 'longitude': -73.8776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11374', 'place_name': 'Rego Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7278, 'longitude': -73.8602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11375', 'place_name': 'Forest Hills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7229, 'longitude': -73.8473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11377', 'place_name': 'Woodside', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.745, 'longitude': -73.9069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11378', 'place_name': 'Maspeth', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7239, 'longitude': -73.8997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11379', 'place_name': 'Middle Village', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7173, 'longitude': -73.8792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11380', 'place_name': 'Elmhurst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7365, 'longitude': -73.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11381', 'place_name': 'Flushing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11385', 'place_name': 'Ridgewood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7036, 'longitude': -73.8961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11386', 'place_name': 'Ridgewood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7001, 'longitude': -73.9057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11405', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11411', 'place_name': 'Cambria Heights', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6947, 'longitude': -73.7374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11412', 'place_name': 'Saint Albans', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6958, 'longitude': -73.7617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11413', 'place_name': 'Springfield Gardens', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6645, 'longitude': -73.7559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11414', 'place_name': 'Howard Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6588, 'longitude': -73.8438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11415', 'place_name': 'Kew Gardens', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7069, 'longitude': -73.8297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11416', 'place_name': 'Ozone Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6838, 'longitude': -73.8514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11417', 'place_name': 'Ozone Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6769, 'longitude': -73.8448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11418', 'place_name': 'Richmond Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6982, 'longitude': -73.8345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11419', 'place_name': 'South Richmond Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6868, 'longitude': -73.823, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '11420', 'place_name': 'South Ozone Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6744, 'longitude': -73.819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11421', 'place_name': 'Woodhaven', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6913, 'longitude': -73.8585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11422', 'place_name': 'Rosedale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6621, 'longitude': -73.7353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11423', 'place_name': 'Hollis', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7142, 'longitude': -73.7677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11424', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11425', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11426', 'place_name': 'Bellerose', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7347, 'longitude': -73.723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11427', 'place_name': 'Queens Village', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7277, 'longitude': -73.7489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11428', 'place_name': 'Queens Village', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7208, 'longitude': -73.7433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11429', 'place_name': 'Queens Village', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.709, 'longitude': -73.7401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11430', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6472, 'longitude': -73.7827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11431', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6869, 'longitude': -73.8501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11432', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7119, 'longitude': -73.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11433', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6969, 'longitude': -73.7877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11434', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6775, 'longitude': -73.7758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11435', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.7029, 'longitude': -73.8111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11436', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6763, 'longitude': -73.7966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11437', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6763, 'longitude': -73.7966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11439', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.722, 'longitude': -73.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11451', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11499', 'place_name': 'Jamaica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11690', 'place_name': 'Far Rockaway', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6054, 'longitude': -73.7551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11691', 'place_name': 'Far Rockaway', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6006, 'longitude': -73.758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11692', 'place_name': 'Arverne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.5923, 'longitude': -73.7933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11693', 'place_name': 'Far Rockaway', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6076, 'longitude': -73.8198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11694', 'place_name': 'Rockaway Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.5766, 'longitude': -73.8428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11695', 'place_name': 'Far Rockaway', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.6514, 'longitude': -73.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11697', 'place_name': 'Breezy Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Queens', 'locality_code': '81', 'latitude': 40.5594, 'longitude': -73.9067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12018', 'place_name': 'Averill Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.6365, 'longitude': -73.5504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12022', 'place_name': 'Berlin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.6919, 'longitude': -73.3702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12024', 'place_name': 'Brainard', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.495, 'longitude': -73.5107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12028', 'place_name': 'Buskirk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.9601, 'longitude': -73.4497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12033', 'place_name': 'Castleton On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.5376, 'longitude': -73.7071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12040', 'place_name': 'Cherry Plain', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.6467, 'longitude': -73.3716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '12052', 'place_name': 'Cropseyville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.7667, 'longitude': -73.4719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12061', 'place_name': 'East Greenbush', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.5951, 'longitude': -73.6826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12062', 'place_name': 'East Nassau', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.5352, 'longitude': -73.4984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12063', 'place_name': 'East Schodack', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.5637, 'longitude': -73.6274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12082', 'place_name': 'Grafton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.7726, 'longitude': -73.4468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12089', 'place_name': 'Hoosick', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.8667, 'longitude': -73.3181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12090', 'place_name': 'Hoosick Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.8937, 'longitude': -73.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12094', 'place_name': 'Johnsonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.8769, 'longitude': -73.4989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12121', 'place_name': 'Melrose', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.8412, 'longitude': -73.6077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12123', 'place_name': 'Nassau', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.5271, 'longitude': -73.6118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12133', 'place_name': 'North Hoosick', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.9261, 'longitude': -73.3464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12138', 'place_name': 'Petersburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.7495, 'longitude': -73.3401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12140', 'place_name': 'Poestenkill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.6918, 'longitude': -73.5627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12144', 'place_name': 'Rensselaer', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.6359, 'longitude': -73.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12153', 'place_name': 'Sand Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.6379, 'longitude': -73.4989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12154', 'place_name': 'Schaghticoke', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.9144, 'longitude': -73.6154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12156', 'place_name': 'Schodack Landing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.4816, 'longitude': -73.748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12168', 'place_name': 'Stephentown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.5487, 'longitude': -73.374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12169', 'place_name': 'Stephentown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.5855, 'longitude': -73.4154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12180', 'place_name': 'Troy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.7287, 'longitude': -73.6683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12181', 'place_name': 'Troy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.7387, 'longitude': -73.6739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12182', 'place_name': 'Troy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.7829, 'longitude': -73.6648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12185', 'place_name': 'Valley Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.8855, 'longitude': -73.5437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12196', 'place_name': 'West Sand Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.638, 'longitude': -73.6109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12198', 'place_name': 'Wynantskill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rensselaer', 'locality_code': '83', 'latitude': 42.6878, 'longitude': -73.6383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10301', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.6316, 'longitude': -74.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10302', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.6306, 'longitude': -74.1379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10303', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.6301, 'longitude': -74.1607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10304', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.6102, 'longitude': -74.0878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10305', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.5973, 'longitude': -74.0768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10306', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.5682, 'longitude': -74.1184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10307', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.5085, 'longitude': -74.2445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10308', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.5518, 'longitude': -74.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10309', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.5352, 'longitude': -74.2116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10310', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.6324, 'longitude': -74.1171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10311', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.6052, 'longitude': -74.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10312', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.5457, 'longitude': -74.1792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10313', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.5644, 'longitude': -74.1468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10314', 'place_name': 'Staten Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Richmond', 'locality_code': '85', 'latitude': 40.6039, 'longitude': -74.1472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10901', 'place_name': 'Suffern', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1177, 'longitude': -74.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10911', 'place_name': 'Bear Mountain', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1609, 'longitude': -74.0608, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '10913', 'place_name': 'Blauvelt', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0626, 'longitude': -73.9629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10920', 'place_name': 'Congers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1487, 'longitude': -73.9413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10923', 'place_name': 'Garnerville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.2021, 'longitude': -74.0005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10927', 'place_name': 'Haverstraw', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1971, 'longitude': -73.969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10931', 'place_name': 'Hillburn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.124, 'longitude': -74.1702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10952', 'place_name': 'Monsey', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1163, 'longitude': -74.0736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10954', 'place_name': 'Nanuet', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0977, 'longitude': -74.0109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10956', 'place_name': 'New City', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1472, 'longitude': -73.9962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10960', 'place_name': 'Nyack', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0914, 'longitude': -73.9252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10962', 'place_name': 'Orangeburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0442, 'longitude': -73.9609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10964', 'place_name': 'Palisades', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0103, 'longitude': -73.925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10965', 'place_name': 'Pearl River', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0629, 'longitude': -74.0159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10968', 'place_name': 'Piermont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0395, 'longitude': -73.9192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10970', 'place_name': 'Pomona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1901, 'longitude': -74.0436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10974', 'place_name': 'Sloatsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1575, 'longitude': -74.2008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10976', 'place_name': 'Sparkill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0256, 'longitude': -73.9229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10977', 'place_name': 'Spring Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1158, 'longitude': -74.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10980', 'place_name': 'Stony Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.2292, 'longitude': -73.9962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10982', 'place_name': 'Tallman', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1112, 'longitude': -74.0999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10983', 'place_name': 'Tappan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0278, 'longitude': -73.9491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10984', 'place_name': 'Thiells', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.2078, 'longitude': -74.0154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10986', 'place_name': 'Tomkins Cove', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.2598, 'longitude': -73.9892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10989', 'place_name': 'Valley Cottage', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.1183, 'longitude': -73.943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10993', 'place_name': 'West Haverstraw', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.209, 'longitude': -73.9821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10994', 'place_name': 'West Nyack', 'state': 'New York', 'state_ab': 'NY', 'county': 'Rockland', 'locality_code': '87', 'latitude': 41.0973, 'longitude': -73.9768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12922', 'place_name': 'Childwold', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.2867, 'longitude': -74.6759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12927', 'place_name': 'Cranberry Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.229, 'longitude': -74.8581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12949', 'place_name': 'Lawrenceville', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.7469, 'longitude': -74.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12965', 'place_name': 'Nicholville', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.703, 'longitude': -74.6805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12967', 'place_name': 'North Lawrence', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.775, 'longitude': -74.6653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12973', 'place_name': 'Piercefield', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.2343, 'longitude': -74.556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13613', 'place_name': 'Brasher Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.8467, 'longitude': -74.7473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13614', 'place_name': 'Brier Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5525, 'longitude': -75.6722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13617', 'place_name': 'Canton', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5924, 'longitude': -75.1628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13621', 'place_name': 'Chase Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.8672, 'longitude': -75.073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13623', 'place_name': 'Chippewa Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.442, 'longitude': -75.7569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13625', 'place_name': 'Colton', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5016, 'longitude': -74.9327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13630', 'place_name': 'De Kalb Junction', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.4896, 'longitude': -75.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13633', 'place_name': 'De Peyster', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.4989, 'longitude': -75.4772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13635', 'place_name': 'Edwards', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.311, 'longitude': -75.2522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13639', 'place_name': 'Fine', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.2541, 'longitude': -75.1379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13642', 'place_name': 'Gouverneur', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.3283, 'longitude': -75.4651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13645', 'place_name': 'Hailesboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.3101, 'longitude': -75.4463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13646', 'place_name': 'Hammond', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.4502, 'longitude': -75.6727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13647', 'place_name': 'Hannawa Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.6087, 'longitude': -74.9732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13649', 'place_name': 'Helena', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.9217, 'longitude': -74.7068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13652', 'place_name': 'Hermon', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.4448, 'longitude': -75.1987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13654', 'place_name': 'Heuvelton', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.593, 'longitude': -75.4203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13658', 'place_name': 'Lisbon', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.7184, 'longitude': -75.2694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13660', 'place_name': 'Madrid', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.769, 'longitude': -75.1413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13662', 'place_name': 'Massena', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.9322, 'longitude': -74.8845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13664', 'place_name': 'Morristown', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5843, 'longitude': -75.6453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13666', 'place_name': 'Newton Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.2177, 'longitude': -74.9423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13667', 'place_name': 'Norfolk', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.8424, 'longitude': -74.9577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13668', 'place_name': 'Norwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.7472, 'longitude': -74.9992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13669', 'place_name': 'Ogdensburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.6902, 'longitude': -75.4774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13670', 'place_name': 'Oswegatchie', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.1933, 'longitude': -75.0659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13672', 'place_name': 'Parishville', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5927, 'longitude': -74.7941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13676', 'place_name': 'Potsdam', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.6592, 'longitude': -74.9681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13677', 'place_name': 'Pyrites', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5148, 'longitude': -75.1858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13678', 'place_name': 'Raymondville', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.8287, 'longitude': -74.9798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13680', 'place_name': 'Rensselaer Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5943, 'longitude': -75.3237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13681', 'place_name': 'Richville', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.44, 'longitude': -75.3777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13683', 'place_name': 'Rooseveltown', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.9728, 'longitude': -74.731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13684', 'place_name': 'Russell', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.3824, 'longitude': -75.1043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13687', 'place_name': 'South Colton', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.5041, 'longitude': -74.8607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13690', 'place_name': 'Star Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.1578, 'longitude': -75.033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13694', 'place_name': 'Waddington', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.8564, 'longitude': -75.2049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13695', 'place_name': 'Wanakena', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.1408, 'longitude': -74.9125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13696', 'place_name': 'West Stockholm', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.7137, 'longitude': -74.9008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13697', 'place_name': 'Winthrop', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.7583, 'longitude': -74.8066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13699', 'place_name': 'Potsdam', 'state': 'New York', 'state_ab': 'NY', 'county': 'St. Lawrence', 'locality_code': '89', 'latitude': 44.6698, 'longitude': -74.9813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12019', 'place_name': 'Ballston Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 42.9192, 'longitude': -73.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12020', 'place_name': 'Ballston Spa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.005, 'longitude': -73.8486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12027', 'place_name': 'Burnt Hills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 42.9329, 'longitude': -73.896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12065', 'place_name': 'Clifton Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 42.8499, 'longitude': -73.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12074', 'place_name': 'Galway', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.0217, 'longitude': -74.029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12118', 'place_name': 'Mechanicville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 42.9168, 'longitude': -73.7214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12148', 'place_name': 'Rexford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 42.8524, 'longitude': -73.8701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12151', 'place_name': 'Round Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 42.9247, 'longitude': -73.7859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12170', 'place_name': 'Stillwater', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.0019, 'longitude': -73.6609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12188', 'place_name': 'Waterford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 42.81, 'longitude': -73.6995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12803', 'place_name': 'South Glens Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.2836, 'longitude': -73.6294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12822', 'place_name': 'Corinth', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.2426, 'longitude': -73.8369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12831', 'place_name': 'Gansevoort', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.1803, 'longitude': -73.7053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12833', 'place_name': 'Greenfield Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.1401, 'longitude': -73.8398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12835', 'place_name': 'Hadley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.3173, 'longitude': -73.8482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12850', 'place_name': 'Middle Grove', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.0975, 'longitude': -74.0167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12859', 'place_name': 'Porter Corners', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.1724, 'longitude': -73.8839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12863', 'place_name': 'Rock City Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.0662, 'longitude': -73.9215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12866', 'place_name': 'Saratoga Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.0708, 'longitude': -73.7408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12871', 'place_name': 'Schuylerville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.0878, 'longitude': -73.6007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12884', 'place_name': 'Victory Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Saratoga', 'locality_code': '91', 'latitude': 43.0884, 'longitude': -73.5917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12008', 'place_name': 'Alplaus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8573, 'longitude': -73.9002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12053', 'place_name': 'Delanson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.748, 'longitude': -74.1868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12056', 'place_name': 'Duanesburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.7708, 'longitude': -74.0839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12137', 'place_name': 'Pattersonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8499, 'longitude': -74.1231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12141', 'place_name': 'Quaker Street', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.7318, 'longitude': -74.1854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12150', 'place_name': 'Rotterdam Junction', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8745, 'longitude': -74.0465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12301', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8142, 'longitude': -73.9396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12302', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.88, 'longitude': -73.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12303', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.7823, 'longitude': -73.9448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12304', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.7841, 'longitude': -73.9094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12305', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8161, 'longitude': -73.9398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12306', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.7904, 'longitude': -73.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12307', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8047, 'longitude': -73.9363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12308', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8179, 'longitude': -73.9206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12309', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8091, 'longitude': -73.8693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12325', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8333, 'longitude': -74.058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12345', 'place_name': 'Schenectady', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schenectady', 'locality_code': '93', 'latitude': 42.8142, 'longitude': -73.9396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12031', 'place_name': 'Carlisle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.7648, 'longitude': -74.4569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12035', 'place_name': 'Central Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.737, 'longitude': -74.3451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12036', 'place_name': 'Charlotteville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.533, 'longitude': -74.6819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12043', 'place_name': 'Cobleskill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.684, 'longitude': -74.4939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12071', 'place_name': 'Fultonham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.5923, 'longitude': -74.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12073', 'place_name': 'Gallupville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.6626, 'longitude': -74.2326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12076', 'place_name': 'Gilboa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.4108, 'longitude': -74.4003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12092', 'place_name': 'Howes Cave', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.7045, 'longitude': -74.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12093', 'place_name': 'Jefferson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.4999, 'longitude': -74.6117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12122', 'place_name': 'Middleburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.5637, 'longitude': -74.3292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12131', 'place_name': 'North Blenheim', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.4899, 'longitude': -74.4282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12149', 'place_name': 'Richmondville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.6424, 'longitude': -74.571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12157', 'place_name': 'Schoharie', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.6615, 'longitude': -74.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12160', 'place_name': 'Sloansville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.7599, 'longitude': -74.3642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12175', 'place_name': 'Summit', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.535, 'longitude': -74.5452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12187', 'place_name': 'Warnerville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.6604, 'longitude': -74.5074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12194', 'place_name': 'West Fulton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.5506, 'longitude': -74.4631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13459', 'place_name': 'Sharon Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schoharie', 'locality_code': '95', 'latitude': 42.7634, 'longitude': -74.5919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14805', 'place_name': 'Alpine', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.351, 'longitude': -76.7348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14812', 'place_name': 'Beaver Dams', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.2798, 'longitude': -76.972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14818', 'place_name': 'Burdett', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.4394, 'longitude': -76.8292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14824', 'place_name': 'Cayuta', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.2774, 'longitude': -76.6974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14841', 'place_name': 'Hector', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.4966, 'longitude': -76.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14863', 'place_name': 'Mecklenburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.4516, 'longitude': -76.7067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14865', 'place_name': 'Montour Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.3437, 'longitude': -76.8396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14869', 'place_name': 'Odessa', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.3609, 'longitude': -76.7717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14876', 'place_name': 'Reading Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.4297, 'longitude': -76.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14887', 'place_name': 'Tyrone', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.3994, 'longitude': -77.0268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14891', 'place_name': 'Watkins Glen', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.3771, 'longitude': -76.9022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14893', 'place_name': 'Wayne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Schuyler', 'locality_code': '97', 'latitude': 42.4741, 'longitude': -77.0977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13065', 'place_name': 'Fayette', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.8227, 'longitude': -76.802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13148', 'place_name': 'Seneca Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.9094, 'longitude': -76.7925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13165', 'place_name': 'Waterloo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.9045, 'longitude': -76.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14521', 'place_name': 'Ovid', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.6898, 'longitude': -76.7941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14541', 'place_name': 'Romulus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.7497, 'longitude': -76.8449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14588', 'place_name': 'Willard', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.6835, 'longitude': -76.8724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14847', 'place_name': 'Interlaken', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.6165, 'longitude': -76.7268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14860', 'place_name': 'Lodi', 'state': 'New York', 'state_ab': 'NY', 'county': 'Seneca', 'locality_code': '99', 'latitude': 42.5966, 'longitude': -76.8339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14529', 'place_name': 'Perkinsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.5398, 'longitude': -77.6283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14572', 'place_name': 'Wayland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.5593, 'longitude': -77.5906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14801', 'place_name': 'Addison', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.0983, 'longitude': -77.266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14807', 'place_name': 'Arkport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.4225, 'longitude': -77.6918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14808', 'place_name': 'Atlanta', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.5596, 'longitude': -77.4669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14809', 'place_name': 'Avoca', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.3679, 'longitude': -77.4641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14810', 'place_name': 'Bath', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.3575, 'longitude': -77.3028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14815', 'place_name': 'Bradford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.3825, 'longitude': -77.0913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14819', 'place_name': 'Cameron', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.2128, 'longitude': -77.4403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14820', 'place_name': 'Cameron Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.1925, 'longitude': -77.365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14821', 'place_name': 'Campbell', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.2386, 'longitude': -77.2066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14823', 'place_name': 'Canisteo', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.2635, 'longitude': -77.5897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14826', 'place_name': 'Cohocton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.5003, 'longitude': -77.4998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14827', 'place_name': 'Coopers Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.1785, 'longitude': -77.1414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14830', 'place_name': 'Corning', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.1383, 'longitude': -77.0475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14831', 'place_name': 'Corning', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.1429, 'longitude': -77.0547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14839', 'place_name': 'Greenwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.1398, 'longitude': -77.636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14840', 'place_name': 'Hammondsport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.4312, 'longitude': -77.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14843', 'place_name': 'Hornell', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.3274, 'longitude': -77.6569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14855', 'place_name': 'Jasper', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.129, 'longitude': -77.4999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14856', 'place_name': 'Kanona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.3742, 'longitude': -77.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14858', 'place_name': 'Lindley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.0284, 'longitude': -77.1397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14870', 'place_name': 'Painted Post', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.171, 'longitude': -77.1194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14873', 'place_name': 'Prattsburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.5224, 'longitude': -77.2983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14874', 'place_name': 'Pulteney', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.5233, 'longitude': -77.1691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14877', 'place_name': 'Rexville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.0726, 'longitude': -77.6767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14879', 'place_name': 'Savona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.3041, 'longitude': -77.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14885', 'place_name': 'Troupsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.0501, 'longitude': -77.5502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14898', 'place_name': 'Woodhull', 'state': 'New York', 'state_ab': 'NY', 'county': 'Steuben', 'locality_code': '101', 'latitude': 42.0736, 'longitude': -77.4203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '501', 'place_name': 'Holtsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8154, 'longitude': -73.0451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '544', 'place_name': 'Holtsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8154, 'longitude': -73.0451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '6390', 'place_name': 'Fishers Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.2639, 'longitude': -72.0178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11701', 'place_name': 'Amityville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.6842, 'longitude': -73.4171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11702', 'place_name': 'Babylon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.6957, 'longitude': -73.3257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11703', 'place_name': 'North Babylon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7321, 'longitude': -73.3236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11704', 'place_name': 'West Babylon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7135, 'longitude': -73.3546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11705', 'place_name': 'Bayport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7444, 'longitude': -73.0542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11706', 'place_name': 'Bay Shore', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7051, 'longitude': -73.243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11707', 'place_name': 'West Babylon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7182, 'longitude': -73.3543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11713', 'place_name': 'Bellport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7733, 'longitude': -72.9469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11715', 'place_name': 'Blue Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7501, 'longitude': -73.0352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11716', 'place_name': 'Bohemia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7678, 'longitude': -73.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11717', 'place_name': 'Brentwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7809, 'longitude': -73.2503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11718', 'place_name': 'Brightwaters', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.728, 'longitude': -73.2646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11719', 'place_name': 'Brookhaven', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7843, 'longitude': -72.8921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11720', 'place_name': 'Centereach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8705, 'longitude': -73.0822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11721', 'place_name': 'Centerport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8929, 'longitude': -73.3754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11722', 'place_name': 'Central Islip', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7866, 'longitude': -73.1961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11724', 'place_name': 'Cold Spring Harbor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8601, 'longitude': -73.4423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11725', 'place_name': 'Commack', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.843, 'longitude': -73.2799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11726', 'place_name': 'Copiague', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.6778, 'longitude': -73.3963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11727', 'place_name': 'Coram', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.885, 'longitude': -73.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11729', 'place_name': 'Deer Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7591, 'longitude': -73.3257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11730', 'place_name': 'East Islip', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7282, 'longitude': -73.1805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11731', 'place_name': 'East Northport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.857, 'longitude': -73.3146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11733', 'place_name': 'East Setauket', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9426, 'longitude': -73.1116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11738', 'place_name': 'Farmingville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8366, 'longitude': -73.0413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11739', 'place_name': 'Great River', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7297, 'longitude': -73.1607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11740', 'place_name': 'Greenlawn', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8621, 'longitude': -73.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11741', 'place_name': 'Holbrook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7964, 'longitude': -73.0718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11742', 'place_name': 'Holtsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8105, 'longitude': -73.0416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11743', 'place_name': 'Huntington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8676, 'longitude': -73.4102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11746', 'place_name': 'Huntington Station', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8143, 'longitude': -73.3634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11747', 'place_name': 'Melville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7946, 'longitude': -73.403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11749', 'place_name': 'Islandia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8067, 'longitude': -73.1709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11751', 'place_name': 'Islip', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7348, 'longitude': -73.2221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11752', 'place_name': 'Islip Terrace', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7548, 'longitude': -73.1827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11754', 'place_name': 'Kings Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8861, 'longitude': -73.2438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11755', 'place_name': 'Lake Grove', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8567, 'longitude': -73.1168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11757', 'place_name': 'Lindenhurst', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.6884, 'longitude': -73.3745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11760', 'place_name': 'Melville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7934, 'longitude': -73.4151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11763', 'place_name': 'Medford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8174, 'longitude': -72.9852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11764', 'place_name': 'Miller Place', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9436, 'longitude': -72.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11766', 'place_name': 'Mount Sinai', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9271, 'longitude': -73.0127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11767', 'place_name': 'Nesconset', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8462, 'longitude': -73.1482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11768', 'place_name': 'Northport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9051, 'longitude': -73.3309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11769', 'place_name': 'Oakdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7382, 'longitude': -73.1297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11770', 'place_name': 'Ocean Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.6443, 'longitude': -73.1613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11772', 'place_name': 'Patchogue', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7609, 'longitude': -72.9871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11775', 'place_name': 'Melville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7934, 'longitude': -73.4151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11776', 'place_name': 'Port Jefferson Station', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9136, 'longitude': -73.0464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11777', 'place_name': 'Port Jefferson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9457, 'longitude': -73.0611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11778', 'place_name': 'Rocky Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9492, 'longitude': -72.9357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11779', 'place_name': 'Ronkonkoma', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8083, 'longitude': -73.1305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11780', 'place_name': 'Saint James', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8813, 'longitude': -73.1591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11782', 'place_name': 'Sayville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7459, 'longitude': -73.0859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11784', 'place_name': 'Selden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8699, 'longitude': -73.0448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11786', 'place_name': 'Shoreham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9485, 'longitude': -72.8927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11787', 'place_name': 'Smithtown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8542, 'longitude': -73.2138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11788', 'place_name': 'Hauppauge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8231, 'longitude': -73.1958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11789', 'place_name': 'Sound Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9567, 'longitude': -72.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11790', 'place_name': 'Stony Brook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9068, 'longitude': -73.1277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11792', 'place_name': 'Wading River', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.952, 'longitude': -72.8348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11794', 'place_name': 'Stony Brook', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9257, 'longitude': -73.1409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11795', 'place_name': 'West Islip', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7117, 'longitude': -73.3007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11796', 'place_name': 'West Sayville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.732, 'longitude': -73.1, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11798', 'place_name': 'Wyandanch', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7523, 'longitude': -73.3761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11901', 'place_name': 'Riverhead', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9262, 'longitude': -72.652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11930', 'place_name': 'Amagansett', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9895, 'longitude': -72.0959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11931', 'place_name': 'Aquebogue', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9445, 'longitude': -72.627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11932', 'place_name': 'Bridgehampton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9339, 'longitude': -72.3077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11933', 'place_name': 'Calverton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9297, 'longitude': -72.7423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11934', 'place_name': 'Center Moriches', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7997, 'longitude': -72.797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11935', 'place_name': 'Cutchogue', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.0139, 'longitude': -72.4803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11937', 'place_name': 'East Hampton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.993, 'longitude': -72.179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11939', 'place_name': 'East Marion', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.1264, 'longitude': -72.3419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11940', 'place_name': 'East Moriches', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.809, 'longitude': -72.7538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11941', 'place_name': 'Eastport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8297, 'longitude': -72.7283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11942', 'place_name': 'East Quogue', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8428, 'longitude': -72.5813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11944', 'place_name': 'Greenport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.1039, 'longitude': -72.3674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11946', 'place_name': 'Hampton Bays', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8726, 'longitude': -72.5202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11947', 'place_name': 'Jamesport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9495, 'longitude': -72.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11948', 'place_name': 'Laurel', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9674, 'longitude': -72.554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11949', 'place_name': 'Manorville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8421, 'longitude': -72.8002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11950', 'place_name': 'Mastic', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8064, 'longitude': -72.8566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11951', 'place_name': 'Mastic Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.7657, 'longitude': -72.8537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11952', 'place_name': 'Mattituck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9943, 'longitude': -72.5363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11953', 'place_name': 'Middle Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8782, 'longitude': -72.9525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11954', 'place_name': 'Montauk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.0459, 'longitude': -71.944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11955', 'place_name': 'Moriches', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8095, 'longitude': -72.8229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11956', 'place_name': 'New Suffolk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9915, 'longitude': -72.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11957', 'place_name': 'Orient', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.1437, 'longitude': -72.2879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11958', 'place_name': 'Peconic', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.0392, 'longitude': -72.4666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11959', 'place_name': 'Quogue', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8226, 'longitude': -72.6012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11960', 'place_name': 'Remsenburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8086, 'longitude': -72.7064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11961', 'place_name': 'Ridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9018, 'longitude': -72.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11962', 'place_name': 'Sagaponack', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9305, 'longitude': -72.2707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11963', 'place_name': 'Sag Harbor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.982, 'longitude': -72.3067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11964', 'place_name': 'Shelter Island', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.064, 'longitude': -72.3366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11965', 'place_name': 'Shelter Island Heights', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.084, 'longitude': -72.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11967', 'place_name': 'Shirley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8015, 'longitude': -72.8676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11968', 'place_name': 'Southampton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9043, 'longitude': -72.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11969', 'place_name': 'Southampton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8843, 'longitude': -72.3895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11970', 'place_name': 'South Jamesport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9365, 'longitude': -72.5773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11971', 'place_name': 'Southold', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 41.0555, 'longitude': -72.429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11972', 'place_name': 'Speonk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8195, 'longitude': -72.7054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11973', 'place_name': 'Upton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8678, 'longitude': -72.8822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11975', 'place_name': 'Wainscott', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9396, 'longitude': -72.2425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11976', 'place_name': 'Water Mill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.9209, 'longitude': -72.3491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11977', 'place_name': 'Westhampton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.818, 'longitude': -72.6699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11978', 'place_name': 'Westhampton Beach', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.8295, 'longitude': -72.6473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '11980', 'place_name': 'Yaphank', 'state': 'New York', 'state_ab': 'NY', 'county': 'Suffolk', 'locality_code': '103', 'latitude': 40.837, 'longitude': -72.9174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12701', 'place_name': 'Monticello', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6516, 'longitude': -74.7007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12719', 'place_name': 'Barryville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.4912, 'longitude': -74.9152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12720', 'place_name': 'Bethel', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6693, 'longitude': -74.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12721', 'place_name': 'Bloomingburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5644, 'longitude': -74.4304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12722', 'place_name': 'Burlingham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5901, 'longitude': -74.3821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12723', 'place_name': 'Callicoon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7673, 'longitude': -75.0563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12724', 'place_name': 'Callicoon Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8368, 'longitude': -74.9466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12725', 'place_name': 'Claryville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.9657, 'longitude': -74.5293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12726', 'place_name': 'Cochecton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.692, 'longitude': -74.9741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12727', 'place_name': 'Cochecton Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6548, 'longitude': -74.9827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12732', 'place_name': 'Eldred', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5328, 'longitude': -74.8968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12733', 'place_name': 'Fallsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7273, 'longitude': -74.6154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12734', 'place_name': 'Ferndale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7349, 'longitude': -74.7345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12736', 'place_name': 'Fremont Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8782, 'longitude': -75.0343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12737', 'place_name': 'Glen Spey', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.4858, 'longitude': -74.7995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12738', 'place_name': 'Glen Wild', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6545, 'longitude': -74.5833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12740', 'place_name': 'Grahamsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8807, 'longitude': -74.5127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12741', 'place_name': 'Hankins', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8391, 'longitude': -75.0534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12742', 'place_name': 'Harris', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7143, 'longitude': -74.7263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12743', 'place_name': 'Highland Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5309, 'longitude': -74.8516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12745', 'place_name': 'Hortonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7629, 'longitude': -75.0306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12747', 'place_name': 'Hurleyville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7356, 'longitude': -74.6743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12748', 'place_name': 'Jeffersonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7784, 'longitude': -74.9196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12749', 'place_name': 'Kauneonga Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6874, 'longitude': -74.8358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12750', 'place_name': 'Kenoza Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7296, 'longitude': -74.9611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12751', 'place_name': 'Kiamesha Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6838, 'longitude': -74.6724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12752', 'place_name': 'Lake Huntington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6782, 'longitude': -74.9949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12754', 'place_name': 'Liberty', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7962, 'longitude': -74.7484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12758', 'place_name': 'Livingston Manor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8778, 'longitude': -74.827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12759', 'place_name': 'Loch Sheldrake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7789, 'longitude': -74.6614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12760', 'place_name': 'Long Eddy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8644, 'longitude': -75.0942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12762', 'place_name': 'Mongaup Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.681, 'longitude': -74.8028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12763', 'place_name': 'Mountain Dale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6918, 'longitude': -74.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12764', 'place_name': 'Narrowsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5921, 'longitude': -75.0107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12765', 'place_name': 'Neversink', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8492, 'longitude': -74.6127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12766', 'place_name': 'North Branch', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8142, 'longitude': -74.9824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12767', 'place_name': 'Obernburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8448, 'longitude': -75.0071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12768', 'place_name': 'Parksville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8517, 'longitude': -74.7359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12769', 'place_name': 'Phillipsport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6515, 'longitude': -74.4362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12770', 'place_name': 'Pond Eddy', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.4511, 'longitude': -74.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12775', 'place_name': 'Rock Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6134, 'longitude': -74.5872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12776', 'place_name': 'Roscoe', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.9609, 'longitude': -74.9346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12777', 'place_name': 'Forestburgh', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5691, 'longitude': -74.7241, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '12778', 'place_name': 'Smallwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6615, 'longitude': -74.8178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12779', 'place_name': 'South Fallsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7042, 'longitude': -74.6444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12781', 'place_name': 'Summitville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6215, 'longitude': -74.4507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12783', 'place_name': 'Swan Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7285, 'longitude': -74.8341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12784', 'place_name': 'Thompsonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6681, 'longitude': -74.6252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12785', 'place_name': 'Westbrookville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.4987, 'longitude': -74.5585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12786', 'place_name': 'White Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.6485, 'longitude': -74.8654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12787', 'place_name': 'White Sulphur Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8002, 'longitude': -74.8286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12788', 'place_name': 'Woodbourne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.7708, 'longitude': -74.5928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12789', 'place_name': 'Woodridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.717, 'longitude': -74.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12790', 'place_name': 'Wurtsboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5877, 'longitude': -74.5039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12791', 'place_name': 'Youngsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.8032, 'longitude': -74.8888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12792', 'place_name': 'Yulan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Sullivan', 'locality_code': '105', 'latitude': 41.5226, 'longitude': -74.9329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13732', 'place_name': 'Apalachin', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.0556, 'longitude': -76.1519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13734', 'place_name': 'Barton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.0695, 'longitude': -76.3983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13736', 'place_name': 'Berkshire', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.3074, 'longitude': -76.192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13743', 'place_name': 'Candor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.2063, 'longitude': -76.3322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13811', 'place_name': 'Newark Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.2281, 'longitude': -76.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13812', 'place_name': 'Nichols', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.0301, 'longitude': -76.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13827', 'place_name': 'Owego', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.1138, 'longitude': -76.2528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13835', 'place_name': 'Richford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.3945, 'longitude': -76.1865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13840', 'place_name': 'Smithboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.0395, 'longitude': -76.4004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13845', 'place_name': 'Tioga Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.0562, 'longitude': -76.348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13864', 'place_name': 'Willseyville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.3029, 'longitude': -76.3897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14859', 'place_name': 'Lockwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.1149, 'longitude': -76.5366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14883', 'place_name': 'Spencer', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.2467, 'longitude': -76.4899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14892', 'place_name': 'Waverly', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tioga', 'locality_code': '107', 'latitude': 42.0172, 'longitude': -76.5333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13053', 'place_name': 'Dryden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4861, 'longitude': -76.2872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13062', 'place_name': 'Etna', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4851, 'longitude': -76.3835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13068', 'place_name': 'Freeville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4998, 'longitude': -76.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13073', 'place_name': 'Groton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.5855, 'longitude': -76.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13102', 'place_name': 'Mc Lean', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.5542, 'longitude': -76.2927, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '14817', 'place_name': 'Brooktondale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.3765, 'longitude': -76.3668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14850', 'place_name': 'Ithaca', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4406, 'longitude': -76.4966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14851', 'place_name': 'Ithaca', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4607, 'longitude': -76.5054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14852', 'place_name': 'Ithaca', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4451, 'longitude': -76.4672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14853', 'place_name': 'Ithaca', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4474, 'longitude': -76.4837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14854', 'place_name': 'Jacksonville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.5084, 'longitude': -76.6149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14867', 'place_name': 'Newfield', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.3621, 'longitude': -76.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14881', 'place_name': 'Slaterville Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.4025, 'longitude': -76.3608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14882', 'place_name': 'Lansing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.5645, 'longitude': -76.5375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14886', 'place_name': 'Trumansburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Tompkins', 'locality_code': '109', 'latitude': 42.521, 'longitude': -76.6681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12401', 'place_name': 'Kingston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.9697, 'longitude': -74.0668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12402', 'place_name': 'Kingston', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.927, 'longitude': -73.9974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12404', 'place_name': 'Accord', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8083, 'longitude': -74.2353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12409', 'place_name': 'Bearsville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0406, 'longitude': -74.1551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12410', 'place_name': 'Big Indian', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.074, 'longitude': -74.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12411', 'place_name': 'Bloomington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8752, 'longitude': -74.0436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12412', 'place_name': 'Boiceville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0048, 'longitude': -74.2658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12416', 'place_name': 'Chichester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.095, 'longitude': -74.2717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12417', 'place_name': 'Connelly', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.9076, 'longitude': -73.9893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12419', 'place_name': 'Cottekill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8467, 'longitude': -74.1038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12420', 'place_name': 'Cragsmoor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6698, 'longitude': -74.3801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12428', 'place_name': 'Ellenville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.7218, 'longitude': -74.4141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12429', 'place_name': 'Esopus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8279, 'longitude': -73.9651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12432', 'place_name': 'Glasco', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0437, 'longitude': -73.9474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12433', 'place_name': 'Glenford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0053, 'longitude': -74.1532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12435', 'place_name': 'Greenfield Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.7281, 'longitude': -74.5201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12440', 'place_name': 'High Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8167, 'longitude': -74.1311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12441', 'place_name': 'Highmount', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.1443, 'longitude': -74.4899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12443', 'place_name': 'Hurley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.9327, 'longitude': -74.0687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12446', 'place_name': 'Kerhonkson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.7939, 'longitude': -74.3035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12448', 'place_name': 'Lake Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0733, 'longitude': -74.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12449', 'place_name': 'Lake Katrine', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.9918, 'longitude': -73.9924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12453', 'place_name': 'Malden On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0987, 'longitude': -73.9354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12456', 'place_name': 'Mount Marion', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0357, 'longitude': -74.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12457', 'place_name': 'Mount Tremper', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0435, 'longitude': -74.2485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12458', 'place_name': 'Napanoch', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.759, 'longitude': -74.3804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12461', 'place_name': 'Olivebridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.875, 'longitude': -74.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12464', 'place_name': 'Phoenicia', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0848, 'longitude': -74.3154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12465', 'place_name': 'Pine Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.1331, 'longitude': -74.4802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12466', 'place_name': 'Port Ewen', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8948, 'longitude': -73.9767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12471', 'place_name': 'Rifton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8403, 'longitude': -74.0306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12472', 'place_name': 'Rosendale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8402, 'longitude': -74.073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12475', 'place_name': 'Ruby', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0176, 'longitude': -74.0079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12477', 'place_name': 'Saugerties', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0738, 'longitude': -73.9797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12480', 'place_name': 'Shandaken', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.1363, 'longitude': -74.3774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12481', 'place_name': 'Shokan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.9767, 'longitude': -74.2119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12483', 'place_name': 'Spring Glen', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6639, 'longitude': -74.4245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12484', 'place_name': 'Stone Ridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8616, 'longitude': -74.1697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12486', 'place_name': 'Tillson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8338, 'longitude': -74.0626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12487', 'place_name': 'Ulster Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.8651, 'longitude': -73.9948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12489', 'place_name': 'Wawarsing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.7606, 'longitude': -74.3535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12490', 'place_name': 'West Camp', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.1231, 'longitude': -73.9349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12491', 'place_name': 'West Hurley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.9973, 'longitude': -74.1049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12493', 'place_name': 'West Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.7953, 'longitude': -73.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12494', 'place_name': 'West Shokan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.9673, 'longitude': -74.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12495', 'place_name': 'Willow', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0849, 'longitude': -74.2407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12498', 'place_name': 'Woodstock', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 42.0348, 'longitude': -74.112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12515', 'place_name': 'Clintondale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6749, 'longitude': -74.0557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12525', 'place_name': 'Gardiner', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6576, 'longitude': -74.1672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12528', 'place_name': 'Highland', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.7167, 'longitude': -73.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12542', 'place_name': 'Marlboro', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6056, 'longitude': -73.988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12547', 'place_name': 'Milton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6535, 'longitude': -73.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12548', 'place_name': 'Modena', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6503, 'longitude': -74.1036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12561', 'place_name': 'New Paltz', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.7464, 'longitude': -74.1092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12568', 'place_name': 'Plattekill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6412, 'longitude': -74.0781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12588', 'place_name': 'Walker Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.6337, 'longitude': -74.3779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12589', 'place_name': 'Wallkill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Ulster', 'locality_code': '111', 'latitude': 41.616, 'longitude': -74.1439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12801', 'place_name': 'Glens Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.3115, 'longitude': -73.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12804', 'place_name': 'Queensbury', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.329, 'longitude': -73.6818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12808', 'place_name': 'Adirondack', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.7165, 'longitude': -73.7825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12810', 'place_name': 'Athol', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.4839, 'longitude': -73.8817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12811', 'place_name': 'Bakers Mills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.6148, 'longitude': -74.0249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12814', 'place_name': 'Bolton Landing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.5766, 'longitude': -73.6714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12815', 'place_name': 'Brant Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.6989, 'longitude': -73.7205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12817', 'place_name': 'Chestertown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.6451, 'longitude': -73.8066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12820', 'place_name': 'Cleverdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.4718, 'longitude': -73.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12824', 'place_name': 'Diamond Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.5156, 'longitude': -73.7001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12836', 'place_name': 'Hague', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.7463, 'longitude': -73.5282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12843', 'place_name': 'Johnsburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.586, 'longitude': -73.9165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12844', 'place_name': 'Kattskill Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.4754, 'longitude': -73.6272, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '12845', 'place_name': 'Lake George', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.4167, 'longitude': -73.6975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12846', 'place_name': 'Lake Luzerne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.3165, 'longitude': -73.8228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12853', 'place_name': 'North Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.6978, 'longitude': -73.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12856', 'place_name': 'North River', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.7237, 'longitude': -74.0873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12860', 'place_name': 'Pottersville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.7312, 'longitude': -73.8193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12862', 'place_name': 'Riparius', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.6617, 'longitude': -73.8971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12874', 'place_name': 'Silver Bay', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.6978, 'longitude': -73.5071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12878', 'place_name': 'Stony Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.4214, 'longitude': -73.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12885', 'place_name': 'Warrensburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.5003, 'longitude': -73.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12886', 'place_name': 'Wevertown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Warren', 'locality_code': '113', 'latitude': 43.6313, 'longitude': -73.9364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12057', 'place_name': 'Eagle Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 42.9808, 'longitude': -73.3522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12809', 'place_name': 'Argyle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.2381, 'longitude': -73.4641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12816', 'place_name': 'Cambridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.0466, 'longitude': -73.3814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12819', 'place_name': 'Clemons', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.6435, 'longitude': -73.4326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12821', 'place_name': 'Comstock', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.4614, 'longitude': -73.4033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12823', 'place_name': 'Cossayuna', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.1837, 'longitude': -73.4268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12827', 'place_name': 'Fort Ann', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.4285, 'longitude': -73.4784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12828', 'place_name': 'Fort Edward', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.2653, 'longitude': -73.5822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12832', 'place_name': 'Granville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.3776, 'longitude': -73.2978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12834', 'place_name': 'Greenwich', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.0947, 'longitude': -73.503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12837', 'place_name': 'Hampton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.5248, 'longitude': -73.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12838', 'place_name': 'Hartford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.3493, 'longitude': -73.4049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12839', 'place_name': 'Hudson Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.3149, 'longitude': -73.5746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12841', 'place_name': 'Huletts Landing', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.6392, 'longitude': -73.5071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12848', 'place_name': 'Middle Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.1001, 'longitude': -73.5246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12849', 'place_name': 'Middle Granville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.4508, 'longitude': -73.3031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12854', 'place_name': 'North Granville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.4525, 'longitude': -73.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12861', 'place_name': 'Putnam Station', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.756, 'longitude': -73.4123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12865', 'place_name': 'Salem', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.1828, 'longitude': -73.3327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12873', 'place_name': 'Shushan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.1106, 'longitude': -73.3231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '12887', 'place_name': 'Whitehall', 'state': 'New York', 'state_ab': 'NY', 'county': 'Washington', 'locality_code': '115', 'latitude': 43.5531, 'longitude': -73.3864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13143', 'place_name': 'Red Creek', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2291, 'longitude': -76.7146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13146', 'place_name': 'Savannah', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.0934, 'longitude': -76.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '13154', 'place_name': 'South Butler', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.1344, 'longitude': -76.7656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14413', 'place_name': 'Alton', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2227, 'longitude': -76.9821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14433', 'place_name': 'Clyde', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.0855, 'longitude': -76.8725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14449', 'place_name': 'East Williamson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2354, 'longitude': -77.1376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14489', 'place_name': 'Lyons', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.0777, 'longitude': -76.9896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14502', 'place_name': 'Macedon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.0784, 'longitude': -77.3372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14505', 'place_name': 'Marion', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.1546, 'longitude': -77.1863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14513', 'place_name': 'Newark', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.0519, 'longitude': -77.0946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14516', 'place_name': 'North Rose', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.1964, 'longitude': -76.9152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14519', 'place_name': 'Ontario', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2291, 'longitude': -77.3088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14520', 'place_name': 'Ontario Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2259, 'longitude': -77.3058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14522', 'place_name': 'Palmyra', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.0622, 'longitude': -77.2218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14538', 'place_name': 'Pultneyville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2836, 'longitude': -77.142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14542', 'place_name': 'Rose', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.1448, 'longitude': -76.8608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14551', 'place_name': 'Sodus', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2217, 'longitude': -77.0514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14555', 'place_name': 'Sodus Point', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2546, 'longitude': -76.9835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14563', 'place_name': 'Union Hill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2228, 'longitude': -77.3717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14568', 'place_name': 'Walworth', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.1402, 'longitude': -77.2858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14589', 'place_name': 'Williamson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2421, 'longitude': -77.17, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14590', 'place_name': 'Wolcott', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wayne', 'locality_code': '117', 'latitude': 43.2341, 'longitude': -76.8217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10501', 'place_name': 'Amawalk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2946, 'longitude': -73.7611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10502', 'place_name': 'Ardsley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0113, 'longitude': -73.8413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10503', 'place_name': 'Ardsley On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0259, 'longitude': -73.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10504', 'place_name': 'Armonk', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.136, 'longitude': -73.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10505', 'place_name': 'Baldwin Place', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3421, 'longitude': -73.7454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10506', 'place_name': 'Bedford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.1909, 'longitude': -73.6355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10507', 'place_name': 'Bedford Hills', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2344, 'longitude': -73.6915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10510', 'place_name': 'Briarcliff Manor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.1444, 'longitude': -73.835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10511', 'place_name': 'Buchanan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2583, 'longitude': -73.9412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10514', 'place_name': 'Chappaqua', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.1705, 'longitude': -73.7715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10517', 'place_name': 'Crompond', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3006, 'longitude': -73.8612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10518', 'place_name': 'Cross River', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2722, 'longitude': -73.602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10519', 'place_name': 'Croton Falls', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3477, 'longitude': -73.661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10520', 'place_name': 'Croton On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.218, 'longitude': -73.8924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10521', 'place_name': 'Croton On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2343, 'longitude': -73.9262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10522', 'place_name': 'Dobbs Ferry', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0118, 'longitude': -73.8665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10523', 'place_name': 'Elmsford', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0572, 'longitude': -73.8136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10526', 'place_name': 'Goldens Bridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3004, 'longitude': -73.6479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10527', 'place_name': 'Granite Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3098, 'longitude': -73.753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10528', 'place_name': 'Harrison', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9719, 'longitude': -73.7181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10530', 'place_name': 'Hartsdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0197, 'longitude': -73.8074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10532', 'place_name': 'Hawthorne', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.1073, 'longitude': -73.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10533', 'place_name': 'Irvington', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0381, 'longitude': -73.8597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10535', 'place_name': 'Jefferson Valley', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3385, 'longitude': -73.7947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10536', 'place_name': 'Katonah', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2709, 'longitude': -73.6841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10538', 'place_name': 'Larchmont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9351, 'longitude': -73.7571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10540', 'place_name': 'Lincolndale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3334, 'longitude': -73.7243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10543', 'place_name': 'Mamaroneck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9525, 'longitude': -73.735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10545', 'place_name': 'Maryknoll', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.119, 'longitude': -73.733, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '10546', 'place_name': 'Millwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2015, 'longitude': -73.7926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10547', 'place_name': 'Mohegan Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3143, 'longitude': -73.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10548', 'place_name': 'Montrose', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2496, 'longitude': -73.9446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10549', 'place_name': 'Mount Kisco', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.205, 'longitude': -73.7299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10550', 'place_name': 'Mount Vernon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9079, 'longitude': -73.838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10551', 'place_name': 'Mount Vernon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9126, 'longitude': -73.8371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10552', 'place_name': 'Mount Vernon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9231, 'longitude': -73.8299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10553', 'place_name': 'Mount Vernon', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9086, 'longitude': -73.8221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10560', 'place_name': 'North Salem', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3414, 'longitude': -73.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10562', 'place_name': 'Ossining', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.1673, 'longitude': -73.8538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10566', 'place_name': 'Peekskill', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2892, 'longitude': -73.9184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10567', 'place_name': 'Cortlandt Manor', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.284, 'longitude': -73.8931, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '10570', 'place_name': 'Pleasantville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.135, 'longitude': -73.7845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10573', 'place_name': 'Port Chester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0222, 'longitude': -73.6798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10576', 'place_name': 'Pound Ridge', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2042, 'longitude': -73.5732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10577', 'place_name': 'Purchase', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0384, 'longitude': -73.7156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10578', 'place_name': 'Purdys', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3259, 'longitude': -73.6551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10580', 'place_name': 'Rye', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9734, 'longitude': -73.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10583', 'place_name': 'Scarsdale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9927, 'longitude': -73.7995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10587', 'place_name': 'Shenorock', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3287, 'longitude': -73.7423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10588', 'place_name': 'Shrub Oak', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3286, 'longitude': -73.8273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10589', 'place_name': 'Somers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3346, 'longitude': -73.6951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10590', 'place_name': 'South Salem', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2553, 'longitude': -73.5402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10591', 'place_name': 'Tarrytown', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0897, 'longitude': -73.844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10594', 'place_name': 'Thornwood', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.1182, 'longitude': -73.7733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10595', 'place_name': 'Valhalla', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0856, 'longitude': -73.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10596', 'place_name': 'Verplanck', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2548, 'longitude': -73.9587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10597', 'place_name': 'Waccabuc', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.3032, 'longitude': -73.6032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10598', 'place_name': 'Yorktown Heights', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.2999, 'longitude': -73.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10601', 'place_name': 'White Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.033, 'longitude': -73.7652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10602', 'place_name': 'White Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.034, 'longitude': -73.7629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10603', 'place_name': 'White Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0499, 'longitude': -73.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10604', 'place_name': 'West Harrison', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0592, 'longitude': -73.7395, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '10605', 'place_name': 'White Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0141, 'longitude': -73.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10606', 'place_name': 'White Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0247, 'longitude': -73.7781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10607', 'place_name': 'White Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.0398, 'longitude': -73.8117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10610', 'place_name': 'White Plains', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 41.119, 'longitude': -73.733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10701', 'place_name': 'Yonkers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9461, 'longitude': -73.8669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10702', 'place_name': 'Yonkers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9312, 'longitude': -73.8987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10703', 'place_name': 'Yonkers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9518, 'longitude': -73.8852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10704', 'place_name': 'Yonkers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9176, 'longitude': -73.8593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10705', 'place_name': 'Yonkers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9177, 'longitude': -73.895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10706', 'place_name': 'Hastings On Hudson', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9878, 'longitude': -73.863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10707', 'place_name': 'Tuckahoe', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9569, 'longitude': -73.8198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10708', 'place_name': 'Bronxville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9391, 'longitude': -73.8353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10709', 'place_name': 'Eastchester', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.955, 'longitude': -73.8086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10710', 'place_name': 'Yonkers', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9656, 'longitude': -73.8434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10801', 'place_name': 'New Rochelle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9166, 'longitude': -73.7877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10802', 'place_name': 'New Rochelle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9115, 'longitude': -73.7824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10803', 'place_name': 'Pelham', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9045, 'longitude': -73.8073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10804', 'place_name': 'New Rochelle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9491, 'longitude': -73.7863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '10805', 'place_name': 'New Rochelle', 'state': 'New York', 'state_ab': 'NY', 'county': 'Westchester', 'locality_code': '119', 'latitude': 40.9002, 'longitude': -73.781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14009', 'place_name': 'Arcade', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.563, 'longitude': -78.4134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14011', 'place_name': 'Attica', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.8499, 'longitude': -78.2798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14024', 'place_name': 'Bliss', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.5799, 'longitude': -78.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14037', 'place_name': 'Cowlesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.8112, 'longitude': -78.4481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14039', 'place_name': 'Dale', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.8263, 'longitude': -78.1749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14066', 'place_name': 'Gainesville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.619, 'longitude': -78.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14082', 'place_name': 'Java Center', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.6634, 'longitude': -78.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14083', 'place_name': 'Java Village', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.6769, 'longitude': -78.441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14113', 'place_name': 'North Java', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.6776, 'longitude': -78.338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14130', 'place_name': 'Pike', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.5565, 'longitude': -78.1528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14145', 'place_name': 'Strykersville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.7249, 'longitude': -78.4347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14167', 'place_name': 'Varysburg', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.7459, 'longitude': -78.3167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14427', 'place_name': 'Castile', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.6359, 'longitude': -78.0547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14530', 'place_name': 'Perry', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.7229, 'longitude': -78.0059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14536', 'place_name': 'Portageville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.557, 'longitude': -78.0856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14549', 'place_name': 'Silver Lake', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.6929, 'longitude': -78.0224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14550', 'place_name': 'Silver Springs', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.6742, 'longitude': -78.0845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14569', 'place_name': 'Warsaw', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.741, 'longitude': -78.1429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14591', 'place_name': 'Wyoming', 'state': 'New York', 'state_ab': 'NY', 'county': 'Wyoming', 'locality_code': '121', 'latitude': 42.8317, 'longitude': -78.0833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14415', 'place_name': 'Bellona', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.7554, 'longitude': -77.0217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14418', 'place_name': 'Branchport', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.6065, 'longitude': -77.2052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14441', 'place_name': 'Dresden', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.6846, 'longitude': -76.9564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14478', 'place_name': 'Keuka Park', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.5708, 'longitude': -77.1226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14507', 'place_name': 'Middlesex', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.6976, 'longitude': -77.2805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14527', 'place_name': 'Penn Yan', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.6645, 'longitude': -77.0569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14544', 'place_name': 'Rushville', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.7597, 'longitude': -77.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14837', 'place_name': 'Dundee', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.5053, 'longitude': -77.0028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14842', 'place_name': 'Himrod', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.5945, 'longitude': -76.9508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14857', 'place_name': 'Lakemont', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.5126, 'longitude': -76.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '14878', 'place_name': 'Rock Stream', 'state': 'New York', 'state_ab': 'NY', 'county': 'Yates', 'locality_code': '123', 'latitude': 42.4485, 'longitude': -76.9364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45105', 'place_name': 'Bentonville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.7498, 'longitude': -83.6126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45144', 'place_name': 'Manchester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.6982, 'longitude': -83.6181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45616', 'place_name': 'Blue Creek', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.7776, 'longitude': -83.3302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45618', 'place_name': 'Cherry Fork', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.8922, 'longitude': -83.6218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45650', 'place_name': 'Lynx', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.7391, 'longitude': -83.4262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45660', 'place_name': 'Peebles', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.9869, 'longitude': -83.3687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45679', 'place_name': 'Seaman', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.9621, 'longitude': -83.5936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45693', 'place_name': 'West Union', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.8017, 'longitude': -83.5333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45697', 'place_name': 'Winchester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Adams', 'locality_code': '1', 'latitude': 38.9353, 'longitude': -83.6661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45801', 'place_name': 'Lima', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7641, 'longitude': -84.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45802', 'place_name': 'Lima', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7818, 'longitude': -84.1386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45804', 'place_name': 'Lima', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7275, 'longitude': -84.089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45805', 'place_name': 'Lima', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7399, 'longitude': -84.1459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45807', 'place_name': 'Lima', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7955, 'longitude': -84.1383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45808', 'place_name': 'Beaverdam', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.8314, 'longitude': -83.9758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45809', 'place_name': 'Gomer', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.8451, 'longitude': -84.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45817', 'place_name': 'Bluffton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.879, 'longitude': -83.8914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45820', 'place_name': 'Cairo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.8304, 'longitude': -84.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45833', 'place_name': 'Delphos', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.8336, 'longitude': -84.3247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45850', 'place_name': 'Harrod', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7177, 'longitude': -83.9436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45854', 'place_name': 'Lafayette', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7582, 'longitude': -83.9499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45887', 'place_name': 'Spencerville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Allen', 'locality_code': '3', 'latitude': 40.7038, 'longitude': -84.3413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44805', 'place_name': 'Ashland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.8559, 'longitude': -82.3189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44838', 'place_name': 'Hayesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.7731, 'longitude': -82.2624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44840', 'place_name': 'Jeromesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.8134, 'longitude': -82.1861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44842', 'place_name': 'Loudonville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.6361, 'longitude': -82.2356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44848', 'place_name': 'Nankin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.9206, 'longitude': -82.2817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44859', 'place_name': 'Nova', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 41.0282, 'longitude': -82.3384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44864', 'place_name': 'Perrysville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.6606, 'longitude': -82.3213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44866', 'place_name': 'Polk', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.9343, 'longitude': -82.2126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44874', 'place_name': 'Savannah', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 40.9653, 'longitude': -82.3652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44880', 'place_name': 'Sullivan', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashland', 'locality_code': '5', 'latitude': 41.0368, 'longitude': -82.2172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44003', 'place_name': 'Andover', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.6225, 'longitude': -80.5754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44004', 'place_name': 'Ashtabula', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.8679, 'longitude': -80.7947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44005', 'place_name': 'Ashtabula', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.8651, 'longitude': -80.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44010', 'place_name': 'Austinburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.7554, 'longitude': -80.8584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44030', 'place_name': 'Conneaut', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.9345, 'longitude': -80.5803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44032', 'place_name': 'Dorset', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.659, 'longitude': -80.6683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44041', 'place_name': 'Geneva', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.8029, 'longitude': -80.9474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44047', 'place_name': 'Jefferson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.7335, 'longitude': -80.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44048', 'place_name': 'Kingsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.8723, 'longitude': -80.6601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44068', 'place_name': 'North Kingsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.9046, 'longitude': -80.685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44076', 'place_name': 'Orwell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.5293, 'longitude': -80.8208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44082', 'place_name': 'Pierpont', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.7677, 'longitude': -80.5741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44084', 'place_name': 'Rock Creek', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.6603, 'longitude': -80.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44085', 'place_name': 'Rome', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.6053, 'longitude': -80.8709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44088', 'place_name': 'Unionville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.7833, 'longitude': -81.0034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44093', 'place_name': 'Williamsfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.5383, 'longitude': -80.5964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44099', 'place_name': 'Windsor', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ashtabula', 'locality_code': '7', 'latitude': 41.5623, 'longitude': -80.9667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45701', 'place_name': 'Athens', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.3178, 'longitude': -82.102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45710', 'place_name': 'Albany', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.2097, 'longitude': -82.2177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45711', 'place_name': 'Amesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.4086, 'longitude': -81.965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45716', 'place_name': 'Buchtel', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.462, 'longitude': -82.1818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45717', 'place_name': 'Carbondale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.3778, 'longitude': -82.271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45719', 'place_name': 'Chauncey', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.4002, 'longitude': -82.1302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45723', 'place_name': 'Coolville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.2141, 'longitude': -81.8329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45732', 'place_name': 'Glouster', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.4978, 'longitude': -82.0871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45735', 'place_name': 'Guysville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.2493, 'longitude': -81.922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45739', 'place_name': 'Hockingport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.1979, 'longitude': -81.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45740', 'place_name': 'Jacksonville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.477, 'longitude': -82.0794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45761', 'place_name': 'Millfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.4077, 'longitude': -82.1113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45764', 'place_name': 'Nelsonville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.4556, 'longitude': -82.2309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45766', 'place_name': 'New Marshfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.3228, 'longitude': -82.2594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45776', 'place_name': 'Shade', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.2129, 'longitude': -82.0218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45777', 'place_name': 'Sharpsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.4359, 'longitude': -81.9115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45778', 'place_name': 'Stewart', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.3213, 'longitude': -81.8929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45780', 'place_name': 'The Plains', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.3662, 'longitude': -82.1341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45782', 'place_name': 'Trimble', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Athens', 'locality_code': '9', 'latitude': 39.4845, 'longitude': -82.0805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45806', 'place_name': 'Lima', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.6752, 'longitude': -84.1244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45819', 'place_name': 'Buckland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.6241, 'longitude': -84.2603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45865', 'place_name': 'Minster', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.391, 'longitude': -84.3729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45869', 'place_name': 'New Bremen', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.4389, 'longitude': -84.3821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45870', 'place_name': 'New Hampshire', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.5563, 'longitude': -83.9514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45871', 'place_name': 'New Knoxville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.5039, 'longitude': -84.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45884', 'place_name': 'Saint Johns', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.5559, 'longitude': -84.0836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45885', 'place_name': 'Saint Marys', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.544, 'longitude': -84.3944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45888', 'place_name': 'Uniopolis', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.6023, 'longitude': -84.086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45895', 'place_name': 'Wapakoneta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.569, 'longitude': -84.1774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45896', 'place_name': 'Waynesfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Auglaize', 'locality_code': '11', 'latitude': 40.6072, 'longitude': -83.9585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43713', 'place_name': 'Barnesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 39.9853, 'longitude': -81.1375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43718', 'place_name': 'Belmont', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.032, 'longitude': -81.0066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43719', 'place_name': 'Bethesda', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0192, 'longitude': -81.0767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43759', 'place_name': 'Morristown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0631, 'longitude': -81.0743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43902', 'place_name': 'Alledonia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 39.9053, 'longitude': -80.9578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43905', 'place_name': 'Barton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1073, 'longitude': -80.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43906', 'place_name': 'Bellaire', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0204, 'longitude': -80.7638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43909', 'place_name': 'Blaine', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0701, 'longitude': -80.8176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43912', 'place_name': 'Bridgeport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0752, 'longitude': -80.7747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43916', 'place_name': 'Colerain', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1224, 'longitude': -80.8149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43927', 'place_name': 'Fairpoint', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1225, 'longitude': -80.938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43928', 'place_name': 'Glencoe', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0109, 'longitude': -80.8993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43933', 'place_name': 'Jacobsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 39.9372, 'longitude': -80.888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43934', 'place_name': 'Lansing', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0756, 'longitude': -80.7901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43935', 'place_name': 'Martins Ferry', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1036, 'longitude': -80.7361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43937', 'place_name': 'Maynard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1302, 'longitude': -80.8773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43940', 'place_name': 'Neffs', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0284, 'longitude': -80.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43942', 'place_name': 'Powhatan Point', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 39.8679, 'longitude': -80.8168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43947', 'place_name': 'Shadyside', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 39.9675, 'longitude': -80.7643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43950', 'place_name': 'Saint Clairsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0778, 'longitude': -80.9788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43951', 'place_name': 'Lafferty', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.111, 'longitude': -81.0102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43967', 'place_name': 'Warnock', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.0226, 'longitude': -80.9373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43972', 'place_name': 'Bannock', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1032, 'longitude': -80.9756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43977', 'place_name': 'Flushing', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1451, 'longitude': -81.0757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43983', 'place_name': 'Piedmont', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1507, 'longitude': -81.2145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43985', 'place_name': 'Holloway', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Belmont', 'locality_code': '13', 'latitude': 40.1623, 'longitude': -81.1326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45101', 'place_name': 'Aberdeen', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.6709, 'longitude': -83.7637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45115', 'place_name': 'Decatur', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.8237, 'longitude': -83.6995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45118', 'place_name': 'Fayetteville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 39.1862, 'longitude': -83.9501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45119', 'place_name': 'Feesburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.8806, 'longitude': -84.0087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45121', 'place_name': 'Georgetown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.8717, 'longitude': -83.9092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45130', 'place_name': 'Hamersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.92, 'longitude': -83.9931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45131', 'place_name': 'Higginsport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.7903, 'longitude': -83.9666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45154', 'place_name': 'Mount Orab', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 39.0454, 'longitude': -83.948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45167', 'place_name': 'Ripley', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.7551, 'longitude': -83.8227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45168', 'place_name': 'Russellville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.8511, 'longitude': -83.7625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45171', 'place_name': 'Sardinia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 38.9832, 'longitude': -83.7966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45275', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Brown', 'locality_code': '15', 'latitude': 39.162, 'longitude': -84.4569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45003', 'place_name': 'College Corner', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.5755, 'longitude': -84.805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45004', 'place_name': 'Collinsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.5153, 'longitude': -84.6094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45011', 'place_name': 'Hamilton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.4059, 'longitude': -84.5221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45012', 'place_name': 'Hamilton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.441, 'longitude': -84.5757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45013', 'place_name': 'Hamilton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.4361, 'longitude': -84.6185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45014', 'place_name': 'Fairfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.3266, 'longitude': -84.5479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45015', 'place_name': 'Hamilton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.3494, 'longitude': -84.5376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45018', 'place_name': 'Fairfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.441, 'longitude': -84.5757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45042', 'place_name': 'Middletown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.5321, 'longitude': -84.3896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45044', 'place_name': 'Middletown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.5151, 'longitude': -84.3983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45050', 'place_name': 'Monroe', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.4413, 'longitude': -84.3652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45053', 'place_name': 'Okeana', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.3537, 'longitude': -84.7761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45055', 'place_name': 'Overpeck', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.4518, 'longitude': -84.5152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45056', 'place_name': 'Oxford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.507, 'longitude': -84.7452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45061', 'place_name': 'Ross', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.3124, 'longitude': -84.6483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45062', 'place_name': 'Seven Mile', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.479, 'longitude': -84.5512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45063', 'place_name': 'Shandon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.3258, 'longitude': -84.7121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45064', 'place_name': 'Somerville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.5554, 'longitude': -84.6219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45067', 'place_name': 'Trenton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.4799, 'longitude': -84.4598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45069', 'place_name': 'West Chester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.3402, 'longitude': -84.3998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45071', 'place_name': 'West Chester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Butler', 'locality_code': '17', 'latitude': 39.3317, 'longitude': -84.4072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44607', 'place_name': 'Augusta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Carroll', 'locality_code': '19', 'latitude': 40.686, 'longitude': -81.0219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44615', 'place_name': 'Carrollton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Carroll', 'locality_code': '19', 'latitude': 40.5787, 'longitude': -81.0818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44620', 'place_name': 'Dellroy', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Carroll', 'locality_code': '19', 'latitude': 40.5861, 'longitude': -81.1986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44639', 'place_name': 'Leesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Carroll', 'locality_code': '19', 'latitude': 40.4517, 'longitude': -81.212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44644', 'place_name': 'Malvern', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Carroll', 'locality_code': '19', 'latitude': 40.6845, 'longitude': -81.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44651', 'place_name': 'Mechanicstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Carroll', 'locality_code': '19', 'latitude': 40.6263, 'longitude': -80.956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44675', 'place_name': 'Sherrodsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Carroll', 'locality_code': '19', 'latitude': 40.5184, 'longitude': -81.2339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43009', 'place_name': 'Cable', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.1784, 'longitude': -83.647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43044', 'place_name': 'Mechanicsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.0647, 'longitude': -83.5724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43047', 'place_name': 'Mingo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.2049, 'longitude': -83.6466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43060', 'place_name': 'North Lewisburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.2229, 'longitude': -83.5615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43070', 'place_name': 'Rosewood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.2158, 'longitude': -83.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43072', 'place_name': 'Saint Paris', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.1058, 'longitude': -83.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43078', 'place_name': 'Urbana', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.1066, 'longitude': -83.7671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43083', 'place_name': 'Westville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.1022, 'longitude': -83.8379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43084', 'place_name': 'Woodstock', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.1816, 'longitude': -83.5461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45389', 'place_name': 'Christiansburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Champaign', 'locality_code': '21', 'latitude': 40.0564, 'longitude': -84.0254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43010', 'place_name': 'Catawba', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9991, 'longitude': -83.6222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45319', 'place_name': 'Donnelsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9189, 'longitude': -83.9449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45323', 'place_name': 'Enon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.8663, 'longitude': -83.9385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45341', 'place_name': 'Medway', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.8789, 'longitude': -84.0218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45344', 'place_name': 'New Carlisle', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.93, 'longitude': -84.0217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45349', 'place_name': 'North Hampton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9893, 'longitude': -83.9389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45368', 'place_name': 'South Charleston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.8543, 'longitude': -83.6653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45369', 'place_name': 'South Vienna', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9473, 'longitude': -83.6157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45372', 'place_name': 'Tremont City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 40.0139, 'longitude': -83.8333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45501', 'place_name': 'Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9271, 'longitude': -83.8132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45502', 'place_name': 'Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9242, 'longitude': -83.8088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45503', 'place_name': 'Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9528, 'longitude': -83.7804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45504', 'place_name': 'Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9408, 'longitude': -83.8343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45505', 'place_name': 'Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9106, 'longitude': -83.7856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45506', 'place_name': 'Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clark', 'locality_code': '23', 'latitude': 39.9104, 'longitude': -83.8275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45102', 'place_name': 'Amelia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.0211, 'longitude': -84.2112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45103', 'place_name': 'Batavia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.0957, 'longitude': -84.1451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45106', 'place_name': 'Bethel', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 38.9424, 'longitude': -84.0919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45112', 'place_name': 'Chilo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 38.7926, 'longitude': -84.1382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45120', 'place_name': 'Felicity', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 38.8262, 'longitude': -84.0986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45122', 'place_name': 'Goshen', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.2209, 'longitude': -84.1188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45140', 'place_name': 'Loveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.2445, 'longitude': -84.2588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45147', 'place_name': 'Miamiville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.2137, 'longitude': -84.3002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45150', 'place_name': 'Milford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.1657, 'longitude': -84.233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45153', 'place_name': 'Moscow', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 38.8583, 'longitude': -84.1958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45156', 'place_name': 'Neville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 38.8101, 'longitude': -84.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45157', 'place_name': 'New Richmond', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 38.9537, 'longitude': -84.2379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45158', 'place_name': 'Newtonsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.182, 'longitude': -84.0863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45160', 'place_name': 'Owensville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.1232, 'longitude': -84.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45176', 'place_name': 'Williamsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.0753, 'longitude': -84.0432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45245', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clermont', 'locality_code': '25', 'latitude': 39.0688, 'longitude': -84.2802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45107', 'place_name': 'Blanchester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.3034, 'longitude': -83.974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45113', 'place_name': 'Clarksville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.4042, 'longitude': -83.9594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45114', 'place_name': 'Cuba', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.3568, 'longitude': -83.8572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45146', 'place_name': 'Martinsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.3127, 'longitude': -83.8005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45148', 'place_name': 'Midland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.2917, 'longitude': -83.8931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45159', 'place_name': 'New Vienna', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.3321, 'longitude': -83.6882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45164', 'place_name': 'Port William', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.5514, 'longitude': -83.7881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45166', 'place_name': 'Reesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.4805, 'longitude': -83.6772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45169', 'place_name': 'Sabina', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.49, 'longitude': -83.6503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45177', 'place_name': 'Wilmington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Clinton', 'locality_code': '27', 'latitude': 39.4488, 'longitude': -83.8417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43920', 'place_name': 'East Liverpool', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.6774, 'longitude': -80.6006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43945', 'place_name': 'Salineville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.6195, 'longitude': -80.835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43962', 'place_name': 'Summitville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.6781, 'longitude': -80.8862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43968', 'place_name': 'Wellsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.6171, 'longitude': -80.6621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44408', 'place_name': 'Columbiana', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8853, 'longitude': -80.6975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44413', 'place_name': 'East Palestine', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8406, 'longitude': -80.5465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44415', 'place_name': 'Elkton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.763, 'longitude': -80.7042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44423', 'place_name': 'Hanoverton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.7731, 'longitude': -80.9144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44427', 'place_name': 'Kensington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.7142, 'longitude': -80.9381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44431', 'place_name': 'Leetonia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8631, 'longitude': -80.7585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44432', 'place_name': 'Lisbon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.7592, 'longitude': -80.7587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44441', 'place_name': 'Negley', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.7579, 'longitude': -80.553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44445', 'place_name': 'New Waterford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8489, 'longitude': -80.6209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44455', 'place_name': 'Rogers', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.7789, 'longitude': -80.6202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44460', 'place_name': 'Salem', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.9, 'longitude': -80.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44490', 'place_name': 'Washingtonville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8973, 'longitude': -80.7631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44492', 'place_name': 'West Point', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.7093, 'longitude': -80.7014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44493', 'place_name': 'Winona', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8286, 'longitude': -80.8967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44625', 'place_name': 'East Rochester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.7563, 'longitude': -81.0175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44634', 'place_name': 'Homeworth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8301, 'longitude': -81.0333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44665', 'place_name': 'North Georgetown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Columbiana', 'locality_code': '29', 'latitude': 40.8436, 'longitude': -80.9794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43803', 'place_name': 'Bakersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.3572, 'longitude': -81.6436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43805', 'place_name': 'Blissfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.3983, 'longitude': -81.9688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43811', 'place_name': 'Conesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.1804, 'longitude': -81.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43812', 'place_name': 'Coshocton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.2754, 'longitude': -81.866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43824', 'place_name': 'Fresno', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.3711, 'longitude': -81.7623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43828', 'place_name': 'Keene', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.3513, 'longitude': -81.8736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43836', 'place_name': 'Plainfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.2087, 'longitude': -81.7197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43843', 'place_name': 'Walhonding', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.3407, 'longitude': -82.1559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43844', 'place_name': 'Warsaw', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.3172, 'longitude': -82.056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43845', 'place_name': 'West Lafayette', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Coshocton', 'locality_code': '31', 'latitude': 40.2718, 'longitude': -81.7361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44820', 'place_name': 'Bucyrus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.8103, 'longitude': -82.9698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44825', 'place_name': 'Chatfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.9542, 'longitude': -82.9432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44827', 'place_name': 'Crestline', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.7927, 'longitude': -82.7367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44833', 'place_name': 'Galion', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.7303, 'longitude': -82.7939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44854', 'place_name': 'New Washington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.9571, 'longitude': -82.8504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44856', 'place_name': 'North Robinson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.7934, 'longitude': -82.8566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44860', 'place_name': 'Oceola', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.8357, 'longitude': -83.1029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44881', 'place_name': 'Sulphur Springs', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.8709, 'longitude': -82.8771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44887', 'place_name': 'Tiro', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Crawford', 'locality_code': '33', 'latitude': 40.881, 'longitude': -82.797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44017', 'place_name': 'Berea', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3676, 'longitude': -81.8618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44022', 'place_name': 'Chagrin Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4494, 'longitude': -81.4314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44040', 'place_name': 'Gates Mills', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5324, 'longitude': -81.415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44070', 'place_name': 'North Olmsted', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4201, 'longitude': -81.9131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44101', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5234, 'longitude': -81.5996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44102', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4735, 'longitude': -81.7398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44103', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5157, 'longitude': -81.6405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44104', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4809, 'longitude': -81.6245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44105', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4509, 'longitude': -81.619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44106', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5084, 'longitude': -81.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44107', 'place_name': 'Lakewood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4847, 'longitude': -81.8018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44108', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5349, 'longitude': -81.609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44109', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4458, 'longitude': -81.7033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44110', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5636, 'longitude': -81.5733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44111', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4571, 'longitude': -81.7844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44112', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5356, 'longitude': -81.5737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44113', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4816, 'longitude': -81.7018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44114', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5064, 'longitude': -81.6743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44115', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4946, 'longitude': -81.667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44116', 'place_name': 'Rocky River', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4694, 'longitude': -81.8512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44117', 'place_name': 'Euclid', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5696, 'longitude': -81.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44118', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5008, 'longitude': -81.5516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44119', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5882, 'longitude': -81.5468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44120', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4714, 'longitude': -81.5839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44121', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5277, 'longitude': -81.5323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44122', 'place_name': 'Beachwood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4701, 'longitude': -81.5232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44123', 'place_name': 'Euclid', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6025, 'longitude': -81.5258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44124', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.501, 'longitude': -81.4694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44125', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4335, 'longitude': -81.6323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44126', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4429, 'longitude': -81.853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44127', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4701, 'longitude': -81.649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44128', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4416, 'longitude': -81.5486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44129', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3897, 'longitude': -81.7351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44130', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3826, 'longitude': -81.7964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44131', 'place_name': 'Independence', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3809, 'longitude': -81.6642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44132', 'place_name': 'Euclid', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6069, 'longitude': -81.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44133', 'place_name': 'North Royalton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3232, 'longitude': -81.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44134', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3853, 'longitude': -81.7044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44135', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4342, 'longitude': -81.8044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44136', 'place_name': 'Strongsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3132, 'longitude': -81.8285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44137', 'place_name': 'Maple Heights', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4105, 'longitude': -81.5603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44138', 'place_name': 'Olmsted Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3734, 'longitude': -81.9158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44139', 'place_name': 'Solon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3866, 'longitude': -81.4421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44140', 'place_name': 'Bay Village', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4841, 'longitude': -81.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44141', 'place_name': 'Brecksville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3166, 'longitude': -81.6261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44142', 'place_name': 'Brookpark', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3979, 'longitude': -81.8118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44143', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.5592, 'longitude': -81.4828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44144', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4385, 'longitude': -81.7398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44145', 'place_name': 'Westlake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4535, 'longitude': -81.9218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44146', 'place_name': 'Bedford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3921, 'longitude': -81.5232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44147', 'place_name': 'Broadview Heights', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.3141, 'longitude': -81.6731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44181', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44188', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44190', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44191', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44192', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4995, 'longitude': -81.6954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44193', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4995, 'longitude': -81.6954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44194', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44195', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44197', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44198', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.6857, 'longitude': -81.6728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44199', 'place_name': 'Cleveland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Cuyahoga', 'locality_code': '35', 'latitude': 41.4995, 'longitude': -81.6954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45303', 'place_name': 'Ansonia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.2151, 'longitude': -84.6406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45304', 'place_name': 'Arcanum', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 39.9888, 'longitude': -84.5312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45328', 'place_name': 'Gettysburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.1147, 'longitude': -84.4934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45331', 'place_name': 'Greenville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.0987, 'longitude': -84.6342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45332', 'place_name': 'Hollansburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 39.9899, 'longitude': -84.7901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45346', 'place_name': 'New Madison', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 39.9687, 'longitude': -84.7222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45348', 'place_name': 'New Weston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.3349, 'longitude': -84.6308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45350', 'place_name': 'North Star', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.3243, 'longitude': -84.5737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45351', 'place_name': 'Osgood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.3406, 'longitude': -84.4963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45352', 'place_name': 'Palestine', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.0503, 'longitude': -84.7457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45358', 'place_name': 'Pitsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 39.987, 'longitude': -84.4866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45362', 'place_name': 'Rossburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.2946, 'longitude': -84.6264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45380', 'place_name': 'Versailles', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.2273, 'longitude': -84.4957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45388', 'place_name': 'Yorkshire', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.3283, 'longitude': -84.4836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45390', 'place_name': 'Union City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Darke', 'locality_code': '37', 'latitude': 40.2018, 'longitude': -84.7832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43512', 'place_name': 'Defiance', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.2799, 'longitude': -84.3626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43519', 'place_name': 'Evansport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.4222, 'longitude': -84.3966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43520', 'place_name': 'Farmer', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.3907, 'longitude': -84.6313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43526', 'place_name': 'Hicksville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.3034, 'longitude': -84.7589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43530', 'place_name': 'Jewell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.3258, 'longitude': -84.2793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43536', 'place_name': 'Mark Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.2917, 'longitude': -84.6278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43549', 'place_name': 'Ney', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.3781, 'longitude': -84.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43556', 'place_name': 'Sherwood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Defiance', 'locality_code': '39', 'latitude': 41.2946, 'longitude': -84.5417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43003', 'place_name': 'Ashley', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.4163, 'longitude': -82.9542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43015', 'place_name': 'Delaware', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.2932, 'longitude': -83.0723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43021', 'place_name': 'Galena', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.2011, 'longitude': -82.8749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43032', 'place_name': 'Kilbourne', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.3286, 'longitude': -82.9588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43035', 'place_name': 'Lewis Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.1879, 'longitude': -82.9878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43061', 'place_name': 'Ostrander', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.274, 'longitude': -83.1978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43065', 'place_name': 'Powell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.1834, 'longitude': -83.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43066', 'place_name': 'Radnor', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.3918, 'longitude': -83.1781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43074', 'place_name': 'Sunbury', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.2655, 'longitude': -82.8511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43082', 'place_name': 'Westerville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Delaware', 'locality_code': '41', 'latitude': 40.1524, 'longitude': -82.882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43438', 'place_name': 'Kelleys Island', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.6008, 'longitude': -82.7068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44089', 'place_name': 'Vermilion', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.41, 'longitude': -82.3554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44814', 'place_name': 'Berlin Heights', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.3205, 'longitude': -82.4777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44816', 'place_name': 'Birmingham', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.3349, 'longitude': -82.355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44824', 'place_name': 'Castalia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.3872, 'longitude': -82.7994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44839', 'place_name': 'Huron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.3757, 'longitude': -82.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44846', 'place_name': 'Milan', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.3111, 'longitude': -82.6126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44870', 'place_name': 'Sandusky', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.4349, 'longitude': -82.7063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44871', 'place_name': 'Sandusky', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Erie', 'locality_code': '43', 'latitude': 41.4489, 'longitude': -82.708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43046', 'place_name': 'Millersport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.8993, 'longitude': -82.5283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43102', 'place_name': 'Amanda', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.6251, 'longitude': -82.7552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43105', 'place_name': 'Baltimore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.8645, 'longitude': -82.624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43107', 'place_name': 'Bremen', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.6909, 'longitude': -82.4096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43110', 'place_name': 'Canal Winchester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.8349, 'longitude': -82.8044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43112', 'place_name': 'Carroll', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.7957, 'longitude': -82.7084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43130', 'place_name': 'Lancaster', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.7187, 'longitude': -82.6031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43136', 'place_name': 'Lithopolis', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.8013, 'longitude': -82.8125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43147', 'place_name': 'Pickerington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.9061, 'longitude': -82.7563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43148', 'place_name': 'Pleasantville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.8227, 'longitude': -82.5043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43150', 'place_name': 'Rushville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.7674, 'longitude': -82.428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43154', 'place_name': 'Stoutsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.6067, 'longitude': -82.8193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43155', 'place_name': 'Sugar Grove', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.6277, 'longitude': -82.5321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43157', 'place_name': 'Thurston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fairfield', 'locality_code': '45', 'latitude': 39.8427, 'longitude': -82.5462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43106', 'place_name': 'Bloomingburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fayette', 'locality_code': '47', 'latitude': 39.6286, 'longitude': -83.4095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43128', 'place_name': 'Jeffersonville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fayette', 'locality_code': '47', 'latitude': 39.659, 'longitude': -83.5687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43142', 'place_name': 'Milledgeville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fayette', 'locality_code': '47', 'latitude': 39.5937, 'longitude': -83.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43160', 'place_name': 'Washington Court House', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fayette', 'locality_code': '47', 'latitude': 39.537, 'longitude': -83.455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43002', 'place_name': 'Amlin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.072, 'longitude': -83.1792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43004', 'place_name': 'Blacklick', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.021, 'longitude': -82.8079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43016', 'place_name': 'Dublin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0985, 'longitude': -83.1537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43017', 'place_name': 'Dublin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.1093, 'longitude': -83.1146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43026', 'place_name': 'Hilliard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0322, 'longitude': -83.1383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43054', 'place_name': 'New Albany', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0847, 'longitude': -82.7988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43068', 'place_name': 'Reynoldsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9551, 'longitude': -82.8035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43069', 'place_name': 'Reynoldsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9555, 'longitude': -82.7992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43081', 'place_name': 'Westerville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.1146, 'longitude': -82.9105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43085', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0999, 'longitude': -83.0157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43086', 'place_name': 'Westerville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43109', 'place_name': 'Brice', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9181, 'longitude': -82.8321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43119', 'place_name': 'Galloway', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9366, 'longitude': -83.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43123', 'place_name': 'Grove City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.8814, 'longitude': -83.0839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43125', 'place_name': 'Groveport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.8581, 'longitude': -82.8872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43126', 'place_name': 'Harrisburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.8139, 'longitude': -83.1664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43194', 'place_name': 'Lockbourne', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.8092, 'longitude': -82.9725, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '43195', 'place_name': 'Groveport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.8614, 'longitude': -82.8916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43199', 'place_name': 'Groveport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43201', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9952, 'longitude': -83.0047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43202', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0201, 'longitude': -83.0118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43203', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9719, 'longitude': -82.9691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43204', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9523, 'longitude': -83.078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43205', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9569, 'longitude': -82.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43206', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9426, 'longitude': -82.9748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43207', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9046, 'longitude': -82.9703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43209', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9539, 'longitude': -82.9301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43210', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0028, 'longitude': -83.0164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43211', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0118, 'longitude': -82.9732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43212', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9874, 'longitude': -83.0456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43213', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9727, 'longitude': -82.8329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43214', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0535, 'longitude': -83.0187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43215', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9671, 'longitude': -83.0044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43216', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43217', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.8277, 'longitude': -82.9342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43218', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43219', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0326, 'longitude': -82.9103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43220', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0495, 'longitude': -83.0669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43221', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0226, 'longitude': -83.0776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43222', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9576, 'longitude': -83.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43223', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9388, 'longitude': -83.0463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43224', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0425, 'longitude': -82.9689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43226', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43227', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9444, 'longitude': -82.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43228', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.9648, 'longitude': -83.126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43229', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0839, 'longitude': -82.9726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43230', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.0347, 'longitude': -82.8726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43231', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.081, 'longitude': -82.9383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43232', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.923, 'longitude': -82.8664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43234', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43235', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.1088, 'longitude': -82.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43236', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.1357, 'longitude': -83.0076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43240', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 40.1454, 'longitude': -82.9817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43251', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43260', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43266', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43268', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43270', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43271', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43272', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43279', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43287', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43291', 'place_name': 'Columbus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Franklin', 'locality_code': '49', 'latitude': 39.969, 'longitude': -83.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43502', 'place_name': 'Archbold', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.5333, 'longitude': -84.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43515', 'place_name': 'Delta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.5577, 'longitude': -83.9866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43521', 'place_name': 'Fayette', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.6717, 'longitude': -84.325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43533', 'place_name': 'Lyons', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.6905, 'longitude': -84.0624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43540', 'place_name': 'Metamora', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.6952, 'longitude': -83.926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43553', 'place_name': 'Pettisville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.5306, 'longitude': -84.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43558', 'place_name': 'Swanton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.5945, 'longitude': -83.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43567', 'place_name': 'Wauseon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Fulton', 'locality_code': '51', 'latitude': 41.5668, 'longitude': -84.1537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45614', 'place_name': 'Bidwell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.9276, 'longitude': -82.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45620', 'place_name': 'Cheshire', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.9587, 'longitude': -82.1235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45623', 'place_name': 'Crown City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.6135, 'longitude': -82.2657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45631', 'place_name': 'Gallipolis', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.8148, 'longitude': -82.229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45643', 'place_name': 'Kerr', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.8683, 'longitude': -82.2562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45658', 'place_name': 'Patriot', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.777, 'longitude': -82.4275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45674', 'place_name': 'Rio Grande', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.8814, 'longitude': -82.3782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45685', 'place_name': 'Thurman', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.8705, 'longitude': -82.4063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45686', 'place_name': 'Vinton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Gallia', 'locality_code': '53', 'latitude': 38.9783, 'longitude': -82.357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44021', 'place_name': 'Burton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.4527, 'longitude': -81.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44023', 'place_name': 'Chagrin Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.3872, 'longitude': -81.3042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44024', 'place_name': 'Chardon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.5719, 'longitude': -81.2056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44026', 'place_name': 'Chesterland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.5344, 'longitude': -81.3421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44033', 'place_name': 'East Claridon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.5333, 'longitude': -81.1112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44046', 'place_name': 'Huntsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.5384, 'longitude': -81.0734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44062', 'place_name': 'Middlefield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.4455, 'longitude': -81.0373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44064', 'place_name': 'Montville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.6034, 'longitude': -81.057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44065', 'place_name': 'Newbury', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.475, 'longitude': -81.2345, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '44072', 'place_name': 'Novelty', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.4763, 'longitude': -81.3342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44073', 'place_name': 'Novelty', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.4948, 'longitude': -81.3407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44080', 'place_name': 'Parkman', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.3706, 'longitude': -81.0651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44086', 'place_name': 'Thompson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Geauga', 'locality_code': '55', 'latitude': 41.6762, 'longitude': -81.0573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45301', 'place_name': 'Alpha', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.7117, 'longitude': -84.0233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45305', 'place_name': 'Bellbrook', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.6402, 'longitude': -84.0824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45307', 'place_name': 'Bowersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.5806, 'longitude': -83.7249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45314', 'place_name': 'Cedarville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.7484, 'longitude': -83.8013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45316', 'place_name': 'Clifton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.797, 'longitude': -83.8256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45324', 'place_name': 'Fairborn', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.8053, 'longitude': -84.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45335', 'place_name': 'Jamestown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.6428, 'longitude': -83.7504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45370', 'place_name': 'Spring Valley', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.6083, 'longitude': -84.026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45384', 'place_name': 'Wilberforce', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.7128, 'longitude': -83.8781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45385', 'place_name': 'Xenia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.6842, 'longitude': -83.9369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45387', 'place_name': 'Yellow Springs', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.7996, 'longitude': -83.8891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45431', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.7574, 'longitude': -84.0569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45433', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Greene', 'locality_code': '57', 'latitude': 39.8138, 'longitude': -84.059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43722', 'place_name': 'Buffalo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.9159, 'longitude': -81.5201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43723', 'place_name': 'Byesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.9623, 'longitude': -81.5485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43725', 'place_name': 'Cambridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 40.027, 'longitude': -81.582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43732', 'place_name': 'Cumberland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.852, 'longitude': -81.6576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43733', 'place_name': 'Derwent', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.9236, 'longitude': -81.543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43736', 'place_name': 'Fairview', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 40.065, 'longitude': -81.2558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43749', 'place_name': 'Kimbolton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 40.1589, 'longitude': -81.549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43750', 'place_name': 'Kipling', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.9945, 'longitude': -81.5006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43755', 'place_name': 'Lore City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 40.0459, 'longitude': -81.4479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43768', 'place_name': 'Old Washington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 40.0392, 'longitude': -81.4522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43772', 'place_name': 'Pleasant City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.9095, 'longitude': -81.558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43773', 'place_name': 'Quaker City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.9866, 'longitude': -81.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43778', 'place_name': 'Salesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 40.0081, 'longitude': -81.3728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43780', 'place_name': 'Senecaville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Guernsey', 'locality_code': '59', 'latitude': 39.9337, 'longitude': -81.458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45001', 'place_name': 'Addyston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1374, 'longitude': -84.7096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45002', 'place_name': 'Cleves', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1937, 'longitude': -84.734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45030', 'place_name': 'Harrison', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2592, 'longitude': -84.7837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45033', 'place_name': 'Hooven', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1773, 'longitude': -84.7627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45041', 'place_name': 'Miamitown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2159, 'longitude': -84.7041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45051', 'place_name': 'Mount Saint Joseph', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.0965, 'longitude': -84.6431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45052', 'place_name': 'North Bend', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1536, 'longitude': -84.7273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45111', 'place_name': 'Camp Dennison', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1962, 'longitude': -84.2897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45174', 'place_name': 'Terrace Park', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1602, 'longitude': -84.3098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45201', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45202', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1072, 'longitude': -84.502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45203', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1075, 'longitude': -84.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45204', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.0963, 'longitude': -84.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45205', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1104, 'longitude': -84.5757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45206', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1269, 'longitude': -84.4853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45207', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1397, 'longitude': -84.4706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45208', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1361, 'longitude': -84.4355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45209', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1516, 'longitude': -84.4278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45211', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1524, 'longitude': -84.5967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45212', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1642, 'longitude': -84.4522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45213', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1802, 'longitude': -84.4204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45214', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1219, 'longitude': -84.5506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45215', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2353, 'longitude': -84.4619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45216', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2003, 'longitude': -84.4859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45217', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1661, 'longitude': -84.4959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45218', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2663, 'longitude': -84.5221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45219', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.127, 'longitude': -84.5131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45220', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1432, 'longitude': -84.5217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45221', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45222', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45223', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1696, 'longitude': -84.5478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45224', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1991, 'longitude': -84.5251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45225', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1447, 'longitude': -84.5533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45226', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1174, 'longitude': -84.4312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45227', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1539, 'longitude': -84.3854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45229', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.149, 'longitude': -84.4892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45230', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.0713, 'longitude': -84.3758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45231', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2418, 'longitude': -84.5437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45232', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1859, 'longitude': -84.5141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45233', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.111, 'longitude': -84.6594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45234', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45235', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45236', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.21, 'longitude': -84.395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45237', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.188, 'longitude': -84.458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45238', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1092, 'longitude': -84.6108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45239', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2045, 'longitude': -84.5799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45240', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2851, 'longitude': -84.5288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45241', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2638, 'longitude': -84.4092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45242', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2447, 'longitude': -84.3455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45243', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1848, 'longitude': -84.3448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45244', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1191, 'longitude': -84.351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45246', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2839, 'longitude': -84.4744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45247', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2208, 'longitude': -84.6418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45248', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1652, 'longitude': -84.6625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45249', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2692, 'longitude': -84.3307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45250', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45251', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2672, 'longitude': -84.5993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45252', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2668, 'longitude': -84.6283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45253', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45254', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45255', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.0584, 'longitude': -84.3396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45258', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45262', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45263', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45264', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45267', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45268', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45269', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45270', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45271', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45273', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45274', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45277', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45280', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.162, 'longitude': -84.4569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45296', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45298', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45299', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.2622, 'longitude': -84.5093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45999', 'place_name': 'Cincinnati', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hamilton', 'locality_code': '61', 'latitude': 39.1668, 'longitude': -84.5382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44804', 'place_name': 'Arcadia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 41.1116, 'longitude': -83.5019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45814', 'place_name': 'Arlington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 40.8761, 'longitude': -83.6685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45816', 'place_name': 'Benton Ridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 41.0031, 'longitude': -83.7931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45839', 'place_name': 'Findlay', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 41.0442, 'longitude': -83.6499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45840', 'place_name': 'Findlay', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 41.0449, 'longitude': -83.6457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45841', 'place_name': 'Jenera', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 40.9004, 'longitude': -83.7256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45858', 'place_name': 'Mc Comb', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 41.1125, 'longitude': -83.8014, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '45867', 'place_name': 'Mount Blanchard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 40.8929, 'longitude': -83.5553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45868', 'place_name': 'Mount Cory', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 40.9437, 'longitude': -83.8093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45881', 'place_name': 'Rawson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 40.9589, 'longitude': -83.7841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45889', 'place_name': 'Van Buren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 41.1327, 'longitude': -83.6473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45890', 'place_name': 'Vanlue', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 40.9583, 'longitude': -83.4971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45897', 'place_name': 'Williamstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hancock', 'locality_code': '63', 'latitude': 40.834, 'longitude': -83.6518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43326', 'place_name': 'Kenton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.6404, 'longitude': -83.6111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43340', 'place_name': 'Mount Victory', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.5232, 'longitude': -83.4942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43345', 'place_name': 'Ridgeway', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.5209, 'longitude': -83.5702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43346', 'place_name': 'Roundhead', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.5732, 'longitude': -83.8462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45810', 'place_name': 'Ada', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.7709, 'longitude': -83.8154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45812', 'place_name': 'Alger', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.706, 'longitude': -83.825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45835', 'place_name': 'Dola', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.7598, 'longitude': -83.7001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45836', 'place_name': 'Dunkirk', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.7824, 'longitude': -83.6339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45843', 'place_name': 'Forest', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.7816, 'longitude': -83.5351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45859', 'place_name': 'Mc Guffey', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hardin', 'locality_code': '65', 'latitude': 40.6899, 'longitude': -83.8111, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '43907', 'place_name': 'Cadiz', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.2632, 'longitude': -81.0307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43973', 'place_name': 'Freeport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.1925, 'longitude': -81.277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43974', 'place_name': 'Harrisville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.1815, 'longitude': -80.8882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43976', 'place_name': 'Hopedale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.3496, 'longitude': -80.9021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43981', 'place_name': 'New Athens', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.1839, 'longitude': -80.9959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43984', 'place_name': 'New Rumley', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.4017, 'longitude': -81.0309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43986', 'place_name': 'Jewett', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.3745, 'longitude': -81.0004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43988', 'place_name': 'Scio', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.4012, 'longitude': -81.1016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44693', 'place_name': 'Deersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.2947, 'longitude': -81.1839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44695', 'place_name': 'Bowerston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.4371, 'longitude': -81.1862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44699', 'place_name': 'Tippecanoe', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Harrison', 'locality_code': '67', 'latitude': 40.2797, 'longitude': -81.2919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43510', 'place_name': 'Colton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.4199, 'longitude': -84.0137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43516', 'place_name': 'Deshler', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.2239, 'longitude': -83.8964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43523', 'place_name': 'Grelton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.3411, 'longitude': -84.0005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43524', 'place_name': 'Hamler', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.2292, 'longitude': -84.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43527', 'place_name': 'Holgate', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.2549, 'longitude': -84.1447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43532', 'place_name': 'Liberty Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.4514, 'longitude': -83.9859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43534', 'place_name': 'Mc Clure', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.3773, 'longitude': -83.9425, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '43535', 'place_name': 'Malinta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.3084, 'longitude': -84.0457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43545', 'place_name': 'Napoleon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.391, 'longitude': -84.1433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43548', 'place_name': 'New Bavaria', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.2037, 'longitude': -84.1683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43550', 'place_name': 'Okolona', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.3267, 'longitude': -84.1117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43555', 'place_name': 'Ridgeville Corners', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Henry', 'locality_code': '69', 'latitude': 41.4351, 'longitude': -84.2544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45123', 'place_name': 'Greenfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Highland', 'locality_code': '71', 'latitude': 39.3478, 'longitude': -83.3898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45132', 'place_name': 'Highland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Highland', 'locality_code': '71', 'latitude': 39.3445, 'longitude': -83.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45133', 'place_name': 'Hillsboro', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Highland', 'locality_code': '71', 'latitude': 39.1679, 'longitude': -83.6064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45135', 'place_name': 'Leesburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Highland', 'locality_code': '71', 'latitude': 39.3458, 'longitude': -83.5481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45142', 'place_name': 'Lynchburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Highland', 'locality_code': '71', 'latitude': 39.2119, 'longitude': -83.8021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45155', 'place_name': 'Mowrystown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Highland', 'locality_code': '71', 'latitude': 39.0388, 'longitude': -83.7505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45172', 'place_name': 'Sinking Spring', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Highland', 'locality_code': '71', 'latitude': 39.0738, 'longitude': -83.3853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43111', 'place_name': 'Carbon Hill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.5045, 'longitude': -82.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43127', 'place_name': 'Haydenville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.4766, 'longitude': -82.3281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43135', 'place_name': 'Laurelville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.4757, 'longitude': -82.7212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43138', 'place_name': 'Logan', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.5372, 'longitude': -82.4126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43144', 'place_name': 'Murray City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.5055, 'longitude': -82.1711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43149', 'place_name': 'Rockbridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.5509, 'longitude': -82.5626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43152', 'place_name': 'South Bloomingville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.4174, 'longitude': -82.5923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43158', 'place_name': 'Union Furnace', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Hocking', 'locality_code': '73', 'latitude': 39.4617, 'longitude': -82.3563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44610', 'place_name': 'Berlin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.5612, 'longitude': -81.7943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44611', 'place_name': 'Big Prairie', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.6188, 'longitude': -82.072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44617', 'place_name': 'Charm', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.5071, 'longitude': -81.7829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44628', 'place_name': 'Glenmont', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.5217, 'longitude': -82.1505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44633', 'place_name': 'Holmesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.633, 'longitude': -81.9275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44637', 'place_name': 'Killbuck', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.4933, 'longitude': -81.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44638', 'place_name': 'Lakeville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.652, 'longitude': -82.1455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44654', 'place_name': 'Millersburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.5567, 'longitude': -81.8324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44660', 'place_name': 'Mount Hope', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.6223, 'longitude': -81.7825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44661', 'place_name': 'Nashville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.5956, 'longitude': -82.113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44687', 'place_name': 'Walnut Creek', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.5415, 'longitude': -81.7218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44690', 'place_name': 'Winesburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Holmes', 'locality_code': '75', 'latitude': 40.6164, 'longitude': -81.6951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44811', 'place_name': 'Bellevue', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.2684, 'longitude': -82.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44826', 'place_name': 'Collins', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.245, 'longitude': -82.4904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44837', 'place_name': 'Greenwich', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.0407, 'longitude': -82.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44847', 'place_name': 'Monroeville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.2181, 'longitude': -82.7023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44850', 'place_name': 'New Haven', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.035, 'longitude': -82.677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44851', 'place_name': 'New London', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.0906, 'longitude': -82.3966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44855', 'place_name': 'North Fairfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.103, 'longitude': -82.5998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44857', 'place_name': 'Norwalk', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.2403, 'longitude': -82.6078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44888', 'place_name': 'Willard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.0531, 'longitude': -82.7263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44889', 'place_name': 'Wakeman', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.2637, 'longitude': -82.3782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44890', 'place_name': 'Willard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Huron', 'locality_code': '77', 'latitude': 41.0628, 'longitude': -82.7288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45621', 'place_name': 'Coalton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jackson', 'locality_code': '79', 'latitude': 39.1108, 'longitude': -82.6077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45640', 'place_name': 'Jackson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jackson', 'locality_code': '79', 'latitude': 39.0428, 'longitude': -82.6472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45656', 'place_name': 'Oak Hill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jackson', 'locality_code': '79', 'latitude': 38.8916, 'longitude': -82.5883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45692', 'place_name': 'Wellston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jackson', 'locality_code': '79', 'latitude': 39.1189, 'longitude': -82.5485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43901', 'place_name': 'Adena', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.2126, 'longitude': -80.8815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43903', 'place_name': 'Amsterdam', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.4731, 'longitude': -80.9596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43908', 'place_name': 'Bergholz', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.5195, 'longitude': -80.884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43910', 'place_name': 'Bloomingdale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.3742, 'longitude': -80.8072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43913', 'place_name': 'Brilliant', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.2683, 'longitude': -80.6319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43917', 'place_name': 'Dillonvale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.2251, 'longitude': -80.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43925', 'place_name': 'East Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.4506, 'longitude': -80.8604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43926', 'place_name': 'Empire', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.5092, 'longitude': -80.6241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43930', 'place_name': 'Hammondsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.5676, 'longitude': -80.7659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43932', 'place_name': 'Irondale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.5111, 'longitude': -80.7915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43938', 'place_name': 'Mingo Junction', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.3203, 'longitude': -80.625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43939', 'place_name': 'Mount Pleasant', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.1753, 'longitude': -80.7979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43941', 'place_name': 'Piney Fork', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.2639, 'longitude': -80.8358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43943', 'place_name': 'Rayland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.2083, 'longitude': -80.7125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43944', 'place_name': 'Richmond', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.4261, 'longitude': -80.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43948', 'place_name': 'Smithfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.2709, 'longitude': -80.7815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43952', 'place_name': 'Steubenville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.3698, 'longitude': -80.634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43953', 'place_name': 'Steubenville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.3524, 'longitude': -80.6781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43961', 'place_name': 'Stratton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.5185, 'longitude': -80.6285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43963', 'place_name': 'Tiltonsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.1681, 'longitude': -80.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43964', 'place_name': 'Toronto', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.4733, 'longitude': -80.6325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43970', 'place_name': 'Wolf Run', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.4673, 'longitude': -80.8893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43971', 'place_name': 'Yorkville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Jefferson', 'locality_code': '81', 'latitude': 40.1581, 'longitude': -80.7077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43005', 'place_name': 'Bladensburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.2845, 'longitude': -82.284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43006', 'place_name': 'Brinkhaven', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.4583, 'longitude': -82.1553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43011', 'place_name': 'Centerburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.2865, 'longitude': -82.68, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43014', 'place_name': 'Danville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.4557, 'longitude': -82.2639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43019', 'place_name': 'Fredericktown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.4976, 'longitude': -82.5857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43022', 'place_name': 'Gambier', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.3782, 'longitude': -82.3828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43028', 'place_name': 'Howard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.4158, 'longitude': -82.3334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43037', 'place_name': 'Martinsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.268, 'longitude': -82.3567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43048', 'place_name': 'Mount Liberty', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.3467, 'longitude': -82.6302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43050', 'place_name': 'Mount Vernon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Knox', 'locality_code': '83', 'latitude': 40.3849, 'longitude': -82.4873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44045', 'place_name': 'Grand River', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.7427, 'longitude': -81.2821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44057', 'place_name': 'Madison', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.8054, 'longitude': -81.0588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44060', 'place_name': 'Mentor', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.6895, 'longitude': -81.3421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44061', 'place_name': 'Mentor', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.6662, 'longitude': -81.3396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44077', 'place_name': 'Painesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.7079, 'longitude': -81.199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44081', 'place_name': 'Perry', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.7679, 'longitude': -81.1433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44092', 'place_name': 'Wickliffe', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.6046, 'longitude': -81.4692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44094', 'place_name': 'Willoughby', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.6302, 'longitude': -81.4076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44095', 'place_name': 'Eastlake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.6587, 'longitude': -81.4445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44096', 'place_name': 'Willoughby', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.6398, 'longitude': -81.4065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44097', 'place_name': 'Eastlake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lake', 'locality_code': '85', 'latitude': 41.6539, 'longitude': -81.4504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45619', 'place_name': 'Chesapeake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.4551, 'longitude': -82.4504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45638', 'place_name': 'Ironton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.5294, 'longitude': -82.6654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45645', 'place_name': 'Kitts Hill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.5649, 'longitude': -82.5489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45659', 'place_name': 'Pedro', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.6503, 'longitude': -82.6477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45669', 'place_name': 'Proctorville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.4635, 'longitude': -82.3523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45675', 'place_name': 'Rock Camp', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.5367, 'longitude': -82.5327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45678', 'place_name': 'Scottown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.594, 'longitude': -82.3967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45680', 'place_name': 'South Point', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.4339, 'longitude': -82.5529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45688', 'place_name': 'Waterloo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.7182, 'longitude': -82.5174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45696', 'place_name': 'Willow Wood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lawrence', 'locality_code': '87', 'latitude': 38.594, 'longitude': -82.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43001', 'place_name': 'Alexandria', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.106, 'longitude': -82.6077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43008', 'place_name': 'Buckeye Lake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.9337, 'longitude': -82.4724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43013', 'place_name': 'Croton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.2376, 'longitude': -82.6989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43018', 'place_name': 'Etna', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.9572, 'longitude': -82.6837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43023', 'place_name': 'Granville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.0788, 'longitude': -82.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43025', 'place_name': 'Hebron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.9535, 'longitude': -82.4919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43027', 'place_name': 'Homer', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.2528, 'longitude': -82.5177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43030', 'place_name': 'Jacksontown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.9595, 'longitude': -82.4129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43031', 'place_name': 'Johnstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.1445, 'longitude': -82.6973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43033', 'place_name': 'Kirkersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.961, 'longitude': -82.5998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43055', 'place_name': 'Newark', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.0724, 'longitude': -82.4046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43056', 'place_name': 'Heath', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.0197, 'longitude': -82.3875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43058', 'place_name': 'Newark', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.0581, 'longitude': -82.4013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43062', 'place_name': 'Pataskala', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.0009, 'longitude': -82.6687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43071', 'place_name': 'Saint Louisville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.1818, 'longitude': -82.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43073', 'place_name': 'Summit Station', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.9965, 'longitude': -82.754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43080', 'place_name': 'Utica', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.2441, 'longitude': -82.4135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43093', 'place_name': 'Newark', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 40.0951, 'longitude': -82.4827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43721', 'place_name': 'Brownsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.947, 'longitude': -82.2565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43740', 'place_name': 'Gratiot', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Licking', 'locality_code': '89', 'latitude': 39.9522, 'longitude': -82.2128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43310', 'place_name': 'Belle Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.5024, 'longitude': -83.7688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43311', 'place_name': 'Bellefontaine', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.3605, 'longitude': -83.7571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43318', 'place_name': 'De Graff', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.3058, 'longitude': -83.9153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43319', 'place_name': 'East Liberty', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.3077, 'longitude': -83.5862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43324', 'place_name': 'Huntsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.4413, 'longitude': -83.7927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43331', 'place_name': 'Lakeview', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.5019, 'longitude': -83.9202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43333', 'place_name': 'Lewistown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.4277, 'longitude': -83.9209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43336', 'place_name': 'Middleburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.2926, 'longitude': -83.5824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43343', 'place_name': 'Quincy', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.2876, 'longitude': -83.9744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43347', 'place_name': 'Rushsylvania', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.4658, 'longitude': -83.6598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43348', 'place_name': 'Russells Point', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.4675, 'longitude': -83.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43357', 'place_name': 'West Liberty', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.2625, 'longitude': -83.7528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43358', 'place_name': 'West Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.4043, 'longitude': -83.5243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43360', 'place_name': 'Zanesfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Logan', 'locality_code': '91', 'latitude': 40.3211, 'longitude': -83.6405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44001', 'place_name': 'Amherst', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.3617, 'longitude': -82.2538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44011', 'place_name': 'Avon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.4467, 'longitude': -82.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44012', 'place_name': 'Avon Lake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.5019, 'longitude': -82.0111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44028', 'place_name': 'Columbia Station', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.3187, 'longitude': -81.9344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44035', 'place_name': 'Elyria', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.3724, 'longitude': -82.1051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44036', 'place_name': 'Elyria', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.4015, 'longitude': -82.0771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44039', 'place_name': 'North Ridgeville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.3964, 'longitude': -82.0033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44044', 'place_name': 'Grafton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.2854, 'longitude': -82.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44049', 'place_name': 'Kipton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.2664, 'longitude': -82.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44050', 'place_name': 'Lagrange', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.2423, 'longitude': -82.1279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44052', 'place_name': 'Lorain', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.4578, 'longitude': -82.171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44053', 'place_name': 'Lorain', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.432, 'longitude': -82.2038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44054', 'place_name': 'Sheffield Lake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.4823, 'longitude': -82.0965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44055', 'place_name': 'Lorain', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.4361, 'longitude': -82.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44074', 'place_name': 'Oberlin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.2899, 'longitude': -82.2229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44090', 'place_name': 'Wellington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lorain', 'locality_code': '93', 'latitude': 41.1712, 'longitude': -82.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43434', 'place_name': 'Harbor View', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6934, 'longitude': -83.4444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43504', 'place_name': 'Berkey', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6989, 'longitude': -83.831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43528', 'place_name': 'Holland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6226, 'longitude': -83.7257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43537', 'place_name': 'Maumee', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.5817, 'longitude': -83.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43542', 'place_name': 'Monclova', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.5684, 'longitude': -83.7757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43547', 'place_name': 'Neapolis', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.492, 'longitude': -83.8706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43560', 'place_name': 'Sylvania', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.708, 'longitude': -83.7068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43566', 'place_name': 'Waterville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.5022, 'longitude': -83.7331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43571', 'place_name': 'Whitehouse', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.5194, 'longitude': -83.8115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43601', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.7207, 'longitude': -83.5694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43603', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43604', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6614, 'longitude': -83.5249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43605', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6525, 'longitude': -83.5085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43606', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6712, 'longitude': -83.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43607', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6504, 'longitude': -83.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43608', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6779, 'longitude': -83.5344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43609', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6298, 'longitude': -83.5773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43610', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6767, 'longitude': -83.5573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43611', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.7045, 'longitude': -83.4892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43612', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.7046, 'longitude': -83.5656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43613', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.7039, 'longitude': -83.6034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43614', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6028, 'longitude': -83.6292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43615', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6492, 'longitude': -83.6706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43616', 'place_name': 'Oregon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6418, 'longitude': -83.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43617', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6668, 'longitude': -83.717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43620', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6654, 'longitude': -83.5536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43623', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.708, 'longitude': -83.6434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43635', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43652', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43654', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43656', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6782, 'longitude': -83.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43657', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43659', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43660', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6546, 'longitude': -83.5329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43661', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6782, 'longitude': -83.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43666', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6782, 'longitude': -83.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43667', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43681', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43682', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43697', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6868, 'longitude': -83.4394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43699', 'place_name': 'Toledo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Lucas', 'locality_code': '95', 'latitude': 41.6538, 'longitude': -83.6589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43064', 'place_name': 'Plain City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Madison', 'locality_code': '97', 'latitude': 40.0974, 'longitude': -83.269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43140', 'place_name': 'London', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Madison', 'locality_code': '97', 'latitude': 39.9001, 'longitude': -83.4439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43143', 'place_name': 'Mount Sterling', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Madison', 'locality_code': '97', 'latitude': 39.7175, 'longitude': -83.2806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43151', 'place_name': 'Sedalia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Madison', 'locality_code': '97', 'latitude': 39.733, 'longitude': -83.4764, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '43153', 'place_name': 'South Solon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Madison', 'locality_code': '97', 'latitude': 39.7423, 'longitude': -83.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43162', 'place_name': 'West Jefferson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Madison', 'locality_code': '97', 'latitude': 39.9424, 'longitude': -83.2853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44401', 'place_name': 'Berlin Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0243, 'longitude': -80.9341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44405', 'place_name': 'Campbell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0778, 'longitude': -80.5897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44406', 'place_name': 'Canfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0293, 'longitude': -80.7564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44416', 'place_name': 'Ellsworth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0242, 'longitude': -80.8573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44422', 'place_name': 'Greenford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9439, 'longitude': -80.7915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44429', 'place_name': 'Lake Milton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.1014, 'longitude': -80.9724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44436', 'place_name': 'Lowellville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0503, 'longitude': -80.5416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44442', 'place_name': 'New Middletown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9646, 'longitude': -80.5534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44443', 'place_name': 'New Springfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9265, 'longitude': -80.5856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44449', 'place_name': 'North Benton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9876, 'longitude': -81.0162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44451', 'place_name': 'North Jackson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.088, 'longitude': -80.8623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44452', 'place_name': 'North Lima', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9649, 'longitude': -80.6549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44454', 'place_name': 'Petersburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9049, 'longitude': -80.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44471', 'place_name': 'Struthers', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0508, 'longitude': -80.5985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44501', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0171, 'longitude': -80.8029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44502', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0774, 'longitude': -80.6409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44503', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.102, 'longitude': -80.65, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44504', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.1237, 'longitude': -80.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44505', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.1257, 'longitude': -80.6277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44506', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.096, 'longitude': -80.6259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44507', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0732, 'longitude': -80.6553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44509', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.105, 'longitude': -80.6945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44510', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.1197, 'longitude': -80.6672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44511', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0704, 'longitude': -80.6931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44512', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0252, 'longitude': -80.6687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44513', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0171, 'longitude': -80.8029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44514', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0093, 'longitude': -80.6183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44515', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.0979, 'longitude': -80.7598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44555', 'place_name': 'Youngstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 41.1039, 'longitude': -80.6436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44609', 'place_name': 'Beloit', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.8957, 'longitude': -80.9897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44619', 'place_name': 'Damascus', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9021, 'longitude': -80.9628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44672', 'place_name': 'Sebring', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mahoning', 'locality_code': '99', 'latitude': 40.9227, 'longitude': -81.0232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43301', 'place_name': 'Marion', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.6166, 'longitude': -83.0693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43302', 'place_name': 'Marion', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.5876, 'longitude': -83.1271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43314', 'place_name': 'Caledonia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.6272, 'longitude': -82.9925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43322', 'place_name': 'Green Camp', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.5322, 'longitude': -83.2078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43332', 'place_name': 'La Rue', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.5789, 'longitude': -83.3734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43335', 'place_name': 'Martel', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.6685, 'longitude': -82.91, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43337', 'place_name': 'Morral', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.6954, 'longitude': -83.2046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43341', 'place_name': 'New Bloomington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.6073, 'longitude': -83.3224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43342', 'place_name': 'Prospect', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.4727, 'longitude': -83.1763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43356', 'place_name': 'Waldo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Marion', 'locality_code': '101', 'latitude': 40.4605, 'longitude': -83.0706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44149', 'place_name': 'Strongsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.3134, 'longitude': -81.8562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44212', 'place_name': 'Brunswick', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.2471, 'longitude': -81.828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44215', 'place_name': 'Chippewa Lake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0653, 'longitude': -81.9017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44233', 'place_name': 'Hinckley', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.2419, 'longitude': -81.7453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44235', 'place_name': 'Homerville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0267, 'longitude': -82.125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44251', 'place_name': 'Westfield Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0288, 'longitude': -81.9283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44253', 'place_name': 'Litchfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.1668, 'longitude': -82.0157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44254', 'place_name': 'Lodi', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0327, 'longitude': -82.0147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44256', 'place_name': 'Medina', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.1404, 'longitude': -81.8584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44258', 'place_name': 'Medina', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.1276, 'longitude': -81.8411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44273', 'place_name': 'Seville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0227, 'longitude': -81.8562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44274', 'place_name': 'Sharon Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0992, 'longitude': -81.7343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44275', 'place_name': 'Spencer', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0983, 'longitude': -82.0999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44280', 'place_name': 'Valley City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.2368, 'longitude': -81.9245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44281', 'place_name': 'Wadsworth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0384, 'longitude': -81.7374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44282', 'place_name': 'Wadsworth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Medina', 'locality_code': '103', 'latitude': 41.0256, 'longitude': -81.7299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45720', 'place_name': 'Chester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 39.0856, 'longitude': -81.9214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45741', 'place_name': 'Langsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 39.0697, 'longitude': -82.2499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45743', 'place_name': 'Long Bottom', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 39.0802, 'longitude': -81.8887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45760', 'place_name': 'Middleport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 38.9993, 'longitude': -82.06, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45769', 'place_name': 'Pomeroy', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 39.0607, 'longitude': -82.0331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45770', 'place_name': 'Portland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 38.9999, 'longitude': -81.8135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45771', 'place_name': 'Racine', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 38.9786, 'longitude': -81.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45772', 'place_name': 'Reedsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 39.149, 'longitude': -81.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45775', 'place_name': 'Rutland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 39.0909, 'longitude': -82.1486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45779', 'place_name': 'Syracuse', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 38.9976, 'longitude': -81.974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45783', 'place_name': 'Tuppers Plains', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Meigs', 'locality_code': '105', 'latitude': 39.1683, 'longitude': -81.8423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45310', 'place_name': 'Burkettsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.3541, 'longitude': -84.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45822', 'place_name': 'Celina', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.5566, 'longitude': -84.6287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45826', 'place_name': 'Chickasaw', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.437, 'longitude': -84.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45828', 'place_name': 'Coldwater', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.4846, 'longitude': -84.6517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45846', 'place_name': 'Fort Recovery', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.4018, 'longitude': -84.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45860', 'place_name': 'Maria Stein', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.4062, 'longitude': -84.5076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45862', 'place_name': 'Mendon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.6777, 'longitude': -84.5152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45866', 'place_name': 'Montezuma', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.489, 'longitude': -84.5494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45882', 'place_name': 'Rockford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.6771, 'longitude': -84.6642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45883', 'place_name': 'Saint Henry', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Mercer', 'locality_code': '107', 'latitude': 40.4091, 'longitude': -84.6333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45308', 'place_name': 'Bradford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.1286, 'longitude': -84.4293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45312', 'place_name': 'Casstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.0716, 'longitude': -84.1088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45317', 'place_name': 'Conover', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.1457, 'longitude': -84.0283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45318', 'place_name': 'Covington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.1176, 'longitude': -84.3496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45326', 'place_name': 'Fletcher', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.1445, 'longitude': -84.101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45337', 'place_name': 'Laura', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 39.9785, 'longitude': -84.3994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45339', 'place_name': 'Ludlow Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 39.9871, 'longitude': -84.3334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45356', 'place_name': 'Piqua', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.1486, 'longitude': -84.2531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45359', 'place_name': 'Pleasant Hill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.0531, 'longitude': -84.3436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45361', 'place_name': 'Potsdam', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 39.9635, 'longitude': -84.4145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45371', 'place_name': 'Tipp City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 39.942, 'longitude': -84.1663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45373', 'place_name': 'Troy', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.0374, 'longitude': -84.2032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45374', 'place_name': 'Troy', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 40.04, 'longitude': -84.2298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45383', 'place_name': 'West Milton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Miami', 'locality_code': '109', 'latitude': 39.9531, 'longitude': -84.3242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43716', 'place_name': 'Beallsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.8484, 'longitude': -81.0368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43747', 'place_name': 'Jerusalem', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.8488, 'longitude': -81.0921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43752', 'place_name': 'Laings', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.7171, 'longitude': -81.01, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43754', 'place_name': 'Lewisville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.7684, 'longitude': -81.2316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43757', 'place_name': 'Malaga', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.8594, 'longitude': -81.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43786', 'place_name': 'Stafford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.7112, 'longitude': -81.2758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43793', 'place_name': 'Woodsfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.7515, 'longitude': -81.0759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43914', 'place_name': 'Cameron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.7687, 'longitude': -80.9454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43915', 'place_name': 'Clarington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.7819, 'longitude': -80.9113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43931', 'place_name': 'Hannibal', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.6673, 'longitude': -80.872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43946', 'place_name': 'Sardis', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.6526, 'longitude': -80.9243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45734', 'place_name': 'Graysville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Monroe', 'locality_code': '111', 'latitude': 39.663, 'longitude': -81.1822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45309', 'place_name': 'Brookville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.8414, 'longitude': -84.4165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45315', 'place_name': 'Clayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.8551, 'longitude': -84.3399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45322', 'place_name': 'Englewood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.877, 'longitude': -84.3319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45325', 'place_name': 'Farmersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6867, 'longitude': -84.4205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45327', 'place_name': 'Germantown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6244, 'longitude': -84.3764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45342', 'place_name': 'Miamisburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6321, 'longitude': -84.2675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45343', 'place_name': 'Miamisburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45345', 'place_name': 'New Lebanon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7398, 'longitude': -84.3956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45354', 'place_name': 'Phillipsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.9054, 'longitude': -84.4028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45377', 'place_name': 'Vandalia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.8883, 'longitude': -84.2023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45401', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45402', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7563, 'longitude': -84.1895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45403', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7617, 'longitude': -84.1498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45404', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7862, 'longitude': -84.1622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45405', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7899, 'longitude': -84.2135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45406', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7821, 'longitude': -84.2373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45409', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7238, 'longitude': -84.1854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45410', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7474, 'longitude': -84.16, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45412', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7589, 'longitude': -84.1916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45413', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45414', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.8285, 'longitude': -84.2024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45415', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.8355, 'longitude': -84.2613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45416', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.8011, 'longitude': -84.2578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45417', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7528, 'longitude': -84.247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45419', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7155, 'longitude': -84.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45420', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7171, 'longitude': -84.1342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45422', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7581, 'longitude': -84.2001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45423', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7589, 'longitude': -84.1916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45424', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.8353, 'longitude': -84.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45426', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7982, 'longitude': -84.3211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45428', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7467, 'longitude': -84.2593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45429', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6841, 'longitude': -84.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45430', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7092, 'longitude': -84.1048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45432', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.739, 'longitude': -84.0856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45434', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7216, 'longitude': -84.029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45435', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45437', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45439', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.701, 'longitude': -84.2187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45440', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6749, 'longitude': -84.1136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45441', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45448', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45449', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6651, 'longitude': -84.2401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45458', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6062, 'longitude': -84.1695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45459', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.6464, 'longitude': -84.1717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45469', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7405, 'longitude': -84.1789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45470', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45475', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45479', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7344, 'longitude': -84.1944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45481', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45482', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45490', 'place_name': 'Dayton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Montgomery', 'locality_code': '113', 'latitude': 39.7505, 'longitude': -84.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43728', 'place_name': 'Chesterhill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morgan', 'locality_code': '115', 'latitude': 39.4953, 'longitude': -81.8773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43756', 'place_name': 'Mcconnelsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morgan', 'locality_code': '115', 'latitude': 39.6487, 'longitude': -81.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43758', 'place_name': 'Malta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morgan', 'locality_code': '115', 'latitude': 39.6482, 'longitude': -81.9127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43787', 'place_name': 'Stockport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morgan', 'locality_code': '115', 'latitude': 39.549, 'longitude': -81.8262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43315', 'place_name': 'Cardington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.5066, 'longitude': -82.9337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43317', 'place_name': 'Chesterville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.4789, 'longitude': -82.6828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43320', 'place_name': 'Edison', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.5905, 'longitude': -82.9023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43321', 'place_name': 'Fulton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.4626, 'longitude': -82.8288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43325', 'place_name': 'Iberia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.6703, 'longitude': -82.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43334', 'place_name': 'Marengo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.3895, 'longitude': -82.8121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43338', 'place_name': 'Mount Gilead', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.5384, 'longitude': -82.8062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43349', 'place_name': 'Shauck', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.6142, 'longitude': -82.6619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43350', 'place_name': 'Sparta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Morrow', 'locality_code': '117', 'latitude': 40.5289, 'longitude': -82.8229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43701', 'place_name': 'Zanesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.9274, 'longitude': -82.0041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43702', 'place_name': 'Zanesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.9403, 'longitude': -82.0132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43720', 'place_name': 'Blue Rock', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8, 'longitude': -81.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43727', 'place_name': 'Chandlersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8897, 'longitude': -81.8301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43734', 'place_name': 'Duncan Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8778, 'longitude': -81.9117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43735', 'place_name': 'East Fultonham', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8501, 'longitude': -82.1221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43738', 'place_name': 'Fultonham', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8555, 'longitude': -82.1378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43746', 'place_name': 'Hopewell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.9601, 'longitude': -82.1756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43762', 'place_name': 'New Concord', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 40.0088, 'longitude': -81.7387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43767', 'place_name': 'Norwich', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.9934, 'longitude': -81.8024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43771', 'place_name': 'Philo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8458, 'longitude': -81.9175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43777', 'place_name': 'Roseville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8187, 'longitude': -82.0792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43791', 'place_name': 'White Cottage', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 39.8713, 'longitude': -82.0987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43802', 'place_name': 'Adamsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 40.0793, 'longitude': -81.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43821', 'place_name': 'Dresden', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 40.1069, 'longitude': -81.9998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43822', 'place_name': 'Frazeysburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 40.1316, 'longitude': -82.1293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43830', 'place_name': 'Nashport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 40.0386, 'longitude': -82.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43842', 'place_name': 'Trinway', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Muskingum', 'locality_code': '119', 'latitude': 40.1412, 'longitude': -82.0099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43711', 'place_name': 'Ava', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Noble', 'locality_code': '121', 'latitude': 39.8317, 'longitude': -81.5748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43717', 'place_name': 'Belle Valley', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Noble', 'locality_code': '121', 'latitude': 39.7906, 'longitude': -81.5562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43724', 'place_name': 'Caldwell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Noble', 'locality_code': '121', 'latitude': 39.7467, 'longitude': -81.5153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43779', 'place_name': 'Sarahsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Noble', 'locality_code': '121', 'latitude': 39.8162, 'longitude': -81.4243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43788', 'place_name': 'Summerfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Noble', 'locality_code': '121', 'latitude': 39.8036, 'longitude': -81.332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45727', 'place_name': 'Dexter City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Noble', 'locality_code': '121', 'latitude': 39.6526, 'longitude': -81.4672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43408', 'place_name': 'Clay Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5686, 'longitude': -83.3632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43412', 'place_name': 'Curtice', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.6477, 'longitude': -83.2858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43416', 'place_name': 'Elmore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.4681, 'longitude': -83.2767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43430', 'place_name': 'Genoa', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.53, 'longitude': -83.359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43432', 'place_name': 'Graytown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5647, 'longitude': -83.2613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43433', 'place_name': 'Gypsum', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5038, 'longitude': -82.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43436', 'place_name': 'Isle Saint George', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.7153, 'longitude': -82.8227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43439', 'place_name': 'Lacarne', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5181, 'longitude': -83.0413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43440', 'place_name': 'Lakeside Marblehead', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5247, 'longitude': -82.7766, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '43445', 'place_name': 'Martin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5694, 'longitude': -83.3116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43446', 'place_name': 'Middle Bass', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.6835, 'longitude': -82.8047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43449', 'place_name': 'Oak Harbor', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5236, 'longitude': -83.1278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43452', 'place_name': 'Port Clinton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.512, 'longitude': -82.9377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43456', 'place_name': 'Put In Bay', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.6514, 'longitude': -82.8226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43458', 'place_name': 'Rocky Ridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.5302, 'longitude': -83.2128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43468', 'place_name': 'Williston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ottawa', 'locality_code': '123', 'latitude': 41.6037, 'longitude': -83.3399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45813', 'place_name': 'Antwerp', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.1887, 'longitude': -84.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45821', 'place_name': 'Cecil', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.2174, 'longitude': -84.6296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45849', 'place_name': 'Grover Hill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.0245, 'longitude': -84.4956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45851', 'place_name': 'Haviland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.0329, 'longitude': -84.6139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45855', 'place_name': 'Latty', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.0879, 'longitude': -84.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45861', 'place_name': 'Melrose', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.0812, 'longitude': -84.4287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45873', 'place_name': 'Oakwood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.0908, 'longitude': -84.3969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45879', 'place_name': 'Paulding', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.141, 'longitude': -84.5722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45880', 'place_name': 'Payne', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Paulding', 'locality_code': '125', 'latitude': 41.0807, 'longitude': -84.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43076', 'place_name': 'Thornville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.8974, 'longitude': -82.4071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43730', 'place_name': 'Corning', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.6361, 'longitude': -82.1102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43731', 'place_name': 'Crooksville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.7623, 'longitude': -82.084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43739', 'place_name': 'Glenford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.8699, 'longitude': -82.3026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43748', 'place_name': 'Junction City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.6965, 'longitude': -82.3155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43760', 'place_name': 'Mount Perry', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.8788, 'longitude': -82.188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43761', 'place_name': 'Moxahala', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.6626, 'longitude': -82.1363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43764', 'place_name': 'New Lexington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.7174, 'longitude': -82.2019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43766', 'place_name': 'New Straitsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.5869, 'longitude': -82.2488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43782', 'place_name': 'Shawnee', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.611, 'longitude': -82.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43783', 'place_name': 'Somerset', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Perry', 'locality_code': '127', 'latitude': 39.7936, 'longitude': -82.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43103', 'place_name': 'Ashville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.7316, 'longitude': -82.9446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43113', 'place_name': 'Circleville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.5988, 'longitude': -82.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43116', 'place_name': 'Commercial Point', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.7699, 'longitude': -83.0602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43117', 'place_name': 'Derby', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.7687, 'longitude': -83.2057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43137', 'place_name': 'Lockbourne', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.8142, 'longitude': -82.9764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43145', 'place_name': 'New Holland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.5589, 'longitude': -83.2504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43146', 'place_name': 'Orient', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.7954, 'longitude': -83.1543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43156', 'place_name': 'Tarlton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.5535, 'longitude': -82.7763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43164', 'place_name': 'Williamsport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pickaway', 'locality_code': '129', 'latitude': 39.6117, 'longitude': -83.1251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45613', 'place_name': 'Beaver', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 39.0332, 'longitude': -82.8514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45624', 'place_name': 'Cynthiana', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 39.1737, 'longitude': -83.3485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45642', 'place_name': 'Jasper', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 39.0523, 'longitude': -83.05, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45646', 'place_name': 'Latham', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 39.0804, 'longitude': -83.3283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45661', 'place_name': 'Piketon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 39.0437, 'longitude': -83.121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45683', 'place_name': 'Stockdale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 38.9555, 'longitude': -82.8584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45687', 'place_name': 'Wakefield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 38.9703, 'longitude': -83.0199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45690', 'place_name': 'Waverly', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Pike', 'locality_code': '131', 'latitude': 39.1264, 'longitude': -83.0049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44201', 'place_name': 'Atwater', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.0335, 'longitude': -81.1985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44202', 'place_name': 'Aurora', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.3176, 'longitude': -81.3454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44211', 'place_name': 'Brady Lake', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.1698, 'longitude': -81.3124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44231', 'place_name': 'Garrettsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.2988, 'longitude': -81.0704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44234', 'place_name': 'Hiram', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.3323, 'longitude': -81.1464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44240', 'place_name': 'Kent', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.1449, 'longitude': -81.3498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44241', 'place_name': 'Streetsboro', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.2491, 'longitude': -81.3383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44242', 'place_name': 'Kent', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.1537, 'longitude': -81.3579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44243', 'place_name': 'Kent', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.1475, 'longitude': -81.3415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44255', 'place_name': 'Mantua', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.2941, 'longitude': -81.2283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44265', 'place_name': 'Randolph', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.0328, 'longitude': -81.2484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44266', 'place_name': 'Ravenna', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.1649, 'longitude': -81.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44272', 'place_name': 'Rootstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.0995, 'longitude': -81.2026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44285', 'place_name': 'Wayland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.1597, 'longitude': -81.07, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44288', 'place_name': 'Windham', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.2392, 'longitude': -81.0535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44411', 'place_name': 'Deerfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.0359, 'longitude': -81.0528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44412', 'place_name': 'Diamond', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Portage', 'locality_code': '133', 'latitude': 41.0935, 'longitude': -81.0425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45070', 'place_name': 'West Elkton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.5897, 'longitude': -84.5581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45311', 'place_name': 'Camden', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.6134, 'longitude': -84.61, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45320', 'place_name': 'Eaton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.7426, 'longitude': -84.6508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45321', 'place_name': 'Eldorado', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.8882, 'longitude': -84.6786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45330', 'place_name': 'Gratis', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.6483, 'longitude': -84.5282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45338', 'place_name': 'Lewisburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.8534, 'longitude': -84.5369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45347', 'place_name': 'New Paris', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.8617, 'longitude': -84.7793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45378', 'place_name': 'Verona', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.9029, 'longitude': -84.4887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45381', 'place_name': 'West Alexandria', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.7259, 'longitude': -84.5352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45382', 'place_name': 'West Manchester', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Preble', 'locality_code': '135', 'latitude': 39.9026, 'longitude': -84.6194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45815', 'place_name': 'Belmore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.1539, 'longitude': -83.9413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45827', 'place_name': 'Cloverdale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.0379, 'longitude': -84.2938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45830', 'place_name': 'Columbus Grove', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 40.9137, 'longitude': -84.0705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45831', 'place_name': 'Continental', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.1148, 'longitude': -84.2358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45837', 'place_name': 'Dupont', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.0463, 'longitude': -84.3195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45844', 'place_name': 'Fort Jennings', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 40.9484, 'longitude': -84.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45848', 'place_name': 'Glandorf', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.0289, 'longitude': -84.0791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45853', 'place_name': 'Kalida', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 40.9828, 'longitude': -84.1994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45856', 'place_name': 'Leipsic', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.1092, 'longitude': -83.9957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45864', 'place_name': 'Miller City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.1038, 'longitude': -84.1315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45875', 'place_name': 'Ottawa', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 41.0192, 'longitude': -84.0472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45876', 'place_name': 'Ottoville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 40.9323, 'longitude': -84.3388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45877', 'place_name': 'Pandora', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 40.9509, 'longitude': -83.9521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45893', 'place_name': 'Vaughnsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Putnam', 'locality_code': '137', 'latitude': 40.8821, 'longitude': -84.148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44813', 'place_name': 'Bellville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.6136, 'longitude': -82.5175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44822', 'place_name': 'Butler', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.5438, 'longitude': -82.399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44843', 'place_name': 'Lucas', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.7039, 'longitude': -82.4087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44862', 'place_name': 'Ontario', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.7729, 'longitude': -82.5321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44865', 'place_name': 'Plymouth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 41.0003, 'longitude': -82.6635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44875', 'place_name': 'Shelby', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.8784, 'longitude': -82.6549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44878', 'place_name': 'Shiloh', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.934, 'longitude': -82.5222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44901', 'place_name': 'Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.8508, 'longitude': -82.5114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44902', 'place_name': 'Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.7559, 'longitude': -82.5123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44903', 'place_name': 'Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.7623, 'longitude': -82.5254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44904', 'place_name': 'Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.6824, 'longitude': -82.5286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44905', 'place_name': 'Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.7779, 'longitude': -82.4613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44906', 'place_name': 'Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.7627, 'longitude': -82.5593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44907', 'place_name': 'Mansfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Richland', 'locality_code': '139', 'latitude': 40.7345, 'longitude': -82.5198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43101', 'place_name': 'Adelphi', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.4667, 'longitude': -82.7471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43115', 'place_name': 'Clarksburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.4904, 'longitude': -83.1563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45601', 'place_name': 'Chillicothe', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.338, 'longitude': -82.9895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45612', 'place_name': 'Bainbridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.2131, 'longitude': -83.2763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45617', 'place_name': 'Bourneville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.2804, 'longitude': -83.159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45628', 'place_name': 'Frankfort', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.391, 'longitude': -83.2034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45633', 'place_name': 'Hallsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.4656, 'longitude': -82.7479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45644', 'place_name': 'Kingston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.4414, 'longitude': -82.8488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45647', 'place_name': 'Londonderry', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.2723, 'longitude': -82.7833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45673', 'place_name': 'Richmond Dale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.2039, 'longitude': -82.812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45681', 'place_name': 'South Salem', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Ross', 'locality_code': '141', 'latitude': 39.3021, 'longitude': -83.272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43407', 'place_name': 'Burgoon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.268, 'longitude': -83.2475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43410', 'place_name': 'Clyde', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.3024, 'longitude': -82.9918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43420', 'place_name': 'Fremont', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.3498, 'longitude': -83.1181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43431', 'place_name': 'Gibsonburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.3805, 'longitude': -83.3358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43435', 'place_name': 'Helena', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.326, 'longitude': -83.3186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43442', 'place_name': 'Lindsey', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.4147, 'longitude': -83.2135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43464', 'place_name': 'Vickery', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.391, 'longitude': -82.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43469', 'place_name': 'Woodville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Sandusky', 'locality_code': '143', 'latitude': 41.4512, 'longitude': -83.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45629', 'place_name': 'Franklin Furnace', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.6282, 'longitude': -82.8145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45630', 'place_name': 'Friendship', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.6991, 'longitude': -83.0916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45636', 'place_name': 'Haverhill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.5848, 'longitude': -82.8321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45648', 'place_name': 'Lucasville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.8938, 'longitude': -82.994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45652', 'place_name': 'Mc Dermott', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.8362, 'longitude': -83.0689, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '45653', 'place_name': 'Minford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.8751, 'longitude': -82.8555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45657', 'place_name': 'Otway', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.852, 'longitude': -83.2222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45662', 'place_name': 'Portsmouth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.7932, 'longitude': -82.9306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45663', 'place_name': 'West Portsmouth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.7495, 'longitude': -83.1335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45671', 'place_name': 'Rarden', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.9577, 'longitude': -83.2365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45677', 'place_name': 'Scioto Furnace', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.7941, 'longitude': -82.7555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45682', 'place_name': 'South Webster', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.82, 'longitude': -82.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45684', 'place_name': 'Stout', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.6546, 'longitude': -83.209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45694', 'place_name': 'Wheelersburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.7418, 'longitude': -82.8204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45699', 'place_name': 'Lucasville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Scioto', 'locality_code': '145', 'latitude': 38.8795, 'longitude': -82.9968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44802', 'place_name': 'Alvada', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.0463, 'longitude': -83.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44807', 'place_name': 'Attica', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.0773, 'longitude': -82.9032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44809', 'place_name': 'Bascom', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.1328, 'longitude': -83.2854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44815', 'place_name': 'Bettsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.2469, 'longitude': -83.2398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44818', 'place_name': 'Bloomville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.0182, 'longitude': -82.9899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44828', 'place_name': 'Flat Rock', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.2371, 'longitude': -82.8597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44830', 'place_name': 'Fostoria', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.1623, 'longitude': -83.4139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44836', 'place_name': 'Green Springs', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.2281, 'longitude': -83.0885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44841', 'place_name': 'Kansas', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.2512, 'longitude': -83.306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44845', 'place_name': 'Melmore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.0242, 'longitude': -83.1098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44853', 'place_name': 'New Riegel', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.0514, 'longitude': -83.3185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44861', 'place_name': 'Old Fort', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.2395, 'longitude': -83.1479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44867', 'place_name': 'Republic', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.1259, 'longitude': -83.0194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44883', 'place_name': 'Tiffin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Seneca', 'locality_code': '147', 'latitude': 41.1238, 'longitude': -83.1844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45302', 'place_name': 'Anna', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.4051, 'longitude': -84.2103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45306', 'place_name': 'Botkins', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.4659, 'longitude': -84.178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45333', 'place_name': 'Houston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.2535, 'longitude': -84.3521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45334', 'place_name': 'Jackson Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.4358, 'longitude': -84.0457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45336', 'place_name': 'Kettlersville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.4413, 'longitude': -84.2626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45340', 'place_name': 'Maplewood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.3643, 'longitude': -84.0565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45353', 'place_name': 'Pemberton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.2952, 'longitude': -84.0323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45360', 'place_name': 'Port Jefferson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.3307, 'longitude': -84.0926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45363', 'place_name': 'Russia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.2341, 'longitude': -84.4123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45365', 'place_name': 'Sidney', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.2874, 'longitude': -84.1622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45367', 'place_name': 'Sidney', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.2842, 'longitude': -84.1555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45845', 'place_name': 'Fort Loramie', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Shelby', 'locality_code': '149', 'latitude': 40.3306, 'longitude': -84.3741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44601', 'place_name': 'Alliance', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.9158, 'longitude': -81.1182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44608', 'place_name': 'Beach City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.6562, 'longitude': -81.5851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44613', 'place_name': 'Brewster', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7142, 'longitude': -81.5957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44614', 'place_name': 'Canal Fulton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8887, 'longitude': -81.5773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44626', 'place_name': 'East Sparta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.6971, 'longitude': -81.3687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44630', 'place_name': 'Greentown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.9295, 'longitude': -81.4001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44632', 'place_name': 'Hartville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.9618, 'longitude': -81.3239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44640', 'place_name': 'Limaville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.9836, 'longitude': -81.1497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44641', 'place_name': 'Louisville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8477, 'longitude': -81.2595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44643', 'place_name': 'Magnolia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.6514, 'longitude': -81.3076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44646', 'place_name': 'Massillon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8116, 'longitude': -81.4973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44647', 'place_name': 'Massillon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7959, 'longitude': -81.5533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44648', 'place_name': 'Massillon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8118, 'longitude': -81.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44650', 'place_name': 'Maximo', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8746, 'longitude': -81.1739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44652', 'place_name': 'Middlebranch', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8951, 'longitude': -81.3262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44657', 'place_name': 'Minerva', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.742, 'longitude': -81.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44662', 'place_name': 'Navarre', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7204, 'longitude': -81.5338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44666', 'place_name': 'North Lawrence', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8387, 'longitude': -81.6299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44669', 'place_name': 'Paris', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8014, 'longitude': -81.154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44670', 'place_name': 'Robertsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7647, 'longitude': -81.1879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44688', 'place_name': 'Waynesburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.6829, 'longitude': -81.2659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44689', 'place_name': 'Wilmot', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.6567, 'longitude': -81.6352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44701', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7824, 'longitude': -81.3712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44702', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8027, 'longitude': -81.3739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44703', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8098, 'longitude': -81.3814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44704', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7991, 'longitude': -81.3537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44705', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8259, 'longitude': -81.3399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44706', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.768, 'longitude': -81.4119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44707', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7598, 'longitude': -81.35, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44708', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.812, 'longitude': -81.4241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44709', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8423, 'longitude': -81.3862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44710', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7911, 'longitude': -81.4169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44711', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8118, 'longitude': -81.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44714', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8272, 'longitude': -81.361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44718', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8465, 'longitude': -81.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44720', 'place_name': 'North Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7989, 'longitude': -81.3784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44721', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8834, 'longitude': -81.3328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44730', 'place_name': 'East Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7873, 'longitude': -81.2826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44735', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8118, 'longitude': -81.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44750', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.7846, 'longitude': -81.4189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44767', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8957, 'longitude': -81.4246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44799', 'place_name': 'Canton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Stark', 'locality_code': '151', 'latitude': 40.8118, 'longitude': -81.3683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44056', 'place_name': 'Macedonia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.3222, 'longitude': -81.4996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44067', 'place_name': 'Northfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.3208, 'longitude': -81.5429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44087', 'place_name': 'Twinsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.3289, 'longitude': -81.4559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44203', 'place_name': 'Barberton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0197, 'longitude': -81.6212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44210', 'place_name': 'Bath', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1889, 'longitude': -81.6362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44216', 'place_name': 'Clinton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 40.9391, 'longitude': -81.5871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44221', 'place_name': 'Cuyahoga Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1401, 'longitude': -81.479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44222', 'place_name': 'Cuyahoga Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1339, 'longitude': -81.4846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44223', 'place_name': 'Cuyahoga Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1464, 'longitude': -81.5107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44224', 'place_name': 'Stow', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1748, 'longitude': -81.438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44232', 'place_name': 'Green', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 40.9325, 'longitude': -81.462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44236', 'place_name': 'Hudson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.2458, 'longitude': -81.4367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44237', 'place_name': 'Hudson', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1287, 'longitude': -81.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44250', 'place_name': 'Lakemore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0222, 'longitude': -81.4279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44260', 'place_name': 'Mogadore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0382, 'longitude': -81.359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44262', 'place_name': 'Munroe Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.142, 'longitude': -81.4376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44264', 'place_name': 'Peninsula', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.2256, 'longitude': -81.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44278', 'place_name': 'Tallmadge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0975, 'longitude': -81.426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44286', 'place_name': 'Richfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.2371, 'longitude': -81.6467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44301', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0449, 'longitude': -81.52, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44302', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.092, 'longitude': -81.542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44303', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1025, 'longitude': -81.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44304', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0814, 'longitude': -81.519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44305', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.076, 'longitude': -81.4644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44306', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0479, 'longitude': -81.4916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44307', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0695, 'longitude': -81.5488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44308', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0796, 'longitude': -81.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44309', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0962, 'longitude': -81.5123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44310', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1075, 'longitude': -81.5006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44311', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0638, 'longitude': -81.52, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44312', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0334, 'longitude': -81.4385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44313', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.122, 'longitude': -81.5685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44314', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0408, 'longitude': -81.5598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44315', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.028, 'longitude': -81.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44316', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0675, 'longitude': -81.4847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44317', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0525, 'longitude': -81.5291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44319', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 40.9791, 'longitude': -81.5347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44320', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0835, 'longitude': -81.5674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44321', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1002, 'longitude': -81.6443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44325', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0764, 'longitude': -81.5103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44326', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.0814, 'longitude': -81.519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44328', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.076, 'longitude': -81.5206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44333', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1552, 'longitude': -81.6314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44334', 'place_name': 'Fairlawn', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1278, 'longitude': -81.6098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44372', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1287, 'longitude': -81.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44396', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1287, 'longitude': -81.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44398', 'place_name': 'Akron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 41.1287, 'longitude': -81.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44685', 'place_name': 'Uniontown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Summit', 'locality_code': '153', 'latitude': 40.9637, 'longitude': -81.4211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44402', 'place_name': 'Bristolville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3797, 'longitude': -80.8568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44403', 'place_name': 'Brookfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.248, 'longitude': -80.5788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44404', 'place_name': 'Burghill', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3347, 'longitude': -80.5441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44410', 'place_name': 'Cortland', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3251, 'longitude': -80.7327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44417', 'place_name': 'Farmdale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3923, 'longitude': -80.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44418', 'place_name': 'Fowler', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3349, 'longitude': -80.6059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44420', 'place_name': 'Girard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.1611, 'longitude': -80.6933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44424', 'place_name': 'Hartford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3091, 'longitude': -80.5847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44425', 'place_name': 'Hubbard', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.1624, 'longitude': -80.5762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44428', 'place_name': 'Kinsman', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.4354, 'longitude': -80.5765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44430', 'place_name': 'Leavittsburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.2445, 'longitude': -80.8869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44437', 'place_name': 'Mc Donald', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.158, 'longitude': -80.7312, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '44438', 'place_name': 'Masury', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.2255, 'longitude': -80.5326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44439', 'place_name': 'Mesopotamia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.4584, 'longitude': -80.9551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44440', 'place_name': 'Mineral Ridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.1318, 'longitude': -80.7553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44444', 'place_name': 'Newton Falls', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.191, 'longitude': -80.9701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44446', 'place_name': 'Niles', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.1824, 'longitude': -80.7558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44450', 'place_name': 'North Bloomfield', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.4569, 'longitude': -80.8068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44453', 'place_name': 'Orangeville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3252, 'longitude': -80.5336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44470', 'place_name': 'Southington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.2983, 'longitude': -80.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44473', 'place_name': 'Vienna', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.2175, 'longitude': -80.655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44481', 'place_name': 'Warren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.1724, 'longitude': -80.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44482', 'place_name': 'Warren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3174, 'longitude': -80.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44483', 'place_name': 'Warren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.2639, 'longitude': -80.8164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44484', 'place_name': 'Warren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.2318, 'longitude': -80.7642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44485', 'place_name': 'Warren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.2405, 'longitude': -80.8441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44486', 'place_name': 'Warren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3174, 'longitude': -80.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44491', 'place_name': 'West Farmington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Trumbull', 'locality_code': '155', 'latitude': 41.3508, 'longitude': -80.9672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43804', 'place_name': 'Baltic', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.4476, 'longitude': -81.6792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43832', 'place_name': 'Newcomerstown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.2739, 'longitude': -81.594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43837', 'place_name': 'Port Washington', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.3404, 'longitude': -81.5215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43840', 'place_name': 'Stone Creek', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.4052, 'longitude': -81.589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44612', 'place_name': 'Bolivar', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.6347, 'longitude': -81.4464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44621', 'place_name': 'Dennison', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.4089, 'longitude': -81.3203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44622', 'place_name': 'Dover', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.5343, 'longitude': -81.4763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44624', 'place_name': 'Dundee', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.589, 'longitude': -81.6058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44629', 'place_name': 'Gnadenhutten', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.3584, 'longitude': -81.4343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44653', 'place_name': 'Midvale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.438, 'longitude': -81.3729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44656', 'place_name': 'Mineral City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.5705, 'longitude': -81.3436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44663', 'place_name': 'New Philadelphia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.4845, 'longitude': -81.4358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44671', 'place_name': 'Sandyville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.6442, 'longitude': -81.3653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44678', 'place_name': 'Somerdale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.5649, 'longitude': -81.3524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44679', 'place_name': 'Stillwater', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.3234, 'longitude': -81.3084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44680', 'place_name': 'Strasburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.6003, 'longitude': -81.5366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44681', 'place_name': 'Sugarcreek', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.5148, 'longitude': -81.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44682', 'place_name': 'Tuscarawas', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.3959, 'longitude': -81.4069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44683', 'place_name': 'Uhrichsville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.3905, 'longitude': -81.3374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44697', 'place_name': 'Zoar', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Tuscarawas', 'locality_code': '157', 'latitude': 40.6142, 'longitude': -81.4223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43007', 'place_name': 'Broadway', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.3406, 'longitude': -83.4163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43029', 'place_name': 'Irwin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.1284, 'longitude': -83.4587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43036', 'place_name': 'Magnetic Springs', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.3528, 'longitude': -83.2634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43040', 'place_name': 'Marysville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.2477, 'longitude': -83.3622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43041', 'place_name': 'Marysville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.2364, 'longitude': -83.3671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43045', 'place_name': 'Milford Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.1817, 'longitude': -83.4373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43067', 'place_name': 'Raymond', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.338, 'longitude': -83.4655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43077', 'place_name': 'Unionville Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.1367, 'longitude': -83.3408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43344', 'place_name': 'Richwood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Union', 'locality_code': '159', 'latitude': 40.437, 'longitude': -83.3136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45832', 'place_name': 'Convoy', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.927, 'longitude': -84.7238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45838', 'place_name': 'Elgin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.7425, 'longitude': -84.4758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45863', 'place_name': 'Middle Point', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.8993, 'longitude': -84.4541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45874', 'place_name': 'Ohio City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.7854, 'longitude': -84.6731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45886', 'place_name': 'Scott', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.9892, 'longitude': -84.5845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45891', 'place_name': 'Van Wert', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.8689, 'longitude': -84.5904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45894', 'place_name': 'Venedocia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.7685, 'longitude': -84.462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45898', 'place_name': 'Willshire', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.7346, 'longitude': -84.7777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45899', 'place_name': 'Wren', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Van Wert', 'locality_code': '161', 'latitude': 40.8009, 'longitude': -84.7752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45622', 'place_name': 'Creola', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Vinton', 'locality_code': '163', 'latitude': 39.3543, 'longitude': -82.503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45634', 'place_name': 'Hamden', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Vinton', 'locality_code': '163', 'latitude': 39.1685, 'longitude': -82.51, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45651', 'place_name': 'Mc Arthur', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Vinton', 'locality_code': '163', 'latitude': 39.28, 'longitude': -82.4753, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '45654', 'place_name': 'New Plymouth', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Vinton', 'locality_code': '163', 'latitude': 39.3884, 'longitude': -82.3892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45672', 'place_name': 'Ray', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Vinton', 'locality_code': '163', 'latitude': 39.2077, 'longitude': -82.6908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45695', 'place_name': 'Wilkesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Vinton', 'locality_code': '163', 'latitude': 39.1416, 'longitude': -82.3682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45698', 'place_name': 'Zaleski', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Vinton', 'locality_code': '163', 'latitude': 39.283, 'longitude': -82.3977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45005', 'place_name': 'Franklin', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.5357, 'longitude': -84.303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45032', 'place_name': 'Harveysburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.5013, 'longitude': -84.0067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45034', 'place_name': 'Kings Mills', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.358, 'longitude': -84.2473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45036', 'place_name': 'Lebanon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.4293, 'longitude': -84.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45039', 'place_name': 'Maineville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.317, 'longitude': -84.2438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45040', 'place_name': 'Mason', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.3357, 'longitude': -84.3149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45054', 'place_name': 'Oregonia', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.4145, 'longitude': -84.0511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45065', 'place_name': 'South Lebanon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.3715, 'longitude': -84.2108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45066', 'place_name': 'Springboro', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.563, 'longitude': -84.2288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45068', 'place_name': 'Waynesville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.5285, 'longitude': -84.0815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45152', 'place_name': 'Morrow', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.3476, 'longitude': -84.1181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45162', 'place_name': 'Pleasant Plain', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Warren', 'locality_code': '165', 'latitude': 39.2884, 'longitude': -84.0967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45712', 'place_name': 'Barlow', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.3987, 'longitude': -81.6649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45713', 'place_name': 'Bartlett', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.4195, 'longitude': -81.8157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45714', 'place_name': 'Belpre', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.2868, 'longitude': -81.5968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45715', 'place_name': 'Beverly', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5714, 'longitude': -81.6346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45721', 'place_name': 'Coal Run', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5676, 'longitude': -81.5812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45724', 'place_name': 'Cutler', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.4042, 'longitude': -81.7657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45729', 'place_name': 'Fleming', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.4136, 'longitude': -81.6078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45742', 'place_name': 'Little Hocking', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.28, 'longitude': -81.7071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45744', 'place_name': 'Lowell', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5385, 'longitude': -81.5197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45745', 'place_name': 'Lower Salem', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5611, 'longitude': -81.3968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45746', 'place_name': 'Macksburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.6204, 'longitude': -81.4471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45750', 'place_name': 'Marietta', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.4281, 'longitude': -81.4644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45767', 'place_name': 'New Matamoras', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5288, 'longitude': -81.094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45768', 'place_name': 'Newport', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.3971, 'longitude': -81.2402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45773', 'place_name': 'Reno', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.4585, 'longitude': -81.2673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45784', 'place_name': 'Vincent', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.3374, 'longitude': -81.6743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45786', 'place_name': 'Waterford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5159, 'longitude': -81.6559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45787', 'place_name': 'Watertown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.4659, 'longitude': -81.6332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45788', 'place_name': 'Whipple', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5136, 'longitude': -81.3668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45789', 'place_name': 'Wingett Run', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Washington', 'locality_code': '167', 'latitude': 39.5428, 'longitude': -81.284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44214', 'place_name': 'Burbank', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.9637, 'longitude': -81.9958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44217', 'place_name': 'Creston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.9788, 'longitude': -81.9211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44230', 'place_name': 'Doylestown', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.965, 'longitude': -81.6848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44270', 'place_name': 'Rittman', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.9684, 'longitude': -81.7826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44276', 'place_name': 'Sterling', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.9369, 'longitude': -81.8305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44287', 'place_name': 'West Salem', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.9485, 'longitude': -82.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44606', 'place_name': 'Apple Creek', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.7551, 'longitude': -81.8093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44618', 'place_name': 'Dalton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.7793, 'longitude': -81.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44627', 'place_name': 'Fredericksburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.686, 'longitude': -81.8518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44636', 'place_name': 'Kidron', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.7384, 'longitude': -81.7428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44645', 'place_name': 'Marshallville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.9067, 'longitude': -81.7225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44659', 'place_name': 'Mount Eaton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.6949, 'longitude': -81.7026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44667', 'place_name': 'Orrville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.8458, 'longitude': -81.7741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44676', 'place_name': 'Shreve', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.6926, 'longitude': -82.0325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44677', 'place_name': 'Smithville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.8592, 'longitude': -81.8633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44691', 'place_name': 'Wooster', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wayne', 'locality_code': '169', 'latitude': 40.8094, 'longitude': -81.9483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43501', 'place_name': 'Alvordton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.6625, 'longitude': -84.4355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43505', 'place_name': 'Blakeslee', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.5239, 'longitude': -84.7303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43506', 'place_name': 'Bryan', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.4748, 'longitude': -84.5629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43517', 'place_name': 'Edgerton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.4425, 'longitude': -84.7349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43518', 'place_name': 'Edon', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.5842, 'longitude': -84.757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43531', 'place_name': 'Kunkle', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.6367, 'longitude': -84.4952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43543', 'place_name': 'Montpelier', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.5982, 'longitude': -84.6147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43554', 'place_name': 'Pioneer', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.6656, 'longitude': -84.5363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43557', 'place_name': 'Stryker', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.4861, 'longitude': -84.4089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43570', 'place_name': 'West Unity', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Williams', 'locality_code': '171', 'latitude': 41.5756, 'longitude': -84.4421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43402', 'place_name': 'Bowling Green', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.3815, 'longitude': -83.6507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43403', 'place_name': 'Bowling Green', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.377, 'longitude': -83.6371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43406', 'place_name': 'Bradner', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.3298, 'longitude': -83.4456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43413', 'place_name': 'Cygnet', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.2401, 'longitude': -83.6433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43414', 'place_name': 'Dunbridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.4581, 'longitude': -83.6102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43437', 'place_name': 'Jerry City', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.2559, 'longitude': -83.6022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43441', 'place_name': 'Lemoyne', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.4959, 'longitude': -83.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43443', 'place_name': 'Luckey', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.4517, 'longitude': -83.4674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43447', 'place_name': 'Millbury', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.5611, 'longitude': -83.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43450', 'place_name': 'Pemberville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.4023, 'longitude': -83.4736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43451', 'place_name': 'Portage', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.3127, 'longitude': -83.6143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43457', 'place_name': 'Risingsun', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.2706, 'longitude': -83.4326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43460', 'place_name': 'Rossford', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.6049, 'longitude': -83.5638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43462', 'place_name': 'Rudolph', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.2967, 'longitude': -83.6832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43463', 'place_name': 'Stony Ridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.5091, 'longitude': -83.5085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43465', 'place_name': 'Walbridge', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.5861, 'longitude': -83.493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43466', 'place_name': 'Wayne', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.2993, 'longitude': -83.4701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43467', 'place_name': 'West Millgrove', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.2426, 'longitude': -83.4896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43511', 'place_name': 'Custar', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.2953, 'longitude': -83.8349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43522', 'place_name': 'Grand Rapids', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.4379, 'longitude': -83.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43525', 'place_name': 'Haskins', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.4667, 'longitude': -83.7055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43529', 'place_name': 'Hoytville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.1872, 'longitude': -83.7847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43541', 'place_name': 'Milton Center', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.3009, 'longitude': -83.8296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43551', 'place_name': 'Perrysburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.5429, 'longitude': -83.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43552', 'place_name': 'Perrysburg', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.557, 'longitude': -83.6272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43565', 'place_name': 'Tontogany', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.4192, 'longitude': -83.7408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43569', 'place_name': 'Weston', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.3516, 'longitude': -83.7973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43619', 'place_name': 'Northwood', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.608, 'longitude': -83.4806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44817', 'place_name': 'Bloomdale', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.1815, 'longitude': -83.5724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '45872', 'place_name': 'North Baltimore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wood', 'locality_code': '173', 'latitude': 41.1867, 'longitude': -83.6806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43316', 'place_name': 'Carey', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.9486, 'longitude': -83.3836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43323', 'place_name': 'Harpster', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.7475, 'longitude': -83.2343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43330', 'place_name': 'Kirby', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.813, 'longitude': -83.4196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43351', 'place_name': 'Upper Sandusky', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.8249, 'longitude': -83.2977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '43359', 'place_name': 'Wharton', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.8612, 'longitude': -83.463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44844', 'place_name': 'Mc Cutchenville', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.9752, 'longitude': -83.2637, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '44849', 'place_name': 'Nevada', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.8259, 'longitude': -83.1266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '44882', 'place_name': 'Sycamore', 'state': 'Ohio', 'state_ab': 'OH', 'county': 'Wyandot', 'locality_code': '175', 'latitude': 40.9413, 'longitude': -83.1492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74457', 'place_name': 'Proctor', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Adair', 'locality_code': '1', 'latitude': 36.0308, 'longitude': -94.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74931', 'place_name': 'Bunch', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Adair', 'locality_code': '1', 'latitude': 35.6826, 'longitude': -94.7611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74960', 'place_name': 'Stilwell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Adair', 'locality_code': '1', 'latitude': 35.8107, 'longitude': -94.6313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74964', 'place_name': 'Watts', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Adair', 'locality_code': '1', 'latitude': 36.1152, 'longitude': -94.6345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74965', 'place_name': 'Westville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Adair', 'locality_code': '1', 'latitude': 35.9912, 'longitude': -94.5926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73716', 'place_name': 'Aline', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.5056, 'longitude': -98.4574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73719', 'place_name': 'Amorita', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.9412, 'longitude': -98.2458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73722', 'place_name': 'Burlington', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.9036, 'longitude': -98.4215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73726', 'place_name': 'Carmen', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.5842, 'longitude': -98.4578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73728', 'place_name': 'Cherokee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.7564, 'longitude': -98.3594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73739', 'place_name': 'Goltry', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.5314, 'longitude': -98.154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73741', 'place_name': 'Helena', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.5438, 'longitude': -98.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73749', 'place_name': 'Jet', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Alfalfa', 'locality_code': '3', 'latitude': 36.6929, 'longitude': -98.1721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74525', 'place_name': 'Atoka', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Atoka', 'locality_code': '5', 'latitude': 34.3445, 'longitude': -96.1418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74533', 'place_name': 'Caney', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Atoka', 'locality_code': '5', 'latitude': 34.2221, 'longitude': -96.2584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74540', 'place_name': 'Daisy', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Atoka', 'locality_code': '5', 'latitude': 34.5384, 'longitude': -95.7088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74555', 'place_name': 'Lane', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Atoka', 'locality_code': '5', 'latitude': 34.2691, 'longitude': -95.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74569', 'place_name': 'Stringtown', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Atoka', 'locality_code': '5', 'latitude': 34.4676, 'longitude': -96.0002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73844', 'place_name': 'Gate', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beaver', 'locality_code': '7', 'latitude': 36.8757, 'longitude': -100.0734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73931', 'place_name': 'Balko', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beaver', 'locality_code': '7', 'latitude': 36.5996, 'longitude': -100.7103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73932', 'place_name': 'Beaver', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beaver', 'locality_code': '7', 'latitude': 36.8341, 'longitude': -100.5177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73938', 'place_name': 'Forgan', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beaver', 'locality_code': '7', 'latitude': 36.9086, 'longitude': -100.5409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73950', 'place_name': 'Turpin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beaver', 'locality_code': '7', 'latitude': 36.8664, 'longitude': -100.8779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73627', 'place_name': 'Carter', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beckham', 'locality_code': '9', 'latitude': 35.2208, 'longitude': -99.4822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73644', 'place_name': 'Elk City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beckham', 'locality_code': '9', 'latitude': 35.4104, 'longitude': -99.4211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73645', 'place_name': 'Erick', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beckham', 'locality_code': '9', 'latitude': 35.2286, 'longitude': -99.8635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73648', 'place_name': 'Elk City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beckham', 'locality_code': '9', 'latitude': 35.412, 'longitude': -99.4043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73662', 'place_name': 'Sayre', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beckham', 'locality_code': '9', 'latitude': 35.3047, 'longitude': -99.6429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73668', 'place_name': 'Texola', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Beckham', 'locality_code': '9', 'latitude': 35.2161, 'longitude': -99.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73040', 'place_name': 'Geary', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 35.6217, 'longitude': -98.3905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73043', 'place_name': 'Greenfield', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 35.7333, 'longitude': -98.3841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73724', 'place_name': 'Canton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 36.0372, 'longitude': -98.5778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73744', 'place_name': 'Hitchcock', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 35.9712, 'longitude': -98.3315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73755', 'place_name': 'Longdale', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 36.1212, 'longitude': -98.55, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73763', 'place_name': 'Okeene', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 36.1165, 'longitude': -98.3254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73770', 'place_name': 'Southard', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 36.0581, 'longitude': -98.5884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73772', 'place_name': 'Watonga', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Blaine', 'locality_code': '11', 'latitude': 35.8538, 'longitude': -98.4175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73449', 'place_name': 'Mead', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.9944, 'longitude': -96.5299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74701', 'place_name': 'Durant', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 34.0061, 'longitude': -96.3847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74702', 'place_name': 'Durant', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.922, 'longitude': -96.1918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74720', 'place_name': 'Achille', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.8396, 'longitude': -96.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74721', 'place_name': 'Albany', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.8815, 'longitude': -96.1628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74723', 'place_name': 'Bennington', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.9771, 'longitude': -96.0188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74726', 'place_name': 'Bokchito', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.9859, 'longitude': -96.1621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74729', 'place_name': 'Caddo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 34.1157, 'longitude': -96.26, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74730', 'place_name': 'Calera', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.9322, 'longitude': -96.4308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74731', 'place_name': 'Cartwright', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.8668, 'longitude': -96.5672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74733', 'place_name': 'Colbert', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.8575, 'longitude': -96.4953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74741', 'place_name': 'Hendrix', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.8016, 'longitude': -96.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74747', 'place_name': 'Kemp', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.773, 'longitude': -96.3555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74748', 'place_name': 'Kenefic', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 34.1481, 'longitude': -96.3622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74753', 'place_name': 'Platter', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Bryan', 'locality_code': '13', 'latitude': 33.907, 'longitude': -96.535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73001', 'place_name': 'Albert', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.2032, 'longitude': -98.3574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73005', 'place_name': 'Anadarko', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.0728, 'longitude': -98.2429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73006', 'place_name': 'Apache', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 34.9034, 'longitude': -98.3695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73009', 'place_name': 'Binger', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.3106, 'longitude': -98.3148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73015', 'place_name': 'Carnegie', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.1235, 'longitude': -98.5755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73017', 'place_name': 'Cement', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 34.9321, 'longitude': -98.1466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73029', 'place_name': 'Cyril', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 34.8959, 'longitude': -98.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73033', 'place_name': 'Eakly', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.3053, 'longitude': -98.5578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73038', 'place_name': 'Fort Cobb', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.1161, 'longitude': -98.4303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73042', 'place_name': 'Gracemont', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.1875, 'longitude': -98.2835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73047', 'place_name': 'Hinton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.4675, 'longitude': -98.3313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73048', 'place_name': 'Hydro', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.452, 'longitude': -98.5604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73053', 'place_name': 'Lookeba', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Caddo', 'locality_code': '15', 'latitude': 35.3679, 'longitude': -98.3898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73014', 'place_name': 'Calumet', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.5476, 'longitude': -98.1512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73022', 'place_name': 'Concho', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.6193, 'longitude': -97.9796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73036', 'place_name': 'El Reno', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.5335, 'longitude': -97.9591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73064', 'place_name': 'Mustang', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.3885, 'longitude': -97.7309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73078', 'place_name': 'Piedmont', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.6695, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73085', 'place_name': 'Yukon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.4895, 'longitude': -97.75, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73090', 'place_name': 'Union City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.3913, 'longitude': -97.9398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73099', 'place_name': 'Yukon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Canadian', 'locality_code': '17', 'latitude': 35.4977, 'longitude': -97.7323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73401', 'place_name': 'Ardmore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.1566, 'longitude': -97.1792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73402', 'place_name': 'Ardmore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.2889, 'longitude': -97.2481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73403', 'place_name': 'Ardmore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.1743, 'longitude': -97.1436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73435', 'place_name': 'Fox', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.3488, 'longitude': -97.4924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73436', 'place_name': 'Gene Autry', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.2939, 'longitude': -97.0339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73437', 'place_name': 'Graham', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.3762, 'longitude': -97.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73438', 'place_name': 'Healdton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.229, 'longitude': -97.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73443', 'place_name': 'Lone Grove', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.1774, 'longitude': -97.2685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73458', 'place_name': 'Springer', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.3038, 'longitude': -97.1223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73463', 'place_name': 'Wilson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.1364, 'longitude': -97.4273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73481', 'place_name': 'Ratliff City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.449, 'longitude': -97.5095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73487', 'place_name': 'Tatums', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.4777, 'longitude': -97.457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73488', 'place_name': 'Tussy', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Carter', 'locality_code': '19', 'latitude': 34.4852, 'longitude': -97.5423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74427', 'place_name': 'Cookson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.7116, 'longitude': -94.9132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74441', 'place_name': 'Hulbert', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.9254, 'longitude': -95.1651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74444', 'place_name': 'Moodys', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 36.0458, 'longitude': -94.9669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74451', 'place_name': 'Park Hill', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.7977, 'longitude': -94.9822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74452', 'place_name': 'Peggs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 36.1154, 'longitude': -95.1199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74464', 'place_name': 'Tahlequah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.9094, 'longitude': -94.9787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74465', 'place_name': 'Tahlequah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.9001, 'longitude': -95.04, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74471', 'place_name': 'Welling', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.8819, 'longitude': -94.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74727', 'place_name': 'Boswell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 34.0245, 'longitude': -95.8403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74735', 'place_name': 'Fort Towson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 34.052, 'longitude': -95.253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74738', 'place_name': 'Grant', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 33.9302, 'longitude': -95.4893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74743', 'place_name': 'Hugo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 34.0113, 'longitude': -95.5139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74756', 'place_name': 'Sawyer', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 34.0277, 'longitude': -95.3558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74759', 'place_name': 'Soper', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 34.0366, 'longitude': -95.6916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74760', 'place_name': 'Spencerville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 34.1508, 'longitude': -95.3771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74761', 'place_name': 'Swink', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Choctaw', 'locality_code': '23', 'latitude': 34.0179, 'longitude': -95.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73933', 'place_name': 'Boise City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cimarron', 'locality_code': '25', 'latitude': 36.7283, 'longitude': -102.5355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73937', 'place_name': 'Felt', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cimarron', 'locality_code': '25', 'latitude': 36.5666, 'longitude': -102.7974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73946', 'place_name': 'Kenton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cimarron', 'locality_code': '25', 'latitude': 36.9031, 'longitude': -102.9653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73947', 'place_name': 'Keyes', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cimarron', 'locality_code': '25', 'latitude': 36.8003, 'longitude': -102.2361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73019', 'place_name': 'Norman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.2086, 'longitude': -97.4445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73026', 'place_name': 'Norman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.2343, 'longitude': -97.2914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73051', 'place_name': 'Lexington', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.0377, 'longitude': -97.2609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73068', 'place_name': 'Noble', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.1417, 'longitude': -97.3409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73069', 'place_name': 'Norman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.2204, 'longitude': -97.4577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73070', 'place_name': 'Norman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.1876, 'longitude': -97.3975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73071', 'place_name': 'Norman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.233, 'longitude': -97.4067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73072', 'place_name': 'Norman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.199, 'longitude': -97.4841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73139', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.3792, 'longitude': -97.5362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73160', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.334, 'longitude': -97.4768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73165', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.3267, 'longitude': -97.3534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73170', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.327, 'longitude': -97.5556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73173', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cleveland', 'locality_code': '27', 'latitude': 35.3425, 'longitude': -97.6317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74534', 'place_name': 'Centrahoma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Coal', 'locality_code': '29', 'latitude': 34.6066, 'longitude': -96.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74535', 'place_name': 'Clarita', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Coal', 'locality_code': '29', 'latitude': 34.4829, 'longitude': -96.4333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74538', 'place_name': 'Coalgate', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Coal', 'locality_code': '29', 'latitude': 34.5344, 'longitude': -96.2167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74556', 'place_name': 'Lehigh', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Coal', 'locality_code': '29', 'latitude': 34.4756, 'longitude': -96.1889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74572', 'place_name': 'Tupelo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Coal', 'locality_code': '29', 'latitude': 34.5598, 'longitude': -96.4274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73501', 'place_name': 'Lawton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.5915, 'longitude': -98.3698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73502', 'place_name': 'Lawton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.6087, 'longitude': -98.3903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73503', 'place_name': 'Fort Sill', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.6595, 'longitude': -98.4004, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '73505', 'place_name': 'Lawton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.6179, 'longitude': -98.4552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73506', 'place_name': 'Lawton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.6309, 'longitude': -98.4576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73507', 'place_name': 'Lawton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.6246, 'longitude': -98.3895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73527', 'place_name': 'Cache', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.6131, 'longitude': -98.6154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73528', 'place_name': 'Chattanooga', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.4262, 'longitude': -98.6514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73538', 'place_name': 'Elgin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.772, 'longitude': -98.4073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73540', 'place_name': 'Faxon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.4645, 'longitude': -98.5577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73541', 'place_name': 'Fletcher', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.7847, 'longitude': -98.2002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73543', 'place_name': 'Geronimo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.4805, 'longitude': -98.3875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73552', 'place_name': 'Indiahoma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.6242, 'longitude': -98.7349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73557', 'place_name': 'Medicine Park', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.7292, 'longitude': -98.5026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73558', 'place_name': 'Meers', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.7828, 'longitude': -98.579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73567', 'place_name': 'Sterling', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Comanche', 'locality_code': '31', 'latitude': 34.7496, 'longitude': -98.1679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73531', 'place_name': 'Devol', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cotton', 'locality_code': '33', 'latitude': 34.1956, 'longitude': -98.577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73562', 'place_name': 'Randlett', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cotton', 'locality_code': '33', 'latitude': 34.174, 'longitude': -98.46, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73568', 'place_name': 'Temple', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cotton', 'locality_code': '33', 'latitude': 34.2607, 'longitude': -98.2371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73572', 'place_name': 'Walters', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Cotton', 'locality_code': '33', 'latitude': 34.3605, 'longitude': -98.314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74301', 'place_name': 'Vinita', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Craig', 'locality_code': '35', 'latitude': 36.6334, 'longitude': -95.1382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74332', 'place_name': 'Big Cabin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Craig', 'locality_code': '35', 'latitude': 36.534, 'longitude': -95.2246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74333', 'place_name': 'Bluejacket', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Craig', 'locality_code': '35', 'latitude': 36.7975, 'longitude': -95.1018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74369', 'place_name': 'Welch', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Craig', 'locality_code': '35', 'latitude': 36.902, 'longitude': -95.1295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74010', 'place_name': 'Bristow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.8209, 'longitude': -96.3758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74028', 'place_name': 'Depew', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.7561, 'longitude': -96.4897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74030', 'place_name': 'Drumright', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.9931, 'longitude': -96.5198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74039', 'place_name': 'Kellyville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.9171, 'longitude': -96.218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74041', 'place_name': 'Kiefer', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.9528, 'longitude': -96.061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74044', 'place_name': 'Mannford', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 36.0927, 'longitude': -96.3576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74046', 'place_name': 'Milfay', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.7551, 'longitude': -96.5658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74047', 'place_name': 'Mounds', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.8896, 'longitude': -96.0887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74052', 'place_name': 'Oilton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 36.0685, 'longitude': -96.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74066', 'place_name': 'Sapulpa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 36.003, 'longitude': -96.1106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74067', 'place_name': 'Sapulpa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 36.0196, 'longitude': -96.0937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74068', 'place_name': 'Shamrock', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.9124, 'longitude': -96.578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74071', 'place_name': 'Slick', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 35.7861, 'longitude': -96.2806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74131', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Creek', 'locality_code': '37', 'latitude': 36.0557, 'longitude': -96.0602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73096', 'place_name': 'Weatherford', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Custer', 'locality_code': '39', 'latitude': 35.535, 'longitude': -98.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73601', 'place_name': 'Clinton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Custer', 'locality_code': '39', 'latitude': 35.5115, 'longitude': -98.9795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73620', 'place_name': 'Arapaho', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Custer', 'locality_code': '39', 'latitude': 35.5789, 'longitude': -98.9595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73625', 'place_name': 'Butler', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Custer', 'locality_code': '39', 'latitude': 35.6336, 'longitude': -99.2427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73639', 'place_name': 'Custer City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Custer', 'locality_code': '39', 'latitude': 35.6894, 'longitude': -98.912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73669', 'place_name': 'Thomas', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Custer', 'locality_code': '39', 'latitude': 35.7382, 'longitude': -98.7388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74338', 'place_name': 'Colcord', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.2333, 'longitude': -94.6547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74342', 'place_name': 'Eucha', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.4063, 'longitude': -94.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74344', 'place_name': 'Grove', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.5929, 'longitude': -94.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74345', 'place_name': 'Grove', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.6036, 'longitude': -94.7297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74346', 'place_name': 'Jay', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.4363, 'longitude': -94.7763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74347', 'place_name': 'Kansas', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.2161, 'longitude': -94.8114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74359', 'place_name': 'Oaks', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.1662, 'longitude': -94.8547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74368', 'place_name': 'Twin Oaks', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Delaware', 'locality_code': '41', 'latitude': 36.2054, 'longitude': -94.8513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73646', 'place_name': 'Fay', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 35.8204, 'longitude': -98.6587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73654', 'place_name': 'Leedey', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 35.8698, 'longitude': -99.3491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73658', 'place_name': 'Oakwood', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 35.9328, 'longitude': -98.7065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73659', 'place_name': 'Putnam', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 35.8539, 'longitude': -98.9638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73663', 'place_name': 'Seiling', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 36.1278, 'longitude': -98.8875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73667', 'place_name': 'Taloga', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 35.9972, 'longitude': -98.9825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73835', 'place_name': 'Camargo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 36.0212, 'longitude': -99.2781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73859', 'place_name': 'Vici', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Dewey', 'locality_code': '43', 'latitude': 36.1372, 'longitude': -99.267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73832', 'place_name': 'Arnett', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ellis', 'locality_code': '45', 'latitude': 36.0522, 'longitude': -99.6514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73840', 'place_name': 'Fargo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ellis', 'locality_code': '45', 'latitude': 36.3761, 'longitude': -99.6237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73843', 'place_name': 'Gage', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ellis', 'locality_code': '45', 'latitude': 36.318, 'longitude': -99.76, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73858', 'place_name': 'Shattuck', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ellis', 'locality_code': '45', 'latitude': 36.2889, 'longitude': -99.8793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73701', 'place_name': 'Enid', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.4028, 'longitude': -97.8623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73702', 'place_name': 'Enid', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.3956, 'longitude': -97.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73703', 'place_name': 'Enid', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.3975, 'longitude': -97.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73705', 'place_name': 'Enid', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.3382, 'longitude': -97.9026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73706', 'place_name': 'Enid', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.3791, 'longitude': -97.7826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73720', 'place_name': 'Bison', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.1962, 'longitude': -97.8805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73727', 'place_name': 'Carrier', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.4922, 'longitude': -98.0422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73730', 'place_name': 'Covington', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.3099, 'longitude': -97.5752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73733', 'place_name': 'Douglas', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.2481, 'longitude': -97.6896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73735', 'place_name': 'Drummond', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.2841, 'longitude': -98.0358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73736', 'place_name': 'Fairmont', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.34, 'longitude': -97.6848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73738', 'place_name': 'Garber', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.4392, 'longitude': -97.5789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73743', 'place_name': 'Hillsdale', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.5631, 'longitude': -97.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73753', 'place_name': 'Kremlin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.5207, 'longitude': -97.8542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73754', 'place_name': 'Lahoma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.385, 'longitude': -98.0727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73773', 'place_name': 'Waukomis', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.2781, 'longitude': -97.8996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74640', 'place_name': 'Hunter', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garfield', 'locality_code': '47', 'latitude': 36.5603, 'longitude': -97.6425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73052', 'place_name': 'Lindsay', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.8211, 'longitude': -97.5998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73057', 'place_name': 'Maysville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.8113, 'longitude': -97.4131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73074', 'place_name': 'Paoli', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.8285, 'longitude': -97.2608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73075', 'place_name': 'Pauls Valley', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.7385, 'longitude': -97.2195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73098', 'place_name': 'Wynnewood', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.6385, 'longitude': -97.177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73433', 'place_name': 'Elmore City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.6265, 'longitude': -97.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73444', 'place_name': 'Hennepin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.4719, 'longitude': -97.3879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74872', 'place_name': 'Stratford', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Garvin', 'locality_code': '49', 'latitude': 34.7714, 'longitude': -96.9763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73002', 'place_name': 'Alex', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 34.9612, 'longitude': -97.7571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73004', 'place_name': 'Amber', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 35.1526, 'longitude': -97.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73011', 'place_name': 'Bradley', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 34.8741, 'longitude': -97.7118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73018', 'place_name': 'Chickasha', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 35.0268, 'longitude': -97.9518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73023', 'place_name': 'Chickasha', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 35.0526, 'longitude': -97.9364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73059', 'place_name': 'Minco', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 35.3067, 'longitude': -97.9664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73067', 'place_name': 'Ninnekah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 34.9143, 'longitude': -97.9333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73079', 'place_name': 'Pocasset', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 35.1544, 'longitude': -97.979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73082', 'place_name': 'Rush Springs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 34.7708, 'longitude': -97.9431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73089', 'place_name': 'Tuttle', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 35.2674, 'longitude': -97.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73092', 'place_name': 'Verden', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grady', 'locality_code': '51', 'latitude': 35.0836, 'longitude': -98.0792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73758', 'place_name': 'Manchester', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grant', 'locality_code': '53', 'latitude': 36.9744, 'longitude': -98.0383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73759', 'place_name': 'Medford', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grant', 'locality_code': '53', 'latitude': 36.8142, 'longitude': -97.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73761', 'place_name': 'Nash', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grant', 'locality_code': '53', 'latitude': 36.6961, 'longitude': -98.0258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73766', 'place_name': 'Pond Creek', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grant', 'locality_code': '53', 'latitude': 36.6643, 'longitude': -97.8019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73771', 'place_name': 'Wakita', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grant', 'locality_code': '53', 'latitude': 36.8753, 'longitude': -97.9427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74636', 'place_name': 'Deer Creek', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grant', 'locality_code': '53', 'latitude': 36.8048, 'longitude': -97.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74643', 'place_name': 'Lamont', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Grant', 'locality_code': '53', 'latitude': 36.6939, 'longitude': -97.5601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73547', 'place_name': 'Granite', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Greer', 'locality_code': '55', 'latitude': 34.9712, 'longitude': -99.3881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73554', 'place_name': 'Mangum', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Greer', 'locality_code': '55', 'latitude': 34.9126, 'longitude': -99.4606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73673', 'place_name': 'Willow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Greer', 'locality_code': '55', 'latitude': 35.0702, 'longitude': -99.5421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73544', 'place_name': 'Gould', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Harmon', 'locality_code': '57', 'latitude': 34.665, 'longitude': -99.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73550', 'place_name': 'Hollis', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Harmon', 'locality_code': '57', 'latitude': 34.6953, 'longitude': -99.9177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73571', 'place_name': 'Vinson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Harmon', 'locality_code': '57', 'latitude': 34.9006, 'longitude': -99.8598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73834', 'place_name': 'Buffalo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Harper', 'locality_code': '59', 'latitude': 36.8523, 'longitude': -99.5538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73848', 'place_name': 'Laverne', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Harper', 'locality_code': '59', 'latitude': 36.7062, 'longitude': -99.8918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73851', 'place_name': 'May', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Harper', 'locality_code': '59', 'latitude': 36.6226, 'longitude': -99.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73855', 'place_name': 'Rosston', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Harper', 'locality_code': '59', 'latitude': 36.8789, 'longitude': -99.9003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74440', 'place_name': 'Hoyt', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Haskell', 'locality_code': '61', 'latitude': 35.2685, 'longitude': -95.2994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74462', 'place_name': 'Stigler', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Haskell', 'locality_code': '61', 'latitude': 35.2686, 'longitude': -95.1071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74472', 'place_name': 'Whitefield', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Haskell', 'locality_code': '61', 'latitude': 35.2646, 'longitude': -95.2645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74552', 'place_name': 'Kinta', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Haskell', 'locality_code': '61', 'latitude': 35.1193, 'longitude': -95.2377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74941', 'place_name': 'Keota', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Haskell', 'locality_code': '61', 'latitude': 35.2645, 'longitude': -94.9028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74943', 'place_name': 'Lequire', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Haskell', 'locality_code': '61', 'latitude': 35.0867, 'longitude': -95.0974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74944', 'place_name': 'Mccurtain', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Haskell', 'locality_code': '61', 'latitude': 35.1404, 'longitude': -95.0127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74531', 'place_name': 'Calvin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Hughes', 'locality_code': '63', 'latitude': 34.878, 'longitude': -96.271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74570', 'place_name': 'Stuart', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Hughes', 'locality_code': '63', 'latitude': 34.8826, 'longitude': -96.1381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74827', 'place_name': 'Atwood', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Hughes', 'locality_code': '63', 'latitude': 34.9562, 'longitude': -96.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74839', 'place_name': 'Dustin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Hughes', 'locality_code': '63', 'latitude': 35.2519, 'longitude': -96.0573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74848', 'place_name': 'Holdenville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Hughes', 'locality_code': '63', 'latitude': 35.0839, 'longitude': -96.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74850', 'place_name': 'Lamar', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Hughes', 'locality_code': '63', 'latitude': 35.0836, 'longitude': -96.1142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74883', 'place_name': 'Wetumka', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Hughes', 'locality_code': '63', 'latitude': 35.2396, 'longitude': -96.2421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73521', 'place_name': 'Altus', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.6484, 'longitude': -99.3205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73522', 'place_name': 'Altus', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.6381, 'longitude': -99.334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73523', 'place_name': 'Altus Afb', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.5982, 'longitude': -99.4408, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '73526', 'place_name': 'Blair', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.7788, 'longitude': -99.3334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73532', 'place_name': 'Duke', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.6668, 'longitude': -99.5482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73537', 'place_name': 'Eldorado', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.4727, 'longitude': -99.646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73539', 'place_name': 'Elmer', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.5137, 'longitude': -99.3167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73549', 'place_name': 'Headrick', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.6265, 'longitude': -99.139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73556', 'place_name': 'Martha', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.7253, 'longitude': -99.387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73560', 'place_name': 'Olustee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jackson', 'locality_code': '65', 'latitude': 34.5496, 'longitude': -99.4287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73456', 'place_name': 'Ringling', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jefferson', 'locality_code': '67', 'latitude': 34.1679, 'longitude': -97.6029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73520', 'place_name': 'Addington', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jefferson', 'locality_code': '67', 'latitude': 34.2445, 'longitude': -97.967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73548', 'place_name': 'Hastings', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jefferson', 'locality_code': '67', 'latitude': 34.2251, 'longitude': -98.1075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73561', 'place_name': 'Oscar', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jefferson', 'locality_code': '67', 'latitude': 34.0313, 'longitude': -97.6481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73565', 'place_name': 'Ryan', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jefferson', 'locality_code': '67', 'latitude': 34.0238, 'longitude': -97.9461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73569', 'place_name': 'Terral', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jefferson', 'locality_code': '67', 'latitude': 33.9379, 'longitude': -97.8053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73573', 'place_name': 'Waurika', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Jefferson', 'locality_code': '67', 'latitude': 34.1745, 'longitude': -97.9973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73432', 'place_name': 'Coleman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.2625, 'longitude': -96.4588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73447', 'place_name': 'Mannsville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.1899, 'longitude': -96.8778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73450', 'place_name': 'Milburn', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.1952, 'longitude': -96.5429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73455', 'place_name': 'Ravia', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.244, 'longitude': -96.7529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73460', 'place_name': 'Tishomingo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.2643, 'longitude': -96.6675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73461', 'place_name': 'Wapanucka', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.3866, 'longitude': -96.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74530', 'place_name': 'Bromide', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.4233, 'longitude': -96.4867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74836', 'place_name': 'Connerville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.4194, 'longitude': -96.6291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74856', 'place_name': 'Mill Creek', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Johnston', 'locality_code': '69', 'latitude': 34.3098, 'longitude': -96.7884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74601', 'place_name': 'Ponca City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.7031, 'longitude': -97.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74602', 'place_name': 'Ponca City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.6954, 'longitude': -97.1377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74604', 'place_name': 'Ponca City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.7299, 'longitude': -97.0454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74631', 'place_name': 'Blackwell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.8006, 'longitude': -97.2867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74632', 'place_name': 'Braman', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.9331, 'longitude': -97.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74641', 'place_name': 'Kaw City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.8382, 'longitude': -96.8833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74646', 'place_name': 'Nardin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.8155, 'longitude': -97.4325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74647', 'place_name': 'Newkirk', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.84, 'longitude': -97.0561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74653', 'place_name': 'Tonkawa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kay', 'locality_code': '71', 'latitude': 36.6806, 'longitude': -97.3063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73016', 'place_name': 'Cashion', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kingfisher', 'locality_code': '73', 'latitude': 35.8, 'longitude': -97.6795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73734', 'place_name': 'Dover', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kingfisher', 'locality_code': '73', 'latitude': 35.9848, 'longitude': -97.9067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73742', 'place_name': 'Hennessey', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kingfisher', 'locality_code': '73', 'latitude': 36.0868, 'longitude': -97.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73750', 'place_name': 'Kingfisher', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kingfisher', 'locality_code': '73', 'latitude': 35.8636, 'longitude': -97.9473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73756', 'place_name': 'Loyal', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kingfisher', 'locality_code': '73', 'latitude': 35.9705, 'longitude': -98.1155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73762', 'place_name': 'Okarche', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kingfisher', 'locality_code': '73', 'latitude': 35.7502, 'longitude': -97.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73764', 'place_name': 'Omega', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kingfisher', 'locality_code': '73', 'latitude': 35.8507, 'longitude': -98.1863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73041', 'place_name': 'Gotebo', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kiowa', 'locality_code': '75', 'latitude': 35.0759, 'longitude': -98.876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73062', 'place_name': 'Mountain View', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kiowa', 'locality_code': '75', 'latitude': 35.0654, 'longitude': -98.7307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73559', 'place_name': 'Mountain Park', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kiowa', 'locality_code': '75', 'latitude': 34.7032, 'longitude': -98.9591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73564', 'place_name': 'Roosevelt', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kiowa', 'locality_code': '75', 'latitude': 34.847, 'longitude': -98.9836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73566', 'place_name': 'Snyder', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kiowa', 'locality_code': '75', 'latitude': 34.6548, 'longitude': -98.9508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73651', 'place_name': 'Hobart', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kiowa', 'locality_code': '75', 'latitude': 35.0255, 'longitude': -99.0944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73655', 'place_name': 'Lone Wolf', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Kiowa', 'locality_code': '75', 'latitude': 34.9806, 'longitude': -99.2502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74545', 'place_name': 'Gowen', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Latimer', 'locality_code': '77', 'latitude': 34.8724, 'longitude': -95.469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74559', 'place_name': 'Panola', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Latimer', 'locality_code': '77', 'latitude': 34.9287, 'longitude': -95.2133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74563', 'place_name': 'Red Oak', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Latimer', 'locality_code': '77', 'latitude': 34.9422, 'longitude': -95.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74578', 'place_name': 'Wilburton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Latimer', 'locality_code': '77', 'latitude': 34.9128, 'longitude': -95.3389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74549', 'place_name': 'Honobia', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.5519, 'longitude': -94.9428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74571', 'place_name': 'Talihina', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.7381, 'longitude': -94.9978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74577', 'place_name': 'Whitesboro', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.6926, 'longitude': -94.8852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74901', 'place_name': 'Arkoma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.3434, 'longitude': -94.4403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74902', 'place_name': 'Pocola', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.2436, 'longitude': -94.476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74930', 'place_name': 'Bokoshe', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.1865, 'longitude': -94.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74932', 'place_name': 'Cameron', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.1494, 'longitude': -94.506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74935', 'place_name': 'Fanshawe', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.9537, 'longitude': -94.8998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74937', 'place_name': 'Heavener', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.8353, 'longitude': -94.6185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74939', 'place_name': 'Hodgen', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.7538, 'longitude': -94.6391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74940', 'place_name': 'Howe', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.9512, 'longitude': -94.6372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74942', 'place_name': 'Leflore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.8979, 'longitude': -94.9758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74947', 'place_name': 'Monroe', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.9906, 'longitude': -94.515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74949', 'place_name': 'Muse', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.6641, 'longitude': -94.719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74951', 'place_name': 'Panama', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.1535, 'longitude': -94.6709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74953', 'place_name': 'Poteau', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.0606, 'longitude': -94.6096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74956', 'place_name': 'Shady Point', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.1293, 'longitude': -94.6665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74959', 'place_name': 'Spiro', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 35.2492, 'longitude': -94.6265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74966', 'place_name': 'Wister', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Le Flore', 'locality_code': '79', 'latitude': 34.9556, 'longitude': -94.7832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74026', 'place_name': 'Davenport', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.7089, 'longitude': -96.767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74079', 'place_name': 'Stroud', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.7398, 'longitude': -96.6719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74824', 'place_name': 'Agra', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.909, 'longitude': -96.8738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74832', 'place_name': 'Carney', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.8054, 'longitude': -97.0159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74834', 'place_name': 'Chandler', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.7017, 'longitude': -96.8809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74855', 'place_name': 'Meeker', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.5211, 'longitude': -96.9981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74864', 'place_name': 'Prague', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.5105, 'longitude': -96.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74869', 'place_name': 'Sparks', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.6138, 'longitude': -96.8163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74875', 'place_name': 'Tryon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.8759, 'longitude': -96.9623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74881', 'place_name': 'Wellston', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Lincoln', 'locality_code': '81', 'latitude': 35.6757, 'longitude': -97.0597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73027', 'place_name': 'Coyle', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.8985, 'longitude': -97.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73028', 'place_name': 'Crescent', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.942, 'longitude': -97.5969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73044', 'place_name': 'Guthrie', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.833, 'longitude': -97.436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73050', 'place_name': 'Langston', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.9419, 'longitude': -97.2557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73056', 'place_name': 'Marshall', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 36.1485, 'longitude': -97.6171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73058', 'place_name': 'Meridian', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 35.8451, 'longitude': -97.2462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73063', 'place_name': 'Mulhall', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 36.0537, 'longitude': -97.4098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73073', 'place_name': 'Orlando', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Logan', 'locality_code': '83', 'latitude': 36.142, 'longitude': -97.396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73430', 'place_name': 'Burneyville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Love', 'locality_code': '85', 'latitude': 33.9515, 'longitude': -97.3249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73441', 'place_name': 'Leon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Love', 'locality_code': '85', 'latitude': 33.8793, 'longitude': -97.4292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73448', 'place_name': 'Marietta', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Love', 'locality_code': '85', 'latitude': 33.9431, 'longitude': -97.1148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73453', 'place_name': 'Overbrook', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Love', 'locality_code': '85', 'latitude': 34.0539, 'longitude': -97.1324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73459', 'place_name': 'Thackerville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Love', 'locality_code': '85', 'latitude': 33.7882, 'longitude': -97.1363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73010', 'place_name': 'Blanchard', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McClain', 'locality_code': '87', 'latitude': 35.1192, 'longitude': -97.6401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73031', 'place_name': 'Dibble', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McClain', 'locality_code': '87', 'latitude': 35.009, 'longitude': -97.6318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73065', 'place_name': 'Newcastle', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McClain', 'locality_code': '87', 'latitude': 35.2453, 'longitude': -97.6216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73080', 'place_name': 'Purcell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McClain', 'locality_code': '87', 'latitude': 35.0103, 'longitude': -97.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73093', 'place_name': 'Washington', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McClain', 'locality_code': '87', 'latitude': 35.1324, 'longitude': -97.487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73095', 'place_name': 'Wayne', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McClain', 'locality_code': '87', 'latitude': 34.9154, 'longitude': -97.329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74831', 'place_name': 'Byars', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McClain', 'locality_code': '87', 'latitude': 34.8904, 'longitude': -97.0997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74722', 'place_name': 'Battiest', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.3934, 'longitude': -94.9249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74724', 'place_name': 'Bethel', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.3598, 'longitude': -94.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74728', 'place_name': 'Broken Bow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.027, 'longitude': -94.7623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74734', 'place_name': 'Eagletown', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.0364, 'longitude': -94.5596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74736', 'place_name': 'Garvin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 33.9192, 'longitude': -94.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74737', 'place_name': 'Golden', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.0303, 'longitude': -94.8986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74740', 'place_name': 'Haworth', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 33.785, 'longitude': -94.633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74745', 'place_name': 'Idabel', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 33.8851, 'longitude': -94.802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74750', 'place_name': 'Millerton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 33.9801, 'longitude': -95.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74752', 'place_name': 'Pickens', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.3965, 'longitude': -95.0119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74754', 'place_name': 'Ringold', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.1799, 'longitude': -95.0704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74755', 'place_name': 'Rufe', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.1272, 'longitude': -95.1174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74764', 'place_name': 'Valliant', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.0091, 'longitude': -95.0686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74766', 'place_name': 'Wright City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.0799, 'longitude': -94.9929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74957', 'place_name': 'Smithville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.4954, 'longitude': -94.6981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74963', 'place_name': 'Watson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McCurtain', 'locality_code': '89', 'latitude': 34.4193, 'longitude': -94.5562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74426', 'place_name': 'Checotah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McIntosh', 'locality_code': '91', 'latitude': 35.4358, 'longitude': -95.535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74432', 'place_name': 'Eufaula', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McIntosh', 'locality_code': '91', 'latitude': 35.2911, 'longitude': -95.6472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74438', 'place_name': 'Hitchita', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McIntosh', 'locality_code': '91', 'latitude': 35.5297, 'longitude': -95.7596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74459', 'place_name': 'Rentiesville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McIntosh', 'locality_code': '91', 'latitude': 35.5214, 'longitude': -95.495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74461', 'place_name': 'Stidham', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McIntosh', 'locality_code': '91', 'latitude': 35.3814, 'longitude': -95.7056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74845', 'place_name': 'Hanna', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'McIntosh', 'locality_code': '91', 'latitude': 35.2604, 'longitude': -95.8675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73718', 'place_name': 'Ames', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Major', 'locality_code': '93', 'latitude': 36.2423, 'longitude': -98.182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73729', 'place_name': 'Cleo Springs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Major', 'locality_code': '93', 'latitude': 36.409, 'longitude': -98.4423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73737', 'place_name': 'Fairview', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Major', 'locality_code': '93', 'latitude': 36.2871, 'longitude': -98.604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73747', 'place_name': 'Isabella', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Major', 'locality_code': '93', 'latitude': 36.2341, 'longitude': -98.3374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73760', 'place_name': 'Meno', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Major', 'locality_code': '93', 'latitude': 36.3815, 'longitude': -98.1635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73768', 'place_name': 'Ringwood', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Major', 'locality_code': '93', 'latitude': 36.3753, 'longitude': -98.2706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73838', 'place_name': 'Chester', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Major', 'locality_code': '93', 'latitude': 36.2621, 'longitude': -98.8838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73439', 'place_name': 'Kingston', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Marshall', 'locality_code': '95', 'latitude': 33.9517, 'longitude': -96.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73440', 'place_name': 'Lebanon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Marshall', 'locality_code': '95', 'latitude': 33.9687, 'longitude': -96.9064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73446', 'place_name': 'Madill', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Marshall', 'locality_code': '95', 'latitude': 34.0784, 'longitude': -96.7597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74330', 'place_name': 'Adair', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.4115, 'longitude': -95.2732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74337', 'place_name': 'Chouteau', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.1669, 'longitude': -95.3416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74340', 'place_name': 'Disney', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.4759, 'longitude': -95.024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74349', 'place_name': 'Ketchum', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.5245, 'longitude': -95.0239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74350', 'place_name': 'Langley', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.4645, 'longitude': -95.0478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74352', 'place_name': 'Locust Grove', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.1819, 'longitude': -95.1689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74361', 'place_name': 'Pryor', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.2921, 'longitude': -95.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74362', 'place_name': 'Pryor', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.2925, 'longitude': -95.2228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74364', 'place_name': 'Rose', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.1951, 'longitude': -94.9643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74365', 'place_name': 'Salina', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.3116, 'longitude': -95.1158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74366', 'place_name': 'Spavinaw', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.3912, 'longitude': -95.0466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74367', 'place_name': 'Strang', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Mayes', 'locality_code': '97', 'latitude': 36.4141, 'longitude': -95.0773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73030', 'place_name': 'Davis', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Murray', 'locality_code': '99', 'latitude': 34.4953, 'longitude': -97.1084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73032', 'place_name': 'Dougherty', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Murray', 'locality_code': '99', 'latitude': 34.402, 'longitude': -97.051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73086', 'place_name': 'Sulphur', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Murray', 'locality_code': '99', 'latitude': 34.5116, 'longitude': -96.9797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74401', 'place_name': 'Muskogee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.7058, 'longitude': -95.5002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74402', 'place_name': 'Muskogee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.7642, 'longitude': -95.3069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74403', 'place_name': 'Muskogee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.7411, 'longitude': -95.3449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74422', 'place_name': 'Boynton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.6577, 'longitude': -95.66, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74423', 'place_name': 'Braggs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.6574, 'longitude': -95.2033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74428', 'place_name': 'Council Hill', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.5556, 'longitude': -95.6514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74434', 'place_name': 'Fort Gibson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.7943, 'longitude': -95.2297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74436', 'place_name': 'Haskell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.8108, 'longitude': -95.684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74439', 'place_name': 'Braggs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.6767, 'longitude': -95.1775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74450', 'place_name': 'Oktaha', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.625, 'longitude': -95.4856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74455', 'place_name': 'Porum', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.3631, 'longitude': -95.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74463', 'place_name': 'Taft', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.7581, 'longitude': -95.5494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74468', 'place_name': 'Wainwright', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.6126, 'longitude': -95.5644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74469', 'place_name': 'Warner', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.4945, 'longitude': -95.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74470', 'place_name': 'Webbers Falls', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Muskogee', 'locality_code': '101', 'latitude': 35.5138, 'longitude': -95.1659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73061', 'place_name': 'Morrison', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Noble', 'locality_code': '103', 'latitude': 36.2902, 'longitude': -97.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73077', 'place_name': 'Perry', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Noble', 'locality_code': '103', 'latitude': 36.2875, 'longitude': -97.2842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73757', 'place_name': 'Lucien', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Noble', 'locality_code': '103', 'latitude': 36.2753, 'longitude': -97.4526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74630', 'place_name': 'Billings', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Noble', 'locality_code': '103', 'latitude': 36.5246, 'longitude': -97.4189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74644', 'place_name': 'Marland', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Noble', 'locality_code': '103', 'latitude': 36.5609, 'longitude': -97.1512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74651', 'place_name': 'Red Rock', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Noble', 'locality_code': '103', 'latitude': 36.4748, 'longitude': -97.164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74027', 'place_name': 'Delaware', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Nowata', 'locality_code': '105', 'latitude': 36.7804, 'longitude': -95.6181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74042', 'place_name': 'Lenapah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Nowata', 'locality_code': '105', 'latitude': 36.8801, 'longitude': -95.6233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74048', 'place_name': 'Nowata', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Nowata', 'locality_code': '105', 'latitude': 36.6946, 'longitude': -95.6404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74072', 'place_name': 'S Coffeyville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Nowata', 'locality_code': '105', 'latitude': 36.9837, 'longitude': -95.6065, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '74083', 'place_name': 'Wann', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Nowata', 'locality_code': '105', 'latitude': 36.9402, 'longitude': -95.7768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74829', 'place_name': 'Boley', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okfuskee', 'locality_code': '107', 'latitude': 35.4913, 'longitude': -96.4704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74833', 'place_name': 'Castle', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okfuskee', 'locality_code': '107', 'latitude': 35.4732, 'longitude': -96.3791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74859', 'place_name': 'Okemah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okfuskee', 'locality_code': '107', 'latitude': 35.4647, 'longitude': -96.3287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74860', 'place_name': 'Paden', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okfuskee', 'locality_code': '107', 'latitude': 35.5182, 'longitude': -96.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74880', 'place_name': 'Weleetka', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okfuskee', 'locality_code': '107', 'latitude': 35.3416, 'longitude': -96.1136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73003', 'place_name': 'Edmond', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6748, 'longitude': -97.4997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73007', 'place_name': 'Arcadia', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6543, 'longitude': -97.3243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73008', 'place_name': 'Bethany', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5043, 'longitude': -97.6399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73012', 'place_name': 'Edmond', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6215, 'longitude': -97.4733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73013', 'place_name': 'Edmond', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6215, 'longitude': -97.4733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73020', 'place_name': 'Choctaw', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4718, 'longitude': -97.2726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73025', 'place_name': 'Edmond', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.722, 'longitude': -97.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73034', 'place_name': 'Edmond', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6665, 'longitude': -97.4798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73039', 'place_name': 'Davis', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 34.506, 'longitude': -97.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73045', 'place_name': 'Harrah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4833, 'longitude': -97.1734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73049', 'place_name': 'Jones', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5753, 'longitude': -97.2891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73054', 'place_name': 'Luther', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6617, 'longitude': -97.1956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73066', 'place_name': 'Nicoma Park', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4928, 'longitude': -97.3276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73083', 'place_name': 'Edmond', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6665, 'longitude': -97.4654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73084', 'place_name': 'Spencer', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5183, 'longitude': -97.3488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73097', 'place_name': 'Wheatland', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.397, 'longitude': -97.6519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73101', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4916, 'longitude': -97.5628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73102', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4726, 'longitude': -97.5199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73103', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.491, 'longitude': -97.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73104', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4794, 'longitude': -97.5017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73105', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5108, 'longitude': -97.5003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73106', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4853, 'longitude': -97.5372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73107', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4874, 'longitude': -97.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73108', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4445, 'longitude': -97.5619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73109', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4259, 'longitude': -97.5261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73110', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4605, 'longitude': -97.3974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73111', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5042, 'longitude': -97.4806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73112', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5184, 'longitude': -97.5746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73113', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73114', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5704, 'longitude': -97.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73115', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4449, 'longitude': -97.446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73116', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5463, 'longitude': -97.5642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73117', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4797, 'longitude': -97.4722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73118', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5136, 'longitude': -97.5319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73119', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.421, 'longitude': -97.5616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73120', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5835, 'longitude': -97.5638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73121', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5062, 'longitude': -97.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73122', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5184, 'longitude': -97.6167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73123', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4676, 'longitude': -97.5164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73124', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73125', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4654, 'longitude': -97.5218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73126', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73127', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4834, 'longitude': -97.6299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73128', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4444, 'longitude': -97.6164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73129', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4312, 'longitude': -97.4913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73130', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4604, 'longitude': -97.3419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73131', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5797, 'longitude': -97.4691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73132', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5583, 'longitude': -97.6375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73134', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.6174, 'longitude': -97.5583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73135', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.411, 'longitude': -97.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73136', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4676, 'longitude': -97.5164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73137', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73140', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5185, 'longitude': -97.4275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73141', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4918, 'longitude': -97.3666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73142', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.599, 'longitude': -97.6251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73143', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73144', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73145', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4304, 'longitude': -97.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73146', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73147', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73148', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73149', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.395, 'longitude': -97.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73150', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4123, 'longitude': -97.3331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73151', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5676, 'longitude': -97.4111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73152', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73153', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73154', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5238, 'longitude': -97.5255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73155', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73156', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73157', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73159', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.3922, 'longitude': -97.5567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73162', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5806, 'longitude': -97.6419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73163', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73164', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73167', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4676, 'longitude': -97.5164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73169', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.3882, 'longitude': -97.6587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73172', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5175, 'longitude': -97.6218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73178', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73179', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4242, 'longitude': -97.6547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73184', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73185', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4676, 'longitude': -97.5164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73189', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73190', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.4676, 'longitude': -97.5164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73194', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73195', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.474, 'longitude': -97.5227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73196', 'place_name': 'Oklahoma City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.5514, 'longitude': -97.4075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74857', 'place_name': 'Newalla', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Oklahoma', 'locality_code': '109', 'latitude': 35.3734, 'longitude': -97.1971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74421', 'place_name': 'Beggs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okmulgee', 'locality_code': '111', 'latitude': 35.7896, 'longitude': -96.0264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74431', 'place_name': 'Dewar', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okmulgee', 'locality_code': '111', 'latitude': 35.4551, 'longitude': -95.9498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74437', 'place_name': 'Henryetta', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okmulgee', 'locality_code': '111', 'latitude': 35.4622, 'longitude': -96.0122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74445', 'place_name': 'Morris', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okmulgee', 'locality_code': '111', 'latitude': 35.6619, 'longitude': -95.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74447', 'place_name': 'Okmulgee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okmulgee', 'locality_code': '111', 'latitude': 35.6288, 'longitude': -95.9697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74456', 'place_name': 'Preston', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okmulgee', 'locality_code': '111', 'latitude': 35.7115, 'longitude': -95.9917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74460', 'place_name': 'Schulter', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Okmulgee', 'locality_code': '111', 'latitude': 35.5145, 'longitude': -95.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74001', 'place_name': 'Avant', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.4901, 'longitude': -96.0616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74002', 'place_name': 'Barnsdall', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.5429, 'longitude': -96.1318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74035', 'place_name': 'Hominy', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.4111, 'longitude': -96.3878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74054', 'place_name': 'Osage', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.2832, 'longitude': -96.3774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74056', 'place_name': 'Pawhuska', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.6904, 'longitude': -96.3121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74060', 'place_name': 'Prue', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.2501, 'longitude': -96.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74070', 'place_name': 'Skiatook', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.3725, 'longitude': -96.0123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74084', 'place_name': 'Wynona', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.5462, 'longitude': -96.3272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74127', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.1576, 'longitude': -96.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74633', 'place_name': 'Burbank', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.6966, 'longitude': -96.7869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74637', 'place_name': 'Fairfax', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.5577, 'longitude': -96.6997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74652', 'place_name': 'Shidler', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Osage', 'locality_code': '113', 'latitude': 36.7819, 'longitude': -96.6607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74331', 'place_name': 'Afton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.6296, 'longitude': -94.9432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74335', 'place_name': 'Cardin', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.9795, 'longitude': -94.8557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74339', 'place_name': 'Commerce', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.9331, 'longitude': -94.873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74343', 'place_name': 'Fairland', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.7418, 'longitude': -94.8279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74354', 'place_name': 'Miami', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.8764, 'longitude': -94.8719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74355', 'place_name': 'Miami', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.8341, 'longitude': -94.877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74358', 'place_name': 'North Miami', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.9173, 'longitude': -94.8797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74360', 'place_name': 'Picher', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.98, 'longitude': -94.8173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74363', 'place_name': 'Quapaw', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.9282, 'longitude': -94.743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74370', 'place_name': 'Wyandotte', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Ottawa', 'locality_code': '115', 'latitude': 36.7796, 'longitude': -94.7002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74020', 'place_name': 'Cleveland', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pawnee', 'locality_code': '117', 'latitude': 36.2553, 'longitude': -96.423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74034', 'place_name': 'Hallett', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pawnee', 'locality_code': '117', 'latitude': 36.2319, 'longitude': -96.562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74038', 'place_name': 'Jennings', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pawnee', 'locality_code': '117', 'latitude': 36.1863, 'longitude': -96.5732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74045', 'place_name': 'Maramec', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pawnee', 'locality_code': '117', 'latitude': 36.242, 'longitude': -96.6803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74058', 'place_name': 'Pawnee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pawnee', 'locality_code': '117', 'latitude': 36.3362, 'longitude': -96.7923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74081', 'place_name': 'Terlton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pawnee', 'locality_code': '117', 'latitude': 36.1889, 'longitude': -96.4876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74650', 'place_name': 'Ralston', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pawnee', 'locality_code': '117', 'latitude': 36.4992, 'longitude': -96.7755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74023', 'place_name': 'Cushing', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 35.9822, 'longitude': -96.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74032', 'place_name': 'Glencoe', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 36.2158, 'longitude': -96.9138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74059', 'place_name': 'Perkins', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 35.9768, 'longitude': -97.0441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74062', 'place_name': 'Ripley', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 35.9985, 'longitude': -96.8967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74074', 'place_name': 'Stillwater', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 36.1043, 'longitude': -97.0609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74075', 'place_name': 'Stillwater', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 36.1396, 'longitude': -97.063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74076', 'place_name': 'Stillwater', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 36.0724, 'longitude': -97.0551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74077', 'place_name': 'Stillwater', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 36.1156, 'longitude': -97.0584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74078', 'place_name': 'Stillwater', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 36.1241, 'longitude': -97.0705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74085', 'place_name': 'Yale', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Payne', 'locality_code': '119', 'latitude': 36.1101, 'longitude': -96.7022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74425', 'place_name': 'Canadian', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 35.1571, 'longitude': -95.6215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74430', 'place_name': 'Crowder', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 35.1334, 'longitude': -95.6602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74442', 'place_name': 'Indianola', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 35.1314, 'longitude': -95.8158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74501', 'place_name': 'Mcalester', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.9262, 'longitude': -95.7592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74502', 'place_name': 'Mcalester', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.9334, 'longitude': -95.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74522', 'place_name': 'Alderson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.9001, 'longitude': -95.6919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74528', 'place_name': 'Blanco', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.7276, 'longitude': -95.7283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74529', 'place_name': 'Blocker', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 35.0615, 'longitude': -95.5683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74546', 'place_name': 'Haileyville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.85, 'longitude': -95.5777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74547', 'place_name': 'Hartshorne', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.8452, 'longitude': -95.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74553', 'place_name': 'Kiowa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.7278, 'longitude': -95.9328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74554', 'place_name': 'Krebs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.9255, 'longitude': -95.7216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74560', 'place_name': 'Pittsburg', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.6975, 'longitude': -95.8439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74561', 'place_name': 'Quinton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 35.1547, 'longitude': -95.4671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74565', 'place_name': 'Savanna', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.8354, 'longitude': -95.838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74576', 'place_name': 'Wardville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pittsburg', 'locality_code': '121', 'latitude': 34.6695, 'longitude': -96.0258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74820', 'place_name': 'Ada', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.78, 'longitude': -96.6924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74821', 'place_name': 'Ada', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.7745, 'longitude': -96.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74825', 'place_name': 'Allen', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.8691, 'longitude': -96.4151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74842', 'place_name': 'Fittstown', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.6148, 'longitude': -96.6345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74843', 'place_name': 'Fitzhugh', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.6615, 'longitude': -96.7745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74844', 'place_name': 'Francis', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.8737, 'longitude': -96.5956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74865', 'place_name': 'Roff', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.6153, 'longitude': -96.8423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74871', 'place_name': 'Stonewall', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pontotoc', 'locality_code': '123', 'latitude': 34.6511, 'longitude': -96.5273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74801', 'place_name': 'Shawnee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.2958, 'longitude': -96.9601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74802', 'place_name': 'Shawnee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.3273, 'longitude': -96.9253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74804', 'place_name': 'Shawnee', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.3868, 'longitude': -96.9331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74826', 'place_name': 'Asher', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 34.9849, 'longitude': -96.8763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74840', 'place_name': 'Earlsboro', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.2628, 'longitude': -96.8041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74851', 'place_name': 'Mcloud', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.4262, 'longitude': -97.079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74852', 'place_name': 'Macomb', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.1205, 'longitude': -97.034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74854', 'place_name': 'Maud', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.1292, 'longitude': -96.7627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74866', 'place_name': 'Saint Louis', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.0588, 'longitude': -96.8444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74873', 'place_name': 'Tecumseh', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 35.2502, 'longitude': -96.9667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74878', 'place_name': 'Wanette', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pottawatomie', 'locality_code': '125', 'latitude': 34.9983, 'longitude': -97.0419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74521', 'place_name': 'Albion', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.6516, 'longitude': -95.0924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74523', 'place_name': 'Antlers', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.2349, 'longitude': -95.6254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74536', 'place_name': 'Clayton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.5906, 'longitude': -95.38, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74543', 'place_name': 'Finley', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.3407, 'longitude': -95.5385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74557', 'place_name': 'Moyers', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.3386, 'longitude': -95.6639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74558', 'place_name': 'Nashoba', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.5072, 'longitude': -95.2075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74562', 'place_name': 'Rattan', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.2454, 'longitude': -95.3442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74567', 'place_name': 'Snow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.4419, 'longitude': -95.4622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74574', 'place_name': 'Tuskahoma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Pushmataha', 'locality_code': '127', 'latitude': 34.6622, 'longitude': -95.2362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73628', 'place_name': 'Cheyenne', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Roger Mills', 'locality_code': '129', 'latitude': 35.6081, 'longitude': -99.6725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73638', 'place_name': 'Crawford', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Roger Mills', 'locality_code': '129', 'latitude': 35.8368, 'longitude': -99.8064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73642', 'place_name': 'Durham', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Roger Mills', 'locality_code': '129', 'latitude': 35.8364, 'longitude': -99.9088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73650', 'place_name': 'Hammon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Roger Mills', 'locality_code': '129', 'latitude': 35.6461, 'longitude': -99.4027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73660', 'place_name': 'Reydon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Roger Mills', 'locality_code': '129', 'latitude': 35.6576, 'longitude': -99.9166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73666', 'place_name': 'Sweetwater', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Roger Mills', 'locality_code': '129', 'latitude': 35.4488, 'longitude': -99.9006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74015', 'place_name': 'Catoosa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.1721, 'longitude': -95.7273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74016', 'place_name': 'Chelsea', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.5356, 'longitude': -95.4489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74017', 'place_name': 'Claremore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.3242, 'longitude': -95.5985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74018', 'place_name': 'Claremore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.3436, 'longitude': -95.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74031', 'place_name': 'Foyil', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.4348, 'longitude': -95.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74036', 'place_name': 'Inola', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.1503, 'longitude': -95.5205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74053', 'place_name': 'Oologah', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.4482, 'longitude': -95.7047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74080', 'place_name': 'Talala', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Rogers', 'locality_code': '131', 'latitude': 36.5429, 'longitude': -95.7142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74818', 'place_name': 'Seminole', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Seminole', 'locality_code': '133', 'latitude': 35.2245, 'longitude': -96.6706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74830', 'place_name': 'Bowlegs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Seminole', 'locality_code': '133', 'latitude': 35.1462, 'longitude': -96.67, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74837', 'place_name': 'Cromwell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Seminole', 'locality_code': '133', 'latitude': 35.3405, 'longitude': -96.4546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74849', 'place_name': 'Konawa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Seminole', 'locality_code': '133', 'latitude': 34.9708, 'longitude': -96.7343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74867', 'place_name': 'Sasakwa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Seminole', 'locality_code': '133', 'latitude': 34.951, 'longitude': -96.5387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74868', 'place_name': 'Seminole', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Seminole', 'locality_code': '133', 'latitude': 35.2521, 'longitude': -96.6683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74884', 'place_name': 'Wewoka', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Seminole', 'locality_code': '133', 'latitude': 35.1463, 'longitude': -96.628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74435', 'place_name': 'Gore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.5418, 'longitude': -95.1095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74936', 'place_name': 'Gans', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.3946, 'longitude': -94.6901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74945', 'place_name': 'Marble City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.5972, 'longitude': -94.8094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74946', 'place_name': 'Moffett', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.3898, 'longitude': -94.4462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74948', 'place_name': 'Muldrow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.402, 'longitude': -94.6332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74954', 'place_name': 'Roland', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.4538, 'longitude': -94.5291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74955', 'place_name': 'Sallisaw', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.4852, 'longitude': -94.779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74962', 'place_name': 'Vian', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Sequoyah', 'locality_code': '135', 'latitude': 35.5404, 'longitude': -94.9888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73055', 'place_name': 'Marlow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.6387, 'longitude': -97.941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73425', 'place_name': 'Countyline', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.4487, 'longitude': -97.5628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73434', 'place_name': 'Foster', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.6379, 'longitude': -97.5455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73442', 'place_name': 'Loco', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.3214, 'longitude': -97.6658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73491', 'place_name': 'Velma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.4565, 'longitude': -97.6689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73529', 'place_name': 'Comanche', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.3765, 'longitude': -97.9793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73533', 'place_name': 'Duncan', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.5073, 'longitude': -97.9403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73534', 'place_name': 'Duncan', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.5189, 'longitude': -97.9733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73536', 'place_name': 'Duncan', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Stephens', 'locality_code': '137', 'latitude': 34.4853, 'longitude': -97.8522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73901', 'place_name': 'Adams', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Texas', 'locality_code': '139', 'latitude': 36.755, 'longitude': -101.078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73939', 'place_name': 'Goodwell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Texas', 'locality_code': '139', 'latitude': 36.6744, 'longitude': -101.7137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73942', 'place_name': 'Guymon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Texas', 'locality_code': '139', 'latitude': 36.6961, 'longitude': -101.4778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73944', 'place_name': 'Hardesty', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Texas', 'locality_code': '139', 'latitude': 36.6018, 'longitude': -101.1539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73945', 'place_name': 'Hooker', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Texas', 'locality_code': '139', 'latitude': 36.8109, 'longitude': -101.2163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73949', 'place_name': 'Texhoma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Texas', 'locality_code': '139', 'latitude': 36.5253, 'longitude': -101.8394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73951', 'place_name': 'Tyrone', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Texas', 'locality_code': '139', 'latitude': 36.9558, 'longitude': -101.0594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73530', 'place_name': 'Davidson', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tillman', 'locality_code': '141', 'latitude': 34.2514, 'longitude': -99.064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73542', 'place_name': 'Frederick', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tillman', 'locality_code': '141', 'latitude': 34.4012, 'longitude': -99.0119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73546', 'place_name': 'Grandfield', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tillman', 'locality_code': '141', 'latitude': 34.2282, 'longitude': -98.6867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73551', 'place_name': 'Hollister', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tillman', 'locality_code': '141', 'latitude': 34.3525, 'longitude': -98.8814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73553', 'place_name': 'Loveland', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tillman', 'locality_code': '141', 'latitude': 34.391, 'longitude': -98.7235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73555', 'place_name': 'Manitou', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tillman', 'locality_code': '141', 'latitude': 34.5075, 'longitude': -98.9792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73570', 'place_name': 'Tipton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tillman', 'locality_code': '141', 'latitude': 34.5098, 'longitude': -99.1315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74008', 'place_name': 'Bixby', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 35.942, 'longitude': -95.8833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74011', 'place_name': 'Broken Arrow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 35.9908, 'longitude': -95.8143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74012', 'place_name': 'Broken Arrow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0447, 'longitude': -95.8079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74013', 'place_name': 'Broken Arrow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0526, 'longitude': -95.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74021', 'place_name': 'Collinsville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.3701, 'longitude': -95.8469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74033', 'place_name': 'Glenpool', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 35.9591, 'longitude': -95.9997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74037', 'place_name': 'Jenks', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0148, 'longitude': -95.9797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74043', 'place_name': 'Leonard', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 35.9183, 'longitude': -95.7988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74050', 'place_name': 'Oakhurst', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0731, 'longitude': -96.0621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74055', 'place_name': 'Owasso', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.2863, 'longitude': -95.8222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74063', 'place_name': 'Sand Springs', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1341, 'longitude': -96.1426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74073', 'place_name': 'Sperry', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.2955, 'longitude': -95.9804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74101', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0391, 'longitude': -95.8687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74102', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.154, 'longitude': -95.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74103', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1539, 'longitude': -95.9954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74104', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1464, 'longitude': -95.9526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74105', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0948, 'longitude': -95.9655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74106', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1883, 'longitude': -95.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74107', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1042, 'longitude': -96.0244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74108', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1499, 'longitude': -95.7923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74110', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1803, 'longitude': -95.9525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74112', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.147, 'longitude': -95.907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74114', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1262, 'longitude': -95.9408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74115', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1754, 'longitude': -95.9112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74116', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.175, 'longitude': -95.8477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74117', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.2393, 'longitude': -95.8979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74119', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1407, 'longitude': -95.9902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74120', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1442, 'longitude': -95.9734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74121', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74126', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.2383, 'longitude': -95.9931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74128', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1459, 'longitude': -95.8514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74129', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1259, 'longitude': -95.8654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74130', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.2395, 'longitude': -95.9596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74132', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.064, 'longitude': -96.0251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74133', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0467, 'longitude': -95.8841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74134', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1162, 'longitude': -95.8225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74135', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0976, 'longitude': -95.9228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74136', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0605, 'longitude': -95.9452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74137', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0284, 'longitude': -95.9306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74141', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74145', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0934, 'longitude': -95.8856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74146', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1093, 'longitude': -95.8506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74147', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74148', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74149', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74150', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74152', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74153', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74155', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74156', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.3024, 'longitude': -95.9605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74157', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74158', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74159', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.0772, 'longitude': -96.0835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74169', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74170', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74171', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.154, 'longitude': -95.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74172', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1543, 'longitude': -95.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74182', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.154, 'longitude': -95.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74186', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.154, 'longitude': -95.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74187', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.154, 'longitude': -95.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74192', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.154, 'longitude': -95.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74193', 'place_name': 'Tulsa', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Tulsa', 'locality_code': '143', 'latitude': 36.1398, 'longitude': -96.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74014', 'place_name': 'Broken Arrow', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 36.0544, 'longitude': -95.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74019', 'place_name': 'Claremore', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 36.2806, 'longitude': -95.6039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74429', 'place_name': 'Coweta', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 35.9578, 'longitude': -95.6526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74446', 'place_name': 'Okay', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 35.8507, 'longitude': -95.3183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74454', 'place_name': 'Porter', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 35.8567, 'longitude': -95.5082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74458', 'place_name': 'Redbird', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 35.8836, 'longitude': -95.5917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74467', 'place_name': 'Wagoner', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 35.9549, 'longitude': -95.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74477', 'place_name': 'Wagoner', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Wagoner', 'locality_code': '145', 'latitude': 35.9636, 'longitude': -95.5139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74003', 'place_name': 'Bartlesville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.744, 'longitude': -95.9921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74004', 'place_name': 'Bartlesville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.7114, 'longitude': -95.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74005', 'place_name': 'Bartlesville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.7473, 'longitude': -95.9808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74006', 'place_name': 'Bartlesville', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.7366, 'longitude': -95.9251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74022', 'place_name': 'Copan', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.9062, 'longitude': -95.913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74029', 'place_name': 'Dewey', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.8013, 'longitude': -95.9345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74051', 'place_name': 'Ochelata', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.5947, 'longitude': -95.9691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74061', 'place_name': 'Ramona', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.5752, 'longitude': -95.8962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '74082', 'place_name': 'Vera', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washington', 'locality_code': '147', 'latitude': 36.4501, 'longitude': -95.8814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73021', 'place_name': 'Colony', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.3448, 'longitude': -98.6707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73024', 'place_name': 'Corn', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.3784, 'longitude': -98.7818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73622', 'place_name': 'Bessie', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.3854, 'longitude': -98.9896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73624', 'place_name': 'Burns Flat', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.3492, 'longitude': -99.188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73626', 'place_name': 'Canute', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.4037, 'longitude': -99.2816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73632', 'place_name': 'Cordell', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.2788, 'longitude': -98.9511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73641', 'place_name': 'Dill City', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.2787, 'longitude': -99.1537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73647', 'place_name': 'Foss', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.4545, 'longitude': -99.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73661', 'place_name': 'Rocky', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.1526, 'longitude': -99.048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73664', 'place_name': 'Sentinel', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Washita', 'locality_code': '149', 'latitude': 35.1617, 'longitude': -99.1706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73717', 'place_name': 'Alva', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woods', 'locality_code': '151', 'latitude': 36.8016, 'longitude': -98.6722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73731', 'place_name': 'Dacoma', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woods', 'locality_code': '151', 'latitude': 36.6606, 'longitude': -98.5942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73746', 'place_name': 'Hopeton', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woods', 'locality_code': '151', 'latitude': 36.6881, 'longitude': -98.6659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73842', 'place_name': 'Freedom', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woods', 'locality_code': '151', 'latitude': 36.809, 'longitude': -99.1319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73860', 'place_name': 'Waynoka', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woods', 'locality_code': '151', 'latitude': 36.5858, 'longitude': -98.8487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73801', 'place_name': 'Woodward', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woodward', 'locality_code': '153', 'latitude': 36.4268, 'longitude': -99.402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73802', 'place_name': 'Woodward', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woodward', 'locality_code': '153', 'latitude': 36.544, 'longitude': -99.3003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73841', 'place_name': 'Fort Supply', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woodward', 'locality_code': '153', 'latitude': 36.5722, 'longitude': -99.5738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73852', 'place_name': 'Mooreland', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woodward', 'locality_code': '153', 'latitude': 36.4428, 'longitude': -99.1832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73853', 'place_name': 'Mutual', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woodward', 'locality_code': '153', 'latitude': 36.214, 'longitude': -99.1145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73857', 'place_name': 'Sharon', 'state': 'Oklahoma', 'state_ab': 'OK', 'county': 'Woodward', 'locality_code': '153', 'latitude': 36.2699, 'longitude': -99.3587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97814', 'place_name': 'Baker City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.7749, 'longitude': -117.8344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97819', 'place_name': 'Bridgeport', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.4931, 'longitude': -117.7655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97833', 'place_name': 'Haines', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.8776, 'longitude': -117.9756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97834', 'place_name': 'Halfway', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.8953, 'longitude': -117.1132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97837', 'place_name': 'Hereford', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.5304, 'longitude': -118.0293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97840', 'place_name': 'Oxbow', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.9749, 'longitude': -116.8629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97870', 'place_name': 'Richland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.797, 'longitude': -117.3018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97877', 'place_name': 'Sumpter', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.7457, 'longitude': -118.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97884', 'place_name': 'Unity', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.4374, 'longitude': -118.1927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97905', 'place_name': 'Durkee', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.4988, 'longitude': -117.4129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97907', 'place_name': 'Huntington', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Baker', 'locality_code': '1', 'latitude': 44.3811, 'longitude': -117.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97324', 'place_name': 'Alsea', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.3691, 'longitude': -123.6089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97326', 'place_name': 'Blodgett', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.6281, 'longitude': -123.6067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97330', 'place_name': 'Corvallis', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.5904, 'longitude': -123.2722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97331', 'place_name': 'Corvallis', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.5638, 'longitude': -123.2779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97333', 'place_name': 'Corvallis', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.5393, 'longitude': -123.2799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97339', 'place_name': 'Corvallis', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.5646, 'longitude': -123.262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97370', 'place_name': 'Philomath', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.5488, 'longitude': -123.3923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97456', 'place_name': 'Monroe', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Benton', 'locality_code': '3', 'latitude': 44.3245, 'longitude': -123.3203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97004', 'place_name': 'Beavercreek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.2597, 'longitude': -122.4751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97009', 'place_name': 'Boring', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.4297, 'longitude': -122.3807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97011', 'place_name': 'Brightwood', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.3652, 'longitude': -122.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97013', 'place_name': 'Canby', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.2514, 'longitude': -122.6832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97015', 'place_name': 'Clackamas', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.415, 'longitude': -122.52, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97017', 'place_name': 'Colton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.1573, 'longitude': -122.4248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97022', 'place_name': 'Eagle Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.3582, 'longitude': -122.3381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97023', 'place_name': 'Estacada', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.2872, 'longitude': -122.3259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97027', 'place_name': 'Gladstone', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.3899, 'longitude': -122.5902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97028', 'place_name': 'Government Camp', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.2972, 'longitude': -121.739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97034', 'place_name': 'Lake Oswego', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.4093, 'longitude': -122.6847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97035', 'place_name': 'Lake Oswego', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.4147, 'longitude': -122.7227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97036', 'place_name': 'Marylhurst', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.4012, 'longitude': -122.6512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97038', 'place_name': 'Molalla', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.1223, 'longitude': -122.5756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97042', 'place_name': 'Mulino', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.213, 'longitude': -122.5351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97045', 'place_name': 'Oregon City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.3377, 'longitude': -122.57, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97049', 'place_name': 'Rhododendron', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.3465, 'longitude': -121.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97055', 'place_name': 'Sandy', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.379, 'longitude': -122.223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97067', 'place_name': 'Welches', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.3399, 'longitude': -121.9598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97068', 'place_name': 'West Linn', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.3669, 'longitude': -122.648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97070', 'place_name': 'Wilsonville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.2986, 'longitude': -122.7699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97089', 'place_name': 'Damascus', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.4176, 'longitude': -122.459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97222', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.4373, 'longitude': -122.6147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97267', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.4021, 'longitude': -122.6144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97268', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97269', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clackamas', 'locality_code': '5', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97102', 'place_name': 'Arch Cape', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clatsop', 'locality_code': '7', 'latitude': 45.8109, 'longitude': -123.963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97103', 'place_name': 'Astoria', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clatsop', 'locality_code': '7', 'latitude': 46.1558, 'longitude': -123.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97110', 'place_name': 'Cannon Beach', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clatsop', 'locality_code': '7', 'latitude': 45.8918, 'longitude': -123.9615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97121', 'place_name': 'Hammond', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clatsop', 'locality_code': '7', 'latitude': 46.198, 'longitude': -123.9527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97138', 'place_name': 'Seaside', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clatsop', 'locality_code': '7', 'latitude': 45.9932, 'longitude': -123.9226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97145', 'place_name': 'Tolovana Park', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clatsop', 'locality_code': '7', 'latitude': 45.8663, 'longitude': -123.9595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97146', 'place_name': 'Warrenton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Clatsop', 'locality_code': '7', 'latitude': 46.145, 'longitude': -123.9254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97016', 'place_name': 'Clatskanie', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 46.0665, 'longitude': -123.2059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97018', 'place_name': 'Columbia City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 45.8925, 'longitude': -122.8122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97048', 'place_name': 'Rainier', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 46.0646, 'longitude': -122.9671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97051', 'place_name': 'Saint Helens', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 45.8608, 'longitude': -122.8282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97053', 'place_name': 'Warren', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 45.826, 'longitude': -122.8634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97054', 'place_name': 'Deer Island', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 45.9356, 'longitude': -122.8985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97056', 'place_name': 'Scappoose', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 45.7655, 'longitude': -122.8928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97064', 'place_name': 'Vernonia', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Columbia', 'locality_code': '9', 'latitude': 45.8573, 'longitude': -123.1967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97407', 'place_name': 'Allegany', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 43.4259, 'longitude': -124.0323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97411', 'place_name': 'Bandon', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 43.0968, 'longitude': -124.4037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97414', 'place_name': 'Broadbent', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 42.985, 'longitude': -124.1189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97420', 'place_name': 'Coos Bay', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 43.2151, 'longitude': -124.1984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97423', 'place_name': 'Coquille', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 43.1884, 'longitude': -124.2014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97449', 'place_name': 'Lakeside', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 43.5833, 'longitude': -124.1624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97458', 'place_name': 'Myrtle Point', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 43.0667, 'longitude': -124.1213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97459', 'place_name': 'North Bend', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 43.4327, 'longitude': -124.2131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97466', 'place_name': 'Powers', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Coos', 'locality_code': '11', 'latitude': 42.88, 'longitude': -124.0709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97751', 'place_name': 'Paulina', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Crook', 'locality_code': '13', 'latitude': 44.2102, 'longitude': -119.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97752', 'place_name': 'Post', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Crook', 'locality_code': '13', 'latitude': 44.0793, 'longitude': -120.2998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97753', 'place_name': 'Powell Butte', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Crook', 'locality_code': '13', 'latitude': 44.2415, 'longitude': -121.0113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97754', 'place_name': 'Prineville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Crook', 'locality_code': '13', 'latitude': 44.3045, 'longitude': -120.8336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97406', 'place_name': 'Agness', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.5748, 'longitude': -124.0648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97415', 'place_name': 'Brookings', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.0526, 'longitude': -124.284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97444', 'place_name': 'Gold Beach', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.4073, 'longitude': -124.4218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97450', 'place_name': 'Langlois', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.9154, 'longitude': -124.4413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97464', 'place_name': 'Ophir', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.5632, 'longitude': -124.3829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97465', 'place_name': 'Port Orford', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.7572, 'longitude': -124.4913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97476', 'place_name': 'Sixes', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.825, 'longitude': -124.4409, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97491', 'place_name': 'Wedderburn', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Curry', 'locality_code': '15', 'latitude': 42.6093, 'longitude': -124.3886, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97701', 'place_name': 'Bend', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.0928, 'longitude': -121.2936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97702', 'place_name': 'Bend', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.0223, 'longitude': -121.2985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97703', 'place_name': 'Bend', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.0915, 'longitude': -121.4073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97707', 'place_name': 'Bend', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 43.8431, 'longitude': -121.5764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97708', 'place_name': 'Bend', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.0582, 'longitude': -121.3153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97709', 'place_name': 'Bend', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.0582, 'longitude': -121.3153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97712', 'place_name': 'Brothers', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 43.7789, 'longitude': -120.477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97739', 'place_name': 'La Pine', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 43.7091, 'longitude': -121.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97756', 'place_name': 'Redmond', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.2767, 'longitude': -121.1896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97759', 'place_name': 'Sisters', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.3165, 'longitude': -121.5091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97760', 'place_name': 'Terrebonne', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Deschutes', 'locality_code': '17', 'latitude': 44.3909, 'longitude': -121.2379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97410', 'place_name': 'Azalea', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 42.845, 'longitude': -123.155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97416', 'place_name': 'Camas Valley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.0557, 'longitude': -123.6655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97417', 'place_name': 'Canyonville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 42.9307, 'longitude': -123.278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97429', 'place_name': 'Days Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 42.9819, 'longitude': -123.1439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97432', 'place_name': 'Dillard', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.1135, 'longitude': -123.4181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97435', 'place_name': 'Drain', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.6877, 'longitude': -123.2929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97436', 'place_name': 'Elkton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.6378, 'longitude': -123.59, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97441', 'place_name': 'Gardiner', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.7301, 'longitude': -124.1104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97442', 'place_name': 'Glendale', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 42.7518, 'longitude': -123.3943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97443', 'place_name': 'Glide', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.3015, 'longitude': -123.1012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97447', 'place_name': 'Idleyld Park', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.3237, 'longitude': -123.024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97457', 'place_name': 'Myrtle Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.0162, 'longitude': -123.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97462', 'place_name': 'Oakland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.453, 'longitude': -123.3558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97467', 'place_name': 'Reedsport', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.7023, 'longitude': -124.0968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97469', 'place_name': 'Riddle', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 42.9389, 'longitude': -123.3612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97470', 'place_name': 'Roseburg', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.2297, 'longitude': -123.2343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97471', 'place_name': 'Roseburg', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.227, 'longitude': -123.5158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97473', 'place_name': 'Scottsburg', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.6765, 'longitude': -123.8041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97479', 'place_name': 'Sutherlin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.3904, 'longitude': -123.2974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97481', 'place_name': 'Tenmile', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.114, 'longitude': -123.5294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97484', 'place_name': 'Tiller', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 42.9177, 'longitude': -122.9079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97486', 'place_name': 'Umpqua', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.3745, 'longitude': -123.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97494', 'place_name': 'Wilbur', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.3284, 'longitude': -123.3332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97495', 'place_name': 'Winchester', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.2878, 'longitude': -123.3055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97496', 'place_name': 'Winston', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.1049, 'longitude': -123.4325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97499', 'place_name': 'Yoncalla', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Douglas', 'locality_code': '19', 'latitude': 43.6043, 'longitude': -123.2926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97812', 'place_name': 'Arlington', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Gilliam', 'locality_code': '21', 'latitude': 45.6664, 'longitude': -120.1971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97823', 'place_name': 'Condon', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Gilliam', 'locality_code': '21', 'latitude': 45.2306, 'longitude': -120.1898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97861', 'place_name': 'Mikkalo', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Gilliam', 'locality_code': '21', 'latitude': 45.4388, 'longitude': -120.2067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97817', 'place_name': 'Bates', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.7138, 'longitude': -118.6469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97820', 'place_name': 'Canyon City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.3911, 'longitude': -118.9465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97825', 'place_name': 'Dayville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.4663, 'longitude': -119.5312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97845', 'place_name': 'John Day', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.416, 'longitude': -118.953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97848', 'place_name': 'Kimberly', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.7226, 'longitude': -119.5965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97856', 'place_name': 'Long Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.7554, 'longitude': -119.097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97864', 'place_name': 'Monument', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.8189, 'longitude': -119.4192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97865', 'place_name': 'Mount Vernon', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.4171, 'longitude': -119.1121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97869', 'place_name': 'Prairie City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.457, 'longitude': -118.6952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97873', 'place_name': 'Seneca', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Grant', 'locality_code': '23', 'latitude': 44.1346, 'longitude': -118.9716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97710', 'place_name': 'Fields', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 42.1862, 'longitude': -118.4758, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97720', 'place_name': 'Burns', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 43.5145, 'longitude': -119.0504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97721', 'place_name': 'Princeton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 43.0198, 'longitude': -119.0696, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97722', 'place_name': 'Diamond', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 42.9508, 'longitude': -118.695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97732', 'place_name': 'Crane', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 43.4262, 'longitude': -118.4642, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97736', 'place_name': 'Frenchglen', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 42.7147, 'longitude': -119.0058, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97738', 'place_name': 'Hines', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 43.5558, 'longitude': -119.0816, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97758', 'place_name': 'Riley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 43.3886, 'longitude': -119.8798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97904', 'place_name': 'Drewsey', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Harney', 'locality_code': '25', 'latitude': 43.8643, 'longitude': -118.4707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97014', 'place_name': 'Cascade Locks', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Hood River', 'locality_code': '27', 'latitude': 45.671, 'longitude': -121.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97031', 'place_name': 'Hood River', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Hood River', 'locality_code': '27', 'latitude': 45.6711, 'longitude': -121.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97041', 'place_name': 'Mount Hood Parkdale', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Hood River', 'locality_code': '27', 'latitude': 45.4929, 'longitude': -121.5983, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97044', 'place_name': 'Odell', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Hood River', 'locality_code': '27', 'latitude': 45.6437, 'longitude': -121.5367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97501', 'place_name': 'Medford', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.2818, 'longitude': -122.9054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97502', 'place_name': 'Central Point', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.3899, 'longitude': -122.9222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97503', 'place_name': 'White City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.4319, 'longitude': -122.8296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97504', 'place_name': 'Medford', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.3363, 'longitude': -122.8398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97520', 'place_name': 'Ashland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.1885, 'longitude': -122.693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97522', 'place_name': 'Butte Falls', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.5492, 'longitude': -122.5638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97524', 'place_name': 'Eagle Point', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.4935, 'longitude': -122.8088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97525', 'place_name': 'Gold Hill', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.4244, 'longitude': -123.0854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97530', 'place_name': 'Jacksonville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.1813, 'longitude': -123.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97535', 'place_name': 'Phoenix', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.2766, 'longitude': -122.8227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97536', 'place_name': 'Prospect', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.7544, 'longitude': -122.509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97537', 'place_name': 'Rogue River', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.4889, 'longitude': -123.1587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97539', 'place_name': 'Shady Cove', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.6107, 'longitude': -122.8125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97540', 'place_name': 'Talent', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.2363, 'longitude': -122.7861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97541', 'place_name': 'Trail', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jackson', 'locality_code': '29', 'latitude': 42.6864, 'longitude': -122.816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97711', 'place_name': 'Ashwood', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 44.7195, 'longitude': -120.7192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97730', 'place_name': 'Camp Sherman', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 44.4604, 'longitude': -121.6412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97734', 'place_name': 'Culver', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 44.4818, 'longitude': -121.2344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97741', 'place_name': 'Madras', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 44.6376, 'longitude': -121.1349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97761', 'place_name': 'Warm Springs', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 44.7468, 'longitude': -121.2909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97497', 'place_name': 'Wolf Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.6522, 'longitude': -123.425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97523', 'place_name': 'Cave Junction', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.1348, 'longitude': -123.6272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97526', 'place_name': 'Grants Pass', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.4638, 'longitude': -123.3457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97527', 'place_name': 'Grants Pass', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.3989, 'longitude': -123.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97528', 'place_name': 'Grants Pass', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.4393, 'longitude': -123.3307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97531', 'place_name': 'Kerby', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.2093, 'longitude': -123.6573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97532', 'place_name': 'Merlin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.5297, 'longitude': -123.4393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97533', 'place_name': 'Murphy', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.308, 'longitude': -123.3273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97534', 'place_name': 'O Brien', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.0879, 'longitude': -123.689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97538', 'place_name': 'Selma', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.2654, 'longitude': -123.5515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97543', 'place_name': 'Wilderville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.3751, 'longitude': -123.5621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97544', 'place_name': 'Williams', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Josephine', 'locality_code': '33', 'latitude': 42.223, 'longitude': -123.2829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97601', 'place_name': 'Klamath Falls', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.2933, 'longitude': -121.8169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97602', 'place_name': 'Klamath Falls', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.2249, 'longitude': -121.7817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97603', 'place_name': 'Klamath Falls', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.1919, 'longitude': -121.7241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97604', 'place_name': 'Crater Lake', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.9465, 'longitude': -122.1769, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97621', 'place_name': 'Beatty', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.4369, 'longitude': -121.22, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97622', 'place_name': 'Bly', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.3995, 'longitude': -121.0806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97623', 'place_name': 'Bonanza', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.2463, 'longitude': -121.3336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97624', 'place_name': 'Chiloquin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.5463, 'longitude': -121.745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97625', 'place_name': 'Dairy', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.2351, 'longitude': -121.5211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97626', 'place_name': 'Fort Klamath', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.6415, 'longitude': -122.038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97627', 'place_name': 'Keno', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.1265, 'longitude': -121.93, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97632', 'place_name': 'Malin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.0195, 'longitude': -121.4221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97633', 'place_name': 'Merrill', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.0295, 'longitude': -121.5985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97634', 'place_name': 'Midland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.1307, 'longitude': -121.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97639', 'place_name': 'Sprague River', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 42.4514, 'longitude': -121.4365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97731', 'place_name': 'Chemult', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 43.146, 'longitude': -121.7974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97733', 'place_name': 'Crescent', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 43.4442, 'longitude': -121.7109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97737', 'place_name': 'Gilchrist', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Klamath', 'locality_code': '35', 'latitude': 43.4771, 'longitude': -121.6853, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97620', 'place_name': 'Adel', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 42.1487, 'longitude': -119.8833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97630', 'place_name': 'Lakeview', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 42.1854, 'longitude': -120.3775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97635', 'place_name': 'New Pine Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 41.9941, 'longitude': -120.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97636', 'place_name': 'Paisley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 42.7031, 'longitude': -120.5532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97637', 'place_name': 'Plush', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 42.5035, 'longitude': -119.8947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97638', 'place_name': 'Silver Lake', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 43.1395, 'longitude': -120.9984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97640', 'place_name': 'Summer Lake', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 42.9447, 'longitude': -120.7946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97641', 'place_name': 'Christmas Valley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 43.2363, 'longitude': -120.6369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97735', 'place_name': 'Fort Rock', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lake', 'locality_code': '37', 'latitude': 43.3565, 'longitude': -121.0539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97401', 'place_name': 'Eugene', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0682, 'longitude': -123.0819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97402', 'place_name': 'Eugene', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0612, 'longitude': -123.1555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97403', 'place_name': 'Eugene', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0385, 'longitude': -123.0614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97404', 'place_name': 'Eugene', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1005, 'longitude': -123.1334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97405', 'place_name': 'Eugene', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0185, 'longitude': -123.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97408', 'place_name': 'Eugene', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1445, 'longitude': -123.0545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97409', 'place_name': 'Alvadore', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1276, 'longitude': -123.2666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97412', 'place_name': 'Blachly', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1966, 'longitude': -123.5348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97413', 'place_name': 'Blue River', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1755, 'longitude': -122.1217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97419', 'place_name': 'Cheshire', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1782, 'longitude': -123.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97424', 'place_name': 'Cottage Grove', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.7839, 'longitude': -123.0529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97426', 'place_name': 'Creswell', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.9058, 'longitude': -123.0284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97430', 'place_name': 'Deadwood', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1462, 'longitude': -123.6816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97431', 'place_name': 'Dexter', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.9217, 'longitude': -122.8424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97434', 'place_name': 'Dorena', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.7361, 'longitude': -122.8946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97437', 'place_name': 'Elmira', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0873, 'longitude': -123.3671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97438', 'place_name': 'Fall Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.9509, 'longitude': -122.6884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97439', 'place_name': 'Florence', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.9881, 'longitude': -124.0993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97440', 'place_name': 'Eugene', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0521, 'longitude': -123.0868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97448', 'place_name': 'Junction City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1988, 'longitude': -123.23, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97451', 'place_name': 'Lorane', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.8376, 'longitude': -123.239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97452', 'place_name': 'Lowell', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.921, 'longitude': -122.7806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97453', 'place_name': 'Mapleton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0312, 'longitude': -123.8657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97454', 'place_name': 'Marcola', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.2064, 'longitude': -122.8246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97455', 'place_name': 'Pleasant Hill', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.9458, 'longitude': -122.9285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97461', 'place_name': 'Noti', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0992, 'longitude': -123.4684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97463', 'place_name': 'Oakridge', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.7376, 'longitude': -122.4377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97475', 'place_name': 'Springfield', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0462, 'longitude': -123.022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97477', 'place_name': 'Springfield', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0611, 'longitude': -123.0153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97478', 'place_name': 'Springfield', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0561, 'longitude': -122.9171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97480', 'place_name': 'Swisshome', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0899, 'longitude': -123.8279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97487', 'place_name': 'Veneta', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0382, 'longitude': -123.3516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97488', 'place_name': 'Vida', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.13, 'longitude': -122.5044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97489', 'place_name': 'Walterville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.1288, 'longitude': -122.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97490', 'place_name': 'Walton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 44.0282, 'longitude': -123.5893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97492', 'place_name': 'Westfir', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.7575, 'longitude': -122.481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97493', 'place_name': 'Westlake', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lane', 'locality_code': '39', 'latitude': 43.914, 'longitude': -124.0334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97341', 'place_name': 'Depoe Bay', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.8322, 'longitude': -124.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97343', 'place_name': 'Eddyville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.6371, 'longitude': -123.7531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97357', 'place_name': 'Logsden', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.7432, 'longitude': -123.7943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97364', 'place_name': 'Neotsu', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.9988, 'longitude': -123.9843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97365', 'place_name': 'Newport', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.6487, 'longitude': -124.0509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97366', 'place_name': 'South Beach', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.5712, 'longitude': -124.06, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97367', 'place_name': 'Lincoln City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.9089, 'longitude': -123.9888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97368', 'place_name': 'Otis', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 45.0138, 'longitude': -123.9332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97369', 'place_name': 'Otter Rock', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.7588, 'longitude': -124.0633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97376', 'place_name': 'Seal Rock', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.4874, 'longitude': -123.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97380', 'place_name': 'Siletz', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.7313, 'longitude': -123.9062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97388', 'place_name': 'Gleneden Beach', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.8812, 'longitude': -124.0343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97390', 'place_name': 'Tidewater', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.4055, 'longitude': -123.9149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97391', 'place_name': 'Toledo', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.6271, 'longitude': -123.9301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97394', 'place_name': 'Waldport', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.4085, 'longitude': -124.0351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97498', 'place_name': 'Yachats', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Lincoln', 'locality_code': '41', 'latitude': 44.3256, 'longitude': -124.0863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97321', 'place_name': 'Albany', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.652, 'longitude': -123.1333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97322', 'place_name': 'Albany', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.626, 'longitude': -123.057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97327', 'place_name': 'Brownsville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.377, 'longitude': -122.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97329', 'place_name': 'Cascadia', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.3973, 'longitude': -122.4817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97335', 'place_name': 'Crabtree', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.6344, 'longitude': -122.8933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97336', 'place_name': 'Crawfordsville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.3593, 'longitude': -122.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97345', 'place_name': 'Foster', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.3836, 'longitude': -122.5449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97348', 'place_name': 'Halsey', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.3862, 'longitude': -123.1251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97355', 'place_name': 'Lebanon', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.5316, 'longitude': -122.8821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97358', 'place_name': 'Lyons', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.7499, 'longitude': -122.595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97360', 'place_name': 'Mill City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.7516, 'longitude': -122.4768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97374', 'place_name': 'Scio', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.7168, 'longitude': -122.7684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97377', 'place_name': 'Shedd', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.453, 'longitude': -123.1065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97386', 'place_name': 'Sweet Home', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.3981, 'longitude': -122.7286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97389', 'place_name': 'Tangent', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.5497, 'longitude': -123.1108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97446', 'place_name': 'Harrisburg', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Linn', 'locality_code': '43', 'latitude': 44.2717, 'longitude': -123.1432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97901', 'place_name': 'Adrian', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 43.6537, 'longitude': -117.0602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97902', 'place_name': 'Arock', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 42.9156, 'longitude': -117.498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97903', 'place_name': 'Brogan', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 44.1994, 'longitude': -117.5904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97906', 'place_name': 'Harper', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 43.8734, 'longitude': -117.5284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97908', 'place_name': 'Ironside', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 44.3009, 'longitude': -117.9444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97909', 'place_name': 'Jamieson', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 44.2161, 'longitude': -117.4813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97910', 'place_name': 'Jordan Valley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 42.8801, 'longitude': -117.281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97911', 'place_name': 'Juntura', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 43.8253, 'longitude': -118.0921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97913', 'place_name': 'Nyssa', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 43.8604, 'longitude': -117.0251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97914', 'place_name': 'Ontario', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 44.0416, 'longitude': -116.9783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97917', 'place_name': 'Riverside', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 43.5099, 'longitude': -118.0986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97918', 'place_name': 'Vale', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 44.0039, 'longitude': -117.2674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97920', 'place_name': 'Westfall', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Malheur', 'locality_code': '45', 'latitude': 43.9922, 'longitude': -117.6877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97002', 'place_name': 'Aurora', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 45.2284, 'longitude': -122.8039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97020', 'place_name': 'Donald', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 45.2199, 'longitude': -122.8405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97026', 'place_name': 'Gervais', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 45.1086, 'longitude': -122.8962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97032', 'place_name': 'Hubbard', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 45.1823, 'longitude': -122.8079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97071', 'place_name': 'Woodburn', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 45.1446, 'longitude': -122.8583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97137', 'place_name': 'Saint Paul', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 45.196, 'longitude': -122.9674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97301', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.949, 'longitude': -123.004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97302', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9039, 'longitude': -123.0445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97303', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9927, 'longitude': -123.0167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97305', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9961, 'longitude': -122.9124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97306', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.8685, 'longitude': -123.0438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97307', 'place_name': 'Keizer', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9901, 'longitude': -123.0262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97308', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9429, 'longitude': -123.0351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97309', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9429, 'longitude': -123.0351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97310', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9271, 'longitude': -122.9861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97311', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9438, 'longitude': -123.0286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97312', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9364, 'longitude': -123.0381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97313', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9849, 'longitude': -122.9988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97314', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9655, 'longitude': -123.0066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97317', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9026, 'longitude': -122.9074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97325', 'place_name': 'Aumsville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.8313, 'longitude': -122.8517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97342', 'place_name': 'Detroit', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.734, 'longitude': -122.1498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97346', 'place_name': 'Gates', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.7527, 'longitude': -122.3995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97350', 'place_name': 'Idanha', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.7001, 'longitude': -122.074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97352', 'place_name': 'Jefferson', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.7495, 'longitude': -123.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97362', 'place_name': 'Mount Angel', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 45.0737, 'longitude': -122.7856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97373', 'place_name': 'Saint Benedict', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9845, 'longitude': -122.457, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97375', 'place_name': 'Scotts Mills', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.9897, 'longitude': -122.6187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97381', 'place_name': 'Silverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.991, 'longitude': -122.7627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97383', 'place_name': 'Stayton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.8021, 'longitude': -122.7624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97384', 'place_name': 'Mehama', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.7903, 'longitude': -122.6187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97385', 'place_name': 'Sublimity', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.8425, 'longitude': -122.8007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97392', 'place_name': 'Turner', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Marion', 'locality_code': '47', 'latitude': 44.8476, 'longitude': -122.9501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97818', 'place_name': 'Boardman', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Morrow', 'locality_code': '49', 'latitude': 45.8272, 'longitude': -119.7206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97836', 'place_name': 'Heppner', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Morrow', 'locality_code': '49', 'latitude': 45.3486, 'longitude': -119.5369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97839', 'place_name': 'Lexington', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Morrow', 'locality_code': '49', 'latitude': 45.4264, 'longitude': -119.7464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97843', 'place_name': 'Ione', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Morrow', 'locality_code': '49', 'latitude': 45.5403, 'longitude': -119.769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97844', 'place_name': 'Irrigon', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Morrow', 'locality_code': '49', 'latitude': 45.8877, 'longitude': -119.507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97010', 'place_name': 'Bridal Veil', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.583, 'longitude': -122.1011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97019', 'place_name': 'Corbett', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5221, 'longitude': -122.2417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97024', 'place_name': 'Fairview', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5473, 'longitude': -122.4414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97030', 'place_name': 'Gresham', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5154, 'longitude': -122.4203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97060', 'place_name': 'Troutdale', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5254, 'longitude': -122.3739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97080', 'place_name': 'Gresham', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.4817, 'longitude': -122.4156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97086', 'place_name': 'Happy Valley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.4446, 'longitude': -122.5372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97201', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5078, 'longitude': -122.6897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97202', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.484, 'longitude': -122.6365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97203', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5889, 'longitude': -122.7347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97204', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5181, 'longitude': -122.6745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97205', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5207, 'longitude': -122.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97206', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.484, 'longitude': -122.5973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97207', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97208', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97209', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.527, 'longitude': -122.6854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97210', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5303, 'longitude': -122.7033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97211', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5653, 'longitude': -122.6448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97212', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5441, 'longitude': -122.6423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97213', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5373, 'longitude': -122.5987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97214', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5142, 'longitude': -122.6364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97215', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5143, 'longitude': -122.599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97216', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5137, 'longitude': -122.5569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97217', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5742, 'longitude': -122.6842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97218', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.56, 'longitude': -122.6001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97219', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.458, 'longitude': -122.7074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97220', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5411, 'longitude': -122.5566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97221', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.4918, 'longitude': -122.7267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97227', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5496, 'longitude': -122.6743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97228', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97230', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5472, 'longitude': -122.5001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97231', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.6401, 'longitude': -122.838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97232', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5287, 'longitude': -122.6363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97233', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5142, 'longitude': -122.4985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97236', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.4887, 'longitude': -122.5091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97238', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97239', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.4983, 'longitude': -122.6913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97240', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97242', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97250', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97251', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97252', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97253', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97254', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5967, 'longitude': -122.5942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97256', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97258', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97266', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.4762, 'longitude': -122.5596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97280', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97282', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97283', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97286', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97290', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97292', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97293', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97294', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97296', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Multnomah', 'locality_code': '51', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97304', 'place_name': 'Salem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Polk', 'locality_code': '53', 'latitude': 44.9588, 'longitude': -123.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97338', 'place_name': 'Dallas', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Polk', 'locality_code': '53', 'latitude': 44.9225, 'longitude': -123.32, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97344', 'place_name': 'Falls City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Polk', 'locality_code': '53', 'latitude': 44.8706, 'longitude': -123.4461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97347', 'place_name': 'Grand Ronde', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Polk', 'locality_code': '53', 'latitude': 45.075, 'longitude': -123.6335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97351', 'place_name': 'Independence', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Polk', 'locality_code': '53', 'latitude': 44.8481, 'longitude': -123.1879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97361', 'place_name': 'Monmouth', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Polk', 'locality_code': '53', 'latitude': 44.8377, 'longitude': -123.2512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97371', 'place_name': 'Rickreall', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Polk', 'locality_code': '53', 'latitude': 45.02, 'longitude': -123.2064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97029', 'place_name': 'Grass Valley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Sherman', 'locality_code': '55', 'latitude': 45.3013, 'longitude': -120.7478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97033', 'place_name': 'Kent', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Sherman', 'locality_code': '55', 'latitude': 45.0838, 'longitude': -120.6649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97039', 'place_name': 'Moro', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Sherman', 'locality_code': '55', 'latitude': 45.4853, 'longitude': -120.6957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97050', 'place_name': 'Rufus', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Sherman', 'locality_code': '55', 'latitude': 45.6948, 'longitude': -120.7359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97065', 'place_name': 'Wasco', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Sherman', 'locality_code': '55', 'latitude': 45.5974, 'longitude': -120.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97107', 'place_name': 'Bay City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.5197, 'longitude': -123.8761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97108', 'place_name': 'Beaver', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.2767, 'longitude': -123.8234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97112', 'place_name': 'Cloverdale', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.2858, 'longitude': -123.8356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97118', 'place_name': 'Garibaldi', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.5626, 'longitude': -123.9001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97122', 'place_name': 'Hebo', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.1768, 'longitude': -123.846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97130', 'place_name': 'Manzanita', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.7184, 'longitude': -123.9351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97131', 'place_name': 'Nehalem', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.7216, 'longitude': -123.9049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97134', 'place_name': 'Oceanside', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.4549, 'longitude': -123.965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97135', 'place_name': 'Pacific City', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.205, 'longitude': -123.959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97136', 'place_name': 'Rockaway Beach', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.6134, 'longitude': -123.9429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97141', 'place_name': 'Tillamook', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.4492, 'longitude': -123.8189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97143', 'place_name': 'Netarts', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.434, 'longitude': -123.9458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97147', 'place_name': 'Wheeler', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.6888, 'longitude': -123.8816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97149', 'place_name': 'Neskowin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Tillamook', 'locality_code': '57', 'latitude': 45.097, 'longitude': -123.9434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97801', 'place_name': 'Pendleton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.6605, 'longitude': -118.7831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97810', 'place_name': 'Adams', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.7674, 'longitude': -118.5625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97813', 'place_name': 'Athena', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.8289, 'longitude': -118.4971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97826', 'place_name': 'Echo', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.7411, 'longitude': -119.1949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97835', 'place_name': 'Helix', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.8665, 'longitude': -118.7222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97838', 'place_name': 'Hermiston', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.845, 'longitude': -119.2849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97859', 'place_name': 'Meacham', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.5215, 'longitude': -118.4335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97862', 'place_name': 'Milton Freewater', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.9486, 'longitude': -118.3912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97868', 'place_name': 'Pilot Rock', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.4227, 'longitude': -118.8483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97875', 'place_name': 'Stanfield', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.786, 'longitude': -119.2116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97880', 'place_name': 'Ukiah', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.0836, 'longitude': -118.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97882', 'place_name': 'Umatilla', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.8998, 'longitude': -119.3553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97886', 'place_name': 'Weston', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Umatilla', 'locality_code': '59', 'latitude': 45.8074, 'longitude': -118.3733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97824', 'place_name': 'Cove', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Union', 'locality_code': '61', 'latitude': 45.3199, 'longitude': -117.8147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97827', 'place_name': 'Elgin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Union', 'locality_code': '61', 'latitude': 45.5941, 'longitude': -117.9112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97841', 'place_name': 'Imbler', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Union', 'locality_code': '61', 'latitude': 45.4599, 'longitude': -117.9544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97850', 'place_name': 'La Grande', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Union', 'locality_code': '61', 'latitude': 45.3304, 'longitude': -118.0852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97867', 'place_name': 'North Powder', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Union', 'locality_code': '61', 'latitude': 45.0317, 'longitude': -117.9337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97876', 'place_name': 'Summerville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Union', 'locality_code': '61', 'latitude': 45.5077, 'longitude': -118.027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97883', 'place_name': 'Union', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Union', 'locality_code': '61', 'latitude': 45.2019, 'longitude': -117.8536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97828', 'place_name': 'Enterprise', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wallowa', 'locality_code': '63', 'latitude': 45.437, 'longitude': -117.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97842', 'place_name': 'Imnaha', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wallowa', 'locality_code': '63', 'latitude': 45.5137, 'longitude': -116.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97846', 'place_name': 'Joseph', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wallowa', 'locality_code': '63', 'latitude': 45.3494, 'longitude': -117.2128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97857', 'place_name': 'Lostine', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wallowa', 'locality_code': '63', 'latitude': 45.4939, 'longitude': -117.4359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97885', 'place_name': 'Wallowa', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wallowa', 'locality_code': '63', 'latitude': 45.5717, 'longitude': -117.5357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97001', 'place_name': 'Antelope', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wasco', 'locality_code': '65', 'latitude': 44.8892, 'longitude': -120.7914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97021', 'place_name': 'Dufur', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wasco', 'locality_code': '65', 'latitude': 45.3913, 'longitude': -121.1432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97037', 'place_name': 'Maupin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wasco', 'locality_code': '65', 'latitude': 45.0742, 'longitude': -121.2282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97040', 'place_name': 'Mosier', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wasco', 'locality_code': '65', 'latitude': 45.6508, 'longitude': -121.379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97057', 'place_name': 'Shaniko', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wasco', 'locality_code': '65', 'latitude': 45.0027, 'longitude': -120.75, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97058', 'place_name': 'The Dalles', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wasco', 'locality_code': '65', 'latitude': 45.5995, 'longitude': -121.1905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97063', 'place_name': 'Tygh Valley', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wasco', 'locality_code': '65', 'latitude': 45.2229, 'longitude': -121.2927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97003', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5201, 'longitude': -122.8604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97005', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4963, 'longitude': -122.8001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97006', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5201, 'longitude': -122.8604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97007', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4505, 'longitude': -122.8652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97008', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.456, 'longitude': -122.7996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97062', 'place_name': 'Tualatin', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.3727, 'longitude': -122.7631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97075', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4871, 'longitude': -122.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97076', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4871, 'longitude': -122.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97077', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4871, 'longitude': -122.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97078', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.452, 'longitude': -122.7893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97079', 'place_name': 'Beaverton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.452, 'longitude': -122.7893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97106', 'place_name': 'Banks', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.6535, 'longitude': -123.121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97109', 'place_name': 'Buxton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.737, 'longitude': -123.2146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97113', 'place_name': 'Cornelius', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.529, 'longitude': -123.0415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97116', 'place_name': 'Forest Grove', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5981, 'longitude': -123.1818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97117', 'place_name': 'Gales Creek', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5957, 'longitude': -123.234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97119', 'place_name': 'Gaston', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4427, 'longitude': -123.1666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97123', 'place_name': 'Hillsboro', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4984, 'longitude': -122.957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97124', 'place_name': 'Hillsboro', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5387, 'longitude': -122.9636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97125', 'place_name': 'Manning', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.6648, 'longitude': -123.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97129', 'place_name': 'Hillsboro', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5387, 'longitude': -122.9636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97133', 'place_name': 'North Plains', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.6686, 'longitude': -123.0281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97140', 'place_name': 'Sherwood', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.3514, 'longitude': -122.8567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97144', 'place_name': 'Timber', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.727, 'longitude': -123.3119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97223', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4403, 'longitude': -122.7793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97224', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4094, 'longitude': -122.8014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97225', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.4985, 'longitude': -122.7787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97229', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5483, 'longitude': -122.8276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97281', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97291', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97298', 'place_name': 'Portland', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Washington', 'locality_code': '67', 'latitude': 45.5235, 'longitude': -122.6762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97750', 'place_name': 'Mitchell', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wheeler', 'locality_code': '69', 'latitude': 44.5657, 'longitude': -120.1456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97830', 'place_name': 'Fossil', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wheeler', 'locality_code': '69', 'latitude': 44.9286, 'longitude': -120.1309, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '97874', 'place_name': 'Spray', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Wheeler', 'locality_code': '69', 'latitude': 44.8242, 'longitude': -119.8303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97101', 'place_name': 'Amity', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.1157, 'longitude': -123.1744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97111', 'place_name': 'Carlton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.2859, 'longitude': -123.1523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97114', 'place_name': 'Dayton', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.1977, 'longitude': -123.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97115', 'place_name': 'Dundee', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.2776, 'longitude': -123.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97127', 'place_name': 'Lafayette', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.2466, 'longitude': -123.1114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97128', 'place_name': 'Mcminnville', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.2097, 'longitude': -123.2043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97132', 'place_name': 'Newberg', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.3099, 'longitude': -122.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97148', 'place_name': 'Yamhill', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.335, 'longitude': -123.2036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97378', 'place_name': 'Sheridan', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.0897, 'longitude': -123.4003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '97396', 'place_name': 'Willamina', 'state': 'Oregon', 'state_ab': 'OR', 'county': 'Yamhill', 'locality_code': '71', 'latitude': 45.0826, 'longitude': -123.5047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17301', 'place_name': 'Abbottstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8881, 'longitude': -76.9931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17303', 'place_name': 'Arendtsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9236, 'longitude': -77.3001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17304', 'place_name': 'Aspers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9765, 'longitude': -77.2287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17306', 'place_name': 'Bendersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9792, 'longitude': -77.2496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17307', 'place_name': 'Biglerville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9281, 'longitude': -77.2885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17310', 'place_name': 'Cashtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8906, 'longitude': -77.3566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17316', 'place_name': 'East Berlin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.9645, 'longitude': -77.0073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17320', 'place_name': 'Fairfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7808, 'longitude': -77.3619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17324', 'place_name': 'Gardners', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0428, 'longitude': -77.1877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17325', 'place_name': 'Gettysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.832, 'longitude': -77.2223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17337', 'place_name': 'Idaville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0157, 'longitude': -77.2001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17340', 'place_name': 'Littlestown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.7495, 'longitude': -77.1003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17343', 'place_name': 'Mc Knightstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8692, 'longitude': -77.3292, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17344', 'place_name': 'Mc Sherrystown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.801, 'longitude': -77.0229, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17350', 'place_name': 'New Oxford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8775, 'longitude': -77.0643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17353', 'place_name': 'Orrtanna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.881, 'longitude': -77.3806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17372', 'place_name': 'York Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 40.0084, 'longitude': -77.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17375', 'place_name': 'Peach Glen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Adams', 'locality_code': '1', 'latitude': 39.8948, 'longitude': -77.2135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15006', 'place_name': 'Bairdford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6312, 'longitude': -79.8814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15007', 'place_name': 'Bakerstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6478, 'longitude': -79.931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15014', 'place_name': 'Brackenridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6082, 'longitude': -79.7414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15015', 'place_name': 'Bradfordwoods', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6372, 'longitude': -80.0811, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15017', 'place_name': 'Bridgeville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3472, 'longitude': -80.1153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15018', 'place_name': 'Buena Vista', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.2773, 'longitude': -79.7992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15020', 'place_name': 'Bunola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.2373, 'longitude': -79.9506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15024', 'place_name': 'Cheswick', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5681, 'longitude': -79.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15025', 'place_name': 'Clairton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3243, 'longitude': -79.9317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15026', 'place_name': 'Clinton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5131, 'longitude': -80.3423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15028', 'place_name': 'Coulters', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15030', 'place_name': 'Creighton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5821, 'longitude': -79.7818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15031', 'place_name': 'Cuddy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3547, 'longitude': -80.1669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15032', 'place_name': 'Curtisville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6423, 'longitude': -79.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15034', 'place_name': 'Dravosburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3527, 'longitude': -79.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15035', 'place_name': 'East Mc Keesport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3839, 'longitude': -79.8079, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15037', 'place_name': 'Elizabeth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.2656, 'longitude': -79.8568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15044', 'place_name': 'Gibsonia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6252, 'longitude': -79.9443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15045', 'place_name': 'Glassport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.326, 'longitude': -79.8883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15046', 'place_name': 'Crescent', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5563, 'longitude': -80.2286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15047', 'place_name': 'Greenock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3123, 'longitude': -79.8067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15049', 'place_name': 'Harwick', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5574, 'longitude': -79.8051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15051', 'place_name': 'Indianola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5695, 'longitude': -79.8637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15056', 'place_name': 'Leetsdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5662, 'longitude': -80.2099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15064', 'place_name': 'Morgan', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3542, 'longitude': -80.1398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15065', 'place_name': 'Natrona Heights', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6421, 'longitude': -79.7273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15071', 'place_name': 'Oakdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4033, 'longitude': -80.1842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15075', 'place_name': 'Rural Ridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5856, 'longitude': -79.8287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15076', 'place_name': 'Russellton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6073, 'longitude': -79.8347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15082', 'place_name': 'Sturgeon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3863, 'longitude': -80.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15084', 'place_name': 'Tarentum', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6187, 'longitude': -79.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15086', 'place_name': 'Warrendale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6534, 'longitude': -80.0795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15088', 'place_name': 'West Elizabeth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.2716, 'longitude': -79.8966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15090', 'place_name': 'Wexford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.612, 'longitude': -80.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15091', 'place_name': 'Wildwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5942, 'longitude': -79.9701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15095', 'place_name': 'Warrendale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6534, 'longitude': -80.0795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15096', 'place_name': 'Warrendale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.6534, 'longitude': -80.0795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15101', 'place_name': 'Allison Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.57, 'longitude': -79.9665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15102', 'place_name': 'Bethel Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.321, 'longitude': -80.0398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15104', 'place_name': 'Braddock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4038, 'longitude': -79.8625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15106', 'place_name': 'Carnegie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4029, 'longitude': -80.0915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15108', 'place_name': 'Coraopolis', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5, 'longitude': -80.1996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15110', 'place_name': 'Duquesne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3704, 'longitude': -79.8522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15112', 'place_name': 'East Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4036, 'longitude': -79.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15116', 'place_name': 'Glenshaw', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5375, 'longitude': -79.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15120', 'place_name': 'Homestead', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3926, 'longitude': -79.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15122', 'place_name': 'West Mifflin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3634, 'longitude': -79.8664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15123', 'place_name': 'West Mifflin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15126', 'place_name': 'Imperial', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4584, 'longitude': -80.2649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15127', 'place_name': 'Ingomar', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5809, 'longitude': -80.0609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15129', 'place_name': 'South Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.2932, 'longitude': -79.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15131', 'place_name': 'Mckeesport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3478, 'longitude': -79.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15132', 'place_name': 'Mckeesport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3478, 'longitude': -79.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15133', 'place_name': 'Mckeesport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3478, 'longitude': -79.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15134', 'place_name': 'Mckeesport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3478, 'longitude': -79.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15135', 'place_name': 'Mckeesport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3478, 'longitude': -79.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15136', 'place_name': 'Mc Kees Rocks', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4717, 'longitude': -80.0876, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15137', 'place_name': 'North Versailles', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3762, 'longitude': -79.8124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15139', 'place_name': 'Oakmont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5196, 'longitude': -79.8369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15140', 'place_name': 'Pitcairn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4048, 'longitude': -79.777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15142', 'place_name': 'Presto', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3847, 'longitude': -80.1209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15143', 'place_name': 'Sewickley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.557, 'longitude': -80.1578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15144', 'place_name': 'Springdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.544, 'longitude': -79.7844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15145', 'place_name': 'Turtle Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4113, 'longitude': -79.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15146', 'place_name': 'Monroeville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.429, 'longitude': -79.7623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15147', 'place_name': 'Verona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4927, 'longitude': -79.8345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15148', 'place_name': 'Wilmerding', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3934, 'longitude': -79.7951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15201', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4752, 'longitude': -79.9528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15202', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5053, 'longitude': -80.0685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15203', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4254, 'longitude': -79.9799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15204', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4554, 'longitude': -80.0644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15205', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4322, 'longitude': -80.1021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15206', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4723, 'longitude': -79.9132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15207', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4003, 'longitude': -79.9338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15208', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4532, 'longitude': -79.8995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15209', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4999, 'longitude': -79.9739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15210', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4072, 'longitude': -79.9839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15211', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4295, 'longitude': -80.0144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15212', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4406, 'longitude': -79.9959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15213', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.444, 'longitude': -79.9552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15214', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4865, 'longitude': -80.014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15215', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5048, 'longitude': -79.9138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15216', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4001, 'longitude': -80.0462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15217', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4308, 'longitude': -79.9205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15218', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4237, 'longitude': -79.89, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15219', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4423, 'longitude': -79.983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15220', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4181, 'longitude': -80.0526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15221', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4346, 'longitude': -79.8655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15222', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4477, 'longitude': -79.9933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15223', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5051, 'longitude': -79.9528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15224', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4642, 'longitude': -79.9448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15225', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5051, 'longitude': -80.1155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15226', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4001, 'longitude': -80.0161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15227', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3805, 'longitude': -79.9667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15228', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3696, 'longitude': -80.0439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15229', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5203, 'longitude': -80.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15230', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15231', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4961, 'longitude': -80.2466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15232', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4525, 'longitude': -79.9319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15233', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4608, 'longitude': -80.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15234', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3688, 'longitude': -80.0224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15235', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4598, 'longitude': -79.8224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15236', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3351, 'longitude': -79.9832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15237', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5488, 'longitude': -80.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15238', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.5346, 'longitude': -79.8805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15239', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4837, 'longitude': -79.7381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15240', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15241', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3323, 'longitude': -80.081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15242', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15243', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.3748, 'longitude': -80.0731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15244', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15250', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15251', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15252', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15253', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15254', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15255', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15257', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15258', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15259', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15260', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4432, 'longitude': -79.9531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15261', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15262', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15264', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15265', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15267', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15268', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15270', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15272', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15274', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15275', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4495, 'longitude': -80.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15276', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15277', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15278', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15279', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15281', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15282', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4406, 'longitude': -79.9959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15283', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15286', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15289', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4446, 'longitude': -79.9451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15290', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.4344, 'longitude': -80.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15295', 'place_name': 'Pittsburgh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Allegheny', 'locality_code': '3', 'latitude': 40.463, 'longitude': -80.0108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15656', 'place_name': 'Leechburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.6344, 'longitude': -79.6201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15673', 'place_name': 'North Apollo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.593, 'longitude': -79.5581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15682', 'place_name': 'Schenley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.6845, 'longitude': -79.6617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15686', 'place_name': 'Spring Church', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.6153, 'longitude': -79.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15736', 'place_name': 'Elderton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.6922, 'longitude': -79.3422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15774', 'place_name': 'Shelocta', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.6388, 'longitude': -79.3191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16049', 'place_name': 'Parker', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 41.1009, 'longitude': -79.6889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16201', 'place_name': 'Kittanning', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.8155, 'longitude': -79.5107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16210', 'place_name': 'Adrian', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.9049, 'longitude': -79.5074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16212', 'place_name': 'Cadogan', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7539, 'longitude': -79.5798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16218', 'place_name': 'Cowansville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.923, 'longitude': -79.5946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16222', 'place_name': 'Dayton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.8741, 'longitude': -79.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16223', 'place_name': 'Distant', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.9695, 'longitude': -79.3567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16226', 'place_name': 'Ford City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7384, 'longitude': -79.5122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16228', 'place_name': 'Ford Cliff', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7608, 'longitude': -79.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16229', 'place_name': 'Freeport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7033, 'longitude': -79.663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16236', 'place_name': 'Mc Grann', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7818, 'longitude': -79.5218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16238', 'place_name': 'Manorville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7863, 'longitude': -79.5213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16244', 'place_name': 'Nu Mine', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.8478, 'longitude': -79.4516, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16245', 'place_name': 'Oak Ridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 41.0076, 'longitude': -79.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16249', 'place_name': 'Rural Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7885, 'longitude': -79.2991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16250', 'place_name': 'Sagamore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.7774, 'longitude': -79.2336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16253', 'place_name': 'Seminole', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.9548, 'longitude': -79.3428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16259', 'place_name': 'Templeton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.9419, 'longitude': -79.4499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16261', 'place_name': 'Widnoon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.9612, 'longitude': -79.4673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16262', 'place_name': 'Worthington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.8378, 'longitude': -79.6298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16263', 'place_name': 'Yatesboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Armstrong', 'locality_code': '5', 'latitude': 40.8001, 'longitude': -79.3342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15001', 'place_name': 'Aliquippa', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.5921, 'longitude': -80.3197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15003', 'place_name': 'Ambridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.6005, 'longitude': -80.2105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15005', 'place_name': 'Baden', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.6416, 'longitude': -80.1985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15009', 'place_name': 'Beaver', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.6972, 'longitude': -80.3365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15010', 'place_name': 'Beaver Falls', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.7687, 'longitude': -80.3592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15027', 'place_name': 'Conway', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.6649, 'longitude': -80.2349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15042', 'place_name': 'Freedom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.683, 'longitude': -80.2147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15043', 'place_name': 'Georgetown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.5743, 'longitude': -80.49, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15050', 'place_name': 'Hookstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.5622, 'longitude': -80.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15052', 'place_name': 'Industry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.6671, 'longitude': -80.4151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15059', 'place_name': 'Midland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.6793, 'longitude': -80.4908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15061', 'place_name': 'Monaca', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.6718, 'longitude': -80.2917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15066', 'place_name': 'New Brighton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.7393, 'longitude': -80.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15074', 'place_name': 'Rochester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.7157, 'longitude': -80.2603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15077', 'place_name': 'Shippingport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.632, 'longitude': -80.414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15081', 'place_name': 'South Heights', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.5763, 'longitude': -80.2383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16115', 'place_name': 'Darlington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.7968, 'longitude': -80.4556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16123', 'place_name': 'Fombell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.8125, 'longitude': -80.2073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16136', 'place_name': 'Koppel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.8348, 'longitude': -80.328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16141', 'place_name': 'New Galilee', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Beaver', 'locality_code': '7', 'latitude': 40.8569, 'longitude': -80.3939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15521', 'place_name': 'Alum Bank', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1858, 'longitude': -78.6206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15522', 'place_name': 'Bedford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 39.9908, 'longitude': -78.5261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15533', 'place_name': 'Breezewood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 39.9905, 'longitude': -78.2453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15534', 'place_name': 'Buffalo Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 39.922, 'longitude': -78.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15535', 'place_name': 'Clearville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 39.8533, 'longitude': -78.4392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15537', 'place_name': 'Everett', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.0098, 'longitude': -78.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15539', 'place_name': 'Fishertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1217, 'longitude': -78.5856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15545', 'place_name': 'Hyndman', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 39.8049, 'longitude': -78.7335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15550', 'place_name': 'Manns Choice', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 39.9808, 'longitude': -78.6423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15554', 'place_name': 'New Paris', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1254, 'longitude': -78.6184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15559', 'place_name': 'Schellsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.0487, 'longitude': -78.6482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16633', 'place_name': 'Defiance', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1601, 'longitude': -78.2346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16650', 'place_name': 'Hopewell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1192, 'longitude': -78.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16655', 'place_name': 'Imler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.2067, 'longitude': -78.5228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16659', 'place_name': 'Loysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1609, 'longitude': -78.375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16664', 'place_name': 'New Enterprise', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.2, 'longitude': -78.4259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16667', 'place_name': 'Osterburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1695, 'longitude': -78.5203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16670', 'place_name': 'Queen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.2592, 'longitude': -78.5075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16672', 'place_name': 'Riddlesburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.162, 'longitude': -78.2545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16678', 'place_name': 'Saxton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.2233, 'longitude': -78.2471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16679', 'place_name': 'Six Mile Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.1576, 'longitude': -78.2108, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16694', 'place_name': 'Wood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.166, 'longitude': -78.1381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16695', 'place_name': 'Woodbury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 40.2185, 'longitude': -78.3666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17211', 'place_name': 'Artemas', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bedford', 'locality_code': '9', 'latitude': 39.7575, 'longitude': -78.4031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18056', 'place_name': 'Hereford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4491, 'longitude': -75.5491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19503', 'place_name': 'Bally', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.405, 'longitude': -75.5769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19504', 'place_name': 'Barto', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3815, 'longitude': -75.5749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19505', 'place_name': 'Bechtelsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3795, 'longitude': -75.6257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19506', 'place_name': 'Bernville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4551, 'longitude': -76.1247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19507', 'place_name': 'Bethel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4808, 'longitude': -76.2742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19508', 'place_name': 'Birdsboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.2563, 'longitude': -75.8344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19510', 'place_name': 'Blandon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4435, 'longitude': -75.8837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19511', 'place_name': 'Bowers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4821, 'longitude': -75.7435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19512', 'place_name': 'Boyertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3339, 'longitude': -75.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19516', 'place_name': 'Centerport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4858, 'longitude': -76.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19518', 'place_name': 'Douglassville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.2709, 'longitude': -75.7397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19519', 'place_name': 'Earlville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.319, 'longitude': -75.7334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19522', 'place_name': 'Fleetwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4473, 'longitude': -75.8185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19523', 'place_name': 'Geigertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.2026, 'longitude': -75.8363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19526', 'place_name': 'Hamburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.5488, 'longitude': -75.9874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19529', 'place_name': 'Kempton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.6328, 'longitude': -75.8513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19530', 'place_name': 'Kutztown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.5214, 'longitude': -75.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19533', 'place_name': 'Leesport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4152, 'longitude': -75.9944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19534', 'place_name': 'Lenhartsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.5736, 'longitude': -75.865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19535', 'place_name': 'Limekiln', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3356, 'longitude': -75.801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19536', 'place_name': 'Lyon Station', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.5218, 'longitude': -75.7419, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19538', 'place_name': 'Maxatawny', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.5426, 'longitude': -75.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19539', 'place_name': 'Mertztown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4992, 'longitude': -75.6872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19540', 'place_name': 'Mohnton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.2584, 'longitude': -75.9833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19541', 'place_name': 'Mohrsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4783, 'longitude': -76.0125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19543', 'place_name': 'Morgantown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.1552, 'longitude': -75.8998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19544', 'place_name': 'Mount Aetna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4187, 'longitude': -76.2944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19545', 'place_name': 'New Berlinville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3397, 'longitude': -75.6302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19547', 'place_name': 'Oley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3833, 'longitude': -75.7706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19548', 'place_name': 'Pine Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.2829, 'longitude': -75.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19550', 'place_name': 'Rehrersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4553, 'longitude': -76.2453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19551', 'place_name': 'Robesonia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3553, 'longitude': -76.1366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19554', 'place_name': 'Shartlesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.5129, 'longitude': -76.1044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19555', 'place_name': 'Shoemakersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4955, 'longitude': -75.9603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19559', 'place_name': 'Strausstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4945, 'longitude': -76.1825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19560', 'place_name': 'Temple', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4025, 'longitude': -75.9046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19562', 'place_name': 'Topton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.5029, 'longitude': -75.7015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19564', 'place_name': 'Virginville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.524, 'longitude': -75.873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19565', 'place_name': 'Wernersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3293, 'longitude': -76.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19567', 'place_name': 'Womelsdorf', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3743, 'longitude': -76.1985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19601', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3466, 'longitude': -75.9351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19602', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3306, 'longitude': -75.9192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19603', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3884, 'longitude': -75.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19604', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3507, 'longitude': -75.9143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19605', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3886, 'longitude': -75.9328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19606', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3351, 'longitude': -75.875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19607', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.2995, 'longitude': -75.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19608', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.3113, 'longitude': -76.0345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19609', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.328, 'longitude': -75.9908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19610', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.338, 'longitude': -75.978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19611', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.325, 'longitude': -75.9442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19612', 'place_name': 'Reading', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Berks', 'locality_code': '11', 'latitude': 40.4389, 'longitude': -75.8853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16601', 'place_name': 'Altoona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.5209, 'longitude': -78.4089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16602', 'place_name': 'Altoona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.5052, 'longitude': -78.3905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16603', 'place_name': 'Altoona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.5018, 'longitude': -78.41, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16617', 'place_name': 'Bellwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.6039, 'longitude': -78.3372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16625', 'place_name': 'Claysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.2821, 'longitude': -78.5083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16631', 'place_name': 'Curryville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.2759, 'longitude': -78.3383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16635', 'place_name': 'Duncansville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.4262, 'longitude': -78.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16637', 'place_name': 'East Freedom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.3282, 'longitude': -78.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16648', 'place_name': 'Hollidaysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.4387, 'longitude': -78.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16662', 'place_name': 'Martinsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.2951, 'longitude': -78.3244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16665', 'place_name': 'Newry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.3937, 'longitude': -78.4356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16673', 'place_name': 'Roaring Spring', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.3277, 'longitude': -78.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16682', 'place_name': 'Sproul', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.2711, 'longitude': -78.4588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16684', 'place_name': 'Tipton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.6367, 'longitude': -78.3036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16686', 'place_name': 'Tyrone', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.6619, 'longitude': -78.2419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16693', 'place_name': 'Williamsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Blair', 'locality_code': '13', 'latitude': 40.4025, 'longitude': -78.2558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16910', 'place_name': 'Alba', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7051, 'longitude': -76.8283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16914', 'place_name': 'Columbia Cross Roads', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.8638, 'longitude': -76.7825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16925', 'place_name': 'Gillett', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.9568, 'longitude': -76.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16926', 'place_name': 'Granville Summit', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.6973, 'longitude': -76.7218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16945', 'place_name': 'Sylvania', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.8051, 'longitude': -76.8569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16947', 'place_name': 'Troy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7781, 'longitude': -76.7711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17724', 'place_name': 'Canton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.6538, 'longitude': -76.8582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17735', 'place_name': 'Grover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.6145, 'longitude': -76.8672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18810', 'place_name': 'Athens', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.949, 'longitude': -76.4889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18814', 'place_name': 'Burlington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7817, 'longitude': -76.6056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18815', 'place_name': 'Camptown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7312, 'longitude': -76.2347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18817', 'place_name': 'East Smithfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.8645, 'longitude': -76.6255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18829', 'place_name': 'Le Raysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.8434, 'longitude': -76.1796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18831', 'place_name': 'Milan', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.8966, 'longitude': -76.5328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18832', 'place_name': 'Monroeton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7135, 'longitude': -76.4872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18833', 'place_name': 'New Albany', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.5987, 'longitude': -76.4398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18837', 'place_name': 'Rome', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.8634, 'longitude': -76.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18840', 'place_name': 'Sayre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.9842, 'longitude': -76.5218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18845', 'place_name': 'Stevensville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7718, 'longitude': -76.1717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18846', 'place_name': 'Sugar Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.6041, 'longitude': -76.2598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18848', 'place_name': 'Towanda', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7638, 'longitude': -76.4645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18850', 'place_name': 'Ulster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.8408, 'longitude': -76.4876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18851', 'place_name': 'Warren Center', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.9394, 'longitude': -76.1964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18853', 'place_name': 'Wyalusing', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7015, 'longitude': -76.2754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18854', 'place_name': 'Wysox', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bradford', 'locality_code': '15', 'latitude': 41.7826, 'longitude': -76.3834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18039', 'place_name': 'Durham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.5757, 'longitude': -75.2232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18077', 'place_name': 'Riegelsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.5782, 'longitude': -75.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18081', 'place_name': 'Springtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.5565, 'longitude': -75.2893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18901', 'place_name': 'Doylestown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3054, 'longitude': -75.1489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18902', 'place_name': 'Doylestown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3477, 'longitude': -75.0968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18910', 'place_name': 'Bedminster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4259, 'longitude': -75.1791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18911', 'place_name': 'Blooming Glen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3695, 'longitude': -75.2482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18912', 'place_name': 'Buckingham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3237, 'longitude': -75.0599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18913', 'place_name': 'Carversville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3865, 'longitude': -75.0627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18914', 'place_name': 'Chalfont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2892, 'longitude': -75.2149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18916', 'place_name': 'Danboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3545, 'longitude': -75.1327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18917', 'place_name': 'Dublin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.375, 'longitude': -75.2045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18920', 'place_name': 'Erwinna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.5087, 'longitude': -75.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18921', 'place_name': 'Ferndale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.5337, 'longitude': -75.1788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18922', 'place_name': 'Forest Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2923, 'longitude': -75.0591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18923', 'place_name': 'Fountainville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3578, 'longitude': -75.1711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18925', 'place_name': 'Furlong', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2945, 'longitude': -75.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18927', 'place_name': 'Hilltown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3235, 'longitude': -75.2548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18928', 'place_name': 'Holicong', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.336, 'longitude': -75.0429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18929', 'place_name': 'Jamison', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2566, 'longitude': -75.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18930', 'place_name': 'Kintnersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.531, 'longitude': -75.2117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18931', 'place_name': 'Lahaska', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3286, 'longitude': -75.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18932', 'place_name': 'Line Lexington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2888, 'longitude': -75.2555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18933', 'place_name': 'Lumberville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3286, 'longitude': -75.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18934', 'place_name': 'Mechanicsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3494, 'longitude': -75.0676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18935', 'place_name': 'Milford Square', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.437, 'longitude': -75.3988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18938', 'place_name': 'New Hope', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3556, 'longitude': -74.9839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18940', 'place_name': 'Newtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.263, 'longitude': -74.9555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18942', 'place_name': 'Ottsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4592, 'longitude': -75.157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18943', 'place_name': 'Penns Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.269, 'longitude': -75.0094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18944', 'place_name': 'Perkasie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3765, 'longitude': -75.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18946', 'place_name': 'Pineville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2962, 'longitude': -75.0057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18947', 'place_name': 'Pipersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4262, 'longitude': -75.1074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18949', 'place_name': 'Plumsteadville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.388, 'longitude': -75.1425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18950', 'place_name': 'Point Pleasant', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4226, 'longitude': -75.0663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18951', 'place_name': 'Quakertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4411, 'longitude': -75.3507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18953', 'place_name': 'Revere', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.5154, 'longitude': -75.161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18954', 'place_name': 'Richboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2167, 'longitude': -75.0029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18955', 'place_name': 'Richlandtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4796, 'longitude': -75.3146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18956', 'place_name': 'Rushland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2628, 'longitude': -75.0157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18960', 'place_name': 'Sellersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.362, 'longitude': -75.319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18962', 'place_name': 'Silverdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3445, 'longitude': -75.2687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18963', 'place_name': 'Solebury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3807, 'longitude': -75.0082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18966', 'place_name': 'Southampton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1868, 'longitude': -75.0071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18968', 'place_name': 'Spinnerstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.439, 'longitude': -75.4371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18970', 'place_name': 'Trumbauersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4107, 'longitude': -75.3782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18972', 'place_name': 'Upper Black Eddy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.5411, 'longitude': -75.1259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18974', 'place_name': 'Warminster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2067, 'longitude': -75.0905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18976', 'place_name': 'Warrington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2464, 'longitude': -75.1354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18977', 'place_name': 'Washington Crossing', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2849, 'longitude': -74.8778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18980', 'place_name': 'Wycombe', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2742, 'longitude': -75.0205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18981', 'place_name': 'Zionhill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.4843, 'longitude': -75.3938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18991', 'place_name': 'Warminster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.3286, 'longitude': -75.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19007', 'place_name': 'Bristol', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1159, 'longitude': -74.8536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19020', 'place_name': 'Bensalem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1109, 'longitude': -74.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19021', 'place_name': 'Croydon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.0933, 'longitude': -74.8991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19030', 'place_name': 'Fairless Hills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1748, 'longitude': -74.8519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19047', 'place_name': 'Langhorne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1813, 'longitude': -74.9104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19048', 'place_name': 'Langhorne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1735, 'longitude': -74.9246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19049', 'place_name': 'Langhorne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1746, 'longitude': -74.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19053', 'place_name': 'Feasterville Trevose', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1547, 'longitude': -74.9904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19054', 'place_name': 'Levittown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1681, 'longitude': -74.8231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19055', 'place_name': 'Levittown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1483, 'longitude': -74.8371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19056', 'place_name': 'Levittown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1519, 'longitude': -74.8826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19057', 'place_name': 'Levittown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1434, 'longitude': -74.8614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19058', 'place_name': 'Levittown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.1551, 'longitude': -74.8288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19067', 'place_name': 'Morrisville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Bucks', 'locality_code': '17', 'latitude': 40.2084, 'longitude': -74.8291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16001', 'place_name': 'Butler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8859, 'longitude': -79.934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16002', 'place_name': 'Butler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8409, 'longitude': -79.8592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16003', 'place_name': 'Butler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8612, 'longitude': -79.8953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16016', 'place_name': 'Boyers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.1084, 'longitude': -79.8989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16017', 'place_name': 'Boyers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.9211, 'longitude': -79.9276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16018', 'place_name': 'Boyers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.9211, 'longitude': -79.9276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16020', 'place_name': 'Boyers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.1092, 'longitude': -79.9047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16021', 'place_name': 'Branchton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.0726, 'longitude': -79.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16022', 'place_name': 'Bruin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.0571, 'longitude': -79.7291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16023', 'place_name': 'Cabot', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7924, 'longitude': -79.76, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16024', 'place_name': 'Callery', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7406, 'longitude': -80.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16025', 'place_name': 'Chicora', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.9458, 'longitude': -79.7462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16027', 'place_name': 'Connoquenessing', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8178, 'longitude': -80.0142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16029', 'place_name': 'East Butler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8778, 'longitude': -79.8464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16030', 'place_name': 'Eau Claire', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.1348, 'longitude': -79.7981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16033', 'place_name': 'Evans City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7808, 'longitude': -80.0592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16034', 'place_name': 'Fenelton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8555, 'longitude': -79.7372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16035', 'place_name': 'Forestville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.1068, 'longitude': -80.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16037', 'place_name': 'Harmony', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8496, 'longitude': -80.1381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16038', 'place_name': 'Harrisville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.1631, 'longitude': -79.9796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16039', 'place_name': 'Herman', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8301, 'longitude': -79.8112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16040', 'place_name': 'Hilliards', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.1009, 'longitude': -79.8215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16041', 'place_name': 'Karns City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.0022, 'longitude': -79.716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16045', 'place_name': 'Lyndora', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.8528, 'longitude': -79.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16046', 'place_name': 'Mars', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7005, 'longitude': -80.0358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16048', 'place_name': 'North Washington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.0472, 'longitude': -79.8089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16050', 'place_name': 'Petrolia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.0442, 'longitude': -79.7711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16051', 'place_name': 'Portersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.9468, 'longitude': -80.139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16052', 'place_name': 'Prospect', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.9049, 'longitude': -80.0679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16053', 'place_name': 'Renfrew', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.81, 'longitude': -79.977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16055', 'place_name': 'Sarver', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7143, 'longitude': -79.7424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16056', 'place_name': 'Saxonburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7361, 'longitude': -79.8352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16057', 'place_name': 'Slippery Rock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.0454, 'longitude': -80.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16059', 'place_name': 'Valencia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7018, 'longitude': -79.9235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16061', 'place_name': 'West Sunbury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 41.0026, 'longitude': -79.8751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16063', 'place_name': 'Zelienople', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.7609, 'longitude': -80.1094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16066', 'place_name': 'Cranberry Township', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Butler', 'locality_code': '19', 'latitude': 40.685, 'longitude': -80.1071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15714', 'place_name': 'Northern Cambria', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6661, 'longitude': -78.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15722', 'place_name': 'Carrolltown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.5891, 'longitude': -78.7037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15737', 'place_name': 'Elmora', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6076, 'longitude': -78.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15738', 'place_name': 'Emeigh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6948, 'longitude': -78.787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15760', 'place_name': 'Marsteller', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6522, 'longitude': -78.8054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15762', 'place_name': 'Nicktown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6016, 'longitude': -78.8114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15773', 'place_name': 'Saint Benedict', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6298, 'longitude': -78.7329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15775', 'place_name': 'Spangler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6351, 'longitude': -78.7692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15901', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.326, 'longitude': -78.9141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15902', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3078, 'longitude': -78.8969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15904', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.285, 'longitude': -78.8654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15905', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3072, 'longitude': -78.943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15906', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3522, 'longitude': -78.9383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15907', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3254, 'longitude': -78.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15909', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4096, 'longitude': -78.8712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15915', 'place_name': 'Johnstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3267, 'longitude': -78.922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15921', 'place_name': 'Beaverdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3173, 'longitude': -78.7009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15922', 'place_name': 'Belsano', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.5176, 'longitude': -78.8767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15925', 'place_name': 'Cassandra', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4085, 'longitude': -78.6407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15927', 'place_name': 'Colver', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.5383, 'longitude': -78.7865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15930', 'place_name': 'Dunlo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.2939, 'longitude': -78.7192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15931', 'place_name': 'Ebensburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4801, 'longitude': -78.7263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15934', 'place_name': 'Elton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.2799, 'longitude': -78.8032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15938', 'place_name': 'Lilly', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4238, 'longitude': -78.6231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15940', 'place_name': 'Loretto', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.5105, 'longitude': -78.6294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15942', 'place_name': 'Mineral Point', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3793, 'longitude': -78.8352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15943', 'place_name': 'Nanty Glo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4704, 'longitude': -78.8375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15945', 'place_name': 'Parkhill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3612, 'longitude': -78.8709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15946', 'place_name': 'Portage', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3724, 'longitude': -78.6328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15948', 'place_name': 'Revloc', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.49, 'longitude': -78.7646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15951', 'place_name': 'Saint Michael', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.337, 'longitude': -78.7709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15952', 'place_name': 'Salix', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.2986, 'longitude': -78.7816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15955', 'place_name': 'Sidman', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3299, 'longitude': -78.746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15956', 'place_name': 'South Fork', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3629, 'longitude': -78.7887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15958', 'place_name': 'Summerhill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.389, 'longitude': -78.756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15960', 'place_name': 'Twin Rocks', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4967, 'longitude': -78.8659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15961', 'place_name': 'Vintondale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4939, 'longitude': -78.9427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15962', 'place_name': 'Wilmore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.3887, 'longitude': -78.7186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16613', 'place_name': 'Ashville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.5513, 'longitude': -78.5346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16619', 'place_name': 'Blandburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6847, 'longitude': -78.4137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16624', 'place_name': 'Chest Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.5702, 'longitude': -78.5991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16629', 'place_name': 'Coupon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.5218, 'longitude': -78.5263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16630', 'place_name': 'Cresson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4608, 'longitude': -78.5861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16636', 'place_name': 'Dysart', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6088, 'longitude': -78.5271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16639', 'place_name': 'Fallentimber', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6867, 'longitude': -78.4992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16640', 'place_name': 'Flinton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6876, 'longitude': -78.5523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16641', 'place_name': 'Gallitzin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4823, 'longitude': -78.5517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16644', 'place_name': 'Glasgow', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.7178, 'longitude': -78.4637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16646', 'place_name': 'Hastings', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6659, 'longitude': -78.7029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16668', 'place_name': 'Patton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.623, 'longitude': -78.635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16675', 'place_name': 'Saint Boniface', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.6712, 'longitude': -78.6755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16699', 'place_name': 'Cresson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cambria', 'locality_code': '21', 'latitude': 40.4845, 'longitude': -78.7022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15832', 'place_name': 'Driftwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cameron', 'locality_code': '23', 'latitude': 41.3764, 'longitude': -78.1632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15834', 'place_name': 'Emporium', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cameron', 'locality_code': '23', 'latitude': 41.5177, 'longitude': -78.2536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15861', 'place_name': 'Sinnamahoning', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cameron', 'locality_code': '23', 'latitude': 41.3762, 'longitude': -78.0661, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18012', 'place_name': 'Aquashicola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.8133, 'longitude': -75.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18030', 'place_name': 'Bowmanstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.8011, 'longitude': -75.6614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18071', 'place_name': 'Palmerton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.817, 'longitude': -75.6011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18210', 'place_name': 'Albrightsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.9748, 'longitude': -75.5842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18212', 'place_name': 'Ashfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.7841, 'longitude': -75.7083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18216', 'place_name': 'Beaver Meadows', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.9281, 'longitude': -75.9146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18229', 'place_name': 'Jim Thorpe', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.87, 'longitude': -75.7397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18230', 'place_name': 'Junedale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.9234, 'longitude': -75.9416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18232', 'place_name': 'Lansford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.8314, 'longitude': -75.8828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18235', 'place_name': 'Lehighton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.8299, 'longitude': -75.6974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18240', 'place_name': 'Nesquehoning', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.8626, 'longitude': -75.8239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18244', 'place_name': 'Parryville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.8181, 'longitude': -75.6727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18250', 'place_name': 'Summit Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.8255, 'longitude': -75.8693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18254', 'place_name': 'Tresckow', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.9159, 'longitude': -75.9657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18255', 'place_name': 'Weatherly', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 40.9411, 'longitude': -75.8306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18624', 'place_name': 'Lake Harmony', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Carbon', 'locality_code': '25', 'latitude': 41.0542, 'longitude': -75.6331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16677', 'place_name': 'Sandy Ridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8136, 'longitude': -78.239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16801', 'place_name': 'State College', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.7925, 'longitude': -77.8523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16802', 'place_name': 'University Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.7997, 'longitude': -77.8623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16803', 'place_name': 'State College', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8082, 'longitude': -77.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16804', 'place_name': 'State College', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.7934, 'longitude': -77.86, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16805', 'place_name': 'State College', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.7934, 'longitude': -77.86, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16820', 'place_name': 'Aaronsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8987, 'longitude': -77.4562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16823', 'place_name': 'Bellefonte', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8978, 'longitude': -77.7732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16826', 'place_name': 'Blanchard', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 41.0642, 'longitude': -77.5978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16827', 'place_name': 'Boalsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.7793, 'longitude': -77.7822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16828', 'place_name': 'Centre Hall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8254, 'longitude': -77.6742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16829', 'place_name': 'Clarence', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 41.0585, 'longitude': -77.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16832', 'place_name': 'Coburn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8383, 'longitude': -77.4509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16835', 'place_name': 'Fleming', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.9046, 'longitude': -77.8752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16841', 'place_name': 'Howard', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 41.0203, 'longitude': -77.6702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16844', 'place_name': 'Julian', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8917, 'longitude': -77.9332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16851', 'place_name': 'Lemont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8082, 'longitude': -77.8125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16852', 'place_name': 'Madisonburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.9334, 'longitude': -77.495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16853', 'place_name': 'Milesburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.9417, 'longitude': -77.785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16854', 'place_name': 'Millheim', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8935, 'longitude': -77.4733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16856', 'place_name': 'Mingoville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.9299, 'longitude': -77.6389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16859', 'place_name': 'Moshannon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 41.0342, 'longitude': -78.0095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16864', 'place_name': 'Orviston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.9722, 'longitude': -77.7602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16865', 'place_name': 'Pennsylvania Furnace', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.71, 'longitude': -77.996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16866', 'place_name': 'Philipsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8863, 'longitude': -78.219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16868', 'place_name': 'Pine Grove Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.7337, 'longitude': -77.8856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16870', 'place_name': 'Port Matilda', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8018, 'longitude': -78.0788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16872', 'place_name': 'Rebersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.9549, 'longitude': -77.4053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16874', 'place_name': 'Snow Shoe', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 41.0376, 'longitude': -77.9523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16875', 'place_name': 'Spring Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.8578, 'longitude': -77.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16882', 'place_name': 'Woodward', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Centre', 'locality_code': '27', 'latitude': 40.9116, 'longitude': -77.3483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19301', 'place_name': 'Paoli', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0426, 'longitude': -75.4827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19310', 'place_name': 'Atglen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9458, 'longitude': -75.9703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19311', 'place_name': 'Avondale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8219, 'longitude': -75.7687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19312', 'place_name': 'Berwyn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0412, 'longitude': -75.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19316', 'place_name': 'Brandamore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.055, 'longitude': -75.8378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19318', 'place_name': 'Chatham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8524, 'longitude': -75.8118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19320', 'place_name': 'Coatesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9843, 'longitude': -75.8253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19330', 'place_name': 'Cochranville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8757, 'longitude': -75.9214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19333', 'place_name': 'Devon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0452, 'longitude': -75.4227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19335', 'place_name': 'Downingtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0161, 'longitude': -75.7183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19341', 'place_name': 'Exton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0468, 'longitude': -75.6432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19343', 'place_name': 'Glenmoore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0846, 'longitude': -75.7711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19344', 'place_name': 'Honey Brook', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0832, 'longitude': -75.8843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19345', 'place_name': 'Immaculata', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8478, 'longitude': -75.7193, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19346', 'place_name': 'Kelton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8087, 'longitude': -75.878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19347', 'place_name': 'Kemblesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.749, 'longitude': -75.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19348', 'place_name': 'Kennett Square', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.855, 'longitude': -75.7, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19350', 'place_name': 'Landenberg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.7696, 'longitude': -75.7807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19351', 'place_name': 'Lewisville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.7226, 'longitude': -75.8749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19352', 'place_name': 'Lincoln University', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.7787, 'longitude': -75.8876, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19353', 'place_name': 'Lionville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0132, 'longitude': -75.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19354', 'place_name': 'Lyndell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0582, 'longitude': -75.7433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19355', 'place_name': 'Malvern', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0468, 'longitude': -75.531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19357', 'place_name': 'Mendenhall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.854, 'longitude': -75.6413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19358', 'place_name': 'Modena', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9621, 'longitude': -75.8025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19360', 'place_name': 'New London', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.7261, 'longitude': -75.7857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19362', 'place_name': 'Nottingham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.7441, 'longitude': -76.0356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19363', 'place_name': 'Oxford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.7827, 'longitude': -75.9815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19365', 'place_name': 'Parkesburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9654, 'longitude': -75.926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19366', 'place_name': 'Pocopson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9004, 'longitude': -75.6258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19367', 'place_name': 'Pomeroy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9643, 'longitude': -75.8866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19369', 'place_name': 'Sadsburyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9903, 'longitude': -75.8936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19371', 'place_name': 'Suplee', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0995, 'longitude': -75.8791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19372', 'place_name': 'Thorndale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9984, 'longitude': -75.759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19374', 'place_name': 'Toughkenamon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8315, 'longitude': -75.7574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19375', 'place_name': 'Unionville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8954, 'longitude': -75.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19376', 'place_name': 'Wagontown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9832, 'longitude': -75.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19380', 'place_name': 'West Chester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9845, 'longitude': -75.5962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19381', 'place_name': 'West Chester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.961, 'longitude': -75.608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19382', 'place_name': 'West Chester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9441, 'longitude': -75.5882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19383', 'place_name': 'West Chester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.961, 'longitude': -75.608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19390', 'place_name': 'West Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.8253, 'longitude': -75.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19395', 'place_name': 'Westtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9328, 'longitude': -75.5448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19397', 'place_name': 'Southeastern', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9832, 'longitude': -75.7481, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19398', 'place_name': 'Southeastern', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9832, 'longitude': -75.7481, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19399', 'place_name': 'Southeastern', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9832, 'longitude': -75.7481, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19421', 'place_name': 'Birchrunville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 39.9832, 'longitude': -75.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19425', 'place_name': 'Chester Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0978, 'longitude': -75.6398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19432', 'place_name': 'Devault', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0796, 'longitude': -75.56, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19442', 'place_name': 'Kimberton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.1307, 'longitude': -75.5721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19457', 'place_name': 'Parker Ford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.1995, 'longitude': -75.5838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19460', 'place_name': 'Phoenixville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.1267, 'longitude': -75.5272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19465', 'place_name': 'Pottstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.1919, 'longitude': -75.6653, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19470', 'place_name': 'Saint Peters', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.1867, 'longitude': -75.7288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19475', 'place_name': 'Spring City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.1765, 'longitude': -75.5697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19480', 'place_name': 'Uwchland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.098, 'longitude': -75.688, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19481', 'place_name': 'Valley Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0923, 'longitude': -75.4537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19482', 'place_name': 'Valley Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0803, 'longitude': -75.4554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19493', 'place_name': 'Valley Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0971, 'longitude': -75.4696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19494', 'place_name': 'Valley Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0971, 'longitude': -75.4696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19495', 'place_name': 'Valley Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0971, 'longitude': -75.4696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19496', 'place_name': 'Valley Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.0971, 'longitude': -75.4696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19520', 'place_name': 'Elverson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Chester', 'locality_code': '29', 'latitude': 40.1568, 'longitude': -75.7866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16028', 'place_name': 'East Brady', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 40.9744, 'longitude': -79.6302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16036', 'place_name': 'Foxburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.1431, 'longitude': -79.6798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16054', 'place_name': 'Saint Petersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.1617, 'longitude': -79.6528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16058', 'place_name': 'Turkey City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.1853, 'longitude': -79.6134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16213', 'place_name': 'Callensburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.1259, 'longitude': -79.5584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16214', 'place_name': 'Clarion', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2123, 'longitude': -79.3773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16220', 'place_name': 'Crown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3898, 'longitude': -79.2709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16221', 'place_name': 'Curllsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2023, 'longitude': -79.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16224', 'place_name': 'Fairmount City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.0429, 'longitude': -79.2784, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16225', 'place_name': 'Fisher', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2665, 'longitude': -79.2425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16230', 'place_name': 'Hawthorn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.0178, 'longitude': -79.2799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16232', 'place_name': 'Knox', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2245, 'longitude': -79.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16233', 'place_name': 'Leeper', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3671, 'longitude': -79.3022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16234', 'place_name': 'Limestone', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2023, 'longitude': -79.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16235', 'place_name': 'Lucinda', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3124, 'longitude': -79.3754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16240', 'place_name': 'Mayport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 40.9906, 'longitude': -79.2617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16242', 'place_name': 'New Bethlehem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 40.9999, 'longitude': -79.3527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16248', 'place_name': 'Rimersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.0411, 'longitude': -79.5017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16254', 'place_name': 'Shippenville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2475, 'longitude': -79.4332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16255', 'place_name': 'Sligo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.1139, 'longitude': -79.4805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16257', 'place_name': 'Snydersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3328, 'longitude': -79.3556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16258', 'place_name': 'Strattanville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.1955, 'longitude': -79.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16260', 'place_name': 'Vowinckel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3957, 'longitude': -79.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16326', 'place_name': 'Fryburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3717, 'longitude': -79.4134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16331', 'place_name': 'Kossuth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2926, 'longitude': -79.5655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16332', 'place_name': 'Lickingville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3789, 'longitude': -79.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16334', 'place_name': 'Marble', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3261, 'longitude': -79.4459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16361', 'place_name': 'Tylersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.3848, 'longitude': -79.3223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16375', 'place_name': 'Lamartine', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clarion', 'locality_code': '31', 'latitude': 41.2226, 'longitude': -79.6339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15721', 'place_name': 'Burnside', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8134, 'longitude': -78.7865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15753', 'place_name': 'La Jose', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.7876, 'longitude': -78.6514, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15757', 'place_name': 'Mahaffey', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8875, 'longitude': -78.7353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15801', 'place_name': 'Du Bois', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.126, 'longitude': -78.7527, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15848', 'place_name': 'Luthersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0532, 'longitude': -78.7428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15849', 'place_name': 'Penfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.2085, 'longitude': -78.5791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15856', 'place_name': 'Rockton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0806, 'longitude': -78.6577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15866', 'place_name': 'Troutville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0256, 'longitude': -78.7853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16616', 'place_name': 'Beccaria', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.7683, 'longitude': -78.4455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16620', 'place_name': 'Brisbin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8387, 'longitude': -78.3526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16627', 'place_name': 'Coalport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.7503, 'longitude': -78.5352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16645', 'place_name': 'Glen Hope', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.7984, 'longitude': -78.4999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16651', 'place_name': 'Houtzdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8305, 'longitude': -78.3618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16656', 'place_name': 'Irvona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8017, 'longitude': -78.5602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16661', 'place_name': 'Madera', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8271, 'longitude': -78.4275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16663', 'place_name': 'Morann', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.7864, 'longitude': -78.367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16666', 'place_name': 'Osceola Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8722, 'longitude': -78.2757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16671', 'place_name': 'Ramey', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8015, 'longitude': -78.3998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16680', 'place_name': 'Smithmill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.7507, 'longitude': -78.4012, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16681', 'place_name': 'Smokerun', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9891, 'longitude': -78.4224, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16692', 'place_name': 'Westover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.7615, 'longitude': -78.7355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16698', 'place_name': 'Houtzdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8251, 'longitude': -78.3511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16821', 'place_name': 'Allport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.967, 'longitude': -78.2014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16825', 'place_name': 'Bigler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9848, 'longitude': -78.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16830', 'place_name': 'Clearfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.021, 'longitude': -78.4435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16833', 'place_name': 'Curwensville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.966, 'longitude': -78.5272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16834', 'place_name': 'Drifting', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0242, 'longitude': -78.1083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16836', 'place_name': 'Frenchville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.1038, 'longitude': -78.2345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16837', 'place_name': 'Glen Richey', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9458, 'longitude': -78.475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16838', 'place_name': 'Grampian', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9818, 'longitude': -78.5949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16839', 'place_name': 'Grassflat', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0036, 'longitude': -78.1104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16840', 'place_name': 'Hawk Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.923, 'longitude': -78.2037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16843', 'place_name': 'Hyde', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.003, 'longitude': -78.4642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16845', 'place_name': 'Karthaus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.1136, 'longitude': -78.0875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16847', 'place_name': 'Kylertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9934, 'longitude': -78.1672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16849', 'place_name': 'Lanse', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9605, 'longitude': -78.1144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16850', 'place_name': 'Lecontes Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0831, 'longitude': -78.2833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16855', 'place_name': 'Mineral Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9981, 'longitude': -78.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16858', 'place_name': 'Morrisdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0001, 'longitude': -78.2357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16860', 'place_name': 'Munson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9468, 'longitude': -78.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16861', 'place_name': 'New Millport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.8652, 'longitude': -78.5237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16863', 'place_name': 'Olanta', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9056, 'longitude': -78.5001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16871', 'place_name': 'Pottersdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.1868, 'longitude': -78.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16873', 'place_name': 'Shawville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0692, 'longitude': -78.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16876', 'place_name': 'Wallaceton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9616, 'longitude': -78.2926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16878', 'place_name': 'West Decatur', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9493, 'longitude': -78.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16879', 'place_name': 'Winburne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 40.9696, 'longitude': -78.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16881', 'place_name': 'Woodland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clearfield', 'locality_code': '33', 'latitude': 41.0098, 'longitude': -78.3214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16822', 'place_name': 'Beech Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.0845, 'longitude': -77.5851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16848', 'place_name': 'Lamar', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.0162, 'longitude': -77.5311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17721', 'place_name': 'Avis', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.186, 'longitude': -77.3162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17726', 'place_name': 'Castanea', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.1227, 'longitude': -77.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17745', 'place_name': 'Lock Haven', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.1425, 'longitude': -77.4436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17747', 'place_name': 'Loganton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.0283, 'longitude': -77.3204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17748', 'place_name': 'Mc Elhattan', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.1355, 'longitude': -77.37, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17750', 'place_name': 'Mackeyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.0545, 'longitude': -77.4614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17751', 'place_name': 'Mill Hall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.0867, 'longitude': -77.4836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17760', 'place_name': 'North Bend', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.4083, 'longitude': -77.6641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17764', 'place_name': 'Renovo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.3334, 'longitude': -77.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17778', 'place_name': 'Westport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.2745, 'longitude': -77.9315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17779', 'place_name': 'Woolrich', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Clinton', 'locality_code': '35', 'latitude': 41.1948, 'longitude': -77.3764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17814', 'place_name': 'Benton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 41.2231, 'longitude': -76.3406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17815', 'place_name': 'Bloomsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 41.0115, 'longitude': -76.4384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17820', 'place_name': 'Catawissa', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 40.918, 'longitude': -76.4416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17846', 'place_name': 'Millville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 41.1261, 'longitude': -76.5208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17858', 'place_name': 'Numidia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 40.8806, 'longitude': -76.4022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17859', 'place_name': 'Orangeville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 41.1016, 'longitude': -76.381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17878', 'place_name': 'Stillwater', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 41.1515, 'longitude': -76.3696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17888', 'place_name': 'Wilburton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 40.8121, 'longitude': -76.3929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17920', 'place_name': 'Aristes', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 40.8167, 'longitude': -76.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18603', 'place_name': 'Berwick', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 41.0665, 'longitude': -76.2443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18631', 'place_name': 'Mifflinville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Columbia', 'locality_code': '37', 'latitude': 41.0323, 'longitude': -76.308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16110', 'place_name': 'Adamsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.5067, 'longitude': -80.3765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16111', 'place_name': 'Atlantic', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.5333, 'longitude': -80.2863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16131', 'place_name': 'Hartstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.5509, 'longitude': -80.3813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16314', 'place_name': 'Cochranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.5205, 'longitude': -80.0573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16316', 'place_name': 'Conneaut Lake', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6189, 'longitude': -80.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16327', 'place_name': 'Guys Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6333, 'longitude': -79.9714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16328', 'place_name': 'Hydetown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6526, 'longitude': -79.727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16335', 'place_name': 'Meadville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6338, 'longitude': -80.1488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16354', 'place_name': 'Titusville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6382, 'longitude': -79.6855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16360', 'place_name': 'Townville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6856, 'longitude': -79.8767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16388', 'place_name': 'Meadville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6596, 'longitude': -80.1576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16403', 'place_name': 'Cambridge Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.8034, 'longitude': -80.0594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16404', 'place_name': 'Centerville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.7243, 'longitude': -79.79, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16406', 'place_name': 'Conneautville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.7455, 'longitude': -80.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16422', 'place_name': 'Harmonsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6609, 'longitude': -80.3178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16424', 'place_name': 'Linesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.6244, 'longitude': -80.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16432', 'place_name': 'Riceville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.7776, 'longitude': -79.8028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16433', 'place_name': 'Saegertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.7268, 'longitude': -80.1479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16434', 'place_name': 'Spartansburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.7936, 'longitude': -79.6849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16435', 'place_name': 'Springboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.8113, 'longitude': -80.3753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16440', 'place_name': 'Venango', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Crawford', 'locality_code': '39', 'latitude': 41.764, 'longitude': -80.0982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17001', 'place_name': 'Camp Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.216, 'longitude': -76.925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17007', 'place_name': 'Boiling Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.1449, 'longitude': -77.1195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17011', 'place_name': 'Camp Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2352, 'longitude': -76.9291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17012', 'place_name': 'Camp Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2398, 'longitude': -76.92, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17013', 'place_name': 'Carlisle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2417, 'longitude': -77.1983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17015', 'place_name': 'Carlisle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.1772, 'longitude': -77.2312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17025', 'place_name': 'Enola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2922, 'longitude': -76.9432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17027', 'place_name': 'Grantham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.158, 'longitude': -76.9964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17043', 'place_name': 'Lemoyne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2469, 'longitude': -76.9001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17050', 'place_name': 'Mechanicsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2122, 'longitude': -77.0265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17055', 'place_name': 'Mechanicsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.179, 'longitude': -77.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17065', 'place_name': 'Mount Holly Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.1115, 'longitude': -77.1902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17070', 'place_name': 'New Cumberland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2151, 'longitude': -76.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17072', 'place_name': 'New Kingstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2306, 'longitude': -77.0794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17081', 'place_name': 'Plainfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.203, 'longitude': -77.2848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17089', 'place_name': 'Camp Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.2697, 'longitude': -76.936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17093', 'place_name': 'Summerdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.3078, 'longitude': -76.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17240', 'place_name': 'Newburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.1333, 'longitude': -77.5669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17241', 'place_name': 'Newville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.1855, 'longitude': -77.4114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17257', 'place_name': 'Shippensburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.0514, 'longitude': -77.5195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17266', 'place_name': 'Walnut Bottom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Cumberland', 'locality_code': '41', 'latitude': 40.086, 'longitude': -77.409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17005', 'place_name': 'Berrysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.601, 'longitude': -76.8117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17018', 'place_name': 'Dauphin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.3846, 'longitude': -76.9283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17023', 'place_name': 'Elizabethville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.555, 'longitude': -76.8355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17028', 'place_name': 'Grantville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.3606, 'longitude': -76.6713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17030', 'place_name': 'Gratz', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.6082, 'longitude': -76.7375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17032', 'place_name': 'Halifax', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.476, 'longitude': -76.894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17033', 'place_name': 'Hershey', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2638, 'longitude': -76.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17034', 'place_name': 'Highspire', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2083, 'longitude': -76.7853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17036', 'place_name': 'Hummelstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2782, 'longitude': -76.7094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17048', 'place_name': 'Lykens', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.5909, 'longitude': -76.7074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17057', 'place_name': 'Middletown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2041, 'longitude': -76.7331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17061', 'place_name': 'Millersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.5587, 'longitude': -76.9305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17080', 'place_name': 'Pillow', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.6392, 'longitude': -76.8029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17097', 'place_name': 'Wiconisco', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.5734, 'longitude': -76.6914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17098', 'place_name': 'Williamstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.5808, 'longitude': -76.6223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17101', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2618, 'longitude': -76.8831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17102', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2728, 'longitude': -76.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17103', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2724, 'longitude': -76.861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17104', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2597, 'longitude': -76.8594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17105', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2785, 'longitude': -76.8752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17106', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2927, 'longitude': -76.8501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17107', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.297, 'longitude': -76.8764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17108', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.3086, 'longitude': -76.8017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17109', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.291, 'longitude': -76.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17110', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.303, 'longitude': -76.8862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17111', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2721, 'longitude': -76.8017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17112', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.3352, 'longitude': -76.7914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17113', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.239, 'longitude': -76.8416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17120', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2657, 'longitude': -76.8827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17121', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2944, 'longitude': -76.8938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17122', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2498, 'longitude': -76.8712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17123', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2675, 'longitude': -76.8837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17124', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2675, 'longitude': -76.886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17125', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2662, 'longitude': -76.8829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17126', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2618, 'longitude': -76.88, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17127', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2615, 'longitude': -76.8809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17128', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2737, 'longitude': -76.8844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17129', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2615, 'longitude': -76.8809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17130', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.2702, 'longitude': -76.8829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17140', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.3086, 'longitude': -76.8464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17177', 'place_name': 'Harrisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Dauphin', 'locality_code': '43', 'latitude': 40.299, 'longitude': -76.8472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19003', 'place_name': 'Ardmore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 40.002, 'longitude': -75.2966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19008', 'place_name': 'Broomall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9747, 'longitude': -75.3602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19010', 'place_name': 'Bryn Mawr', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 40.0236, 'longitude': -75.3295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19013', 'place_name': 'Chester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8498, 'longitude': -75.3747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19014', 'place_name': 'Aston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8643, 'longitude': -75.4332, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19015', 'place_name': 'Brookhaven', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8654, 'longitude': -75.3885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19016', 'place_name': 'Chester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.934, 'longitude': -75.406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19017', 'place_name': 'Chester Heights', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8901, 'longitude': -75.4755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19018', 'place_name': 'Clifton Heights', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9218, 'longitude': -75.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19022', 'place_name': 'Crum Lynne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8685, 'longitude': -75.3374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19023', 'place_name': 'Darby', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9176, 'longitude': -75.2696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19026', 'place_name': 'Drexel Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9503, 'longitude': -75.304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19028', 'place_name': 'Edgemont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9748, 'longitude': -75.4505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19029', 'place_name': 'Essington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8621, 'longitude': -75.2971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19032', 'place_name': 'Folcroft', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8905, 'longitude': -75.2821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19033', 'place_name': 'Folsom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8901, 'longitude': -75.3296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19036', 'place_name': 'Glenolden', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9048, 'longitude': -75.2946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19037', 'place_name': 'Glen Riddle Lima', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.934, 'longitude': -75.406, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19039', 'place_name': 'Gradyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9432, 'longitude': -75.4694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19041', 'place_name': 'Haverford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 40.0097, 'longitude': -75.3121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19043', 'place_name': 'Holmes', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9003, 'longitude': -75.3087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19050', 'place_name': 'Lansdowne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9375, 'longitude': -75.2637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19052', 'place_name': 'Lenni', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8942, 'longitude': -75.4456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19060', 'place_name': 'Garnet Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.852, 'longitude': -75.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19061', 'place_name': 'Marcus Hook', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8295, 'longitude': -75.4354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19063', 'place_name': 'Media', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9188, 'longitude': -75.3991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19064', 'place_name': 'Springfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9296, 'longitude': -75.3338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19065', 'place_name': 'Media', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9211, 'longitude': -75.3861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19070', 'place_name': 'Morton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9063, 'longitude': -75.3238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19073', 'place_name': 'Newtown Square', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9863, 'longitude': -75.407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19074', 'place_name': 'Norwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.887, 'longitude': -75.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19076', 'place_name': 'Prospect Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8857, 'longitude': -75.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19078', 'place_name': 'Ridley Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8784, 'longitude': -75.3215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19079', 'place_name': 'Sharon Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9035, 'longitude': -75.2695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19080', 'place_name': 'Wayne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 40.044, 'longitude': -75.3877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19081', 'place_name': 'Swarthmore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8967, 'longitude': -75.3474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19082', 'place_name': 'Upper Darby', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9579, 'longitude': -75.2681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19083', 'place_name': 'Havertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9774, 'longitude': -75.3106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19085', 'place_name': 'Villanova', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 40.0399, 'longitude': -75.3459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19086', 'place_name': 'Wallingford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8871, 'longitude': -75.3721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19087', 'place_name': 'Wayne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 40.0612, 'longitude': -75.3999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19088', 'place_name': 'Wayne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.934, 'longitude': -75.406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19089', 'place_name': 'Wayne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 40.044, 'longitude': -75.3877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19091', 'place_name': 'Media', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.934, 'longitude': -75.406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19094', 'place_name': 'Woodlyn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.876, 'longitude': -75.3463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19098', 'place_name': 'Holmes', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8954, 'longitude': -75.3107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19113', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.865, 'longitude': -75.2752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19317', 'place_name': 'Chadds Ford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8648, 'longitude': -75.5885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19319', 'place_name': 'Cheyney', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9209, 'longitude': -75.5222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19331', 'place_name': 'Concordville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8823, 'longitude': -75.5165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19339', 'place_name': 'Concordville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.934, 'longitude': -75.406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19340', 'place_name': 'Concordville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.8851, 'longitude': -75.5202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19342', 'place_name': 'Glen Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9015, 'longitude': -75.5049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19373', 'place_name': 'Thornton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Delaware', 'locality_code': '45', 'latitude': 39.9041, 'longitude': -75.5313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15821', 'place_name': 'Benezett', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.3253, 'longitude': -78.3576, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15822', 'place_name': 'Brandy Camp', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.3209, 'longitude': -78.6875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15823', 'place_name': 'Brockport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.2822, 'longitude': -78.7128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15827', 'place_name': 'Byrnedale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.2865, 'longitude': -78.5051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15831', 'place_name': 'Dagus Mines', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.3539, 'longitude': -78.6056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15841', 'place_name': 'Force', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.2629, 'longitude': -78.5298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15845', 'place_name': 'Johnsonburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.4928, 'longitude': -78.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15846', 'place_name': 'Kersey', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.3563, 'longitude': -78.6015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15853', 'place_name': 'Ridgway', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.3621, 'longitude': -78.7262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15857', 'place_name': 'Saint Marys', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.4289, 'longitude': -78.5505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15868', 'place_name': 'Weedville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.2685, 'longitude': -78.4952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15870', 'place_name': 'Wilcox', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.5735, 'longitude': -78.6823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16728', 'place_name': 'De Young', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.4159, 'longitude': -78.6651, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16734', 'place_name': 'James City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Elk', 'locality_code': '47', 'latitude': 41.6192, 'longitude': -78.8394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16401', 'place_name': 'Albion', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.8947, 'longitude': -80.3111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16407', 'place_name': 'Corry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9226, 'longitude': -79.6567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16410', 'place_name': 'Cranesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9162, 'longitude': -80.3085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16411', 'place_name': 'East Springfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9794, 'longitude': -80.4303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16412', 'place_name': 'Edinboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.8756, 'longitude': -80.1356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16413', 'place_name': 'Elgin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9031, 'longitude': -79.7437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16415', 'place_name': 'Fairview', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.0407, 'longitude': -80.2395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16417', 'place_name': 'Girard', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9896, 'longitude': -80.3178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16421', 'place_name': 'Harborcreek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1767, 'longitude': -79.9416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16423', 'place_name': 'Lake City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.0204, 'longitude': -80.3388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16426', 'place_name': 'Mc Kean', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.999, 'longitude': -80.1473, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16427', 'place_name': 'Mill Village', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.8773, 'longitude': -79.9692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16428', 'place_name': 'North East', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.2008, 'longitude': -79.8332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16430', 'place_name': 'North Springfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9999, 'longitude': -80.4258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16438', 'place_name': 'Union City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.8939, 'longitude': -79.8455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16441', 'place_name': 'Waterford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9603, 'longitude': -79.9996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16442', 'place_name': 'Wattsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.0391, 'longitude': -79.8363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16443', 'place_name': 'West Springfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.9465, 'longitude': -80.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16444', 'place_name': 'Edinboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.8707, 'longitude': -80.1218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16475', 'place_name': 'Albion', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 41.8906, 'longitude': -80.3665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16501', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.126, 'longitude': -80.086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16502', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1133, 'longitude': -80.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16503', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1265, 'longitude': -80.064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16504', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1108, 'longitude': -80.0521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16505', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1109, 'longitude': -80.1534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16506', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.0738, 'longitude': -80.1484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16507', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1316, 'longitude': -80.0864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16508', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.0976, 'longitude': -80.0935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16509', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.0763, 'longitude': -80.0668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16510', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1087, 'longitude': -79.9535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16511', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1553, 'longitude': -80.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16512', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16514', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1827, 'longitude': -80.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16515', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1827, 'longitude': -80.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16522', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16530', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16531', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1827, 'longitude': -80.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16534', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16538', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16541', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16544', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1827, 'longitude': -80.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16546', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1827, 'longitude': -80.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16550', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16553', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1292, 'longitude': -80.0851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16563', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1192, 'longitude': -79.9865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16565', 'place_name': 'Erie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Erie', 'locality_code': '49', 'latitude': 42.1827, 'longitude': -80.0649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15012', 'place_name': 'Belle Vernon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.1588, 'longitude': -79.8122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15401', 'place_name': 'Uniontown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8897, 'longitude': -79.7282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15410', 'place_name': 'Adah', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8965, 'longitude': -79.922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15413', 'place_name': 'Allison', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9868, 'longitude': -79.8637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15415', 'place_name': 'Brier Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9808, 'longitude': -79.8504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15416', 'place_name': 'Brownfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.857, 'longitude': -79.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15417', 'place_name': 'Brownsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0237, 'longitude': -79.8839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15420', 'place_name': 'Cardale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9567, 'longitude': -79.8662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15421', 'place_name': 'Chalk Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8451, 'longitude': -79.5991, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15422', 'place_name': 'Chestnut Ridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9812, 'longitude': -79.8116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15425', 'place_name': 'Connellsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0265, 'longitude': -79.5566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15428', 'place_name': 'Dawson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0638, 'longitude': -79.6602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15430', 'place_name': 'Dickerson Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0418, 'longitude': -79.66, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15431', 'place_name': 'Dunbar', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9722, 'longitude': -79.6431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15433', 'place_name': 'East Millsboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9822, 'longitude': -79.9664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15435', 'place_name': 'Fairbank', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9434, 'longitude': -79.8495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15436', 'place_name': 'Fairchance', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8229, 'longitude': -79.7551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15437', 'place_name': 'Farmington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.807, 'longitude': -79.5832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15438', 'place_name': 'Fayette City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0988, 'longitude': -79.8366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15439', 'place_name': 'Gans', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.7429, 'longitude': -79.8242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15440', 'place_name': 'Gibbon Glade', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.7364, 'longitude': -79.5736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15442', 'place_name': 'Grindstone', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0084, 'longitude': -79.8404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15443', 'place_name': 'Hibbs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9317, 'longitude': -79.8825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15444', 'place_name': 'Hiller', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.012, 'longitude': -79.9088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15445', 'place_name': 'Hopwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8728, 'longitude': -79.6568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15446', 'place_name': 'Indian Head', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0248, 'longitude': -79.395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15447', 'place_name': 'Isabella', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.946, 'longitude': -79.9393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15449', 'place_name': 'Keisterville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9636, 'longitude': -79.7853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15450', 'place_name': 'La Belle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9983, 'longitude': -79.9754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15451', 'place_name': 'Lake Lynn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.7501, 'longitude': -79.8618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15454', 'place_name': 'Leckrone', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8615, 'longitude': -79.8701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15455', 'place_name': 'Leisenring', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9985, 'longitude': -79.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15456', 'place_name': 'Lemont Furnace', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9311, 'longitude': -79.6477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15458', 'place_name': 'Mc Clellandtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8882, 'longitude': -79.8694, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15459', 'place_name': 'Markleysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.7597, 'longitude': -79.46, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15460', 'place_name': 'Martin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8065, 'longitude': -79.9098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15461', 'place_name': 'Masontown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8424, 'longitude': -79.9003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15462', 'place_name': 'Melcroft', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.052, 'longitude': -79.3892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15463', 'place_name': 'Merrittstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8825, 'longitude': -79.8336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15464', 'place_name': 'Mill Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.968, 'longitude': -79.4622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15465', 'place_name': 'Mount Braddock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9321, 'longitude': -79.6522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15466', 'place_name': 'Newell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0751, 'longitude': -79.8943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15467', 'place_name': 'New Geneva', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.7884, 'longitude': -79.9092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15468', 'place_name': 'New Salem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9242, 'longitude': -79.8356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15469', 'place_name': 'Normalville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0418, 'longitude': -79.4151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15470', 'place_name': 'Ohiopyle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8507, 'longitude': -79.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15472', 'place_name': 'Oliver', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9183, 'longitude': -79.7158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15473', 'place_name': 'Perryopolis', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0646, 'longitude': -79.7756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15474', 'place_name': 'Point Marion', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.7351, 'longitude': -79.899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15475', 'place_name': 'Republic', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9626, 'longitude': -79.8767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15476', 'place_name': 'Ronco', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8697, 'longitude': -79.9206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15478', 'place_name': 'Smithfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.7923, 'longitude': -79.8127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15480', 'place_name': 'Smock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9961, 'longitude': -79.7678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15482', 'place_name': 'Star Junction', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0651, 'longitude': -79.769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15484', 'place_name': 'Uledi', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.8936, 'longitude': -79.7856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15486', 'place_name': 'Vanderbilt', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0246, 'longitude': -79.6955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15488', 'place_name': 'Waltersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9763, 'longitude': -79.7689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15489', 'place_name': 'West Leisenring', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 39.9561, 'longitude': -79.7007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15490', 'place_name': 'White', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0726, 'longitude': -79.4251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15492', 'place_name': 'Wickhaven', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.1194, 'longitude': -79.7623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15631', 'place_name': 'Everson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fayette', 'locality_code': '51', 'latitude': 40.0911, 'longitude': -79.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15828', 'place_name': 'Clarington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Forest', 'locality_code': '53', 'latitude': 41.3233, 'longitude': -79.1466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16217', 'place_name': 'Cooksburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Forest', 'locality_code': '53', 'latitude': 41.3384, 'longitude': -79.1971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16239', 'place_name': 'Marienville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Forest', 'locality_code': '53', 'latitude': 41.4622, 'longitude': -79.1306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16321', 'place_name': 'East Hickory', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Forest', 'locality_code': '53', 'latitude': 41.584, 'longitude': -79.4017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16322', 'place_name': 'Endeavor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Forest', 'locality_code': '53', 'latitude': 41.5895, 'longitude': -79.385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16353', 'place_name': 'Tionesta', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Forest', 'locality_code': '53', 'latitude': 41.5116, 'longitude': -79.3663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16370', 'place_name': 'West Hickory', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Forest', 'locality_code': '53', 'latitude': 41.5687, 'longitude': -79.4081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17201', 'place_name': 'Chambersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.9313, 'longitude': -77.6579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17202', 'place_name': 'Chambersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.9072, 'longitude': -77.636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17210', 'place_name': 'Amberson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.1704, 'longitude': -77.6772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17214', 'place_name': 'Blue Ridge Summit', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7399, 'longitude': -77.4707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17217', 'place_name': 'Concord', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.2252, 'longitude': -77.725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17219', 'place_name': 'Doylesburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.2184, 'longitude': -77.6797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17220', 'place_name': 'Dry Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.1781, 'longitude': -77.7353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17221', 'place_name': 'Fannettsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.0717, 'longitude': -77.821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17222', 'place_name': 'Fayetteville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.9065, 'longitude': -77.531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17224', 'place_name': 'Fort Loudon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.9547, 'longitude': -77.8984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17225', 'place_name': 'Greencastle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7818, 'longitude': -77.747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17231', 'place_name': 'Lemasters', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.8594, 'longitude': -77.8579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17232', 'place_name': 'Lurgan', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.1055, 'longitude': -77.6405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17235', 'place_name': 'Marion', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.8587, 'longitude': -77.6981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17236', 'place_name': 'Mercersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.8195, 'longitude': -77.9073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17237', 'place_name': 'Mont Alto', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.8417, 'longitude': -77.5537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17244', 'place_name': 'Orrstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.0731, 'longitude': -77.6398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17246', 'place_name': 'Pleasant Hall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.0531, 'longitude': -77.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17247', 'place_name': 'Quincy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7995, 'longitude': -77.5811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17250', 'place_name': 'Rouzerville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7364, 'longitude': -77.5247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17251', 'place_name': 'Roxbury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.1104, 'longitude': -77.6619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17252', 'place_name': 'Saint Thomas', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.9241, 'longitude': -77.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17254', 'place_name': 'Scotland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.9696, 'longitude': -77.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17256', 'place_name': 'Shady Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7834, 'longitude': -77.6749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17261', 'place_name': 'South Mountain', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.8465, 'longitude': -77.4878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17262', 'place_name': 'Spring Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.1734, 'longitude': -77.7092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17263', 'place_name': 'State Line', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7248, 'longitude': -77.7186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17265', 'place_name': 'Upperstrasburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.058, 'longitude': -77.7368, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17268', 'place_name': 'Waynesboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7635, 'longitude': -77.5674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17271', 'place_name': 'Willow Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 40.1137, 'longitude': -77.7969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17272', 'place_name': 'Zullinger', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Franklin', 'locality_code': '55', 'latitude': 39.7714, 'longitude': -77.627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15536', 'place_name': 'Crystal Spring', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 39.92, 'longitude': -78.2258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16689', 'place_name': 'Waterfall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.1276, 'longitude': -78.0628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16691', 'place_name': 'Wells Tannery', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.101, 'longitude': -78.1403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17212', 'place_name': 'Big Cove Tannery', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 39.8127, 'longitude': -78.0645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17215', 'place_name': 'Burnt Cabins', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.0753, 'longitude': -77.9017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17223', 'place_name': 'Fort Littleton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.078, 'longitude': -77.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17228', 'place_name': 'Harrisonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 39.9761, 'longitude': -78.0841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17229', 'place_name': 'Hustontown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 40.0441, 'longitude': -78.0148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17233', 'place_name': 'Mc Connellsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 39.9443, 'longitude': -77.9901, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17238', 'place_name': 'Needmore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 39.8713, 'longitude': -78.1439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17267', 'place_name': 'Warfordsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Fulton', 'locality_code': '57', 'latitude': 39.7698, 'longitude': -78.1986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15310', 'place_name': 'Aleppo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8246, 'longitude': -80.4579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15315', 'place_name': 'Bobtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.7612, 'longitude': -79.9814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15316', 'place_name': 'Brave', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.7245, 'longitude': -80.2537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15320', 'place_name': 'Carmichaels', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8825, 'longitude': -79.971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15322', 'place_name': 'Clarksville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.9667, 'longitude': -80.0452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15325', 'place_name': 'Crucible', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.9502, 'longitude': -79.9676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15327', 'place_name': 'Dilliner', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.7555, 'longitude': -79.9771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15334', 'place_name': 'Garards Fort', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8083, 'longitude': -79.9679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15337', 'place_name': 'Graysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.9092, 'longitude': -80.3952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15338', 'place_name': 'Greensboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8045, 'longitude': -79.9399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15341', 'place_name': 'Holbrook', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8489, 'longitude': -80.3385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15344', 'place_name': 'Jefferson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.9334, 'longitude': -80.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15346', 'place_name': 'Mather', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.9354, 'longitude': -80.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15349', 'place_name': 'Mount Morris', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.774, 'longitude': -80.0246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15351', 'place_name': 'Nemacolin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8779, 'longitude': -79.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15352', 'place_name': 'New Freeport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.7507, 'longitude': -80.4542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15353', 'place_name': 'Nineveh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.9615, 'longitude': -80.3078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15357', 'place_name': 'Rices Landing', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.944, 'longitude': -79.9857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15359', 'place_name': 'Rogersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8765, 'longitude': -80.2758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15362', 'place_name': 'Spraggs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.7447, 'longitude': -80.2145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15364', 'place_name': 'Sycamore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.9415, 'longitude': -80.2906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15370', 'place_name': 'Waynesburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8917, 'longitude': -80.1795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15380', 'place_name': 'Wind Ridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Greene', 'locality_code': '59', 'latitude': 39.8971, 'longitude': -80.4647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16611', 'place_name': 'Alexandria', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.5485, 'longitude': -78.0951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16621', 'place_name': 'Broad Top', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.2019, 'longitude': -78.1406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16622', 'place_name': 'Calvin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.3367, 'longitude': -78.0272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16623', 'place_name': 'Cassville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.294, 'longitude': -78.0272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16634', 'place_name': 'Dudley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.2054, 'longitude': -78.1814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16638', 'place_name': 'Entriken', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.334, 'longitude': -78.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16647', 'place_name': 'Hesston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.4121, 'longitude': -78.1281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16652', 'place_name': 'Huntingdon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.5023, 'longitude': -78.005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16654', 'place_name': 'Huntingdon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.4848, 'longitude': -78.0103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16657', 'place_name': 'James Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.3567, 'longitude': -78.1887, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16660', 'place_name': 'Mc Connellstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.4025, 'longitude': -77.967, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '16669', 'place_name': 'Petersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.603, 'longitude': -77.9984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16674', 'place_name': 'Robertsdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.1787, 'longitude': -78.1117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16683', 'place_name': 'Spruce Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.6218, 'longitude': -78.1361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16685', 'place_name': 'Todd', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.271, 'longitude': -78.0772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16877', 'place_name': 'Warriors Mark', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.7414, 'longitude': -78.0775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17052', 'place_name': 'Mapleton Depot', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.3864, 'longitude': -77.9604, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17060', 'place_name': 'Mill Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.4679, 'longitude': -77.8967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17066', 'place_name': 'Mount Union', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.3901, 'longitude': -77.8637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17213', 'place_name': 'Blairs Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.2548, 'longitude': -77.7695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17239', 'place_name': 'Neelyton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.1371, 'longitude': -77.858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17243', 'place_name': 'Orbisonia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.2389, 'longitude': -77.9069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17249', 'place_name': 'Rockhill Furnace', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.2414, 'longitude': -77.8995, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17253', 'place_name': 'Saltillo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.2133, 'longitude': -78.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17255', 'place_name': 'Shade Gap', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.173, 'longitude': -77.868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17260', 'place_name': 'Shirleysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.2979, 'longitude': -77.8742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17264', 'place_name': 'Three Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Huntingdon', 'locality_code': '61', 'latitude': 40.1834, 'longitude': -77.9941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15681', 'place_name': 'Saltsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5429, 'longitude': -79.3978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15701', 'place_name': 'Indiana', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6196, 'longitude': -79.1596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15705', 'place_name': 'Indiana', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6215, 'longitude': -79.1525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15710', 'place_name': 'Alverda', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6303, 'longitude': -78.857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15712', 'place_name': 'Arcadia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7817, 'longitude': -78.8536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15713', 'place_name': 'Aultman', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5698, 'longitude': -79.2617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15716', 'place_name': 'Black Lick', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.4725, 'longitude': -79.1869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15717', 'place_name': 'Blairsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.4413, 'longitude': -79.2533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15720', 'place_name': 'Brush Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5292, 'longitude': -79.0846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15723', 'place_name': 'Chambersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7056, 'longitude': -79.1615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15724', 'place_name': 'Cherry Tree', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7554, 'longitude': -78.8474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15725', 'place_name': 'Clarksburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5039, 'longitude': -79.3677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15727', 'place_name': 'Clune', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5503, 'longitude': -79.3237, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15728', 'place_name': 'Clymer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6688, 'longitude': -79.0119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15729', 'place_name': 'Commodore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7016, 'longitude': -78.9134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15731', 'place_name': 'Coral', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.4992, 'longitude': -79.1739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15732', 'place_name': 'Creekside', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7199, 'longitude': -79.2014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15734', 'place_name': 'Dixonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7165, 'longitude': -79.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15739', 'place_name': 'Ernest', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.678, 'longitude': -79.1657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15741', 'place_name': 'Gipsy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.8073, 'longitude': -78.8764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15742', 'place_name': 'Glen Campbell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.8508, 'longitude': -78.8555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15745', 'place_name': 'Heilwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6207, 'longitude': -78.9186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15746', 'place_name': 'Hillsdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7517, 'longitude': -78.885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15747', 'place_name': 'Home', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7834, 'longitude': -79.1641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15748', 'place_name': 'Homer City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5245, 'longitude': -79.0843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15750', 'place_name': 'Josephine', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.4828, 'longitude': -79.185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15752', 'place_name': 'Kent', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5412, 'longitude': -79.282, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15754', 'place_name': 'Lucernemines', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5567, 'longitude': -79.1515, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15756', 'place_name': 'Mc Intyre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5684, 'longitude': -79.2999, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15758', 'place_name': 'Marchand', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.8576, 'longitude': -79.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15759', 'place_name': 'Marion Center', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7814, 'longitude': -79.0252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15761', 'place_name': 'Mentcle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6373, 'longitude': -78.8823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15763', 'place_name': 'Northpoint', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.9037, 'longitude': -79.1257, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15765', 'place_name': 'Penn Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6213, 'longitude': -78.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15771', 'place_name': 'Rochester Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.8308, 'longitude': -78.9892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15772', 'place_name': 'Rossiter', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.8846, 'longitude': -78.9414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15777', 'place_name': 'Starford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7027, 'longitude': -78.9588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15783', 'place_name': 'West Lebanon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.6026, 'longitude': -79.3537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15920', 'place_name': 'Armagh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.4603, 'longitude': -79.0097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15929', 'place_name': 'Dilltown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.4665, 'longitude': -79.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15949', 'place_name': 'Robinson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.4042, 'longitude': -79.1395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15957', 'place_name': 'Strongstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.5727, 'longitude': -78.9, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16211', 'place_name': 'Beyer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7865, 'longitude': -79.2011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16246', 'place_name': 'Plumville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.7931, 'longitude': -79.1806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16256', 'place_name': 'Smicksburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Indiana', 'locality_code': '63', 'latitude': 40.8372, 'longitude': -79.1614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15711', 'place_name': 'Anita', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.0018, 'longitude': -78.9666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15715', 'place_name': 'Big Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9704, 'longitude': -78.8758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15730', 'place_name': 'Coolspring', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.0431, 'longitude': -79.0836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15733', 'place_name': 'De Lancey', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.1411, 'longitude': -78.9629, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15744', 'place_name': 'Hamilton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9233, 'longitude': -79.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15764', 'place_name': 'Oliveburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9926, 'longitude': -79.0291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15767', 'place_name': 'Punxsutawney', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9479, 'longitude': -78.9681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15770', 'place_name': 'Ringgold', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9997, 'longitude': -79.1766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15776', 'place_name': 'Sprankle Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.0133, 'longitude': -79.114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15778', 'place_name': 'Timblin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9684, 'longitude': -79.2014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15780', 'place_name': 'Valier', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9159, 'longitude': -79.0448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15781', 'place_name': 'Walston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 40.9651, 'longitude': -78.9948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15784', 'place_name': 'Worthville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.0238, 'longitude': -79.1387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15824', 'place_name': 'Brockway', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.2406, 'longitude': -78.8116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15825', 'place_name': 'Brookville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.1627, 'longitude': -79.0816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15829', 'place_name': 'Corsica', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.1762, 'longitude': -79.1976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15840', 'place_name': 'Falls Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.1455, 'longitude': -78.8128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15847', 'place_name': 'Knox Dale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.0862, 'longitude': -79.0264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15851', 'place_name': 'Reynoldsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.097, 'longitude': -78.8886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15860', 'place_name': 'Sigel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.3099, 'longitude': -79.054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15863', 'place_name': 'Stump Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.0126, 'longitude': -78.8373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15864', 'place_name': 'Summerville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.1058, 'longitude': -79.1726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15865', 'place_name': 'Sykesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Jefferson', 'locality_code': '65', 'latitude': 41.0514, 'longitude': -78.8195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17014', 'place_name': 'Cocolamus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.6479, 'longitude': -77.2125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17021', 'place_name': 'East Waterford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.3542, 'longitude': -77.6528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17035', 'place_name': 'Honey Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.4309, 'longitude': -77.5761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17049', 'place_name': 'Mc Alisterville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.6469, 'longitude': -77.2602, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17056', 'place_name': 'Mexico', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.5373, 'longitude': -77.3543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17058', 'place_name': 'Mifflin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.5695, 'longitude': -77.4028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17059', 'place_name': 'Mifflintown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.5727, 'longitude': -77.3761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17076', 'place_name': 'Oakland Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.6147, 'longitude': -77.3192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17082', 'place_name': 'Port Royal', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.5107, 'longitude': -77.431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17086', 'place_name': 'Richfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.6884, 'longitude': -77.1223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17094', 'place_name': 'Thompsontown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Juniata', 'locality_code': '67', 'latitude': 40.5908, 'longitude': -77.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18403', 'place_name': 'Archbald', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4876, 'longitude': -75.5334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18407', 'place_name': 'Carbondale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.5831, 'longitude': -75.5056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18410', 'place_name': 'Chinchilla', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4865, 'longitude': -75.6933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18411', 'place_name': 'Clarks Summit', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4878, 'longitude': -75.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18414', 'place_name': 'Dalton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.5395, 'longitude': -75.7037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18416', 'place_name': 'Elmhurst', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.3756, 'longitude': -75.548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18420', 'place_name': 'Fleetville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.5981, 'longitude': -75.7146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18433', 'place_name': 'Jermyn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.5744, 'longitude': -75.5881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18434', 'place_name': 'Jessup', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4724, 'longitude': -75.5689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18440', 'place_name': 'La Plume', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.5516, 'longitude': -75.7676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18444', 'place_name': 'Moscow', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.3432, 'longitude': -75.5301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18447', 'place_name': 'Olyphant', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4677, 'longitude': -75.6015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18448', 'place_name': 'Olyphant', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4649, 'longitude': -75.5962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18452', 'place_name': 'Peckville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4821, 'longitude': -75.5899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18471', 'place_name': 'Waverly', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.5238, 'longitude': -75.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18501', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4019, 'longitude': -75.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18502', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4092, 'longitude': -75.6649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18503', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4095, 'longitude': -75.6642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18504', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4128, 'longitude': -75.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18505', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.3914, 'longitude': -75.6657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18507', 'place_name': 'Moosic', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.3554, 'longitude': -75.6805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18508', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4389, 'longitude': -75.6625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18509', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4274, 'longitude': -75.6465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18510', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.408, 'longitude': -75.6484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18512', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.435, 'longitude': -75.6103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18515', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4035, 'longitude': -75.7065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18517', 'place_name': 'Taylor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.3904, 'longitude': -75.7158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18518', 'place_name': 'Old Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.3701, 'longitude': -75.7391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18519', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4092, 'longitude': -75.6649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18540', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4019, 'longitude': -75.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18577', 'place_name': 'Scranton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.4019, 'longitude': -75.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18653', 'place_name': 'Ransom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lackawanna', 'locality_code': '69', 'latitude': 41.3945, 'longitude': -75.8242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17022', 'place_name': 'Elizabethtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1553, 'longitude': -76.6025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17501', 'place_name': 'Akron', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1573, 'longitude': -76.2042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17502', 'place_name': 'Bainbridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1086, 'longitude': -76.6726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17503', 'place_name': 'Bart', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0185, 'longitude': -76.2976, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17504', 'place_name': 'Bausman', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.024, 'longitude': -76.3281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17505', 'place_name': 'Bird In Hand', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0561, 'longitude': -76.183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17506', 'place_name': 'Blue Ball', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1173, 'longitude': -76.0524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17507', 'place_name': 'Bowmansville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1966, 'longitude': -76.016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17508', 'place_name': 'Brownstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.124, 'longitude': -76.2176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17509', 'place_name': 'Christiana', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.904, 'longitude': -76.0401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17512', 'place_name': 'Columbia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0391, 'longitude': -76.4862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17516', 'place_name': 'Conestoga', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9403, 'longitude': -76.3575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17517', 'place_name': 'Denver', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.2297, 'longitude': -76.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17518', 'place_name': 'Drumore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.8183, 'longitude': -76.2499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17519', 'place_name': 'East Earl', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1395, 'longitude': -76.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17520', 'place_name': 'East Petersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1008, 'longitude': -76.3512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17521', 'place_name': 'Elm', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.2044, 'longitude': -76.3464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17522', 'place_name': 'Ephrata', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1756, 'longitude': -76.1821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17527', 'place_name': 'Gap', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.002, 'longitude': -75.9978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17528', 'place_name': 'Goodville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1257, 'longitude': -76.0033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17529', 'place_name': 'Gordonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0353, 'longitude': -76.1106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17532', 'place_name': 'Holtwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.8631, 'longitude': -76.3008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17533', 'place_name': 'Hopeland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.2339, 'longitude': -76.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17534', 'place_name': 'Intercourse', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0367, 'longitude': -76.1069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17535', 'place_name': 'Kinzers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0053, 'longitude': -76.0493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17536', 'place_name': 'Kirkwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.8257, 'longitude': -76.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17537', 'place_name': 'Lampeter', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9885, 'longitude': -76.2387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17538', 'place_name': 'Landisville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0892, 'longitude': -76.4156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17540', 'place_name': 'Leola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0964, 'longitude': -76.1921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17543', 'place_name': 'Lititz', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1846, 'longitude': -76.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17545', 'place_name': 'Manheim', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1702, 'longitude': -76.4168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17547', 'place_name': 'Marietta', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0664, 'longitude': -76.5645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17549', 'place_name': 'Martindale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1545, 'longitude': -76.0876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17550', 'place_name': 'Maytown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0754, 'longitude': -76.5822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17551', 'place_name': 'Millersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9982, 'longitude': -76.3566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17552', 'place_name': 'Mount Joy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1083, 'longitude': -76.5103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17554', 'place_name': 'Mountville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0427, 'longitude': -76.4277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17555', 'place_name': 'Narvon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1252, 'longitude': -75.9756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17557', 'place_name': 'New Holland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1005, 'longitude': -76.0801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17560', 'place_name': 'New Providence', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9098, 'longitude': -76.2243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17562', 'place_name': 'Paradise', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9852, 'longitude': -76.1081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17563', 'place_name': 'Peach Bottom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.7705, 'longitude': -76.1791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17564', 'place_name': 'Penryn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0185, 'longitude': -76.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17565', 'place_name': 'Pequea', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9058, 'longitude': -76.3209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17566', 'place_name': 'Quarryville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.8949, 'longitude': -76.1465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17567', 'place_name': 'Reamstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.2099, 'longitude': -76.1164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17568', 'place_name': 'Refton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9469, 'longitude': -76.2322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17569', 'place_name': 'Reinholds', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.2688, 'longitude': -76.1013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17570', 'place_name': 'Rheems', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1301, 'longitude': -76.5705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17572', 'place_name': 'Ronks', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0208, 'longitude': -76.1661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17573', 'place_name': 'Ronks', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0262, 'longitude': -76.1686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17575', 'place_name': 'Silver Spring', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0647, 'longitude': -76.4343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17576', 'place_name': 'Smoketown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0376, 'longitude': -76.1969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17578', 'place_name': 'Stevens', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.2194, 'longitude': -76.1626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17579', 'place_name': 'Strasburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9701, 'longitude': -76.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17580', 'place_name': 'Talmage', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1168, 'longitude': -76.2131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17581', 'place_name': 'Terre Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1585, 'longitude': -76.0511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17582', 'place_name': 'Washington Boro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9881, 'longitude': -76.4402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17583', 'place_name': 'West Willow', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.9723, 'longitude': -76.2873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17584', 'place_name': 'Willow Street', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 39.967, 'longitude': -76.2752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17585', 'place_name': 'Witmer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0484, 'longitude': -76.2114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17601', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0766, 'longitude': -76.3107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17602', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0335, 'longitude': -76.2844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17603', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0091, 'longitude': -76.3671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17604', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0651, 'longitude': -76.3356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17605', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0185, 'longitude': -76.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17606', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.1102, 'longitude': -76.3054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17607', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0185, 'longitude': -76.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17608', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0185, 'longitude': -76.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17611', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0379, 'longitude': -76.3055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17622', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0418, 'longitude': -76.3012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17699', 'place_name': 'Lancaster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.0185, 'longitude': -76.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19501', 'place_name': 'Adamstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lancaster', 'locality_code': '71', 'latitude': 40.2423, 'longitude': -76.0577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16101', 'place_name': 'New Castle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.9922, 'longitude': -80.3284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16102', 'place_name': 'New Castle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.9677, 'longitude': -80.3907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16103', 'place_name': 'New Castle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.9897, 'longitude': -80.3084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16105', 'place_name': 'New Castle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.0241, 'longitude': -80.3454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16107', 'place_name': 'New Castle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.9897, 'longitude': -80.3084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16108', 'place_name': 'New Castle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.9897, 'longitude': -80.3084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16112', 'place_name': 'Bessemer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.9755, 'longitude': -80.4937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16116', 'place_name': 'Edinburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.0276, 'longitude': -80.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16117', 'place_name': 'Ellwood City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.8729, 'longitude': -80.2559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16120', 'place_name': 'Enon Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.8721, 'longitude': -80.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16132', 'place_name': 'Hillsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.0113, 'longitude': -80.4975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16140', 'place_name': 'New Bedford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.0973, 'longitude': -80.5048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16142', 'place_name': 'New Wilmington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.1382, 'longitude': -80.3245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16143', 'place_name': 'Pulaski', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.0942, 'longitude': -80.4685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16155', 'place_name': 'Villa Maria', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.0737, 'longitude': -80.5073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16156', 'place_name': 'Volant', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.0938, 'longitude': -80.2441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16157', 'place_name': 'Wampum', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.8819, 'longitude': -80.3392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16160', 'place_name': 'West Pittsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 40.9301, 'longitude': -80.3611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16172', 'place_name': 'New Wilmington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lawrence', 'locality_code': '73', 'latitude': 41.12, 'longitude': -80.3332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17003', 'place_name': 'Annville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3456, 'longitude': -76.5447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17010', 'place_name': 'Campbelltown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.2776, 'longitude': -76.5852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17016', 'place_name': 'Cornwall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.2755, 'longitude': -76.4053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17026', 'place_name': 'Fredericksburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.4524, 'longitude': -76.4267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17038', 'place_name': 'Jonestown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.4361, 'longitude': -76.5038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17039', 'place_name': 'Kleinfeltersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3005, 'longitude': -76.2584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17041', 'place_name': 'Lawn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.2236, 'longitude': -76.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17042', 'place_name': 'Lebanon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3316, 'longitude': -76.3976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17046', 'place_name': 'Lebanon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3812, 'longitude': -76.4368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17064', 'place_name': 'Mount Gretna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.2476, 'longitude': -76.4711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17067', 'place_name': 'Myerstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3789, 'longitude': -76.3143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17073', 'place_name': 'Newmanstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3495, 'longitude': -76.2133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17077', 'place_name': 'Ono', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.4029, 'longitude': -76.5347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17078', 'place_name': 'Palmyra', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3011, 'longitude': -76.5886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17083', 'place_name': 'Quentin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.2796, 'longitude': -76.4397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17085', 'place_name': 'Rexmont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.2771, 'longitude': -76.3857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17087', 'place_name': 'Richland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.3806, 'longitude': -76.2654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17088', 'place_name': 'Schaefferstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lebanon', 'locality_code': '75', 'latitude': 40.2984, 'longitude': -76.2944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18011', 'place_name': 'Alburtis', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5145, 'longitude': -75.6029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18025', 'place_name': 'Bethlehem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6259, 'longitude': -75.3705, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18031', 'place_name': 'Breinigsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5526, 'longitude': -75.6553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18032', 'place_name': 'Catasauqua', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6557, 'longitude': -75.4693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18034', 'place_name': 'Center Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5396, 'longitude': -75.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18036', 'place_name': 'Coopersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5076, 'longitude': -75.3888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18037', 'place_name': 'Coplay', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6701, 'longitude': -75.4955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18046', 'place_name': 'East Texas', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5476, 'longitude': -75.5613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18049', 'place_name': 'Emmaus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5293, 'longitude': -75.501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18051', 'place_name': 'Fogelsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.593, 'longitude': -75.6568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18052', 'place_name': 'Whitehall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6567, 'longitude': -75.5041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18053', 'place_name': 'Germansville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.7118, 'longitude': -75.7147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18059', 'place_name': 'Laurys Station', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.7177, 'longitude': -75.5335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18060', 'place_name': 'Limeport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.509, 'longitude': -75.4471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18062', 'place_name': 'Macungie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5285, 'longitude': -75.5666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18065', 'place_name': 'Neffs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6967, 'longitude': -75.6116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18066', 'place_name': 'New Tripoli', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6545, 'longitude': -75.7417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18068', 'place_name': 'Old Zionsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.4865, 'longitude': -75.5202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18069', 'place_name': 'Orefield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6248, 'longitude': -75.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18078', 'place_name': 'Schnecksville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6819, 'longitude': -75.6239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18079', 'place_name': 'Slatedale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.7455, 'longitude': -75.6592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18080', 'place_name': 'Slatington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.7345, 'longitude': -75.6186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18087', 'place_name': 'Trexlertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5482, 'longitude': -75.5961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18092', 'place_name': 'Zionsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.4734, 'longitude': -75.5261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18098', 'place_name': 'Emmaus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5395, 'longitude': -75.4969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18099', 'place_name': 'Emmaus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5395, 'longitude': -75.4969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18101', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6026, 'longitude': -75.4691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18102', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6068, 'longitude': -75.4781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18103', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5891, 'longitude': -75.4645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18104', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6018, 'longitude': -75.5225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18105', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6084, 'longitude': -75.4902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18106', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5824, 'longitude': -75.5911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18109', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.6366, 'longitude': -75.4405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18195', 'place_name': 'Allentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lehigh', 'locality_code': '77', 'latitude': 40.5843, 'longitude': -75.6248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18201', 'place_name': 'Hazleton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9488, 'longitude': -75.9563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18202', 'place_name': 'Hazleton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9506, 'longitude': -76.0487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18219', 'place_name': 'Conyngham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9907, 'longitude': -76.0564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18221', 'place_name': 'Drifton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.0016, 'longitude': -75.9057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18222', 'place_name': 'Drums', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.0255, 'longitude': -75.9768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18223', 'place_name': 'Ebervale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9862, 'longitude': -75.9413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18224', 'place_name': 'Freeland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.0196, 'longitude': -75.888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18225', 'place_name': 'Harleigh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9806, 'longitude': -75.9713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18234', 'place_name': 'Lattimer Mines', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9925, 'longitude': -75.9626, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18239', 'place_name': 'Milnesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9961, 'longitude': -75.9815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18246', 'place_name': 'Rock Glen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9654, 'longitude': -76.1844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18247', 'place_name': 'Saint Johns', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.0281, 'longitude': -76.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18249', 'place_name': 'Sugarloaf', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9971, 'longitude': -76.0717, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18251', 'place_name': 'Sybertsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.0015, 'longitude': -76.0763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18256', 'place_name': 'Weston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 40.9448, 'longitude': -76.1452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18601', 'place_name': 'Beach Haven', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.0684, 'longitude': -76.1758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18602', 'place_name': 'Bear Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.1922, 'longitude': -75.7161, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18611', 'place_name': 'Cambra', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.1981, 'longitude': -76.3058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18612', 'place_name': 'Dallas', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3494, 'longitude': -75.9834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18617', 'place_name': 'Glen Lyon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.1746, 'longitude': -76.0746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18618', 'place_name': 'Harveys Lake', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3592, 'longitude': -76.0451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18621', 'place_name': 'Hunlock Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2459, 'longitude': -76.0879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18622', 'place_name': 'Huntington Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.1906, 'longitude': -76.2335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18627', 'place_name': 'Lehman', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3166, 'longitude': -76.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18634', 'place_name': 'Nanticoke', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.1963, 'longitude': -76.0044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18635', 'place_name': 'Nescopeck', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.0469, 'longitude': -76.1981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18640', 'place_name': 'Pittston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3175, 'longitude': -75.7885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18641', 'place_name': 'Pittston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3361, 'longitude': -75.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18642', 'place_name': 'Duryea', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3486, 'longitude': -75.7611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18643', 'place_name': 'Pittston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3665, 'longitude': -75.8362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18644', 'place_name': 'Wyoming', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3197, 'longitude': -75.8541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18651', 'place_name': 'Plymouth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2458, 'longitude': -75.9481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18654', 'place_name': 'Shawanese', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3501, 'longitude': -76.0319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18655', 'place_name': 'Shickshinny', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.1513, 'longitude': -76.1081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18656', 'place_name': 'Sweet Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3066, 'longitude': -76.1339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18660', 'place_name': 'Wapwallopen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.068, 'longitude': -76.0857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18661', 'place_name': 'White Haven', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.079, 'longitude': -75.7715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18690', 'place_name': 'Dallas', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.3362, 'longitude': -75.9633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18701', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2436, 'longitude': -75.885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18702', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2208, 'longitude': -75.7736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18703', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2421, 'longitude': -75.8857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18704', 'place_name': 'Kingston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2742, 'longitude': -75.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18705', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2689, 'longitude': -75.8453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18706', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2044, 'longitude': -75.9113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18707', 'place_name': 'Mountain Top', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.135, 'longitude': -75.9376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18708', 'place_name': 'Shavertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2998, 'longitude': -75.9711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18709', 'place_name': 'Luzerne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2843, 'longitude': -75.8935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18710', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18711', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18762', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18764', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18765', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18766', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2448, 'longitude': -75.8896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18767', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18769', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18773', 'place_name': 'Wilkes Barre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Luzerne', 'locality_code': '79', 'latitude': 41.2722, 'longitude': -75.8801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17701', 'place_name': 'Williamsport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2412, 'longitude': -77.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17702', 'place_name': 'Williamsport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.1943, 'longitude': -77.0547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17703', 'place_name': 'Williamsport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2412, 'longitude': -77.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17705', 'place_name': 'Williamsport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.3327, 'longitude': -77.0236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17720', 'place_name': 'Antes Fort', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.1865, 'longitude': -77.2184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17723', 'place_name': 'Jersey Shore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.432, 'longitude': -77.4562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17727', 'place_name': 'Cedar Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.5299, 'longitude': -77.4917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17728', 'place_name': 'Cogan Station', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.3152, 'longitude': -77.069, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17737', 'place_name': 'Hughesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.256, 'longitude': -76.7141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17739', 'place_name': 'Jersey Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.3573, 'longitude': -77.4066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17740', 'place_name': 'Jersey Shore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.247, 'longitude': -77.2706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17742', 'place_name': 'Lairdsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2359, 'longitude': -76.605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17744', 'place_name': 'Linden', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2472, 'longitude': -77.1527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17752', 'place_name': 'Montgomery', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.1788, 'longitude': -76.8839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17754', 'place_name': 'Montoursville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2663, 'longitude': -76.903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17756', 'place_name': 'Muncy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2137, 'longitude': -76.7633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17762', 'place_name': 'Picture Rocks', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2798, 'longitude': -76.713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17763', 'place_name': 'Ralston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.5038, 'longitude': -76.9583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17769', 'place_name': 'Slate Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.4728, 'longitude': -77.5016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17771', 'place_name': 'Trout Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.4125, 'longitude': -77.0098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17774', 'place_name': 'Unityville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.2436, 'longitude': -76.5183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17776', 'place_name': 'Waterville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Lycoming', 'locality_code': '81', 'latitude': 41.3114, 'longitude': -77.3604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16333', 'place_name': 'Ludlow', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.7284, 'longitude': -78.9434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16701', 'place_name': 'Bradford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.9547, 'longitude': -78.654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16724', 'place_name': 'Crosby', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.7451, 'longitude': -78.3903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16725', 'place_name': 'Custer City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.9059, 'longitude': -78.6517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16726', 'place_name': 'Cyclone', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.8186, 'longitude': -78.5957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16727', 'place_name': 'Derrick City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.9726, 'longitude': -78.5626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16729', 'place_name': 'Duke Center', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.954, 'longitude': -78.4923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16730', 'place_name': 'East Smethport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.8087, 'longitude': -78.4195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16731', 'place_name': 'Eldred', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.9489, 'longitude': -78.3884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16732', 'place_name': 'Gifford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.8581, 'longitude': -78.5964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16733', 'place_name': 'Hazel Hurst', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.7059, 'longitude': -78.5825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16735', 'place_name': 'Kane', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.6619, 'longitude': -78.7978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16738', 'place_name': 'Lewis Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.8211, 'longitude': -78.6805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16740', 'place_name': 'Mount Jewett', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.7247, 'longitude': -78.6446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16743', 'place_name': 'Port Allegany', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.8169, 'longitude': -78.2799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16744', 'place_name': 'Rew', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.9015, 'longitude': -78.5392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16745', 'place_name': 'Rixford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.9262, 'longitude': -78.4942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16749', 'place_name': 'Smethport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.8021, 'longitude': -78.4702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16750', 'place_name': 'Turtlepoint', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'McKean', 'locality_code': '83', 'latitude': 41.8847, 'longitude': -78.3308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16113', 'place_name': 'Clark', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.2866, 'longitude': -80.4237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16114', 'place_name': 'Clarks Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.3931, 'longitude': -80.1837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16121', 'place_name': 'Farrell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.211, 'longitude': -80.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16124', 'place_name': 'Fredonia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.3241, 'longitude': -80.2699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16125', 'place_name': 'Greenville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.4057, 'longitude': -80.3739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16127', 'place_name': 'Grove City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.1607, 'longitude': -80.0841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16130', 'place_name': 'Hadley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.4432, 'longitude': -80.2153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16133', 'place_name': 'Jackson Center', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.2801, 'longitude': -80.1037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16134', 'place_name': 'Jamestown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.4566, 'longitude': -80.4492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16137', 'place_name': 'Mercer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.2325, 'longitude': -80.234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16145', 'place_name': 'Sandy Lake', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.3383, 'longitude': -80.0497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16146', 'place_name': 'Sharon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.2316, 'longitude': -80.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16148', 'place_name': 'Hermitage', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.2326, 'longitude': -80.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16150', 'place_name': 'Sharpsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.2676, 'longitude': -80.4656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16151', 'place_name': 'Sheakleyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.4435, 'longitude': -80.2055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16153', 'place_name': 'Stoneboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.3439, 'longitude': -80.0976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16154', 'place_name': 'Transfer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.3244, 'longitude': -80.4197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16159', 'place_name': 'West Middlesex', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.1741, 'longitude': -80.4528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16161', 'place_name': 'Wheatland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.2009, 'longitude': -80.4978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16311', 'place_name': 'Carlton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mercer', 'locality_code': '85', 'latitude': 41.4815, 'longitude': -80.0203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17002', 'place_name': 'Allensville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.5075, 'longitude': -77.8392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17004', 'place_name': 'Belleville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.6016, 'longitude': -77.7358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17009', 'place_name': 'Burnham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.6361, 'longitude': -77.5625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17029', 'place_name': 'Granville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.5537, 'longitude': -77.6255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17044', 'place_name': 'Lewistown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.5994, 'longitude': -77.5756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17051', 'place_name': 'Mc Veytown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.5046, 'longitude': -77.7186, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17054', 'place_name': 'Mattawana', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.496, 'longitude': -77.7237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17063', 'place_name': 'Milroy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.7203, 'longitude': -77.5567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17075', 'place_name': 'Newton Hamilton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.3931, 'longitude': -77.8316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17084', 'place_name': 'Reedsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.6722, 'longitude': -77.6116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17099', 'place_name': 'Yeagertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Mifflin', 'locality_code': '87', 'latitude': 40.6431, 'longitude': -77.5805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18058', 'place_name': 'Kunkletown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.8999, 'longitude': -75.476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18301', 'place_name': 'East Stroudsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0367, 'longitude': -75.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18320', 'place_name': 'Analomink', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0712, 'longitude': -75.2364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18321', 'place_name': 'Bartonsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.008, 'longitude': -75.2967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18322', 'place_name': 'Brodheadsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.9309, 'longitude': -75.4104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18323', 'place_name': 'Buck Hill Falls', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1879, 'longitude': -75.2657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18325', 'place_name': 'Canadensis', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.2338, 'longitude': -75.2573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18326', 'place_name': 'Cresco', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.154, 'longitude': -75.2805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18327', 'place_name': 'Delaware Water Gap', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.9793, 'longitude': -75.143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18330', 'place_name': 'Effort', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.9669, 'longitude': -75.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18331', 'place_name': 'Gilbert', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.9089, 'longitude': -75.4314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18332', 'place_name': 'Henryville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0889, 'longitude': -75.2798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18333', 'place_name': 'Kresgeville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.8982, 'longitude': -75.5074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18334', 'place_name': 'Long Pond', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0677, 'longitude': -75.4482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18335', 'place_name': 'Marshalls Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0508, 'longitude': -75.2083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18341', 'place_name': 'Minisink Hills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0004, 'longitude': -75.1371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18342', 'place_name': 'Mountainhome', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1737, 'longitude': -75.271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18344', 'place_name': 'Mount Pocono', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1216, 'longitude': -75.3529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18346', 'place_name': 'Pocono Summit', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1353, 'longitude': -75.4079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18347', 'place_name': 'Pocono Lake', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1187, 'longitude': -75.5559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18348', 'place_name': 'Pocono Lake Preserve', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0338, 'longitude': -75.308, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18349', 'place_name': 'Pocono Manor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1001, 'longitude': -75.3588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18350', 'place_name': 'Pocono Pines', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1054, 'longitude': -75.476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18352', 'place_name': 'Reeders', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.019, 'longitude': -75.336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18353', 'place_name': 'Saylorsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.8965, 'longitude': -75.367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18354', 'place_name': 'Sciota', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.9257, 'longitude': -75.325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18355', 'place_name': 'Scotrun', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0751, 'longitude': -75.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18356', 'place_name': 'Shawnee On Delaware', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0123, 'longitude': -75.1107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18357', 'place_name': 'Skytop', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.2336, 'longitude': -75.2389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18360', 'place_name': 'Stroudsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 40.9877, 'longitude': -75.2485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18370', 'place_name': 'Swiftwater', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0879, 'longitude': -75.3483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18372', 'place_name': 'Tannersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0472, 'longitude': -75.3244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18466', 'place_name': 'Tobyhanna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.1836, 'longitude': -75.3918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18610', 'place_name': 'Blakeslee', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Monroe', 'locality_code': '89', 'latitude': 41.0485, 'longitude': -75.5343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18041', 'place_name': 'East Greenville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.4119, 'longitude': -75.5056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18054', 'place_name': 'Green Lane', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3534, 'longitude': -75.4351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18070', 'place_name': 'Palm', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.4317, 'longitude': -75.5331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18073', 'place_name': 'Pennsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3911, 'longitude': -75.4866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18074', 'place_name': 'Perkiomenville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3157, 'longitude': -75.5022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18076', 'place_name': 'Red Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3758, 'longitude': -75.4846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18084', 'place_name': 'Sumneytown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3278, 'longitude': -75.454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18915', 'place_name': 'Colmar', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2728, 'longitude': -75.2563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18918', 'place_name': 'Earlington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.32, 'longitude': -75.3742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18924', 'place_name': 'Franconia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3081, 'longitude': -75.3586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18936', 'place_name': 'Montgomeryville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2241, 'longitude': -75.231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18957', 'place_name': 'Salford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3029, 'longitude': -75.4486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18958', 'place_name': 'Salfordville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2904, 'longitude': -75.4355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18964', 'place_name': 'Souderton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2884, 'longitude': -75.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18969', 'place_name': 'Telford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3205, 'longitude': -75.352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18971', 'place_name': 'Tylersport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.347, 'longitude': -75.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18979', 'place_name': 'Woxall', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3107, 'longitude': -75.4488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19001', 'place_name': 'Abington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1238, 'longitude': -75.1148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19002', 'place_name': 'Ambler', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1809, 'longitude': -75.2156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19004', 'place_name': 'Bala Cynwyd', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0118, 'longitude': -75.2342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19006', 'place_name': 'Huntingdon Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1284, 'longitude': -75.0607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19009', 'place_name': 'Bryn Athyn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.135, 'longitude': -75.0623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19012', 'place_name': 'Cheltenham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0603, 'longitude': -75.1048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19025', 'place_name': 'Dresher', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1431, 'longitude': -75.1624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19027', 'place_name': 'Elkins Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.075, 'longitude': -75.1315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19031', 'place_name': 'Flourtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1068, 'longitude': -75.2115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19034', 'place_name': 'Fort Washington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1386, 'longitude': -75.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19035', 'place_name': 'Gladwyne', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0451, 'longitude': -75.2821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19038', 'place_name': 'Glenside', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1096, 'longitude': -75.155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19040', 'place_name': 'Hatboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1785, 'longitude': -75.1072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19044', 'place_name': 'Horsham', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1821, 'longitude': -75.1479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19046', 'place_name': 'Jenkintown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.098, 'longitude': -75.1078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19066', 'place_name': 'Merion Station', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.003, 'longitude': -75.2503, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19072', 'place_name': 'Narberth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0177, 'longitude': -75.2594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19075', 'place_name': 'Oreland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1132, 'longitude': -75.1869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19090', 'place_name': 'Willow Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1567, 'longitude': -75.1269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19095', 'place_name': 'Wyncote', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0867, 'longitude': -75.1524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19096', 'place_name': 'Wynnewood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40, 'longitude': -75.276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19126', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0568, 'longitude': -75.1379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19401', 'place_name': 'Norristown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1245, 'longitude': -75.3304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19403', 'place_name': 'Norristown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1496, 'longitude': -75.3796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19404', 'place_name': 'Norristown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2119, 'longitude': -75.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19405', 'place_name': 'Bridgeport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.103, 'longitude': -75.3402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19406', 'place_name': 'King Of Prussia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0956, 'longitude': -75.3737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19407', 'place_name': 'Audubon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2119, 'longitude': -75.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19408', 'place_name': 'Eagleville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1566, 'longitude': -75.4131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19409', 'place_name': 'Fairview Village', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1579, 'longitude': -75.3871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19415', 'place_name': 'Eagleville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1572, 'longitude': -75.406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19422', 'place_name': 'Blue Bell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1576, 'longitude': -75.2799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19423', 'place_name': 'Cedars', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2174, 'longitude': -75.365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19424', 'place_name': 'Blue Bell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1523, 'longitude': -75.2663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19426', 'place_name': 'Collegeville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1913, 'longitude': -75.4373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19428', 'place_name': 'Conshohocken', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0825, 'longitude': -75.3044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19429', 'place_name': 'Conshohocken', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0793, 'longitude': -75.3016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19430', 'place_name': 'Creamery', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1851, 'longitude': -75.42, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19435', 'place_name': 'Frederick', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3275, 'longitude': -75.5692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19436', 'place_name': 'Gwynedd', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2021, 'longitude': -75.2507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19437', 'place_name': 'Gwynedd Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1811, 'longitude': -75.2579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19438', 'place_name': 'Harleysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2659, 'longitude': -75.3883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19440', 'place_name': 'Hatfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2778, 'longitude': -75.2975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19441', 'place_name': 'Harleysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2795, 'longitude': -75.3871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19443', 'place_name': 'Kulpsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.241, 'longitude': -75.3439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19444', 'place_name': 'Lafayette Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.0896, 'longitude': -75.2601, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19446', 'place_name': 'Lansdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2378, 'longitude': -75.2955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19450', 'place_name': 'Lederach', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2119, 'longitude': -75.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19451', 'place_name': 'Mainland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2119, 'longitude': -75.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19453', 'place_name': 'Mont Clare', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1364, 'longitude': -75.4999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19454', 'place_name': 'North Wales', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2166, 'longitude': -75.2565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19455', 'place_name': 'North Wales', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2109, 'longitude': -75.2782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19456', 'place_name': 'Oaks', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1318, 'longitude': -75.4596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19462', 'place_name': 'Plymouth Meeting', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1077, 'longitude': -75.2796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19464', 'place_name': 'Pottstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2635, 'longitude': -75.6172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19468', 'place_name': 'Royersford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2075, 'longitude': -75.5329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19472', 'place_name': 'Sassamansville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3448, 'longitude': -75.5775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19473', 'place_name': 'Schwenksville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2471, 'longitude': -75.4602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19474', 'place_name': 'Skippack', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2251, 'longitude': -75.4031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19477', 'place_name': 'Spring House', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1839, 'longitude': -75.2327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19478', 'place_name': 'Spring Mount', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2759, 'longitude': -75.4618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19484', 'place_name': 'Valley Forge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2119, 'longitude': -75.3559, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19486', 'place_name': 'West Point', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2033, 'longitude': -75.3019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19490', 'place_name': 'Worcester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.1929, 'longitude': -75.3576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19492', 'place_name': 'Zieglerville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.2901, 'longitude': -75.503, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '19525', 'place_name': 'Gilbertsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montgomery', 'locality_code': '91', 'latitude': 40.3059, 'longitude': -75.5953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17821', 'place_name': 'Danville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montour', 'locality_code': '93', 'latitude': 40.9799, 'longitude': -76.6229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17822', 'place_name': 'Danville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montour', 'locality_code': '93', 'latitude': 40.9674, 'longitude': -76.6049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17884', 'place_name': 'Washingtonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Montour', 'locality_code': '93', 'latitude': 41.0518, 'longitude': -76.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18001', 'place_name': 'Lehigh Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6934, 'longitude': -75.4712, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18002', 'place_name': 'Lehigh Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6656, 'longitude': -75.4262, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18003', 'place_name': 'Lehigh Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6934, 'longitude': -75.4712, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '18013', 'place_name': 'Bangor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.853, 'longitude': -75.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18014', 'place_name': 'Bath', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.7551, 'longitude': -75.4086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18015', 'place_name': 'Bethlehem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6002, 'longitude': -75.3805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18016', 'place_name': 'Bethlehem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6934, 'longitude': -75.4712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18017', 'place_name': 'Bethlehem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6622, 'longitude': -75.3903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18018', 'place_name': 'Bethlehem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6278, 'longitude': -75.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18020', 'place_name': 'Bethlehem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6693, 'longitude': -75.3349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18035', 'place_name': 'Cherryville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.751, 'longitude': -75.5394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18038', 'place_name': 'Danielsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.7866, 'longitude': -75.5186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18040', 'place_name': 'Easton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.7449, 'longitude': -75.2217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18042', 'place_name': 'Easton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6516, 'longitude': -75.224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18043', 'place_name': 'Easton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6884, 'longitude': -75.2207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18044', 'place_name': 'Easton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6884, 'longitude': -75.2207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18045', 'place_name': 'Easton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6957, 'longitude': -75.2865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18055', 'place_name': 'Hellertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.5817, 'longitude': -75.3255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18063', 'place_name': 'Martins Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.7825, 'longitude': -75.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18064', 'place_name': 'Nazareth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.745, 'longitude': -75.3199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18067', 'place_name': 'Northampton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.6998, 'longitude': -75.4874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18072', 'place_name': 'Pen Argyl', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.8518, 'longitude': -75.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18083', 'place_name': 'Stockertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.754, 'longitude': -75.2621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18085', 'place_name': 'Tatamy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.7406, 'longitude': -75.2549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18086', 'place_name': 'Treichlers', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.7361, 'longitude': -75.5449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18088', 'place_name': 'Walnutport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.7615, 'longitude': -75.5657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18091', 'place_name': 'Wind Gap', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.8169, 'longitude': -75.3264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18343', 'place_name': 'Mount Bethel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.9008, 'longitude': -75.1115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18351', 'place_name': 'Portland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northampton', 'locality_code': '95', 'latitude': 40.9214, 'longitude': -75.097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17017', 'place_name': 'Dalmatia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.6483, 'longitude': -76.8797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17730', 'place_name': 'Dewart', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 41.1092, 'longitude': -76.8766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17749', 'place_name': 'Mc Ewensville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 41.072, 'longitude': -76.8184, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17772', 'place_name': 'Turbotville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 41.1119, 'longitude': -76.7425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17777', 'place_name': 'Watsontown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 41.102, 'longitude': -76.8532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17801', 'place_name': 'Sunbury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.8551, 'longitude': -76.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17823', 'place_name': 'Dornsife', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7571, 'longitude': -76.7626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17824', 'place_name': 'Elysburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.8639, 'longitude': -76.5569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17830', 'place_name': 'Herndon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.6918, 'longitude': -76.8008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17832', 'place_name': 'Marion Heights', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.8046, 'longitude': -76.4651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17834', 'place_name': 'Kulpmont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7933, 'longitude': -76.4744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17836', 'place_name': 'Leck Kill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7101, 'longitude': -76.6271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17840', 'place_name': 'Locust Gap', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7727, 'longitude': -76.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17847', 'place_name': 'Milton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 41.0168, 'longitude': -76.8398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17850', 'place_name': 'Montandon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.9661, 'longitude': -76.8575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17851', 'place_name': 'Mount Carmel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7955, 'longitude': -76.4195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17857', 'place_name': 'Northumberland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.9044, 'longitude': -76.7908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17860', 'place_name': 'Paxinos', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.8448, 'longitude': -76.635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17865', 'place_name': 'Potts Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.9937, 'longitude': -76.7891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17866', 'place_name': 'Coal Township', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7917, 'longitude': -76.5519, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17867', 'place_name': 'Rebuck', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7141, 'longitude': -76.6886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17868', 'place_name': 'Riverside', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.9529, 'longitude': -76.6311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17872', 'place_name': 'Shamokin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.789, 'longitude': -76.5588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17877', 'place_name': 'Snydertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.879, 'longitude': -76.6673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17881', 'place_name': 'Trevorton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Northumberland', 'locality_code': '97', 'latitude': 40.7819, 'longitude': -76.6702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17006', 'place_name': 'Blain', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.3293, 'longitude': -77.5117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17020', 'place_name': 'Duncannon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.4087, 'longitude': -77.0473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17024', 'place_name': 'Elliottsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.4096, 'longitude': -77.3121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17037', 'place_name': 'Ickesburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.4363, 'longitude': -77.397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17040', 'place_name': 'Landisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.3326, 'longitude': -77.3191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17045', 'place_name': 'Liverpool', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.5753, 'longitude': -77.0083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17047', 'place_name': 'Loysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.3658, 'longitude': -77.4138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17053', 'place_name': 'Marysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.3351, 'longitude': -76.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17062', 'place_name': 'Millerstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.5505, 'longitude': -77.1298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17068', 'place_name': 'New Bloomfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.4193, 'longitude': -77.1938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17069', 'place_name': 'New Buffalo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.4543, 'longitude': -76.9697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17071', 'place_name': 'New Germantown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.309, 'longitude': -77.5697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17074', 'place_name': 'Newport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.4827, 'longitude': -77.1659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17090', 'place_name': 'Shermans Dale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Perry', 'locality_code': '99', 'latitude': 40.3299, 'longitude': -77.1809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19019', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19092', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19093', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19099', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9523, 'longitude': -75.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19101', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19102', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9489, 'longitude': -75.1661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19103', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9513, 'longitude': -75.1741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19104', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9597, 'longitude': -75.2024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19105', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9523, 'longitude': -75.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19106', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9474, 'longitude': -75.1473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19107', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9487, 'longitude': -75.1593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19108', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9598, 'longitude': -75.1616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19109', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9496, 'longitude': -75.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19110', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9502, 'longitude': -75.1636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19111', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0596, 'longitude': -75.0818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19112', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.8893, 'longitude': -75.1782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19114', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0634, 'longitude': -74.999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19115', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0903, 'longitude': -75.041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19116', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.1166, 'longitude': -75.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19118', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0723, 'longitude': -75.2034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19119', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0547, 'longitude': -75.1866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19120', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0343, 'longitude': -75.1213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19121', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9811, 'longitude': -75.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19122', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.978, 'longitude': -75.1459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19123', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.966, 'longitude': -75.151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19124', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0178, 'longitude': -75.0895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19125', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9788, 'longitude': -75.1262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19127', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0275, 'longitude': -75.2242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19128', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0402, 'longitude': -75.2231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19129', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0118, 'longitude': -75.1861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19130', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9677, 'longitude': -75.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19131', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9845, 'longitude': -75.2282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19132', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9954, 'longitude': -75.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19133', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9925, 'longitude': -75.1415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19134', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9925, 'longitude': -75.1133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19135', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0247, 'longitude': -75.0518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19136', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0422, 'longitude': -75.0244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19137', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0008, 'longitude': -75.0727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19138', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0568, 'longitude': -75.1569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19139', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9612, 'longitude': -75.2303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19140', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0118, 'longitude': -75.1456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19141', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0365, 'longitude': -75.1451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19142', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9223, 'longitude': -75.2338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19143', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9448, 'longitude': -75.2288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19144', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0338, 'longitude': -75.1731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19145', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9227, 'longitude': -75.1812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19146', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9379, 'longitude': -75.1794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19147', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9362, 'longitude': -75.1563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19148', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9207, 'longitude': -75.1595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19149', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0369, 'longitude': -75.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19150', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0726, 'longitude': -75.1706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19151', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9772, 'longitude': -75.2545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19152', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0606, 'longitude': -75.0471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19153', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9055, 'longitude': -75.2444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19154', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0897, 'longitude': -74.9781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19155', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19160', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19161', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19162', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19170', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19171', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9523, 'longitude': -75.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19172', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9473, 'longitude': -75.15, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19173', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9523, 'longitude': -75.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19175', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9906, 'longitude': -75.1296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19176', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9522, 'longitude': -75.1642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19177', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19178', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19179', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19181', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19182', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19183', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9523, 'longitude': -75.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19184', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19185', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19187', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9523, 'longitude': -75.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19188', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19190', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9484, 'longitude': -75.1442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19191', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9523, 'longitude': -75.1638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19192', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9511, 'longitude': -75.1676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19193', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19194', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19195', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 39.9525, 'longitude': -75.1645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19196', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19197', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19244', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19255', 'place_name': 'Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Philadelphia', 'locality_code': '101', 'latitude': 40.0018, 'longitude': -75.1179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18302', 'place_name': 'East Stroudsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.0936, 'longitude': -75.1187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18324', 'place_name': 'Bushkill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.1285, 'longitude': -75.0132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18328', 'place_name': 'Dingmans Ferry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.24, 'longitude': -74.938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18336', 'place_name': 'Matamoras', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.3674, 'longitude': -74.7154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18337', 'place_name': 'Milford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.3228, 'longitude': -74.8824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18340', 'place_name': 'Millrift', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.4093, 'longitude': -74.7432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18371', 'place_name': 'Tamiment', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.1423, 'longitude': -75.0271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18425', 'place_name': 'Greeley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.4372, 'longitude': -75.0125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18426', 'place_name': 'Greentown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.3321, 'longitude': -75.2819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18435', 'place_name': 'Lackawaxen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.482, 'longitude': -74.986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18451', 'place_name': 'Paupack', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.3962, 'longitude': -75.1963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18457', 'place_name': 'Rowland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.4719, 'longitude': -75.0485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18458', 'place_name': 'Shohola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.4182, 'longitude': -74.918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18464', 'place_name': 'Tafton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Pike', 'locality_code': '103', 'latitude': 41.4045, 'longitude': -75.183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16720', 'place_name': 'Austin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.6296, 'longitude': -78.0908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16746', 'place_name': 'Roulette', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.7738, 'longitude': -78.1538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16748', 'place_name': 'Shinglehouse', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.9572, 'longitude': -78.1906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16915', 'place_name': 'Coudersport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.7762, 'longitude': -77.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16922', 'place_name': 'Galeton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.723, 'longitude': -77.6548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16923', 'place_name': 'Genesee', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.9401, 'longitude': -77.8725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16927', 'place_name': 'Harrison Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.9587, 'longitude': -77.6587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16937', 'place_name': 'Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.9656, 'longitude': -77.7111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16941', 'place_name': 'Genesee', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.9883, 'longitude': -77.758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16948', 'place_name': 'Ulysses', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.8459, 'longitude': -77.7126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17729', 'place_name': 'Cross Fork', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Potter', 'locality_code': '105', 'latitude': 41.4737, 'longitude': -77.8095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17901', 'place_name': 'Pottsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.684, 'longitude': -76.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17921', 'place_name': 'Ashland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7732, 'longitude': -76.343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17922', 'place_name': 'Auburn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.5962, 'longitude': -76.1344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17923', 'place_name': 'Branchdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6643, 'longitude': -76.3328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17925', 'place_name': 'Brockton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7508, 'longitude': -76.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17929', 'place_name': 'Cressona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6284, 'longitude': -76.195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17930', 'place_name': 'Cumbola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7114, 'longitude': -76.1392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17931', 'place_name': 'Frackville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7825, 'longitude': -76.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17932', 'place_name': 'Frackville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.784, 'longitude': -76.2302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17933', 'place_name': 'Friedensburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6026, 'longitude': -76.2408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17934', 'place_name': 'Gilberton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7986, 'longitude': -76.2155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17935', 'place_name': 'Girardville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7922, 'longitude': -76.2858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17936', 'place_name': 'Gordon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7489, 'longitude': -76.3355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17938', 'place_name': 'Hegins', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6669, 'longitude': -76.4732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17941', 'place_name': 'Klingerstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6676, 'longitude': -76.6507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17943', 'place_name': 'Lavelle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7634, 'longitude': -76.3827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17944', 'place_name': 'Llewellyn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6729, 'longitude': -76.2791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17945', 'place_name': 'Locustdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7773, 'longitude': -76.3761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17946', 'place_name': 'Lost Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8081, 'longitude': -76.2407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17948', 'place_name': 'Mahanoy City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8123, 'longitude': -76.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17949', 'place_name': 'Mahanoy Plane', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.794, 'longitude': -76.2433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17951', 'place_name': 'Mar Lin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.683, 'longitude': -76.2387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17952', 'place_name': 'Mary D', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7473, 'longitude': -76.0628, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17953', 'place_name': 'Middleport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7331, 'longitude': -76.0858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17954', 'place_name': 'Minersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6904, 'longitude': -76.2597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17957', 'place_name': 'Muir', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.5926, 'longitude': -76.5161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17959', 'place_name': 'New Philadelphia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7195, 'longitude': -76.1158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17960', 'place_name': 'New Ringgold', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7149, 'longitude': -75.9484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17961', 'place_name': 'Orwigsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6431, 'longitude': -76.084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17963', 'place_name': 'Pine Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.5671, 'longitude': -76.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17964', 'place_name': 'Pitman', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7049, 'longitude': -76.5233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17965', 'place_name': 'Port Carbon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6977, 'longitude': -76.166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17966', 'place_name': 'Ravine', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.5745, 'longitude': -76.4038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17967', 'place_name': 'Ringtown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8559, 'longitude': -76.2349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17968', 'place_name': 'Sacramento', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6352, 'longitude': -76.6128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17970', 'place_name': 'Saint Clair', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7193, 'longitude': -76.1924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17972', 'place_name': 'Schuylkill Haven', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6306, 'longitude': -76.17, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17974', 'place_name': 'Seltzer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6954, 'longitude': -76.2338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17976', 'place_name': 'Shenandoah', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8167, 'longitude': -76.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17978', 'place_name': 'Spring Glen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6258, 'longitude': -76.6218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17979', 'place_name': 'Summit Station', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.5545, 'longitude': -76.2038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17980', 'place_name': 'Tower City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.5845, 'longitude': -76.55, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17981', 'place_name': 'Tremont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6343, 'longitude': -76.3905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17982', 'place_name': 'Tuscarora', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7815, 'longitude': -76.0134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17983', 'place_name': 'Valley View', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.6445, 'longitude': -76.5448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17985', 'place_name': 'Zion Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.9141, 'longitude': -76.1931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18211', 'place_name': 'Andreas', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7465, 'longitude': -75.8342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18214', 'place_name': 'Barnesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8138, 'longitude': -76.0611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18218', 'place_name': 'Coaldale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8219, 'longitude': -75.9104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18220', 'place_name': 'Delano', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8389, 'longitude': -76.0694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18231', 'place_name': 'Kelayres', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.9002, 'longitude': -76.0054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18237', 'place_name': 'Mcadoo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8979, 'longitude': -75.9971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18241', 'place_name': 'Nuremberg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.9395, 'longitude': -76.1716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18242', 'place_name': 'Oneida', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.911, 'longitude': -76.1223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18245', 'place_name': 'Quakake', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.8518, 'longitude': -76.036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18248', 'place_name': 'Sheppton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.902, 'longitude': -76.1188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18252', 'place_name': 'Tamaqua', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.7983, 'longitude': -75.9735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '19549', 'place_name': 'Port Clinton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Schuylkill', 'locality_code': '107', 'latitude': 40.5818, 'longitude': -76.0267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17812', 'place_name': 'Beaver Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.7528, 'longitude': -77.2318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17813', 'place_name': 'Beavertown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.7774, 'longitude': -77.1691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17827', 'place_name': 'Freeburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.765, 'longitude': -76.9395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17831', 'place_name': 'Hummels Wharf', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.8344, 'longitude': -76.8354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17833', 'place_name': 'Kreamer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.8031, 'longitude': -76.9639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17841', 'place_name': 'Mc Clure', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.6991, 'longitude': -77.3758, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17842', 'place_name': 'Middleburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.7977, 'longitude': -77.0468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17843', 'place_name': 'Beaver Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.7462, 'longitude': -77.2094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17853', 'place_name': 'Mount Pleasant Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.7237, 'longitude': -77.0135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17861', 'place_name': 'Paxtonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.7725, 'longitude': -77.0833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17862', 'place_name': 'Penns Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.8598, 'longitude': -77.0553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17864', 'place_name': 'Port Trevorton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.6996, 'longitude': -76.9082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17870', 'place_name': 'Selinsgrove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.8224, 'longitude': -76.8683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17876', 'place_name': 'Shamokin Dam', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.8459, 'longitude': -76.8224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17882', 'place_name': 'Troxelville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Snyder', 'locality_code': '109', 'latitude': 40.8031, 'longitude': -77.2053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15411', 'place_name': 'Addison', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.7476, 'longitude': -79.3454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15424', 'place_name': 'Confluence', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.8129, 'longitude': -79.3567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15485', 'place_name': 'Ursina', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.8173, 'longitude': -79.3306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15501', 'place_name': 'Somerset', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.0248, 'longitude': -79.0808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15502', 'place_name': 'Hidden Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.046, 'longitude': -79.2585, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15510', 'place_name': 'Somerset', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.9633, 'longitude': -79.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15520', 'place_name': 'Acosta', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1104, 'longitude': -79.0689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15530', 'place_name': 'Berlin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.9188, 'longitude': -78.9637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15531', 'place_name': 'Boswell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1918, 'longitude': -79.0362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15532', 'place_name': 'Boynton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.7673, 'longitude': -79.062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15538', 'place_name': 'Fairhope', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.868, 'longitude': -78.8362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15540', 'place_name': 'Fort Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.7961, 'longitude': -79.2472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15541', 'place_name': 'Friedens', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.011, 'longitude': -78.9033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15542', 'place_name': 'Garrett', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.8646, 'longitude': -79.0616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15544', 'place_name': 'Gray', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1377, 'longitude': -79.0926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15546', 'place_name': 'Jenners', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1431, 'longitude': -79.0428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15547', 'place_name': 'Jennerstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1595, 'longitude': -79.0616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15548', 'place_name': 'Kantner', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1011, 'longitude': -78.9387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15549', 'place_name': 'Listie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.0208, 'longitude': -79.0123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15551', 'place_name': 'Markleton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.8691, 'longitude': -79.2879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15552', 'place_name': 'Meyersdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.7905, 'longitude': -79.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15553', 'place_name': 'New Baltimore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.9828, 'longitude': -78.7719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15555', 'place_name': 'Quecreek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.0914, 'longitude': -79.0872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15557', 'place_name': 'Rockwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.9373, 'longitude': -79.1865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15558', 'place_name': 'Salisbury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.7531, 'longitude': -79.0835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15560', 'place_name': 'Shanksville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.0171, 'longitude': -78.9077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15561', 'place_name': 'Sipesville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.0964, 'longitude': -79.0902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15562', 'place_name': 'Springs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.748, 'longitude': -79.1237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15563', 'place_name': 'Stoystown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.0948, 'longitude': -78.9658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15564', 'place_name': 'Wellersburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.7299, 'longitude': -78.8441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15565', 'place_name': 'West Salisbury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 39.7542, 'longitude': -79.095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15924', 'place_name': 'Cairnbrook', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1149, 'longitude': -78.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15926', 'place_name': 'Central City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.0913, 'longitude': -78.8448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15928', 'place_name': 'Davidsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.2245, 'longitude': -78.9363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15935', 'place_name': 'Hollsopple', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.2343, 'longitude': -78.9515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15936', 'place_name': 'Hooversville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.1488, 'longitude': -78.9141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15937', 'place_name': 'Jerome', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.2084, 'longitude': -78.9873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15953', 'place_name': 'Seanor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.212, 'longitude': -78.8984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15959', 'place_name': 'Tire Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.268, 'longitude': -78.9156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15963', 'place_name': 'Windber', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Somerset', 'locality_code': '111', 'latitude': 40.2287, 'longitude': -78.8303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17731', 'place_name': 'Eagles Mere', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.4109, 'longitude': -76.5819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17758', 'place_name': 'Muncy Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.3426, 'longitude': -76.5852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17768', 'place_name': 'Shunk', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.5536, 'longitude': -76.7455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18614', 'place_name': 'Dushore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.5232, 'longitude': -76.4021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18616', 'place_name': 'Forksville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.5269, 'longitude': -76.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18619', 'place_name': 'Hillsgrove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.4482, 'longitude': -76.6979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18626', 'place_name': 'Laporte', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.4329, 'longitude': -76.5169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18628', 'place_name': 'Lopez', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.418, 'longitude': -76.3002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18632', 'place_name': 'Mildred', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Sullivan', 'locality_code': '113', 'latitude': 41.4792, 'longitude': -76.3831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18413', 'place_name': 'Clifford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.649, 'longitude': -75.5988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18421', 'place_name': 'Forest City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.6515, 'longitude': -75.4666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18430', 'place_name': 'Herrick Center', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.742, 'longitude': -75.4894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18441', 'place_name': 'Lenoxville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.6595, 'longitude': -75.6282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18465', 'place_name': 'Thompson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.834, 'longitude': -75.5342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18470', 'place_name': 'Union Dale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7079, 'longitude': -75.5465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18801', 'place_name': 'Montrose', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.8396, 'longitude': -75.8821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18812', 'place_name': 'Brackney', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.9666, 'longitude': -75.9375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18813', 'place_name': 'Brooklyn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7512, 'longitude': -75.8069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18816', 'place_name': 'Dimock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7465, 'longitude': -75.8983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18818', 'place_name': 'Friendsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.9164, 'longitude': -76.0257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18820', 'place_name': 'Gibson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.8034, 'longitude': -75.6441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18821', 'place_name': 'Great Bend', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.9717, 'longitude': -75.7432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18822', 'place_name': 'Hallstead', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.9598, 'longitude': -75.7826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18823', 'place_name': 'Harford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7761, 'longitude': -75.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18824', 'place_name': 'Hop Bottom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.6932, 'longitude': -75.7897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18825', 'place_name': 'Jackson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.8203, 'longitude': -75.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18826', 'place_name': 'Kingsley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7659, 'longitude': -75.7831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18827', 'place_name': 'Lanesboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.957, 'longitude': -75.5849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18828', 'place_name': 'Lawton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7573, 'longitude': -76.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18830', 'place_name': 'Little Meadows', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.9766, 'longitude': -76.1185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18834', 'place_name': 'New Milford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.8664, 'longitude': -75.7171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18842', 'place_name': 'South Gibson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7342, 'longitude': -75.6302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18843', 'place_name': 'South Montrose', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7973, 'longitude': -75.8913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18844', 'place_name': 'Springville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.7147, 'longitude': -75.9025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18847', 'place_name': 'Susquehanna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Susquehanna', 'locality_code': '115', 'latitude': 41.9487, 'longitude': -75.5862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16901', 'place_name': 'Wellsboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.7373, 'longitude': -77.308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16911', 'place_name': 'Arnot', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.6626, 'longitude': -77.123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16912', 'place_name': 'Blossburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.6698, 'longitude': -77.0797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16917', 'place_name': 'Covington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.7448, 'longitude': -77.0772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16920', 'place_name': 'Elkland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9882, 'longitude': -77.3134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16921', 'place_name': 'Gaines', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.7471, 'longitude': -77.568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16928', 'place_name': 'Knoxville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9596, 'longitude': -77.4357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16929', 'place_name': 'Lawrenceville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9783, 'longitude': -77.1136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16930', 'place_name': 'Liberty', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.5656, 'longitude': -77.1195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16932', 'place_name': 'Mainesburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.784, 'longitude': -76.9983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16933', 'place_name': 'Mansfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.8123, 'longitude': -77.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16935', 'place_name': 'Middlebury Center', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.8664, 'longitude': -77.3128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16936', 'place_name': 'Millerton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9625, 'longitude': -76.9748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16938', 'place_name': 'Morris', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.5475, 'longitude': -77.292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16939', 'place_name': 'Morris Run', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.6775, 'longitude': -77.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16940', 'place_name': 'Nelson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9787, 'longitude': -77.2419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16942', 'place_name': 'Osceola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9848, 'longitude': -77.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16943', 'place_name': 'Sabinsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.8408, 'longitude': -77.6155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16946', 'place_name': 'Tioga', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9125, 'longitude': -77.1393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16950', 'place_name': 'Westfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.9193, 'longitude': -77.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17765', 'place_name': 'Roaring Branch', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Tioga', 'locality_code': '117', 'latitude': 41.5692, 'longitude': -76.9421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17810', 'place_name': 'Allenwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 41.1264, 'longitude': -76.9724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17829', 'place_name': 'Hartleton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.9005, 'longitude': -77.1558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17835', 'place_name': 'Laurelton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.8831, 'longitude': -77.1986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17837', 'place_name': 'Lewisburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.9702, 'longitude': -76.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17844', 'place_name': 'Mifflinburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.9218, 'longitude': -77.0505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17845', 'place_name': 'Millmont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.8803, 'longitude': -77.1941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17855', 'place_name': 'New Berlin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.8802, 'longitude': -76.9861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17856', 'place_name': 'New Columbia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 41.0541, 'longitude': -76.9019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17880', 'place_name': 'Swengel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.8923, 'longitude': -77.1266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17883', 'place_name': 'Vicksburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.9387, 'longitude': -76.988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17885', 'place_name': 'Weikert', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.8584, 'longitude': -77.2953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17886', 'place_name': 'West Milton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 41.0179, 'longitude': -76.8708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17887', 'place_name': 'White Deer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 41.0759, 'longitude': -76.8747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17889', 'place_name': 'Winfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Union', 'locality_code': '119', 'latitude': 40.8908, 'longitude': -76.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16301', 'place_name': 'Oil City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.4319, 'longitude': -79.6916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16317', 'place_name': 'Cooperstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.498, 'longitude': -79.8757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16319', 'place_name': 'Cranberry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.3197, 'longitude': -79.6317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16323', 'place_name': 'Franklin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.4048, 'longitude': -79.8309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16341', 'place_name': 'Pleasantville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.5867, 'longitude': -79.5685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16342', 'place_name': 'Polk', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.3583, 'longitude': -79.9346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16343', 'place_name': 'Reno', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.411, 'longitude': -79.7493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16344', 'place_name': 'Rouseville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.4717, 'longitude': -79.6881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16346', 'place_name': 'Seneca', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.3744, 'longitude': -79.6759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16362', 'place_name': 'Utica', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.4798, 'longitude': -79.9403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16364', 'place_name': 'Venus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.3761, 'longitude': -79.5048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16372', 'place_name': 'Clintonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.2002, 'longitude': -79.8734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16373', 'place_name': 'Emlenton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.2028, 'longitude': -79.747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16374', 'place_name': 'Kennerdell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Venango', 'locality_code': '121', 'latitude': 41.2848, 'longitude': -79.7393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16312', 'place_name': 'Chandlers Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.9358, 'longitude': -79.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16313', 'place_name': 'Clarendon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.7302, 'longitude': -79.1719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16329', 'place_name': 'Irvine', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8117, 'longitude': -79.2643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16340', 'place_name': 'Pittsfield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8366, 'longitude': -79.4196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16345', 'place_name': 'Russell', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.9461, 'longitude': -79.1271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16347', 'place_name': 'Sheffield', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.7005, 'longitude': -79.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16350', 'place_name': 'Sugar Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.9475, 'longitude': -79.3186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16351', 'place_name': 'Tidioute', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.703, 'longitude': -79.3752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16352', 'place_name': 'Tiona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.7434, 'longitude': -79.0528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16365', 'place_name': 'Warren', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8436, 'longitude': -79.1726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16366', 'place_name': 'Warren', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8439, 'longitude': -79.145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16367', 'place_name': 'Warren', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8439, 'longitude': -79.145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16368', 'place_name': 'Irvine', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8117, 'longitude': -79.2643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16369', 'place_name': 'Irvine', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8117, 'longitude': -79.2643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16371', 'place_name': 'Youngsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8537, 'longitude': -79.3187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16402', 'place_name': 'Bear Lake', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.9701, 'longitude': -79.4614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16405', 'place_name': 'Columbus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.9382, 'longitude': -79.5731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16416', 'place_name': 'Garland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.8188, 'longitude': -79.4463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16420', 'place_name': 'Grand Valley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.6963, 'longitude': -79.5473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '16436', 'place_name': 'Spring Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Warren', 'locality_code': '123', 'latitude': 41.92, 'longitude': -79.4482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15004', 'place_name': 'Atlasburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3413, 'longitude': -80.3822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15019', 'place_name': 'Bulger', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.4051, 'longitude': -80.3622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15021', 'place_name': 'Burgettstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3821, 'longitude': -80.4044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15022', 'place_name': 'Charleroi', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1404, 'longitude': -79.92, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15033', 'place_name': 'Donora', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1768, 'longitude': -79.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15038', 'place_name': 'Elrama', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2521, 'longitude': -79.9252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15053', 'place_name': 'Joffre', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.38, 'longitude': -80.3605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15054', 'place_name': 'Langeloth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3625, 'longitude': -80.4086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15055', 'place_name': 'Lawrence', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3058, 'longitude': -80.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15057', 'place_name': 'Mc Donald', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3697, 'longitude': -80.2562, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '15060', 'place_name': 'Midway', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.368, 'longitude': -80.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15063', 'place_name': 'Monongahela', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1937, 'longitude': -79.9241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15067', 'place_name': 'New Eagle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2066, 'longitude': -79.9534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15078', 'place_name': 'Slovan', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3584, 'longitude': -80.3879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15301', 'place_name': 'Washington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1717, 'longitude': -80.256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15311', 'place_name': 'Amity', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0498, 'longitude': -80.1681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15312', 'place_name': 'Avella', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2734, 'longitude': -80.4565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15313', 'place_name': 'Beallsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0655, 'longitude': -80.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15314', 'place_name': 'Bentleyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1187, 'longitude': -80.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15317', 'place_name': 'Canonsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2706, 'longitude': -80.1668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15321', 'place_name': 'Cecil', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3234, 'longitude': -80.1879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15323', 'place_name': 'Claysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1179, 'longitude': -80.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15324', 'place_name': 'Cokeburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1008, 'longitude': -80.0652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15329', 'place_name': 'Prosperity', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0224, 'longitude': -80.2613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15330', 'place_name': 'Eighty Four', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1868, 'longitude': -80.0627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15331', 'place_name': 'Ellsworth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1073, 'longitude': -80.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15332', 'place_name': 'Finleyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2593, 'longitude': -79.9753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15333', 'place_name': 'Fredericktown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0026, 'longitude': -79.9981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15336', 'place_name': 'Gastonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2601, 'longitude': -79.9927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15339', 'place_name': 'Hendersonville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3018, 'longitude': -80.1543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15340', 'place_name': 'Hickory', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2925, 'longitude': -80.3025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15342', 'place_name': 'Houston', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2425, 'longitude': -80.2209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15345', 'place_name': 'Marianna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0331, 'longitude': -80.1145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15347', 'place_name': 'Meadow Lands', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2174, 'longitude': -80.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15348', 'place_name': 'Millsboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 39.9867, 'longitude': -79.9937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15350', 'place_name': 'Muse', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2928, 'longitude': -80.2003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15358', 'place_name': 'Richeyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0563, 'longitude': -79.9926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15360', 'place_name': 'Scenery Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0859, 'longitude': -80.0703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15361', 'place_name': 'Southview', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.3282, 'longitude': -80.2563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15363', 'place_name': 'Strabane', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2505, 'longitude': -80.1984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15365', 'place_name': 'Taylorstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1611, 'longitude': -80.3781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15366', 'place_name': 'Van Voorhis', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1562, 'longitude': -79.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15367', 'place_name': 'Venetia', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2755, 'longitude': -80.0598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15368', 'place_name': 'Vestaburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0144, 'longitude': -79.9889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15376', 'place_name': 'West Alexander', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1065, 'longitude': -80.4978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15377', 'place_name': 'West Finley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 39.9914, 'longitude': -80.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15378', 'place_name': 'Westland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2775, 'longitude': -80.2731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15379', 'place_name': 'West Middletown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.2417, 'longitude': -80.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15412', 'place_name': 'Allenport', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0959, 'longitude': -79.8499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15419', 'place_name': 'California', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0625, 'longitude': -79.8953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15423', 'place_name': 'Coal Center', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0973, 'longitude': -79.8839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15427', 'place_name': 'Daisytown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0743, 'longitude': -79.967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15429', 'place_name': 'Denbo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0081, 'longitude': -79.9392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15432', 'place_name': 'Dunlevy', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.1151, 'longitude': -79.8627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15434', 'place_name': 'Elco', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0797, 'longitude': -79.8758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15477', 'place_name': 'Roscoe', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0787, 'longitude': -79.8656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15483', 'place_name': 'Stockdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Washington', 'locality_code': '125', 'latitude': 40.0826, 'longitude': -79.8501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18405', 'place_name': 'Beach Lake', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.6034, 'longitude': -75.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18415', 'place_name': 'Damascus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.7366, 'longitude': -75.1312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18417', 'place_name': 'Equinunk', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.8117, 'longitude': -75.1891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18424', 'place_name': 'Gouldsboro', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.2448, 'longitude': -75.5037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18427', 'place_name': 'Hamlin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.4047, 'longitude': -75.4069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18428', 'place_name': 'Hawley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.4787, 'longitude': -75.1978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18431', 'place_name': 'Honesdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.5792, 'longitude': -75.2528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18436', 'place_name': 'Lake Ariel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.4395, 'longitude': -75.4313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18437', 'place_name': 'Lake Como', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.8666, 'longitude': -75.3231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18438', 'place_name': 'Lakeville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.4223, 'longitude': -75.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18439', 'place_name': 'Lakewood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.8171, 'longitude': -75.3838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18443', 'place_name': 'Milanville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.667, 'longitude': -75.1185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18445', 'place_name': 'Newfoundland', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.3041, 'longitude': -75.3384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18449', 'place_name': 'Orson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.8137, 'longitude': -75.448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18453', 'place_name': 'Pleasant Mount', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.7322, 'longitude': -75.3989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18454', 'place_name': 'Poyntelle', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.8206, 'longitude': -75.4199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18455', 'place_name': 'Preston Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.8867, 'longitude': -75.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18456', 'place_name': 'Prompton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.582, 'longitude': -75.3207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18459', 'place_name': 'South Canaan', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.616, 'longitude': -75.2747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18460', 'place_name': 'South Sterling', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.2643, 'longitude': -75.348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18461', 'place_name': 'Starlight', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.9251, 'longitude': -75.3212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18462', 'place_name': 'Starrucca', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.8907, 'longitude': -75.449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18463', 'place_name': 'Sterling', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.3412, 'longitude': -75.3899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18469', 'place_name': 'Tyler Hill', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.7011, 'longitude': -75.1422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18472', 'place_name': 'Waymart', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.5703, 'longitude': -75.4065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18473', 'place_name': 'White Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wayne', 'locality_code': '127', 'latitude': 41.5262, 'longitude': -75.2035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15062', 'place_name': 'Monessen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1524, 'longitude': -79.8835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15068', 'place_name': 'New Kensington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.5616, 'longitude': -79.7129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15069', 'place_name': 'New Kensington', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.5698, 'longitude': -79.7648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15072', 'place_name': 'Pricedale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1393, 'longitude': -79.8562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15083', 'place_name': 'Sutersville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2382, 'longitude': -79.7922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15085', 'place_name': 'Trafford', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3857, 'longitude': -79.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15087', 'place_name': 'Webster', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1851, 'longitude': -79.8487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15089', 'place_name': 'West Newton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2075, 'longitude': -79.758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15448', 'place_name': 'Jacobs Creek', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1331, 'longitude': -79.7417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15479', 'place_name': 'Smithton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1553, 'longitude': -79.7381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15601', 'place_name': 'Greensburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3074, 'longitude': -79.5424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15605', 'place_name': 'Greensburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3602, 'longitude': -79.4398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15606', 'place_name': 'Greensburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3015, 'longitude': -79.5389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15610', 'place_name': 'Acme', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1201, 'longitude': -79.4051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15611', 'place_name': 'Adamsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3126, 'longitude': -79.6565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15612', 'place_name': 'Alverton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1373, 'longitude': -79.5997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15613', 'place_name': 'Apollo', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.5565, 'longitude': -79.5772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15615', 'place_name': 'Ardara', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3578, 'longitude': -79.735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15616', 'place_name': 'Armbrust', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2237, 'longitude': -79.5512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15617', 'place_name': 'Arona', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.268, 'longitude': -79.6591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15618', 'place_name': 'Avonmore', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.5221, 'longitude': -79.4853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15619', 'place_name': 'Bovard', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3198, 'longitude': -79.5034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15620', 'place_name': 'Bradenville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3238, 'longitude': -79.3434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15621', 'place_name': 'Calumet', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2109, 'longitude': -79.4853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15622', 'place_name': 'Champion', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.044, 'longitude': -79.3247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15623', 'place_name': 'Claridge', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3692, 'longitude': -79.619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15624', 'place_name': 'Crabtree', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3623, 'longitude': -79.4706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15625', 'place_name': 'Darragh', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2665, 'longitude': -79.6787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15626', 'place_name': 'Delmont', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.4139, 'longitude': -79.5764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15627', 'place_name': 'Derry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3349, 'longitude': -79.3326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15628', 'place_name': 'Donegal', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.0996, 'longitude': -79.381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15629', 'place_name': 'East Vandergrift', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.598, 'longitude': -79.5624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15632', 'place_name': 'Export', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.4252, 'longitude': -79.611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15633', 'place_name': 'Forbes Road', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.354, 'longitude': -79.5217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15634', 'place_name': 'Grapeville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3239, 'longitude': -79.6049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15635', 'place_name': 'Hannastown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.352, 'longitude': -79.4979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15636', 'place_name': 'Harrison City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.366, 'longitude': -79.6565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15637', 'place_name': 'Herminie', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2455, 'longitude': -79.7172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15638', 'place_name': 'Hostetter', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2662, 'longitude': -79.3984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15639', 'place_name': 'Hunker', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2149, 'longitude': -79.5824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15640', 'place_name': 'Hutchinson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2251, 'longitude': -79.7328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15641', 'place_name': 'Hyde Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.6311, 'longitude': -79.5899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15642', 'place_name': 'Irwin', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3191, 'longitude': -79.7205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15644', 'place_name': 'Jeannette', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3295, 'longitude': -79.6144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15646', 'place_name': 'Jones Mills', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.0889, 'longitude': -79.3427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15647', 'place_name': 'Larimer', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3453, 'longitude': -79.7264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15650', 'place_name': 'Latrobe', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2926, 'longitude': -79.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15655', 'place_name': 'Laughlintown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.212, 'longitude': -79.1978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15658', 'place_name': 'Ligonier', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2431, 'longitude': -79.2375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15660', 'place_name': 'Lowber', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2459, 'longitude': -79.7709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15661', 'place_name': 'Loyalhanna', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3222, 'longitude': -79.3601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15662', 'place_name': 'Luxor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3342, 'longitude': -79.4781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15663', 'place_name': 'Madison', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2467, 'longitude': -79.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15664', 'place_name': 'Mammoth', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3108, 'longitude': -79.6172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15665', 'place_name': 'Manor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.334, 'longitude': -79.67, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15666', 'place_name': 'Mount Pleasant', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1742, 'longitude': -79.5134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15668', 'place_name': 'Murrysville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.4467, 'longitude': -79.6842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15670', 'place_name': 'New Alexandria', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3987, 'longitude': -79.422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15671', 'place_name': 'New Derry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3494, 'longitude': -79.3225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15672', 'place_name': 'New Stanton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2192, 'longitude': -79.6095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15674', 'place_name': 'Norvelt', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.216, 'longitude': -79.4872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15675', 'place_name': 'Penn', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3301, 'longitude': -79.6413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15676', 'place_name': 'Pleasant Unity', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2424, 'longitude': -79.4542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15677', 'place_name': 'Rector', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1864, 'longitude': -79.2473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15678', 'place_name': 'Rillton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2872, 'longitude': -79.7262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15679', 'place_name': 'Ruffs Dale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1585, 'longitude': -79.6277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15680', 'place_name': 'Salina', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.5189, 'longitude': -79.4959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15683', 'place_name': 'Scottdale', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1029, 'longitude': -79.593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15684', 'place_name': 'Slickville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.4653, 'longitude': -79.5067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15685', 'place_name': 'Southwest', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3602, 'longitude': -79.4398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15687', 'place_name': 'Stahlstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1386, 'longitude': -79.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15688', 'place_name': 'Tarrs', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1686, 'longitude': -79.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15689', 'place_name': 'United', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2184, 'longitude': -79.4878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15690', 'place_name': 'Vandergrift', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.6418, 'longitude': -79.5399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15691', 'place_name': 'Wendel', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.294, 'longitude': -79.6866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15692', 'place_name': 'Westmoreland City', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3294, 'longitude': -79.6806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15693', 'place_name': 'Whitney', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2534, 'longitude': -79.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15695', 'place_name': 'Wyano', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.1962, 'longitude': -79.6942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15696', 'place_name': 'Youngstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2793, 'longitude': -79.3661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15697', 'place_name': 'Youngwood', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2395, 'longitude': -79.5823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15698', 'place_name': 'Yukon', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.2155, 'longitude': -79.6849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15779', 'place_name': 'Torrance', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3992, 'longitude': -79.2177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15923', 'place_name': 'Bolivar', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3673, 'longitude': -79.1605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15944', 'place_name': 'New Florence', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.3823, 'longitude': -79.0968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '15954', 'place_name': 'Seward', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Westmoreland', 'locality_code': '129', 'latitude': 40.4099, 'longitude': -79.0232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18419', 'place_name': 'Factoryville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.5762, 'longitude': -75.7652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18446', 'place_name': 'Nicholson', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.6412, 'longitude': -75.7641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18615', 'place_name': 'Falls', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.4667, 'longitude': -75.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18623', 'place_name': 'Laceyville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.6662, 'longitude': -76.1426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18625', 'place_name': 'Lake Winola', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.5096, 'longitude': -75.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18629', 'place_name': 'Mehoopany', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.5587, 'longitude': -76.1035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18630', 'place_name': 'Meshoppen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.6392, 'longitude': -76.0155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18636', 'place_name': 'Noxen', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.4181, 'longitude': -76.046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '18657', 'place_name': 'Tunkhannock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'Wyoming', 'locality_code': '131', 'latitude': 41.5387, 'longitude': -75.9466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17019', 'place_name': 'Dillsburg', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0964, 'longitude': -77.0339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17302', 'place_name': 'Airville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.821, 'longitude': -76.4012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17309', 'place_name': 'Brogue', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8608, 'longitude': -76.4673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17311', 'place_name': 'Codorus', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8718, 'longitude': -76.7599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17312', 'place_name': 'Craley', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9467, 'longitude': -76.5066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17313', 'place_name': 'Dallastown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9124, 'longitude': -76.6535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17314', 'place_name': 'Delta', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.7518, 'longitude': -76.3441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17315', 'place_name': 'Dover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0062, 'longitude': -76.8555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17317', 'place_name': 'East Prospect', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9701, 'longitude': -76.5217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17318', 'place_name': 'Emigsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0215, 'longitude': -76.7266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17319', 'place_name': 'Etters', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.1545, 'longitude': -76.8019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17321', 'place_name': 'Fawn Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.751, 'longitude': -76.4392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17322', 'place_name': 'Felton', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.836, 'longitude': -76.5937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17323', 'place_name': 'Franklintown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.075, 'longitude': -77.0279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17327', 'place_name': 'Glen Rock', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.7813, 'longitude': -76.7477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17329', 'place_name': 'Glenville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.757, 'longitude': -76.8153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17331', 'place_name': 'Hanover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.7943, 'longitude': -76.9812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17332', 'place_name': 'Hanover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8007, 'longitude': -76.983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17333', 'place_name': 'Hanover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8007, 'longitude': -76.983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17334', 'place_name': 'Hanover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.805, 'longitude': -76.9736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17335', 'place_name': 'Hanover', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8144, 'longitude': -76.9837, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17339', 'place_name': 'Lewisberry', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.1463, 'longitude': -76.87, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17342', 'place_name': 'Loganville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8536, 'longitude': -76.708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17345', 'place_name': 'Manchester', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0695, 'longitude': -76.7332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17347', 'place_name': 'Mount Wolf', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0711, 'longitude': -76.6966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17349', 'place_name': 'New Freedom', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.7423, 'longitude': -76.6841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17352', 'place_name': 'New Park', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.76, 'longitude': -76.5042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17354', 'place_name': 'Porters Sideling', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8246, 'longitude': -76.8993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17355', 'place_name': 'Railroad', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.7573, 'longitude': -76.6994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17356', 'place_name': 'Red Lion', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9026, 'longitude': -76.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17358', 'place_name': 'Rossville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.973, 'longitude': -76.6878, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '17360', 'place_name': 'Seven Valleys', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8556, 'longitude': -76.7383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17361', 'place_name': 'Shrewsbury', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.7601, 'longitude': -76.6748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17362', 'place_name': 'Spring Grove', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8572, 'longitude': -76.8774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17363', 'place_name': 'Stewartstown', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.772, 'longitude': -76.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17364', 'place_name': 'Thomasville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9346, 'longitude': -76.8822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17365', 'place_name': 'Wellsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0557, 'longitude': -76.9443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17366', 'place_name': 'Windsor', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9233, 'longitude': -76.5591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17368', 'place_name': 'Wrightsville', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9966, 'longitude': -76.527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17370', 'place_name': 'York Haven', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.1222, 'longitude': -76.7737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17371', 'place_name': 'York New Salem', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9006, 'longitude': -76.7896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17401', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9635, 'longitude': -76.7269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17402', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.959, 'longitude': -76.6592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17403', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9494, 'longitude': -76.713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17404', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0023, 'longitude': -76.7712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17405', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0086, 'longitude': -76.5972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17406', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 40.0046, 'longitude': -76.5947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17407', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.8833, 'longitude': -76.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '17408', 'place_name': 'York', 'state': 'Pennsylvania', 'state_ab': 'PA', 'county': 'York', 'locality_code': '133', 'latitude': 39.9492, 'longitude': -76.8018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2806', 'place_name': 'Barrington', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Bristol', 'locality_code': '1', 'latitude': 41.7443, 'longitude': -71.3175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2809', 'place_name': 'Bristol', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Bristol', 'locality_code': '1', 'latitude': 41.6825, 'longitude': -71.2676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2872', 'place_name': 'Prudence Island', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Bristol', 'locality_code': '1', 'latitude': 41.7071, 'longitude': -71.2868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2885', 'place_name': 'Warren', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Bristol', 'locality_code': '1', 'latitude': 41.7256, 'longitude': -71.2702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2816', 'place_name': 'Coventry', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.6914, 'longitude': -71.5768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2817', 'place_name': 'West Greenwich', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.64, 'longitude': -71.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2818', 'place_name': 'East Greenwich', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.6498, 'longitude': -71.474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2827', 'place_name': 'Greene', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.7062, 'longitude': -71.7356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2886', 'place_name': 'Warwick', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.7026, 'longitude': -71.4476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2887', 'place_name': 'Warwick', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.7001, 'longitude': -71.4162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2888', 'place_name': 'Warwick', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.7494, 'longitude': -71.4084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2889', 'place_name': 'Warwick', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.7141, 'longitude': -71.3901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2893', 'place_name': 'West Warwick', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Kent', 'locality_code': '3', 'latitude': 41.7004, 'longitude': -71.5183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2801', 'place_name': 'Adamsville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.5301, 'longitude': -71.2841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2835', 'place_name': 'Jamestown', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.5164, 'longitude': -71.3761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2837', 'place_name': 'Little Compton', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.522, 'longitude': -71.1612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2840', 'place_name': 'Newport', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.4876, 'longitude': -71.3271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2841', 'place_name': 'Newport', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.499, 'longitude': -71.299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2842', 'place_name': 'Middletown', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.5198, 'longitude': -71.2731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2871', 'place_name': 'Portsmouth', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.5944, 'longitude': -71.252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2878', 'place_name': 'Tiverton', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Newport', 'locality_code': '5', 'latitude': 41.6338, 'longitude': -71.1808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2802', 'place_name': 'Albion', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9512, 'longitude': -71.4545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2814', 'place_name': 'Chepachet', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9155, 'longitude': -71.6795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2815', 'place_name': 'Clayville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7778, 'longitude': -71.6706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2823', 'place_name': 'Fiskeville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7312, 'longitude': -71.5468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2824', 'place_name': 'Forestdale', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 42.0002, 'longitude': -71.5631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2825', 'place_name': 'Foster', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7815, 'longitude': -71.7187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2826', 'place_name': 'Glendale', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9762, 'longitude': -71.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2828', 'place_name': 'Greenville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8734, 'longitude': -71.5569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2829', 'place_name': 'Harmony', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8793, 'longitude': -71.5894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2830', 'place_name': 'Harrisville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9764, 'longitude': -71.6534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2831', 'place_name': 'Hope', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7516, 'longitude': -71.5612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2838', 'place_name': 'Manville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9689, 'longitude': -71.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2839', 'place_name': 'Mapleville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9417, 'longitude': -71.6376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2857', 'place_name': 'North Scituate', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8439, 'longitude': -71.6242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2858', 'place_name': 'Oakland', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9573, 'longitude': -71.6478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2859', 'place_name': 'Pascoag', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9627, 'longitude': -71.7099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2860', 'place_name': 'Pawtucket', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8729, 'longitude': -71.3907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2861', 'place_name': 'Pawtucket', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8814, 'longitude': -71.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2862', 'place_name': 'Pawtucket', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8612, 'longitude': -71.3691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2863', 'place_name': 'Central Falls', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8883, 'longitude': -71.3945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2864', 'place_name': 'Cumberland', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9484, 'longitude': -71.4154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2865', 'place_name': 'Lincoln', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9089, 'longitude': -71.4348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2876', 'place_name': 'Slatersville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9984, 'longitude': -71.5763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2895', 'place_name': 'Woonsocket', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9846, 'longitude': -71.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2896', 'place_name': 'North Smithfield', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.9724, 'longitude': -71.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2901', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8227, 'longitude': -71.4145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2902', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8184, 'longitude': -71.4249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2903', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.82, 'longitude': -71.4158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2904', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8541, 'longitude': -71.4378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2905', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7845, 'longitude': -71.3959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2906', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8351, 'longitude': -71.3971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2907', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7971, 'longitude': -71.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2908', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8383, 'longitude': -71.4377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2909', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8206, 'longitude': -71.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2910', 'place_name': 'Cranston', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7766, 'longitude': -71.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2911', 'place_name': 'North Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8547, 'longitude': -71.4735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2912', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.824, 'longitude': -71.4128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2914', 'place_name': 'East Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8138, 'longitude': -71.3688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2915', 'place_name': 'Riverside', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7723, 'longitude': -71.3542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2916', 'place_name': 'Rumford', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8425, 'longitude': -71.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2917', 'place_name': 'Smithfield', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8964, 'longitude': -71.5207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2918', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8415, 'longitude': -71.4404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2919', 'place_name': 'Johnston', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.8274, 'longitude': -71.52, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2920', 'place_name': 'Cranston', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7716, 'longitude': -71.4659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2921', 'place_name': 'Cranston', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.7614, 'longitude': -71.5061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2940', 'place_name': 'Providence', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Providence', 'locality_code': '7', 'latitude': 41.824, 'longitude': -71.4128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2804', 'place_name': 'Ashaway', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4231, 'longitude': -71.7837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2807', 'place_name': 'Block Island', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.1715, 'longitude': -71.5748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2808', 'place_name': 'Bradford', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4114, 'longitude': -71.7465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2812', 'place_name': 'Carolina', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4691, 'longitude': -71.6751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2813', 'place_name': 'Charlestown', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4007, 'longitude': -71.6615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2822', 'place_name': 'Exeter', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.574, 'longitude': -71.6076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2832', 'place_name': 'Hope Valley', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.5096, 'longitude': -71.7339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2833', 'place_name': 'Hopkinton', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4751, 'longitude': -71.7726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2836', 'place_name': 'Kenyon', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4474, 'longitude': -71.6204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2852', 'place_name': 'North Kingstown', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.5894, 'longitude': -71.4625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2873', 'place_name': 'Rockville', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.5199, 'longitude': -71.774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2874', 'place_name': 'Saunderstown', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.5105, 'longitude': -71.4427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2875', 'place_name': 'Shannock', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.456, 'longitude': -71.6355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2877', 'place_name': 'Slocum', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.5289, 'longitude': -71.5299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2879', 'place_name': 'Wakefield', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4437, 'longitude': -71.5342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2880', 'place_name': 'Wakefield', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.3753, 'longitude': -71.6439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2881', 'place_name': 'Kingston', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4803, 'longitude': -71.5292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2882', 'place_name': 'Narragansett', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4353, 'longitude': -71.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2883', 'place_name': 'Peace Dale', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.4512, 'longitude': -71.4987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2891', 'place_name': 'Westerly', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.3691, 'longitude': -71.8126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2892', 'place_name': 'West Kingston', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.5058, 'longitude': -71.6211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2894', 'place_name': 'Wood River Junction', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.45, 'longitude': -71.7074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '2898', 'place_name': 'Wyoming', 'state': 'Rhode Island', 'state_ab': 'RI', 'county': 'Washington', 'locality_code': '9', 'latitude': 41.5041, 'longitude': -71.663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29620', 'place_name': 'Abbeville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Abbeville', 'locality_code': '1', 'latitude': 34.1819, 'longitude': -82.3785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29628', 'place_name': 'Calhoun Falls', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Abbeville', 'locality_code': '1', 'latitude': 34.0999, 'longitude': -82.5805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29638', 'place_name': 'Donalds', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Abbeville', 'locality_code': '1', 'latitude': 34.3304, 'longitude': -82.3367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29639', 'place_name': 'Due West', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Abbeville', 'locality_code': '1', 'latitude': 34.3344, 'longitude': -82.4002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29659', 'place_name': 'Lowndesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Abbeville', 'locality_code': '1', 'latitude': 34.2126, 'longitude': -82.6496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29137', 'place_name': 'Salley', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5972, 'longitude': -81.3184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29164', 'place_name': 'Wagener', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.6494, 'longitude': -81.3995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29801', 'place_name': 'Aiken', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.553, 'longitude': -81.7194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29802', 'place_name': 'Aiken', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5604, 'longitude': -81.7196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29803', 'place_name': 'Aiken', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5059, 'longitude': -81.6951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29804', 'place_name': 'Aiken', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5377, 'longitude': -81.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29805', 'place_name': 'Aiken', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.6993, 'longitude': -81.6465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29808', 'place_name': 'Aiken', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5377, 'longitude': -81.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29809', 'place_name': 'New Ellenton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.413, 'longitude': -81.69, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29816', 'place_name': 'Bath', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5046, 'longitude': -81.869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29822', 'place_name': 'Clearwater', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.4997, 'longitude': -81.8649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29828', 'place_name': 'Gloverville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5182, 'longitude': -81.8277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29829', 'place_name': 'Graniteville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.563, 'longitude': -81.8147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29831', 'place_name': 'Jackson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.3389, 'longitude': -81.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29834', 'place_name': 'Langley', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5179, 'longitude': -81.844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29839', 'place_name': 'Montmorenci', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5073, 'longitude': -81.5992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29841', 'place_name': 'North Augusta', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5251, 'longitude': -81.9394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29842', 'place_name': 'Beech Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.4707, 'longitude': -81.8639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29850', 'place_name': 'Vaucluse', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.6126, 'longitude': -81.8098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29851', 'place_name': 'Warrenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.526, 'longitude': -81.7956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29856', 'place_name': 'Windsor', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.4674, 'longitude': -81.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29860', 'place_name': 'North Augusta', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.6028, 'longitude': -81.9748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29861', 'place_name': 'North Augusta', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Aiken', 'locality_code': '3', 'latitude': 33.5018, 'longitude': -81.9651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29810', 'place_name': 'Allendale', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Allendale', 'locality_code': '5', 'latitude': 33.0077, 'longitude': -81.3203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29827', 'place_name': 'Fairfax', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Allendale', 'locality_code': '5', 'latitude': 32.9515, 'longitude': -81.2586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29836', 'place_name': 'Martin', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Allendale', 'locality_code': '5', 'latitude': 33.1093, 'longitude': -81.5003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29846', 'place_name': 'Sycamore', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Allendale', 'locality_code': '5', 'latitude': 33.0241, 'longitude': -81.2258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29849', 'place_name': 'Ulmer', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Allendale', 'locality_code': '5', 'latitude': 33.0988, 'longitude': -81.2068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29621', 'place_name': 'Anderson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.5261, 'longitude': -82.6304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29622', 'place_name': 'Anderson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.5034, 'longitude': -82.6501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29623', 'place_name': 'Anderson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.4381, 'longitude': -82.8354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29624', 'place_name': 'Anderson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.4373, 'longitude': -82.6251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29625', 'place_name': 'Anderson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.5271, 'longitude': -82.7087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29626', 'place_name': 'Anderson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.4596, 'longitude': -82.7614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29627', 'place_name': 'Belton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.5087, 'longitude': -82.5101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29654', 'place_name': 'Honea Path', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.4417, 'longitude': -82.4255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29655', 'place_name': 'Iva', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.3198, 'longitude': -82.6574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29656', 'place_name': 'La France', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.6252, 'longitude': -82.7654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29669', 'place_name': 'Pelzer', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.6461, 'longitude': -82.4673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29670', 'place_name': 'Pendleton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.6369, 'longitude': -82.7406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29677', 'place_name': 'Sandy Springs', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.5975, 'longitude': -82.7568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29684', 'place_name': 'Starr', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.3962, 'longitude': -82.6897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29689', 'place_name': 'Townville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.5226, 'longitude': -82.8963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29697', 'place_name': 'Williamston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Anderson', 'locality_code': '7', 'latitude': 34.6206, 'longitude': -82.511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29003', 'place_name': 'Bamberg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Bamberg', 'locality_code': '9', 'latitude': 33.2779, 'longitude': -81.0177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29042', 'place_name': 'Denmark', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Bamberg', 'locality_code': '9', 'latitude': 33.3209, 'longitude': -81.1407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29081', 'place_name': 'Ehrhardt', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Bamberg', 'locality_code': '9', 'latitude': 33.1044, 'longitude': -81.0221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29843', 'place_name': 'Olar', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Bamberg', 'locality_code': '9', 'latitude': 33.1836, 'longitude': -81.164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29812', 'place_name': 'Barnwell', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Barnwell', 'locality_code': '11', 'latitude': 33.2335, 'longitude': -81.3523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29813', 'place_name': 'Hilda', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Barnwell', 'locality_code': '11', 'latitude': 33.2735, 'longitude': -81.247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29817', 'place_name': 'Blackville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Barnwell', 'locality_code': '11', 'latitude': 33.3645, 'longitude': -81.2718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29826', 'place_name': 'Elko', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Barnwell', 'locality_code': '11', 'latitude': 33.3804, 'longitude': -81.3796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29853', 'place_name': 'Williston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Barnwell', 'locality_code': '11', 'latitude': 33.3926, 'longitude': -81.4161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29901', 'place_name': 'Beaufort', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.4244, 'longitude': -80.5653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29902', 'place_name': 'Beaufort', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.4316, 'longitude': -80.6698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29903', 'place_name': 'Beaufort', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.444, 'longitude': -80.7352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29904', 'place_name': 'Beaufort', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.3906, 'longitude': -80.661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29905', 'place_name': 'Parris Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.3281, 'longitude': -80.6915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29906', 'place_name': 'Beaufort', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.3823, 'longitude': -80.7603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29907', 'place_name': 'Beaufort', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.4316, 'longitude': -80.6698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29910', 'place_name': 'Bluffton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.2513, 'longitude': -80.8721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29914', 'place_name': 'Dale', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.5527, 'longitude': -80.677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29915', 'place_name': 'Daufuskie Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.1145, 'longitude': -80.8686, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29920', 'place_name': 'Saint Helena Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.3716, 'longitude': -80.5383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29925', 'place_name': 'Hilton Head Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.2132, 'longitude': -80.7997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29926', 'place_name': 'Hilton Head Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.2077, 'longitude': -80.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29928', 'place_name': 'Hilton Head Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.1665, 'longitude': -80.7569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29931', 'place_name': 'Lobeco', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.5527, 'longitude': -80.7434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29935', 'place_name': 'Port Royal', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.3874, 'longitude': -80.6844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29938', 'place_name': 'Hilton Head Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.3906, 'longitude': -80.661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29940', 'place_name': 'Seabrook', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.5693, 'longitude': -80.7192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29941', 'place_name': 'Sheldon', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Beaufort', 'locality_code': '13', 'latitude': 32.5431, 'longitude': -80.8126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29410', 'place_name': 'Hanahan', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 32.9185, 'longitude': -80.022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29431', 'place_name': 'Bonneau', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.2703, 'longitude': -79.8736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29434', 'place_name': 'Cordesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.1362, 'longitude': -79.8826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29436', 'place_name': 'Cross', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.3364, 'longitude': -80.1859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29445', 'place_name': 'Goose Creek', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.058, 'longitude': -80.0101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29450', 'place_name': 'Huger', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.0439, 'longitude': -79.7841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29453', 'place_name': 'Jamestown', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.2221, 'longitude': -79.6282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29456', 'place_name': 'Ladson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 32.993, 'longitude': -80.1257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29461', 'place_name': 'Moncks Corner', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.1971, 'longitude': -80.0233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29468', 'place_name': 'Pineville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.4199, 'longitude': -80.0932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29469', 'place_name': 'Pinopolis', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.2241, 'longitude': -80.0398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29476', 'place_name': 'Russellville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.3971, 'longitude': -79.9717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29479', 'place_name': 'Saint Stephen', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.3362, 'longitude': -79.9236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29486', 'place_name': 'Summerville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 33.0185, 'longitude': -80.1756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29492', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Berkeley', 'locality_code': '15', 'latitude': 32.9668, 'longitude': -79.8528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29030', 'place_name': 'Cameron', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Calhoun', 'locality_code': '17', 'latitude': 33.5703, 'longitude': -80.7081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29135', 'place_name': 'Saint Matthews', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Calhoun', 'locality_code': '17', 'latitude': 33.6967, 'longitude': -80.8678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29401', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7795, 'longitude': -79.9371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29402', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7766, 'longitude': -79.9309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29403', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7976, 'longitude': -79.9493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29404', 'place_name': 'Charleston Afb', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8982, 'longitude': -80.0686, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29405', 'place_name': 'North Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.853, 'longitude': -79.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29406', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.9352, 'longitude': -80.0325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29407', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7993, 'longitude': -80.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29409', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7961, 'longitude': -79.9605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29412', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.718, 'longitude': -79.9537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29413', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8488, 'longitude': -79.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29414', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8215, 'longitude': -80.0568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29415', 'place_name': 'North Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8546, 'longitude': -79.9748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29416', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8488, 'longitude': -79.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29417', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8488, 'longitude': -79.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29418', 'place_name': 'North Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8929, 'longitude': -80.0458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29419', 'place_name': 'North Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8546, 'longitude': -79.9748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29422', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8488, 'longitude': -79.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29423', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8488, 'longitude': -79.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29424', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7831, 'longitude': -79.937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29425', 'place_name': 'Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7862, 'longitude': -79.9471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29426', 'place_name': 'Adams Run', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.779, 'longitude': -80.3288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29429', 'place_name': 'Awendaw', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 33.0063, 'longitude': -79.6561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29439', 'place_name': 'Folly Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.663, 'longitude': -79.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29449', 'place_name': 'Hollywood', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7105, 'longitude': -80.2744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29451', 'place_name': 'Isle Of Palms', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7943, 'longitude': -79.7729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29455', 'place_name': 'Johns Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7924, 'longitude': -80.1081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29457', 'place_name': 'Johns Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7924, 'longitude': -80.1081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29458', 'place_name': 'Mc Clellanville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 33.1194, 'longitude': -79.5074, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29464', 'place_name': 'Mount Pleasant', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8473, 'longitude': -79.8206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29465', 'place_name': 'Mount Pleasant', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7941, 'longitude': -79.8626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29466', 'place_name': 'Mount Pleasant', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.8674, 'longitude': -79.8049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29470', 'place_name': 'Ravenel', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7881, 'longitude': -80.2223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29482', 'place_name': 'Sullivans Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.7637, 'longitude': -79.8399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29487', 'place_name': 'Wadmalaw Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Charleston', 'locality_code': '19', 'latitude': 32.6529, 'longitude': -80.1829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29340', 'place_name': 'Gaffney', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.0615, 'longitude': -81.6491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29341', 'place_name': 'Gaffney', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.0999, 'longitude': -81.7056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29342', 'place_name': 'Gaffney', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 34.9963, 'longitude': -81.6524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29702', 'place_name': 'Blacksburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Cherokee', 'locality_code': '21', 'latitude': 35.1095, 'longitude': -81.4942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29014', 'place_name': 'Blackstock', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chester', 'locality_code': '23', 'latitude': 34.5779, 'longitude': -81.1249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29055', 'place_name': 'Great Falls', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chester', 'locality_code': '23', 'latitude': 34.5705, 'longitude': -80.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29706', 'place_name': 'Chester', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chester', 'locality_code': '23', 'latitude': 34.7149, 'longitude': -81.2186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29712', 'place_name': 'Edgemoor', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chester', 'locality_code': '23', 'latitude': 34.797, 'longitude': -80.9891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29714', 'place_name': 'Fort Lawn', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chester', 'locality_code': '23', 'latitude': 34.7006, 'longitude': -80.9092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29724', 'place_name': 'Lando', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chester', 'locality_code': '23', 'latitude': 34.7763, 'longitude': -81.0101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29729', 'place_name': 'Richburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chester', 'locality_code': '23', 'latitude': 34.6822, 'longitude': -80.9891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29101', 'place_name': 'Mc Bee', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.4606, 'longitude': -80.2544, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29520', 'place_name': 'Cheraw', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.6863, 'longitude': -79.9174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29584', 'place_name': 'Patrick', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.5598, 'longitude': -80.065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29709', 'place_name': 'Chesterfield', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.7278, 'longitude': -80.0958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29718', 'place_name': 'Jefferson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.6546, 'longitude': -80.3639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29727', 'place_name': 'Mount Croghan', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.7439, 'longitude': -80.2428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29728', 'place_name': 'Pageland', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.7722, 'longitude': -80.3966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29741', 'place_name': 'Ruby', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Chesterfield', 'locality_code': '25', 'latitude': 34.7379, 'longitude': -80.191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29001', 'place_name': 'Alcolu', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.7684, 'longitude': -80.1788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29041', 'place_name': 'Davis Station', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.6027, 'longitude': -80.2645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29051', 'place_name': 'Gable', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.8644, 'longitude': -80.1276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29102', 'place_name': 'Manning', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.6184, 'longitude': -80.2116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29111', 'place_name': 'New Zion', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.7957, 'longitude': -80.0148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29143', 'place_name': 'Sardinia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.8343, 'longitude': -80.0829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29148', 'place_name': 'Summerton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.5946, 'longitude': -80.3606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29162', 'place_name': 'Turbeville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Clarendon', 'locality_code': '27', 'latitude': 33.8907, 'longitude': -80.0184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29082', 'place_name': 'Lodge', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 33.0377, 'longitude': -80.9417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29433', 'place_name': 'Canadys', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 33.0614, 'longitude': -80.6312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29435', 'place_name': 'Cottageville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 32.9612, 'longitude': -80.4794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29438', 'place_name': 'Edisto Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 32.5486, 'longitude': -80.307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29446', 'place_name': 'Green Pond', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 32.6628, 'longitude': -80.528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29452', 'place_name': 'Jacksonboro', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 32.7305, 'longitude': -80.4609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29474', 'place_name': 'Round O', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 32.9405, 'longitude': -80.5739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29475', 'place_name': 'Ruffin', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 33.0103, 'longitude': -80.8137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29481', 'place_name': 'Smoaks', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 33.0963, 'longitude': -80.813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29488', 'place_name': 'Walterboro', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 32.9052, 'longitude': -80.6668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29493', 'place_name': 'Williams', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 33.0327, 'longitude': -80.8445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29929', 'place_name': 'Islandton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Colleton', 'locality_code': '29', 'latitude': 32.9503, 'longitude': -80.8916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29069', 'place_name': 'Lamar', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Darlington', 'locality_code': '31', 'latitude': 34.1862, 'longitude': -80.0963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29079', 'place_name': 'Lydia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Darlington', 'locality_code': '31', 'latitude': 34.289, 'longitude': -80.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29532', 'place_name': 'Darlington', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Darlington', 'locality_code': '31', 'latitude': 34.3003, 'longitude': -79.8732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29540', 'place_name': 'Darlington', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Darlington', 'locality_code': '31', 'latitude': 34.3843, 'longitude': -79.8422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29550', 'place_name': 'Hartsville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Darlington', 'locality_code': '31', 'latitude': 34.3756, 'longitude': -80.0842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29551', 'place_name': 'Hartsville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Darlington', 'locality_code': '31', 'latitude': 34.3659, 'longitude': -80.1324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29593', 'place_name': 'Society Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Darlington', 'locality_code': '31', 'latitude': 34.4512, 'longitude': -79.8865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29536', 'place_name': 'Dillon', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dillon', 'locality_code': '33', 'latitude': 34.4146, 'longitude': -79.377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29543', 'place_name': 'Fork', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dillon', 'locality_code': '33', 'latitude': 34.2873, 'longitude': -79.2501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29547', 'place_name': 'Hamer', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dillon', 'locality_code': '33', 'latitude': 34.4849, 'longitude': -79.3502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29563', 'place_name': 'Lake View', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dillon', 'locality_code': '33', 'latitude': 34.3445, 'longitude': -79.1929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29565', 'place_name': 'Latta', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dillon', 'locality_code': '33', 'latitude': 34.3398, 'longitude': -79.4417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29567', 'place_name': 'Little Rock', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dillon', 'locality_code': '33', 'latitude': 34.5613, 'longitude': -79.4335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29420', 'place_name': 'North Charleston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 32.9336, 'longitude': -80.1026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29437', 'place_name': 'Dorchester', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.1247, 'longitude': -80.4034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29447', 'place_name': 'Grover', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.1052, 'longitude': -80.5948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29448', 'place_name': 'Harleyville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.2205, 'longitude': -80.4501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29471', 'place_name': 'Reevesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.1872, 'longitude': -80.6672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29472', 'place_name': 'Ridgeville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.108, 'longitude': -80.3086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29477', 'place_name': 'Saint George', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.1845, 'longitude': -80.5732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29483', 'place_name': 'Summerville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.028, 'longitude': -80.1739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29484', 'place_name': 'Summerville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 33.0023, 'longitude': -80.2267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29485', 'place_name': 'Summerville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Dorchester', 'locality_code': '35', 'latitude': 32.9756, 'longitude': -80.1831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29824', 'place_name': 'Edgefield', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Edgefield', 'locality_code': '37', 'latitude': 33.8056, 'longitude': -81.966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29832', 'place_name': 'Johnston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Edgefield', 'locality_code': '37', 'latitude': 33.8231, 'longitude': -81.7972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29847', 'place_name': 'Trenton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Edgefield', 'locality_code': '37', 'latitude': 33.6938, 'longitude': -81.8534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29015', 'place_name': 'Blair', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Fairfield', 'locality_code': '39', 'latitude': 34.4967, 'longitude': -81.3459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29065', 'place_name': 'Jenkinsville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Fairfield', 'locality_code': '39', 'latitude': 34.2717, 'longitude': -81.2712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29130', 'place_name': 'Ridgeway', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Fairfield', 'locality_code': '39', 'latitude': 34.3167, 'longitude': -80.9288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29132', 'place_name': 'Rion', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Fairfield', 'locality_code': '39', 'latitude': 34.3074, 'longitude': -81.1252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29180', 'place_name': 'Winnsboro', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Fairfield', 'locality_code': '39', 'latitude': 34.381, 'longitude': -81.109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29114', 'place_name': 'Olanta', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 33.9285, 'longitude': -79.9153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29161', 'place_name': 'Timmonsville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.1012, 'longitude': -79.9378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29501', 'place_name': 'Florence', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.1838, 'longitude': -79.7728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29502', 'place_name': 'Florence', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.201, 'longitude': -79.7847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29503', 'place_name': 'Florence', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.063, 'longitude': -79.6506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29504', 'place_name': 'Florence', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.0416, 'longitude': -79.6933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29505', 'place_name': 'Florence', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.1231, 'longitude': -79.6893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29506', 'place_name': 'Florence', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.2153, 'longitude': -79.6468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29530', 'place_name': 'Coward', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 33.9905, 'longitude': -79.7515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29541', 'place_name': 'Effingham', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 34.0946, 'longitude': -79.7918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29555', 'place_name': 'Johnsonville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 33.8299, 'longitude': -79.4783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29560', 'place_name': 'Lake City', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 33.8655, 'longitude': -79.7418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29583', 'place_name': 'Pamplico', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 33.9922, 'longitude': -79.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29591', 'place_name': 'Scranton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Florence', 'locality_code': '41', 'latitude': 33.9281, 'longitude': -79.7731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29440', 'place_name': 'Georgetown', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Georgetown', 'locality_code': '43', 'latitude': 33.4308, 'longitude': -79.3235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29442', 'place_name': 'Georgetown', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Georgetown', 'locality_code': '43', 'latitude': 33.4037, 'longitude': -79.2264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29510', 'place_name': 'Andrews', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Georgetown', 'locality_code': '43', 'latitude': 33.4525, 'longitude': -79.5604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29576', 'place_name': 'Murrells Inlet', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Georgetown', 'locality_code': '43', 'latitude': 33.5507, 'longitude': -79.0528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29585', 'place_name': 'Pawleys Island', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Georgetown', 'locality_code': '43', 'latitude': 33.4508, 'longitude': -79.1341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29601', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8472, 'longitude': -82.406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29602', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8007, 'longitude': -82.3956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29603', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8377, 'longitude': -82.3715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29604', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8497, 'longitude': -82.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29605', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8001, 'longitude': -82.3932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29606', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8497, 'longitude': -82.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29607', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8285, 'longitude': -82.3516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29608', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8497, 'longitude': -82.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29609', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8921, 'longitude': -82.4002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29610', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8497, 'longitude': -82.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29611', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8533, 'longitude': -82.4493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29612', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8497, 'longitude': -82.4538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29613', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.9249, 'longitude': -82.4331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29614', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8724, 'longitude': -82.3626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29615', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8661, 'longitude': -82.3198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29616', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8526, 'longitude': -82.394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29617', 'place_name': 'Greenville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.912, 'longitude': -82.4666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29635', 'place_name': 'Cleveland', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 35.0654, 'longitude': -82.6093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29636', 'place_name': 'Conestee', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.7682, 'longitude': -82.3498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29644', 'place_name': 'Fountain Inn', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.6578, 'longitude': -82.2441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29650', 'place_name': 'Greer', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.8968, 'longitude': -82.2674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29651', 'place_name': 'Greer', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.9453, 'longitude': -82.2209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29652', 'place_name': 'Greer', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.9387, 'longitude': -82.2271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29661', 'place_name': 'Marietta', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 35.0296, 'longitude': -82.5136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29662', 'place_name': 'Mauldin', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.7807, 'longitude': -82.3035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29673', 'place_name': 'Piedmont', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.7244, 'longitude': -82.4702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29680', 'place_name': 'Simpsonville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.6962, 'longitude': -82.2893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29681', 'place_name': 'Simpsonville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.7512, 'longitude': -82.255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29683', 'place_name': 'Slater', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 35.0289, 'longitude': -82.4941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29687', 'place_name': 'Taylors', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 34.9245, 'longitude': -82.3197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29688', 'place_name': 'Tigerville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 35.0477, 'longitude': -82.353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29690', 'place_name': 'Travelers Rest', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenville', 'locality_code': '45', 'latitude': 35.0039, 'longitude': -82.4272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29646', 'place_name': 'Greenwood', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.1758, 'longitude': -82.1562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29647', 'place_name': 'Greenwood', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.1788, 'longitude': -82.1631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29648', 'place_name': 'Greenwood', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.2124, 'longitude': -82.1681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29649', 'place_name': 'Greenwood', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.223, 'longitude': -82.1582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29653', 'place_name': 'Hodges', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.2882, 'longitude': -82.2142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29666', 'place_name': 'Ninety Six', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.1652, 'longitude': -82.0292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29692', 'place_name': 'Ware Shoals', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.4025, 'longitude': -82.2678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29695', 'place_name': 'Hodges', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.2876, 'longitude': -82.2443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29819', 'place_name': 'Bradley', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 34.0326, 'longitude': -82.2027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29848', 'place_name': 'Troy', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Greenwood', 'locality_code': '47', 'latitude': 33.9876, 'longitude': -82.2979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29911', 'place_name': 'Brunson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.9413, 'longitude': -81.1807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29913', 'place_name': 'Crocketville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.9166, 'longitude': -81.0773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29916', 'place_name': 'Early Branch', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.723, 'longitude': -80.9634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29918', 'place_name': 'Estill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.7375, 'longitude': -81.2178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29921', 'place_name': 'Furman', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.6816, 'longitude': -81.1882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29922', 'place_name': 'Garnett', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.6007, 'longitude': -81.2396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29923', 'place_name': 'Gifford', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.8596, 'longitude': -81.239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29924', 'place_name': 'Hampton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.8729, 'longitude': -81.0973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29932', 'place_name': 'Luray', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.8138, 'longitude': -81.2398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29933', 'place_name': 'Miley', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.9479, 'longitude': -81.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29939', 'place_name': 'Scotia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.6786, 'longitude': -81.2455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29944', 'place_name': 'Varnville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.8349, 'longitude': -81.0288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29945', 'place_name': 'Yemassee', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Hampton', 'locality_code': '49', 'latitude': 32.643, 'longitude': -80.8129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29511', 'place_name': 'Aynor', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.9823, 'longitude': -79.1777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29526', 'place_name': 'Conway', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.8731, 'longitude': -79.0557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29527', 'place_name': 'Conway', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.7827, 'longitude': -79.1473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29528', 'place_name': 'Conway', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.9358, 'longitude': -78.9192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29544', 'place_name': 'Galivants Ferry', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 34.0563, 'longitude': -79.2464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29545', 'place_name': 'Green Sea', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 34.1668, 'longitude': -78.9589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29566', 'place_name': 'Little River', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.8768, 'longitude': -78.6508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29568', 'place_name': 'Longs', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.9064, 'longitude': -78.7934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29569', 'place_name': 'Loris', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 34.0558, 'longitude': -78.9161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29572', 'place_name': 'Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.7587, 'longitude': -78.8044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29575', 'place_name': 'Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.6286, 'longitude': -78.9736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29577', 'place_name': 'Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.6994, 'longitude': -78.9137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29578', 'place_name': 'Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.7389, 'longitude': -78.9996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29579', 'place_name': 'Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.7377, 'longitude': -78.9787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29581', 'place_name': 'Nichols', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 34.2426, 'longitude': -79.1625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29582', 'place_name': 'North Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.8343, 'longitude': -78.6606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29587', 'place_name': 'Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.6211, 'longitude': -78.9632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29588', 'place_name': 'Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.7226, 'longitude': -78.9782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29597', 'place_name': 'North Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.816, 'longitude': -78.68, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29598', 'place_name': 'North Myrtle Beach', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Horry', 'locality_code': '51', 'latitude': 33.816, 'longitude': -78.68, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29909', 'place_name': 'Okatie', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Jasper', 'locality_code': '53', 'latitude': 32.3301, 'longitude': -80.8435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29912', 'place_name': 'Coosawhatchie', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Jasper', 'locality_code': '53', 'latitude': 32.5888, 'longitude': -80.9273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29927', 'place_name': 'Hardeeville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Jasper', 'locality_code': '53', 'latitude': 32.2635, 'longitude': -81.0669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29934', 'place_name': 'Pineland', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Jasper', 'locality_code': '53', 'latitude': 32.5931, 'longitude': -81.1078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29936', 'place_name': 'Ridgeland', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Jasper', 'locality_code': '53', 'latitude': 32.4807, 'longitude': -80.9804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29943', 'place_name': 'Tillman', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Jasper', 'locality_code': '53', 'latitude': 32.468, 'longitude': -81.1667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29009', 'place_name': 'Bethune', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.4201, 'longitude': -80.3662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29020', 'place_name': 'Camden', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.2696, 'longitude': -80.591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29021', 'place_name': 'Camden', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.2974, 'longitude': -80.6089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29032', 'place_name': 'Cassatt', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.3424, 'longitude': -80.5, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29045', 'place_name': 'Elgin', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.162, 'longitude': -80.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29074', 'place_name': 'Liberty Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.457, 'longitude': -80.7892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29078', 'place_name': 'Lugoff', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.2296, 'longitude': -80.7147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29175', 'place_name': 'Westville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Kershaw', 'locality_code': '55', 'latitude': 34.4418, 'longitude': -80.6033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29058', 'place_name': 'Heath Springs', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lancaster', 'locality_code': '57', 'latitude': 34.6024, 'longitude': -80.7103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29067', 'place_name': 'Kershaw', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lancaster', 'locality_code': '57', 'latitude': 34.5578, 'longitude': -80.5546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29707', 'place_name': 'Fort Mill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lancaster', 'locality_code': '57', 'latitude': 34.9773, 'longitude': -80.8584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29720', 'place_name': 'Lancaster', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lancaster', 'locality_code': '57', 'latitude': 34.749, 'longitude': -80.7616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29721', 'place_name': 'Lancaster', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lancaster', 'locality_code': '57', 'latitude': 34.6994, 'longitude': -80.7817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29722', 'place_name': 'Lancaster', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lancaster', 'locality_code': '57', 'latitude': 34.7673, 'longitude': -80.6589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29744', 'place_name': 'Van Wyck', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lancaster', 'locality_code': '57', 'latitude': 34.8585, 'longitude': -80.8459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29325', 'place_name': 'Clinton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Laurens', 'locality_code': '59', 'latitude': 34.4707, 'longitude': -81.8772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29332', 'place_name': 'Cross Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Laurens', 'locality_code': '59', 'latitude': 34.2693, 'longitude': -81.9843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29351', 'place_name': 'Joanna', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Laurens', 'locality_code': '59', 'latitude': 34.4068, 'longitude': -81.8191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29360', 'place_name': 'Laurens', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Laurens', 'locality_code': '59', 'latitude': 34.499, 'longitude': -82.0143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29370', 'place_name': 'Mountville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Laurens', 'locality_code': '59', 'latitude': 34.3408, 'longitude': -81.9584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29384', 'place_name': 'Waterloo', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Laurens', 'locality_code': '59', 'latitude': 34.3367, 'longitude': -82.088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29645', 'place_name': 'Gray Court', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Laurens', 'locality_code': '59', 'latitude': 34.5953, 'longitude': -82.1147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29010', 'place_name': 'Bishopville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lee', 'locality_code': '61', 'latitude': 34.2241, 'longitude': -80.275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29046', 'place_name': 'Elliott', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lee', 'locality_code': '61', 'latitude': 34.1071, 'longitude': -80.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29080', 'place_name': 'Lynchburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lee', 'locality_code': '61', 'latitude': 34.0526, 'longitude': -80.0988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29006', 'place_name': 'Batesburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.8702, 'longitude': -81.5505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29033', 'place_name': 'Cayce', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9626, 'longitude': -81.0671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29036', 'place_name': 'Chapin', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 34.1312, 'longitude': -81.3318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29053', 'place_name': 'Gaston', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.8337, 'longitude': -81.1174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29054', 'place_name': 'Gilbert', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9581, 'longitude': -81.3914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29070', 'place_name': 'Leesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9132, 'longitude': -81.4598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29071', 'place_name': 'Lexington', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9815, 'longitude': -81.2362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29072', 'place_name': 'Lexington', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9724, 'longitude': -81.2359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29073', 'place_name': 'Lexington', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.8632, 'longitude': -81.2351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29123', 'place_name': 'Pelion', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.7766, 'longitude': -81.2502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29160', 'place_name': 'Swansea', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.7339, 'longitude': -81.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29169', 'place_name': 'West Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.995, 'longitude': -81.0888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29170', 'place_name': 'West Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9568, 'longitude': -81.1405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29171', 'place_name': 'West Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9252, 'longitude': -81.2483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29172', 'place_name': 'West Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9, 'longitude': -81.091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29212', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 34.0726, 'longitude': -81.1796, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29228', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Lexington', 'locality_code': '63', 'latitude': 33.9252, 'longitude': -81.2483, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29821', 'place_name': 'Clarks Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'McCormick', 'locality_code': '65', 'latitude': 33.6505, 'longitude': -82.1488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29835', 'place_name': 'Mc Cormick', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'McCormick', 'locality_code': '65', 'latitude': 33.9146, 'longitude': -82.2719, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29838', 'place_name': 'Modoc', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'McCormick', 'locality_code': '65', 'latitude': 33.7052, 'longitude': -82.2187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29840', 'place_name': 'Mount Carmel', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'McCormick', 'locality_code': '65', 'latitude': 34.0065, 'longitude': -82.5324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29844', 'place_name': 'Parksville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'McCormick', 'locality_code': '65', 'latitude': 33.7854, 'longitude': -82.2111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29845', 'place_name': 'Plum Branch', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'McCormick', 'locality_code': '65', 'latitude': 33.8329, 'longitude': -82.248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29899', 'place_name': 'Mc Cormick', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'McCormick', 'locality_code': '65', 'latitude': 33.8356, 'longitude': -82.32, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29519', 'place_name': 'Centenary', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marion', 'locality_code': '67', 'latitude': 34.027, 'longitude': -79.3537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29546', 'place_name': 'Gresham', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marion', 'locality_code': '67', 'latitude': 33.9069, 'longitude': -79.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29571', 'place_name': 'Marion', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marion', 'locality_code': '67', 'latitude': 34.1562, 'longitude': -79.3898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29574', 'place_name': 'Mullins', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marion', 'locality_code': '67', 'latitude': 34.2044, 'longitude': -79.2542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29589', 'place_name': 'Rains', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marion', 'locality_code': '67', 'latitude': 34.1053, 'longitude': -79.3221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29592', 'place_name': 'Sellers', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marion', 'locality_code': '67', 'latitude': 34.258, 'longitude': -79.4783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29512', 'place_name': 'Bennettsville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marlboro', 'locality_code': '69', 'latitude': 34.6255, 'longitude': -79.6898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29516', 'place_name': 'Blenheim', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marlboro', 'locality_code': '69', 'latitude': 34.5171, 'longitude': -79.6442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29525', 'place_name': 'Clio', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marlboro', 'locality_code': '69', 'latitude': 34.5805, 'longitude': -79.5453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29570', 'place_name': 'Mc Coll', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marlboro', 'locality_code': '69', 'latitude': 34.6704, 'longitude': -79.5597, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29594', 'place_name': 'Tatum', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marlboro', 'locality_code': '69', 'latitude': 34.6405, 'longitude': -79.5869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29596', 'place_name': 'Wallace', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Marlboro', 'locality_code': '69', 'latitude': 34.7307, 'longitude': -79.8011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29037', 'place_name': 'Chappells', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.1856, 'longitude': -81.8644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29075', 'place_name': 'Little Mountain', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.1676, 'longitude': -81.4184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29108', 'place_name': 'Newberry', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.2847, 'longitude': -81.6157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29122', 'place_name': 'Peak', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.2386, 'longitude': -81.3271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29126', 'place_name': 'Pomaria', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.3063, 'longitude': -81.45, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29127', 'place_name': 'Prosperity', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.1832, 'longitude': -81.5324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29145', 'place_name': 'Silverstreet', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.2207, 'longitude': -81.7741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29178', 'place_name': 'Whitmire', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.4955, 'longitude': -81.606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29355', 'place_name': 'Kinards', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Newberry', 'locality_code': '71', 'latitude': 34.3804, 'longitude': -81.7773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29643', 'place_name': 'Fair Play', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.5112, 'longitude': -82.9854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29658', 'place_name': 'Long Creek', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.7634, 'longitude': -83.2776, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29664', 'place_name': 'Mountain Rest', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.8541, 'longitude': -83.1134, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29665', 'place_name': 'Newry', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.7247, 'longitude': -82.9106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29672', 'place_name': 'Seneca', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.774, 'longitude': -82.9457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29675', 'place_name': 'Richland', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.7641, 'longitude': -83.0883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29676', 'place_name': 'Salem', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.8728, 'longitude': -82.9607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29678', 'place_name': 'Seneca', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.6828, 'longitude': -82.9362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29679', 'place_name': 'Seneca', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.6857, 'longitude': -82.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29686', 'place_name': 'Tamassee', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.897, 'longitude': -83.0375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29691', 'place_name': 'Walhalla', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.7648, 'longitude': -83.064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29693', 'place_name': 'Westminster', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.6965, 'longitude': -83.1535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29696', 'place_name': 'West Union', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Oconee', 'locality_code': '73', 'latitude': 34.7516, 'longitude': -83.0399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29018', 'place_name': 'Bowman', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.3475, 'longitude': -80.6709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29038', 'place_name': 'Cope', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.3726, 'longitude': -80.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29039', 'place_name': 'Cordova', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.4275, 'longitude': -80.8857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29047', 'place_name': 'Elloree', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.531, 'longitude': -80.572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29048', 'place_name': 'Eutawville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.3922, 'longitude': -80.32, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29059', 'place_name': 'Holly Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.3276, 'longitude': -80.4024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29107', 'place_name': 'Neeses', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.5318, 'longitude': -81.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29112', 'place_name': 'North', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.6211, 'longitude': -81.0601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29113', 'place_name': 'Norway', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.4534, 'longitude': -81.1097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29115', 'place_name': 'Orangeburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.5025, 'longitude': -80.8593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29116', 'place_name': 'Orangeburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.4959, 'longitude': -80.8246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29117', 'place_name': 'Orangeburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.4918, 'longitude': -80.8556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29118', 'place_name': 'Orangeburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.5675, 'longitude': -80.9248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29133', 'place_name': 'Rowesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.3703, 'longitude': -80.8331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29142', 'place_name': 'Santee', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.4835, 'longitude': -80.4805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29146', 'place_name': 'Springfield', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.5343, 'longitude': -81.2499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29163', 'place_name': 'Vance', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.4139, 'longitude': -80.4617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29432', 'place_name': 'Branchville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Orangeburg', 'locality_code': '75', 'latitude': 33.2628, 'longitude': -80.8059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29630', 'place_name': 'Central', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.7401, 'longitude': -82.7947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29631', 'place_name': 'Clemson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.6831, 'longitude': -82.825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29632', 'place_name': 'Clemson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.6834, 'longitude': -82.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29633', 'place_name': 'Clemson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.6834, 'longitude': -82.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29634', 'place_name': 'Clemson', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.6834, 'longitude': -82.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29640', 'place_name': 'Easley', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.829, 'longitude': -82.5796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29641', 'place_name': 'Easley', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.8135, 'longitude': -82.6531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29642', 'place_name': 'Easley', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.7901, 'longitude': -82.5937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29657', 'place_name': 'Liberty', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.7872, 'longitude': -82.6974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29667', 'place_name': 'Norris', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.7648, 'longitude': -82.7567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29671', 'place_name': 'Pickens', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.9024, 'longitude': -82.7058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29682', 'place_name': 'Six Mile', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.8283, 'longitude': -82.8278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29685', 'place_name': 'Sunset', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Pickens', 'locality_code': '77', 'latitude': 34.9706, 'longitude': -82.8076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29002', 'place_name': 'Ballentine', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.1265, 'longitude': -81.2348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29016', 'place_name': 'Blythewood', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.1911, 'longitude': -80.9758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29044', 'place_name': 'Eastover', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 33.9153, 'longitude': -80.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29052', 'place_name': 'Gadsden', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 33.8455, 'longitude': -80.7532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29061', 'place_name': 'Hopkins', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 33.9349, 'longitude': -80.8449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29063', 'place_name': 'Irmo', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.1103, 'longitude': -81.1966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29147', 'place_name': 'State Park', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0907, 'longitude': -80.9662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29177', 'place_name': 'White Rock', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.1504, 'longitude': -81.2601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29201', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0004, 'longitude': -81.0334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29202', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29203', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0635, 'longitude': -81.0265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29204', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.026, 'longitude': -81.0046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29205', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 33.9903, 'longitude': -80.9997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29206', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0247, 'longitude': -80.9532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29207', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0197, 'longitude': -80.9391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29208', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29209', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 33.9659, 'longitude': -80.9355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29210', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0479, 'longitude': -81.1101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29211', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29214', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29215', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29216', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29217', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29218', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29219', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29220', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29221', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29222', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29223', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0853, 'longitude': -80.9167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29224', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29225', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.0007, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29226', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29227', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29229', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.1388, 'longitude': -80.8892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29230', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.1075, 'longitude': -81.0626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29240', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29250', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29260', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29290', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29292', 'place_name': 'Columbia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Richland', 'locality_code': '79', 'latitude': 34.006, 'longitude': -80.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29105', 'place_name': 'Monetta', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Saluda', 'locality_code': '81', 'latitude': 33.8084, 'longitude': -81.5956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29129', 'place_name': 'Ridge Spring', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Saluda', 'locality_code': '81', 'latitude': 33.8714, 'longitude': -81.6559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29138', 'place_name': 'Saluda', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Saluda', 'locality_code': '81', 'latitude': 34.0175, 'longitude': -81.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29166', 'place_name': 'Ward', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Saluda', 'locality_code': '81', 'latitude': 33.8849, 'longitude': -81.7283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29301', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9352, 'longitude': -81.9654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29302', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.8939, 'longitude': -81.834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29303', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9803, 'longitude': -81.9168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29304', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9166, 'longitude': -81.8639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29305', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9496, 'longitude': -81.932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29306', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.8937, 'longitude': -81.9228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29307', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9839, 'longitude': -81.8313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29316', 'place_name': 'Boiling Springs', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.0465, 'longitude': -81.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29319', 'place_name': 'Spartanburg', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9496, 'longitude': -81.932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29320', 'place_name': 'Arcadia', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9572, 'longitude': -81.9916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29322', 'place_name': 'Campobello', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.108, 'longitude': -82.1403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29323', 'place_name': 'Chesnee', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.1154, 'longitude': -81.8678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29324', 'place_name': 'Clifton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9796, 'longitude': -81.8179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29329', 'place_name': 'Converse', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9921, 'longitude': -81.8348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29330', 'place_name': 'Cowpens', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.039, 'longitude': -81.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29331', 'place_name': 'Cross Anchor', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.6383, 'longitude': -81.8567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29333', 'place_name': 'Drayton', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9685, 'longitude': -81.9064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29334', 'place_name': 'Duncan', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9176, 'longitude': -82.1258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29335', 'place_name': 'Enoree', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.671, 'longitude': -81.9237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29336', 'place_name': 'Fairforest', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9565, 'longitude': -82.0101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29338', 'place_name': 'Fingerville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.134, 'longitude': -82.0065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29346', 'place_name': 'Glendale', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9448, 'longitude': -81.8376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29348', 'place_name': 'Gramling', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.0768, 'longitude': -82.1326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29349', 'place_name': 'Inman', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.0528, 'longitude': -82.054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29356', 'place_name': 'Landrum', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.1565, 'longitude': -82.2115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29365', 'place_name': 'Lyman', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9684, 'longitude': -82.1435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29368', 'place_name': 'Mayo', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 35.084, 'longitude': -81.8598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29369', 'place_name': 'Moore', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.8646, 'longitude': -82.0215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29372', 'place_name': 'Pacolet', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9017, 'longitude': -81.7587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29373', 'place_name': 'Pacolet Mills', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9226, 'longitude': -81.7426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29374', 'place_name': 'Pauline', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.7855, 'longitude': -81.8492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29375', 'place_name': 'Reidville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.8636, 'longitude': -82.1101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29376', 'place_name': 'Roebuck', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.8688, 'longitude': -81.9526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29377', 'place_name': 'Startex', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9285, 'longitude': -82.099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29378', 'place_name': 'Una', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.969, 'longitude': -81.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29385', 'place_name': 'Wellford', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.9514, 'longitude': -82.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29386', 'place_name': 'White Stone', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.8882, 'longitude': -81.969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29388', 'place_name': 'Woodruff', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Spartanburg', 'locality_code': '83', 'latitude': 34.7579, 'longitude': -82.0447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29040', 'place_name': 'Dalzell', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 34.0144, 'longitude': -80.4665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29062', 'place_name': 'Horatio', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 34.0213, 'longitude': -80.5659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29104', 'place_name': 'Mayesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.9502, 'longitude': -80.2173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29125', 'place_name': 'Pinewood', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.7642, 'longitude': -80.4978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29128', 'place_name': 'Rembert', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 34.1085, 'longitude': -80.4945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29150', 'place_name': 'Sumter', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.9137, 'longitude': -80.3542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29151', 'place_name': 'Sumter', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.8999, 'longitude': -80.3743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29152', 'place_name': 'Shaw Afb', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.9204, 'longitude': -80.3415, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29153', 'place_name': 'Sumter', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.9446, 'longitude': -80.3206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29154', 'place_name': 'Sumter', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.8821, 'longitude': -80.4028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29168', 'place_name': 'Wedgefield', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Sumter', 'locality_code': '85', 'latitude': 33.8953, 'longitude': -80.498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29031', 'place_name': 'Carlisle', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Union', 'locality_code': '87', 'latitude': 34.567, 'longitude': -81.4814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29321', 'place_name': 'Buffalo', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Union', 'locality_code': '87', 'latitude': 34.7247, 'longitude': -81.6826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29353', 'place_name': 'Jonesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Union', 'locality_code': '87', 'latitude': 34.8125, 'longitude': -81.6431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29364', 'place_name': 'Lockhart', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Union', 'locality_code': '87', 'latitude': 34.7865, 'longitude': -81.462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29379', 'place_name': 'Union', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Union', 'locality_code': '87', 'latitude': 34.7269, 'longitude': -81.6202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29395', 'place_name': 'Jonesville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Union', 'locality_code': '87', 'latitude': 34.8466, 'longitude': -81.7227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29056', 'place_name': 'Greeleyville', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Williamsburg', 'locality_code': '89', 'latitude': 33.5966, 'longitude': -79.9802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29518', 'place_name': 'Cades', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Williamsburg', 'locality_code': '89', 'latitude': 33.7886, 'longitude': -79.848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29554', 'place_name': 'Hemingway', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Williamsburg', 'locality_code': '89', 'latitude': 33.7419, 'longitude': -79.4489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29556', 'place_name': 'Kingstree', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Williamsburg', 'locality_code': '89', 'latitude': 33.6878, 'longitude': -79.7832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29564', 'place_name': 'Lane', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Williamsburg', 'locality_code': '89', 'latitude': 33.5083, 'longitude': -79.8715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29580', 'place_name': 'Nesmith', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Williamsburg', 'locality_code': '89', 'latitude': 33.6625, 'longitude': -79.5589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29590', 'place_name': 'Salters', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'Williamsburg', 'locality_code': '89', 'latitude': 33.5611, 'longitude': -79.83, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29703', 'place_name': 'Bowling Green', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 35.1499, 'longitude': -81.2123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29704', 'place_name': 'Catawba', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.8507, 'longitude': -80.9342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29708', 'place_name': 'Fort Mill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 35.0502, 'longitude': -80.9908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29710', 'place_name': 'Clover', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 35.1065, 'longitude': -81.2201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29715', 'place_name': 'Fort Mill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 35.0108, 'longitude': -80.9266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29716', 'place_name': 'Fort Mill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 35.0074, 'longitude': -80.9451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29717', 'place_name': 'Hickory Grove', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9708, 'longitude': -81.4306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29726', 'place_name': 'Mc Connells', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.8677, 'longitude': -81.2368, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '29730', 'place_name': 'Rock Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9151, 'longitude': -81.0129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29731', 'place_name': 'Rock Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9926, 'longitude': -81.1787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29732', 'place_name': 'Rock Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9681, 'longitude': -81.0489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29733', 'place_name': 'Rock Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9926, 'longitude': -81.1787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29734', 'place_name': 'Rock Hill', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9926, 'longitude': -81.1787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29742', 'place_name': 'Sharon', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9084, 'longitude': -81.3729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29743', 'place_name': 'Smyrna', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 35.0308, 'longitude': -81.3896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '29745', 'place_name': 'York', 'state': 'South Carolina', 'state_ab': 'SC', 'county': 'York', 'locality_code': '91', 'latitude': 34.9947, 'longitude': -81.2245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57368', 'place_name': 'Plankinton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Aurora', 'locality_code': '3', 'latitude': 43.7373, 'longitude': -98.4694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57375', 'place_name': 'Stickney', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Aurora', 'locality_code': '3', 'latitude': 43.5842, 'longitude': -98.5088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57383', 'place_name': 'White Lake', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Aurora', 'locality_code': '3', 'latitude': 43.7564, 'longitude': -98.7076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57324', 'place_name': 'Cavour', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.365, 'longitude': -98.0208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57348', 'place_name': 'Hitchcock', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.5834, 'longitude': -98.4509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57350', 'place_name': 'Huron', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.359, 'longitude': -98.2163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57379', 'place_name': 'Virgil', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.2908, 'longitude': -98.4243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57381', 'place_name': 'Wessington', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.4128, 'longitude': -98.692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57384', 'place_name': 'Wolsey', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.3991, 'longitude': -98.4743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57386', 'place_name': 'Yale', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.5225, 'longitude': -98.0401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57399', 'place_name': 'Huron', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Beadle', 'locality_code': '5', 'latitude': 44.3633, 'longitude': -98.2143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57551', 'place_name': 'Martin', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bennett', 'locality_code': '7', 'latitude': 43.1722, 'longitude': -101.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57574', 'place_name': 'Tuthill', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bennett', 'locality_code': '7', 'latitude': 43.1196, 'longitude': -101.4701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57714', 'place_name': 'Allen', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bennett', 'locality_code': '7', 'latitude': 43.2908, 'longitude': -101.9329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57059', 'place_name': 'Scotland', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bon Homme', 'locality_code': '9', 'latitude': 43.1212, 'longitude': -97.7296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57062', 'place_name': 'Springfield', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bon Homme', 'locality_code': '9', 'latitude': 42.8687, 'longitude': -97.9288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57063', 'place_name': 'Tabor', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bon Homme', 'locality_code': '9', 'latitude': 42.9383, 'longitude': -97.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57066', 'place_name': 'Tyndall', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bon Homme', 'locality_code': '9', 'latitude': 42.99, 'longitude': -97.8633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57315', 'place_name': 'Avon', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Bon Homme', 'locality_code': '9', 'latitude': 43.0397, 'longitude': -98.0283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57002', 'place_name': 'Aurora', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.2838, 'longitude': -96.7043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57006', 'place_name': 'Brookings', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.3056, 'longitude': -96.7914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57007', 'place_name': 'Brookings', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.3697, 'longitude': -96.7907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57026', 'place_name': 'Elkton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.235, 'longitude': -96.5011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57061', 'place_name': 'Sinai', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.2444, 'longitude': -97.0409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57071', 'place_name': 'Volga', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.3224, 'longitude': -96.9251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57220', 'place_name': 'Bruce', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.4675, 'longitude': -96.911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57276', 'place_name': 'White', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brookings', 'locality_code': '11', 'latitude': 44.4132, 'longitude': -96.615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57401', 'place_name': 'Aberdeen', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.4661, 'longitude': -98.4856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57402', 'place_name': 'Aberdeen', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.5896, 'longitude': -98.352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57426', 'place_name': 'Barnard', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.7325, 'longitude': -98.4965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57427', 'place_name': 'Bath', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.4564, 'longitude': -98.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57432', 'place_name': 'Claremont', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.6661, 'longitude': -98.0404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57433', 'place_name': 'Columbia', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.6512, 'longitude': -98.3158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57439', 'place_name': 'Ferney', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.329, 'longitude': -98.0837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57441', 'place_name': 'Frederick', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.8493, 'longitude': -98.5176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57445', 'place_name': 'Groton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.4503, 'longitude': -98.1058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57446', 'place_name': 'Hecla', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.8725, 'longitude': -98.1918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57449', 'place_name': 'Houghton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.7967, 'longitude': -98.0952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57474', 'place_name': 'Stratford', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.2866, 'longitude': -98.2792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57479', 'place_name': 'Warner', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.3486, 'longitude': -98.4757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57481', 'place_name': 'Westport', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brown', 'locality_code': '13', 'latitude': 45.6705, 'longitude': -98.5802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57325', 'place_name': 'Chamberlain', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brule', 'locality_code': '15', 'latitude': 43.7953, 'longitude': -99.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57326', 'place_name': 'Chamberlain', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brule', 'locality_code': '15', 'latitude': 43.8108, 'longitude': -99.3307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57355', 'place_name': 'Kimball', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brule', 'locality_code': '15', 'latitude': 43.7467, 'longitude': -98.9584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57370', 'place_name': 'Pukwana', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Brule', 'locality_code': '15', 'latitude': 43.7783, 'longitude': -99.1779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57339', 'place_name': 'Fort Thompson', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Buffalo', 'locality_code': '17', 'latitude': 44.0517, 'longitude': -99.3973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57341', 'place_name': 'Gann Valley', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Buffalo', 'locality_code': '17', 'latitude': 44.0693, 'longitude': -99.0543, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57717', 'place_name': 'Belle Fourche', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Butte', 'locality_code': '19', 'latitude': 44.6723, 'longitude': -103.8396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57760', 'place_name': 'Newell', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Butte', 'locality_code': '19', 'latitude': 44.741, 'longitude': -103.3914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57762', 'place_name': 'Nisland', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Butte', 'locality_code': '19', 'latitude': 44.6665, 'longitude': -103.5402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57788', 'place_name': 'Vale', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Butte', 'locality_code': '19', 'latitude': 44.6222, 'longitude': -103.3795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57632', 'place_name': 'Herreid', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Campbell', 'locality_code': '21', 'latitude': 45.8452, 'longitude': -100.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57646', 'place_name': 'Mound City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Campbell', 'locality_code': '21', 'latitude': 45.6786, 'longitude': -100.0479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57648', 'place_name': 'Pollock', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Campbell', 'locality_code': '21', 'latitude': 45.889, 'longitude': -100.2875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57329', 'place_name': 'Dante', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Charles Mix', 'locality_code': '23', 'latitude': 42.9967, 'longitude': -98.1746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57342', 'place_name': 'Geddes', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Charles Mix', 'locality_code': '23', 'latitude': 43.2597, 'longitude': -98.6926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57356', 'place_name': 'Lake Andes', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Charles Mix', 'locality_code': '23', 'latitude': 43.1303, 'longitude': -98.4964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57361', 'place_name': 'Marty', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Charles Mix', 'locality_code': '23', 'latitude': 42.9925, 'longitude': -98.4251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57367', 'place_name': 'Pickstown', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Charles Mix', 'locality_code': '23', 'latitude': 43.0673, 'longitude': -98.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57369', 'place_name': 'Platte', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Charles Mix', 'locality_code': '23', 'latitude': 43.4251, 'longitude': -98.9479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57380', 'place_name': 'Wagner', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Charles Mix', 'locality_code': '23', 'latitude': 43.0819, 'longitude': -98.2819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57217', 'place_name': 'Bradley', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clark', 'locality_code': '25', 'latitude': 45.0751, 'longitude': -97.6387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57225', 'place_name': 'Clark', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clark', 'locality_code': '25', 'latitude': 44.878, 'longitude': -97.7265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57236', 'place_name': 'Garden City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clark', 'locality_code': '25', 'latitude': 44.9841, 'longitude': -97.5814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57258', 'place_name': 'Raymond', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clark', 'locality_code': '25', 'latitude': 44.8637, 'longitude': -97.9168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57271', 'place_name': 'Vienna', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clark', 'locality_code': '25', 'latitude': 44.7362, 'longitude': -97.5307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57278', 'place_name': 'Willow Lake', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clark', 'locality_code': '25', 'latitude': 44.6272, 'longitude': -97.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57322', 'place_name': 'Carpenter', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clark', 'locality_code': '25', 'latitude': 44.6648, 'longitude': -97.9168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57010', 'place_name': 'Burbank', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clay', 'locality_code': '27', 'latitude': 42.7638, 'longitude': -96.8466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57037', 'place_name': 'Irene', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clay', 'locality_code': '27', 'latitude': 43.1027, 'longitude': -97.2558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57069', 'place_name': 'Vermillion', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clay', 'locality_code': '27', 'latitude': 42.7951, 'longitude': -96.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57073', 'place_name': 'Wakonda', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Clay', 'locality_code': '27', 'latitude': 42.996, 'longitude': -97.0694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57201', 'place_name': 'Watertown', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Codington', 'locality_code': '29', 'latitude': 44.9043, 'longitude': -97.124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57235', 'place_name': 'Florence', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Codington', 'locality_code': '29', 'latitude': 45.0554, 'longitude': -97.2866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57243', 'place_name': 'Henry', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Codington', 'locality_code': '29', 'latitude': 44.8858, 'longitude': -97.4442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57245', 'place_name': 'Kranzburg', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Codington', 'locality_code': '29', 'latitude': 44.8923, 'longitude': -96.9174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57263', 'place_name': 'South Shore', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Codington', 'locality_code': '29', 'latitude': 45.1049, 'longitude': -96.9859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57272', 'place_name': 'Wallace', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Codington', 'locality_code': '29', 'latitude': 45.0815, 'longitude': -97.4458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57621', 'place_name': 'Bullhead', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.7656, 'longitude': -101.0807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57634', 'place_name': 'Keldron', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.7528, 'longitude': -101.8843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57639', 'place_name': 'Little Eagle', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.6758, 'longitude': -100.8043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57641', 'place_name': 'Mc Intosh', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.7084, 'longitude': -101.1546, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57642', 'place_name': 'Mc Laughlin', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.8763, 'longitude': -100.8915, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57645', 'place_name': 'Morristown', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.9386, 'longitude': -101.7232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57657', 'place_name': 'Trail City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.4725, 'longitude': -100.7254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57658', 'place_name': 'Wakpala', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.7006, 'longitude': -100.5332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57659', 'place_name': 'Walker', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.9103, 'longitude': -101.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57660', 'place_name': 'Watauga', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Corson', 'locality_code': '31', 'latitude': 45.9276, 'longitude': -101.5129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57722', 'place_name': 'Buffalo Gap', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Custer', 'locality_code': '33', 'latitude': 43.4958, 'longitude': -103.3157, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57730', 'place_name': 'Custer', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Custer', 'locality_code': '33', 'latitude': 43.6573, 'longitude': -103.4258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57738', 'place_name': 'Fairburn', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Custer', 'locality_code': '33', 'latitude': 43.6623, 'longitude': -103.2133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57744', 'place_name': 'Hermosa', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Custer', 'locality_code': '33', 'latitude': 43.8188, 'longitude': -103.206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57773', 'place_name': 'Pringle', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Custer', 'locality_code': '33', 'latitude': 43.6086, 'longitude': -103.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57301', 'place_name': 'Mitchell', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Davison', 'locality_code': '35', 'latitude': 43.7094, 'longitude': -98.0298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57334', 'place_name': 'Ethan', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Davison', 'locality_code': '35', 'latitude': 43.5478, 'longitude': -97.9881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57363', 'place_name': 'Mount Vernon', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Davison', 'locality_code': '35', 'latitude': 43.7204, 'longitude': -98.2633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57219', 'place_name': 'Bristol', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Day', 'locality_code': '37', 'latitude': 45.288, 'longitude': -97.8086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57239', 'place_name': 'Grenville', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Day', 'locality_code': '37', 'latitude': 45.5097, 'longitude': -97.3092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57261', 'place_name': 'Roslyn', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Day', 'locality_code': '37', 'latitude': 45.5006, 'longitude': -97.5401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57273', 'place_name': 'Waubay', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Day', 'locality_code': '37', 'latitude': 45.3784, 'longitude': -97.295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57274', 'place_name': 'Webster', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Day', 'locality_code': '37', 'latitude': 45.3151, 'longitude': -97.5254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57422', 'place_name': 'Andover', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Day', 'locality_code': '37', 'latitude': 45.4222, 'longitude': -97.9175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57468', 'place_name': 'Pierpont', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Day', 'locality_code': '37', 'latitude': 45.496, 'longitude': -97.8128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57213', 'place_name': 'Astoria', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Deuel', 'locality_code': '39', 'latitude': 44.5735, 'longitude': -96.5416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57218', 'place_name': 'Brandt', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Deuel', 'locality_code': '39', 'latitude': 44.6738, 'longitude': -96.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57226', 'place_name': 'Clear Lake', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Deuel', 'locality_code': '39', 'latitude': 44.7612, 'longitude': -96.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57237', 'place_name': 'Gary', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Deuel', 'locality_code': '39', 'latitude': 44.827, 'longitude': -96.5044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57238', 'place_name': 'Goodwin', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Deuel', 'locality_code': '39', 'latitude': 44.8754, 'longitude': -96.8608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57268', 'place_name': 'Toronto', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Deuel', 'locality_code': '39', 'latitude': 44.5786, 'longitude': -96.7077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57625', 'place_name': 'Eagle Butte', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Dewey', 'locality_code': '41', 'latitude': 45.0016, 'longitude': -101.2329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57630', 'place_name': 'Glencross', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Dewey', 'locality_code': '41', 'latitude': 45.4483, 'longitude': -100.9213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57633', 'place_name': 'Isabel', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Dewey', 'locality_code': '41', 'latitude': 45.3962, 'longitude': -101.4385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57636', 'place_name': 'Lantry', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Dewey', 'locality_code': '41', 'latitude': 45.0144, 'longitude': -101.4315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57652', 'place_name': 'Ridgeview', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Dewey', 'locality_code': '41', 'latitude': 45.2024, 'longitude': -100.605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57656', 'place_name': 'Timber Lake', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Dewey', 'locality_code': '41', 'latitude': 45.3927, 'longitude': -101.0351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57661', 'place_name': 'Whitehorse', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Dewey', 'locality_code': '41', 'latitude': 45.2705, 'longitude': -100.8865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57313', 'place_name': 'Armour', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Douglas', 'locality_code': '43', 'latitude': 43.316, 'longitude': -98.3414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57328', 'place_name': 'Corsica', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Douglas', 'locality_code': '43', 'latitude': 43.4213, 'longitude': -98.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57330', 'place_name': 'Delmont', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Douglas', 'locality_code': '43', 'latitude': 43.2573, 'longitude': -98.1596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57344', 'place_name': 'Harrison', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Douglas', 'locality_code': '43', 'latitude': 43.4297, 'longitude': -98.5273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57364', 'place_name': 'New Holland', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Douglas', 'locality_code': '43', 'latitude': 43.4291, 'longitude': -98.6069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57428', 'place_name': 'Bowdle', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Edmunds', 'locality_code': '45', 'latitude': 45.453, 'longitude': -99.654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57448', 'place_name': 'Hosmer', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Edmunds', 'locality_code': '45', 'latitude': 45.569, 'longitude': -99.4857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57451', 'place_name': 'Ipswich', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Edmunds', 'locality_code': '45', 'latitude': 45.4489, 'longitude': -99.0148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57471', 'place_name': 'Roscoe', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Edmunds', 'locality_code': '45', 'latitude': 45.4271, 'longitude': -99.3326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57735', 'place_name': 'Edgemont', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Fall River', 'locality_code': '47', 'latitude': 43.2874, 'longitude': -103.811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57747', 'place_name': 'Hot Springs', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Fall River', 'locality_code': '47', 'latitude': 43.4223, 'longitude': -103.4766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57763', 'place_name': 'Oelrichs', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Fall River', 'locality_code': '47', 'latitude': 43.1551, 'longitude': -103.2162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57766', 'place_name': 'Oral', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Fall River', 'locality_code': '47', 'latitude': 43.3876, 'longitude': -103.1832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57782', 'place_name': 'Smithwick', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Fall River', 'locality_code': '47', 'latitude': 43.3014, 'longitude': -103.2183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57435', 'place_name': 'Cresbard', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Faulk', 'locality_code': '49', 'latitude': 45.1691, 'longitude': -98.9411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57438', 'place_name': 'Faulkton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Faulk', 'locality_code': '49', 'latitude': 45.0855, 'longitude': -99.1954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57466', 'place_name': 'Onaka', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Faulk', 'locality_code': '49', 'latitude': 45.1965, 'longitude': -99.4551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57467', 'place_name': 'Orient', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Faulk', 'locality_code': '49', 'latitude': 44.8343, 'longitude': -99.1058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57470', 'place_name': 'Rockham', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Faulk', 'locality_code': '49', 'latitude': 44.8767, 'longitude': -98.8669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57473', 'place_name': 'Seneca', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Faulk', 'locality_code': '49', 'latitude': 45.0262, 'longitude': -99.461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57216', 'place_name': 'Big Stone City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.285, 'longitude': -96.5614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57246', 'place_name': 'Labolt', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.0415, 'longitude': -96.6892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57251', 'place_name': 'Marvin', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.2727, 'longitude': -96.91, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57252', 'place_name': 'Milbank', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.2061, 'longitude': -96.6255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57259', 'place_name': 'Revillo', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.0805, 'longitude': -96.5557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57264', 'place_name': 'Stockholm', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.1031, 'longitude': -96.8106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57265', 'place_name': 'Strandburg', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.0389, 'longitude': -96.7901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57269', 'place_name': 'Twin Brooks', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Grant', 'locality_code': '51', 'latitude': 45.2309, 'longitude': -96.8237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57317', 'place_name': 'Bonesteel', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Gregory', 'locality_code': '53', 'latitude': 43.0695, 'longitude': -98.988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57335', 'place_name': 'Fairfax', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Gregory', 'locality_code': '53', 'latitude': 43.0351, 'longitude': -98.8308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57523', 'place_name': 'Burke', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Gregory', 'locality_code': '53', 'latitude': 43.1825, 'longitude': -99.2937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57529', 'place_name': 'Dallas', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Gregory', 'locality_code': '53', 'latitude': 43.2351, 'longitude': -99.514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57533', 'place_name': 'Gregory', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Gregory', 'locality_code': '53', 'latitude': 43.2136, 'longitude': -99.3622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57538', 'place_name': 'Herrick', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Gregory', 'locality_code': '53', 'latitude': 43.1012, 'longitude': -99.2173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57571', 'place_name': 'Saint Charles', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Gregory', 'locality_code': '53', 'latitude': 43.0852, 'longitude': -99.0925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57552', 'place_name': 'Midland', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Haakon', 'locality_code': '55', 'latitude': 44.0717, 'longitude': -101.1554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57553', 'place_name': 'Milesville', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Haakon', 'locality_code': '55', 'latitude': 44.4283, 'longitude': -101.7523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57567', 'place_name': 'Philip', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Haakon', 'locality_code': '55', 'latitude': 44.055, 'longitude': -101.6876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57221', 'place_name': 'Bryant', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hamlin', 'locality_code': '57', 'latitude': 44.5987, 'longitude': -97.4537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57223', 'place_name': 'Castlewood', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hamlin', 'locality_code': '57', 'latitude': 44.7313, 'longitude': -97.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57234', 'place_name': 'Estelline', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hamlin', 'locality_code': '57', 'latitude': 44.6029, 'longitude': -96.8928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57241', 'place_name': 'Hayti', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hamlin', 'locality_code': '57', 'latitude': 44.6647, 'longitude': -97.2305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57242', 'place_name': 'Hazel', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hamlin', 'locality_code': '57', 'latitude': 44.7572, 'longitude': -97.3083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57248', 'place_name': 'Lake Norden', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hamlin', 'locality_code': '57', 'latitude': 44.5844, 'longitude': -97.2009, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57362', 'place_name': 'Miller', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hand', 'locality_code': '59', 'latitude': 44.4966, 'longitude': -98.9894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57371', 'place_name': 'Ree Heights', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hand', 'locality_code': '59', 'latitude': 44.5603, 'longitude': -99.2286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57373', 'place_name': 'Saint Lawrence', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hand', 'locality_code': '59', 'latitude': 44.5215, 'longitude': -98.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57311', 'place_name': 'Alexandria', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hanson', 'locality_code': '61', 'latitude': 43.6684, 'longitude': -97.7563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57332', 'place_name': 'Emery', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hanson', 'locality_code': '61', 'latitude': 43.5656, 'longitude': -97.6475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57340', 'place_name': 'Fulton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hanson', 'locality_code': '61', 'latitude': 43.7588, 'longitude': -97.8712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57650', 'place_name': 'Ralph', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Harding', 'locality_code': '63', 'latitude': 45.8554, 'longitude': -103.0356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57651', 'place_name': 'Reva', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Harding', 'locality_code': '63', 'latitude': 45.5277, 'longitude': -103.0692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57720', 'place_name': 'Buffalo', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Harding', 'locality_code': '63', 'latitude': 45.574, 'longitude': -103.5826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57724', 'place_name': 'Camp Crook', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Harding', 'locality_code': '63', 'latitude': 45.6402, 'longitude': -104.0278, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57755', 'place_name': 'Ludlow', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Harding', 'locality_code': '63', 'latitude': 45.8366, 'longitude': -103.3491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57776', 'place_name': 'Redig', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Harding', 'locality_code': '63', 'latitude': 45.2711, 'longitude': -103.5482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57501', 'place_name': 'Pierre', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hughes', 'locality_code': '65', 'latitude': 44.3695, 'longitude': -100.3211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57522', 'place_name': 'Blunt', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hughes', 'locality_code': '65', 'latitude': 44.5026, 'longitude': -99.9463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57536', 'place_name': 'Harrold', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hughes', 'locality_code': '65', 'latitude': 44.5215, 'longitude': -99.7382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57029', 'place_name': 'Freeman', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hutchinson', 'locality_code': '67', 'latitude': 43.3605, 'longitude': -97.4601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57045', 'place_name': 'Menno', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hutchinson', 'locality_code': '67', 'latitude': 43.234, 'longitude': -97.565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57052', 'place_name': 'Olivet', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hutchinson', 'locality_code': '67', 'latitude': 43.2928, 'longitude': -97.7184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57331', 'place_name': 'Dimock', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hutchinson', 'locality_code': '67', 'latitude': 43.4705, 'longitude': -97.9988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57354', 'place_name': 'Kaylor', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hutchinson', 'locality_code': '67', 'latitude': 43.3341, 'longitude': -97.7569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57366', 'place_name': 'Parkston', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hutchinson', 'locality_code': '67', 'latitude': 43.3978, 'longitude': -97.9678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57376', 'place_name': 'Tripp', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hutchinson', 'locality_code': '67', 'latitude': 43.2404, 'longitude': -97.9713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57345', 'place_name': 'Highmore', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hyde', 'locality_code': '69', 'latitude': 44.5326, 'longitude': -99.4543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57346', 'place_name': 'Stephan', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hyde', 'locality_code': '69', 'latitude': 44.248, 'longitude': -99.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57540', 'place_name': 'Holabird', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Hyde', 'locality_code': '69', 'latitude': 44.5173, 'longitude': -99.5943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57521', 'place_name': 'Belvidere', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jackson', 'locality_code': '71', 'latitude': 43.886, 'longitude': -101.2387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57543', 'place_name': 'Kadoka', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jackson', 'locality_code': '71', 'latitude': 43.8446, 'longitude': -101.5523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57547', 'place_name': 'Long Valley', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jackson', 'locality_code': '71', 'latitude': 43.4754, 'longitude': -101.4294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57577', 'place_name': 'Wanblee', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jackson', 'locality_code': '71', 'latitude': 43.5589, 'longitude': -101.7219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57750', 'place_name': 'Interior', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jackson', 'locality_code': '71', 'latitude': 43.7319, 'longitude': -101.9642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57312', 'place_name': 'Alpena', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jerauld', 'locality_code': '73', 'latitude': 44.1709, 'longitude': -98.3962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57358', 'place_name': 'Lane', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jerauld', 'locality_code': '73', 'latitude': 44.0696, 'longitude': -98.4252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57382', 'place_name': 'Wessington Springs', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jerauld', 'locality_code': '73', 'latitude': 44.0664, 'longitude': -98.6751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57531', 'place_name': 'Draper', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jones', 'locality_code': '75', 'latitude': 43.926, 'longitude': -100.5085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57559', 'place_name': 'Murdo', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jones', 'locality_code': '75', 'latitude': 43.8961, 'longitude': -100.7121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57562', 'place_name': 'Okaton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Jones', 'locality_code': '75', 'latitude': 43.8861, 'longitude': -100.8918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57051', 'place_name': 'Oldham', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Kingsbury', 'locality_code': '77', 'latitude': 44.2457, 'longitude': -97.2696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57212', 'place_name': 'Arlington', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Kingsbury', 'locality_code': '77', 'latitude': 44.3668, 'longitude': -97.0687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57214', 'place_name': 'Badger', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Kingsbury', 'locality_code': '77', 'latitude': 44.4918, 'longitude': -97.2184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57231', 'place_name': 'De Smet', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Kingsbury', 'locality_code': '77', 'latitude': 44.3852, 'longitude': -97.5634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57233', 'place_name': 'Erwin', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Kingsbury', 'locality_code': '77', 'latitude': 44.4915, 'longitude': -97.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57249', 'place_name': 'Lake Preston', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Kingsbury', 'locality_code': '77', 'latitude': 44.3692, 'longitude': -97.3828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57353', 'place_name': 'Iroquois', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Kingsbury', 'locality_code': '77', 'latitude': 44.3455, 'longitude': -97.8542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57016', 'place_name': 'Chester', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lake', 'locality_code': '79', 'latitude': 43.8981, 'longitude': -96.9759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57042', 'place_name': 'Madison', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lake', 'locality_code': '79', 'latitude': 44.0054, 'longitude': -97.1149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57050', 'place_name': 'Nunda', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lake', 'locality_code': '79', 'latitude': 44.1525, 'longitude': -96.9942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57054', 'place_name': 'Ramona', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lake', 'locality_code': '79', 'latitude': 44.1229, 'longitude': -97.2349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57057', 'place_name': 'Rutland', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lake', 'locality_code': '79', 'latitude': 44.0683, 'longitude': -96.9519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57075', 'place_name': 'Wentworth', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lake', 'locality_code': '79', 'latitude': 43.9852, 'longitude': -96.9615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57076', 'place_name': 'Winfred', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lake', 'locality_code': '79', 'latitude': 43.9972, 'longitude': -97.3623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57732', 'place_name': 'Deadwood', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lawrence', 'locality_code': '81', 'latitude': 44.3767, 'longitude': -103.7296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57754', 'place_name': 'Lead', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lawrence', 'locality_code': '81', 'latitude': 44.263, 'longitude': -103.8712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57759', 'place_name': 'Nemo', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lawrence', 'locality_code': '81', 'latitude': 44.2097, 'longitude': -103.5449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57779', 'place_name': 'Saint Onge', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lawrence', 'locality_code': '81', 'latitude': 44.5473, 'longitude': -103.7232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57783', 'place_name': 'Spearfish', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lawrence', 'locality_code': '81', 'latitude': 44.4946, 'longitude': -103.865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57793', 'place_name': 'Whitewood', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lawrence', 'locality_code': '81', 'latitude': 44.4589, 'longitude': -103.637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57799', 'place_name': 'Spearfish', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lawrence', 'locality_code': '81', 'latitude': 44.4958, 'longitude': -103.8703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57013', 'place_name': 'Canton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lincoln', 'locality_code': '83', 'latitude': 43.3038, 'longitude': -96.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57027', 'place_name': 'Fairview', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lincoln', 'locality_code': '83', 'latitude': 43.197, 'longitude': -96.5135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57032', 'place_name': 'Harrisburg', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lincoln', 'locality_code': '83', 'latitude': 43.446, 'longitude': -96.6864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57034', 'place_name': 'Hudson', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lincoln', 'locality_code': '83', 'latitude': 43.1284, 'longitude': -96.5306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57039', 'place_name': 'Lennox', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lincoln', 'locality_code': '83', 'latitude': 43.3451, 'longitude': -96.8821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57064', 'place_name': 'Tea', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lincoln', 'locality_code': '83', 'latitude': 43.4711, 'longitude': -96.8177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57077', 'place_name': 'Worthing', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lincoln', 'locality_code': '83', 'latitude': 43.3291, 'longitude': -96.7628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57365', 'place_name': 'Oacoma', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lyman', 'locality_code': '85', 'latitude': 43.7975, 'longitude': -99.3947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57544', 'place_name': 'Kennebec', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lyman', 'locality_code': '85', 'latitude': 43.8921, 'longitude': -99.8502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57548', 'place_name': 'Lower Brule', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lyman', 'locality_code': '85', 'latitude': 44.0937, 'longitude': -99.6139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57568', 'place_name': 'Presho', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lyman', 'locality_code': '85', 'latitude': 43.8995, 'longitude': -100.0746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57569', 'place_name': 'Reliance', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lyman', 'locality_code': '85', 'latitude': 43.8789, 'longitude': -99.6032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57576', 'place_name': 'Vivian', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Lyman', 'locality_code': '85', 'latitude': 43.9535, 'longitude': -100.286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57012', 'place_name': 'Canistota', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McCook', 'locality_code': '87', 'latitude': 43.5856, 'longitude': -97.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57048', 'place_name': 'Montrose', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McCook', 'locality_code': '87', 'latitude': 43.7063, 'longitude': -97.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57058', 'place_name': 'Salem', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McCook', 'locality_code': '87', 'latitude': 43.7356, 'longitude': -97.3797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57319', 'place_name': 'Bridgewater', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McCook', 'locality_code': '87', 'latitude': 43.5503, 'longitude': -97.4691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57374', 'place_name': 'Spencer', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McCook', 'locality_code': '87', 'latitude': 43.7557, 'longitude': -97.5936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57437', 'place_name': 'Eureka', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McPherson', 'locality_code': '89', 'latitude': 45.7707, 'longitude': -99.3308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57456', 'place_name': 'Leola', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McPherson', 'locality_code': '89', 'latitude': 45.7228, 'longitude': -98.9409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57457', 'place_name': 'Long Lake', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'McPherson', 'locality_code': '89', 'latitude': 45.8566, 'longitude': -99.2051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57232', 'place_name': 'Eden', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Marshall', 'locality_code': '91', 'latitude': 45.6211, 'longitude': -97.3741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57247', 'place_name': 'Lake City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Marshall', 'locality_code': '91', 'latitude': 45.6899, 'longitude': -97.3481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57270', 'place_name': 'Veblen', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Marshall', 'locality_code': '91', 'latitude': 45.8535, 'longitude': -97.3122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57421', 'place_name': 'Amherst', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Marshall', 'locality_code': '91', 'latitude': 45.7585, 'longitude': -97.9274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57430', 'place_name': 'Britton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Marshall', 'locality_code': '91', 'latitude': 45.8023, 'longitude': -97.7418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57454', 'place_name': 'Langford', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Marshall', 'locality_code': '91', 'latitude': 45.6174, 'longitude': -97.7925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57626', 'place_name': 'Faith', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.9926, 'longitude': -102.0541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57706', 'place_name': 'Ellsworth Afb', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.1447, 'longitude': -103.0759, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57718', 'place_name': 'Black Hawk', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.1512, 'longitude': -103.3486, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57737', 'place_name': 'Enning', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.5755, 'longitude': -102.5632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57741', 'place_name': 'Fort Meade', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.4093, 'longitude': -103.4554, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57748', 'place_name': 'Howes', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.5838, 'longitude': -102.0229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57758', 'place_name': 'Mud Butte', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 45.031, 'longitude': -102.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57769', 'place_name': 'Piedmont', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.2287, 'longitude': -103.3688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57785', 'place_name': 'Sturgis', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.3692, 'longitude': -103.3617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57787', 'place_name': 'Union Center', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.6539, 'longitude': -102.7252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57792', 'place_name': 'White Owl', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Meade', 'locality_code': '93', 'latitude': 44.6182, 'longitude': -102.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57560', 'place_name': 'Norris', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Mellette', 'locality_code': '95', 'latitude': 43.4662, 'longitude': -101.1517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57579', 'place_name': 'White River', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Mellette', 'locality_code': '95', 'latitude': 43.5666, 'longitude': -100.7449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57585', 'place_name': 'Wood', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Mellette', 'locality_code': '95', 'latitude': 43.5366, 'longitude': -100.4379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57321', 'place_name': 'Canova', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Miner', 'locality_code': '97', 'latitude': 43.8855, 'longitude': -97.5342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57323', 'place_name': 'Carthage', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Miner', 'locality_code': '97', 'latitude': 44.1496, 'longitude': -97.7116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57337', 'place_name': 'Fedora', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Miner', 'locality_code': '97', 'latitude': 43.9841, 'longitude': -97.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57349', 'place_name': 'Howard', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Miner', 'locality_code': '97', 'latitude': 44.0371, 'longitude': -97.5603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57003', 'place_name': 'Baltic', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.7309, 'longitude': -96.7563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57005', 'place_name': 'Brandon', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5926, 'longitude': -96.586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57018', 'place_name': 'Colton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.7951, 'longitude': -96.9572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57020', 'place_name': 'Crooks', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6669, 'longitude': -96.8221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57022', 'place_name': 'Dell Rapids', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.8228, 'longitude': -96.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57030', 'place_name': 'Garretson', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.7162, 'longitude': -96.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57033', 'place_name': 'Hartford', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6155, 'longitude': -96.9501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57035', 'place_name': 'Humboldt', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.612, 'longitude': -97.0697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57041', 'place_name': 'Lyons', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.7285, 'longitude': -96.8709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57055', 'place_name': 'Renner', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6366, 'longitude': -96.7119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57068', 'place_name': 'Valley Springs', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5773, 'longitude': -96.4956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57101', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5464, 'longitude': -96.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57103', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5374, 'longitude': -96.6864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57104', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5514, 'longitude': -96.7375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57105', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.524, 'longitude': -96.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57106', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5179, 'longitude': -96.7924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57107', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5566, 'longitude': -96.8028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57108', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.4775, 'longitude': -96.7041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57109', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6746, 'longitude': -96.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57110', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5486, 'longitude': -96.6332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57117', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6746, 'longitude': -96.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57118', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6746, 'longitude': -96.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57186', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.5424, 'longitude': -96.7312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57193', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6746, 'longitude': -96.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57197', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6746, 'longitude': -96.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57198', 'place_name': 'Sioux Falls', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Minnehaha', 'locality_code': '99', 'latitude': 43.6746, 'longitude': -96.7913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57017', 'place_name': 'Colman', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Moody', 'locality_code': '101', 'latitude': 43.9558, 'longitude': -96.8189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57024', 'place_name': 'Egan', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Moody', 'locality_code': '101', 'latitude': 43.9866, 'longitude': -96.6493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57028', 'place_name': 'Flandreau', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Moody', 'locality_code': '101', 'latitude': 44.0658, 'longitude': -96.6222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57065', 'place_name': 'Trent', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Moody', 'locality_code': '101', 'latitude': 43.8942, 'longitude': -96.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57701', 'place_name': 'Rapid City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.1415, 'longitude': -103.2052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57702', 'place_name': 'Rapid City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.0036, 'longitude': -103.3589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57703', 'place_name': 'Rapid City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.048, 'longitude': -103.1763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57709', 'place_name': 'Rapid City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.0761, 'longitude': -103.3171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57719', 'place_name': 'Box Elder', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.1199, 'longitude': -103.0682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57725', 'place_name': 'Caputa', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 43.9481, 'longitude': -102.7935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57745', 'place_name': 'Hill City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 43.9377, 'longitude': -103.5782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57751', 'place_name': 'Keystone', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 43.8848, 'longitude': -103.3995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57761', 'place_name': 'New Underwood', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.0874, 'longitude': -102.8136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57767', 'place_name': 'Owanka', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.0631, 'longitude': -102.5628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57775', 'place_name': 'Quinn', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.1035, 'longitude': -102.0159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57780', 'place_name': 'Scenic', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 43.7994, 'longitude': -102.5353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57790', 'place_name': 'Wall', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 43.9812, 'longitude': -102.2245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57791', 'place_name': 'Wasta', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Pennington', 'locality_code': '103', 'latitude': 44.225, 'longitude': -102.4311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57620', 'place_name': 'Bison', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Perkins', 'locality_code': '105', 'latitude': 45.5161, 'longitude': -102.4827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57638', 'place_name': 'Lemmon', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Perkins', 'locality_code': '105', 'latitude': 45.9159, 'longitude': -102.1928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57640', 'place_name': 'Lodgepole', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Perkins', 'locality_code': '105', 'latitude': 45.8232, 'longitude': -102.7599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57644', 'place_name': 'Meadow', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Perkins', 'locality_code': '105', 'latitude': 45.3538, 'longitude': -102.2844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57649', 'place_name': 'Prairie City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Perkins', 'locality_code': '105', 'latitude': 45.5813, 'longitude': -102.8085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57442', 'place_name': 'Gettysburg', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Potter', 'locality_code': '107', 'latitude': 45.0259, 'longitude': -99.9766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57450', 'place_name': 'Hoven', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Potter', 'locality_code': '107', 'latitude': 45.2278, 'longitude': -99.7763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57455', 'place_name': 'Lebanon', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Potter', 'locality_code': '107', 'latitude': 45.0123, 'longitude': -99.7366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57475', 'place_name': 'Tolstoy', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Potter', 'locality_code': '107', 'latitude': 45.1702, 'longitude': -99.6176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57224', 'place_name': 'Claire City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.8755, 'longitude': -97.1073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57227', 'place_name': 'Corona', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.3595, 'longitude': -96.6649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57255', 'place_name': 'New Effington', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.8659, 'longitude': -96.915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57256', 'place_name': 'Ortley', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.2657, 'longitude': -97.1925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57257', 'place_name': 'Peever', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.5206, 'longitude': -97.0012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57260', 'place_name': 'Rosholt', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.8753, 'longitude': -96.7174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57262', 'place_name': 'Sisseton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.6732, 'longitude': -97.0715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57266', 'place_name': 'Summit', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.3521, 'longitude': -97.0427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57279', 'place_name': 'Wilmot', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Roberts', 'locality_code': '109', 'latitude': 45.4125, 'longitude': -96.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57314', 'place_name': 'Artesian', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Sanborn', 'locality_code': '111', 'latitude': 44.021, 'longitude': -98.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57359', 'place_name': 'Letcher', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Sanborn', 'locality_code': '111', 'latitude': 43.8923, 'longitude': -98.1743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57385', 'place_name': 'Woonsocket', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Sanborn', 'locality_code': '111', 'latitude': 44.0572, 'longitude': -98.243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57716', 'place_name': 'Batesland', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Shannon', 'locality_code': '113', 'latitude': 43.1085, 'longitude': -102.2006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57752', 'place_name': 'Kyle', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Shannon', 'locality_code': '113', 'latitude': 43.425, 'longitude': -102.1765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57756', 'place_name': 'Manderson', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Shannon', 'locality_code': '113', 'latitude': 43.2353, 'longitude': -102.4707, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57764', 'place_name': 'Oglala', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Shannon', 'locality_code': '113', 'latitude': 43.1886, 'longitude': -102.7396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57770', 'place_name': 'Pine Ridge', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Shannon', 'locality_code': '113', 'latitude': 43.1124, 'longitude': -102.5984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57772', 'place_name': 'Porcupine', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Shannon', 'locality_code': '113', 'latitude': 43.2397, 'longitude': -102.331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57794', 'place_name': 'Wounded Knee', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Shannon', 'locality_code': '113', 'latitude': 43.1405, 'longitude': -102.3657, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '57424', 'place_name': 'Ashton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 45.0465, 'longitude': -98.3973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57429', 'place_name': 'Brentford', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 45.1635, 'longitude': -98.3193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57434', 'place_name': 'Conde', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 45.1393, 'longitude': -98.1534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57436', 'place_name': 'Doland', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 44.8159, 'longitude': -98.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57440', 'place_name': 'Frankfort', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 44.8084, 'longitude': -98.2935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57460', 'place_name': 'Mansfield', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 45.243, 'longitude': -98.5629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57461', 'place_name': 'Mellette', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 45.1631, 'longitude': -98.4824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57465', 'place_name': 'Northville', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 45.1611, 'longitude': -98.6589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57469', 'place_name': 'Redfield', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 44.8719, 'longitude': -98.5112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57476', 'place_name': 'Tulare', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 44.7305, 'longitude': -98.5539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57477', 'place_name': 'Turton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Spink', 'locality_code': '115', 'latitude': 45.0379, 'longitude': -98.0996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57532', 'place_name': 'Fort Pierre', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Stanley', 'locality_code': '117', 'latitude': 44.3426, 'longitude': -100.4043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57537', 'place_name': 'Hayes', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Stanley', 'locality_code': '117', 'latitude': 44.3703, 'longitude': -101.0215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57520', 'place_name': 'Agar', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Sully', 'locality_code': '119', 'latitude': 44.8393, 'longitude': -100.0712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57564', 'place_name': 'Onida', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Sully', 'locality_code': '119', 'latitude': 44.7125, 'longitude': -100.0957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57555', 'place_name': 'Mission', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Todd', 'locality_code': '121', 'latitude': 43.285, 'longitude': -100.5954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57563', 'place_name': 'Okreek', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Todd', 'locality_code': '121', 'latitude': 43.3633, 'longitude': -100.3809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57566', 'place_name': 'Parmelee', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Todd', 'locality_code': '121', 'latitude': 43.3117, 'longitude': -101.0081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57570', 'place_name': 'Rosebud', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Todd', 'locality_code': '121', 'latitude': 43.2328, 'longitude': -100.8535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57572', 'place_name': 'Saint Francis', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Todd', 'locality_code': '121', 'latitude': 43.1444, 'longitude': -100.9051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57528', 'place_name': 'Colome', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Tripp', 'locality_code': '123', 'latitude': 43.2273, 'longitude': -99.6933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57534', 'place_name': 'Hamill', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Tripp', 'locality_code': '123', 'latitude': 43.6439, 'longitude': -99.6918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57541', 'place_name': 'Ideal', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Tripp', 'locality_code': '123', 'latitude': 43.5596, 'longitude': -99.9279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57580', 'place_name': 'Winner', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Tripp', 'locality_code': '123', 'latitude': 43.3318, 'longitude': -99.8033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57584', 'place_name': 'Witten', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Tripp', 'locality_code': '123', 'latitude': 43.4498, 'longitude': -100.0783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57014', 'place_name': 'Centerville', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.1176, 'longitude': -96.9636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57015', 'place_name': 'Chancellor', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.408, 'longitude': -96.9827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57021', 'place_name': 'Davis', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.2864, 'longitude': -96.9792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57036', 'place_name': 'Hurley', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.2893, 'longitude': -97.1904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57043', 'place_name': 'Marion', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.4188, 'longitude': -97.2771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57047', 'place_name': 'Monroe', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.5207, 'longitude': -97.212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57053', 'place_name': 'Parker', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.402, 'longitude': -97.1333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57070', 'place_name': 'Viborg', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Turner', 'locality_code': '125', 'latitude': 43.1815, 'longitude': -97.114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57001', 'place_name': 'Alcester', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Union', 'locality_code': '127', 'latitude': 43.0047, 'longitude': -96.6332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57004', 'place_name': 'Beresford', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Union', 'locality_code': '127', 'latitude': 43.0874, 'longitude': -96.7813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57025', 'place_name': 'Elk Point', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Union', 'locality_code': '127', 'latitude': 42.7382, 'longitude': -96.687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57038', 'place_name': 'Jefferson', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Union', 'locality_code': '127', 'latitude': 42.6013, 'longitude': -96.5784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57049', 'place_name': 'North Sioux City', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Union', 'locality_code': '127', 'latitude': 42.5249, 'longitude': -96.5074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57420', 'place_name': 'Akaska', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Walworth', 'locality_code': '129', 'latitude': 45.3324, 'longitude': -100.1186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57452', 'place_name': 'Java', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Walworth', 'locality_code': '129', 'latitude': 45.4492, 'longitude': -99.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57472', 'place_name': 'Selby', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Walworth', 'locality_code': '129', 'latitude': 45.4786, 'longitude': -100.0541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57601', 'place_name': 'Mobridge', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Walworth', 'locality_code': '129', 'latitude': 45.5407, 'longitude': -100.4315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57631', 'place_name': 'Glenham', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Walworth', 'locality_code': '129', 'latitude': 45.5335, 'longitude': -100.2716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57031', 'place_name': 'Gayville', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Yankton', 'locality_code': '135', 'latitude': 42.8835, 'longitude': -97.183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57040', 'place_name': 'Lesterville', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Yankton', 'locality_code': '135', 'latitude': 43.0394, 'longitude': -97.5956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57046', 'place_name': 'Mission Hill', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Yankton', 'locality_code': '135', 'latitude': 42.9836, 'longitude': -97.3349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57067', 'place_name': 'Utica', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Yankton', 'locality_code': '135', 'latitude': 43.0164, 'longitude': -97.3694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57072', 'place_name': 'Volin', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Yankton', 'locality_code': '135', 'latitude': 42.9572, 'longitude': -97.1803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57078', 'place_name': 'Yankton', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Yankton', 'locality_code': '135', 'latitude': 42.8821, 'longitude': -97.3986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57622', 'place_name': 'Cherry Creek', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Ziebach', 'locality_code': '137', 'latitude': 44.6055, 'longitude': -101.4999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '57623', 'place_name': 'Dupree', 'state': 'South Dakota', 'state_ab': 'SD', 'county': 'Ziebach', 'locality_code': '137', 'latitude': 45.0079, 'longitude': -101.6337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37705', 'place_name': 'Andersonville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.1915, 'longitude': -84.0544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37710', 'place_name': 'Briceville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.1626, 'longitude': -84.2992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37716', 'place_name': 'Clinton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.0869, 'longitude': -84.1897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37717', 'place_name': 'Clinton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.11, 'longitude': -84.1672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37769', 'place_name': 'Lake City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.2032, 'longitude': -84.1386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37828', 'place_name': 'Norris', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.2005, 'longitude': -84.0858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37830', 'place_name': 'Oak Ridge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.0159, 'longitude': -84.2623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37831', 'place_name': 'Oak Ridge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Anderson', 'locality_code': '1', 'latitude': 36.106, 'longitude': -84.1958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37020', 'place_name': 'Bell Buckle', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bedford', 'locality_code': '3', 'latitude': 35.6381, 'longitude': -86.3949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37160', 'place_name': 'Shelbyville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bedford', 'locality_code': '3', 'latitude': 35.4863, 'longitude': -86.4624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37161', 'place_name': 'Shelbyville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bedford', 'locality_code': '3', 'latitude': 35.4834, 'longitude': -86.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37162', 'place_name': 'Shelbyville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bedford', 'locality_code': '3', 'latitude': 35.5108, 'longitude': -86.45, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37180', 'place_name': 'Unionville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bedford', 'locality_code': '3', 'latitude': 35.6224, 'longitude': -86.5639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37183', 'place_name': 'Wartrace', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bedford', 'locality_code': '3', 'latitude': 35.5123, 'longitude': -86.3277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37360', 'place_name': 'Normandy', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bedford', 'locality_code': '3', 'latitude': 35.4296, 'longitude': -86.2557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38221', 'place_name': 'Big Sandy', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Benton', 'locality_code': '5', 'latitude': 36.2285, 'longitude': -88.0627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38320', 'place_name': 'Camden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Benton', 'locality_code': '5', 'latitude': 36.0556, 'longitude': -88.1119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38333', 'place_name': 'Eva', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Benton', 'locality_code': '5', 'latitude': 36.1142, 'longitude': -87.982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38341', 'place_name': 'Holladay', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Benton', 'locality_code': '5', 'latitude': 35.8951, 'longitude': -88.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37367', 'place_name': 'Pikeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bledsoe', 'locality_code': '7', 'latitude': 35.6408, 'longitude': -85.2077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37701', 'place_name': 'Alcoa', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.7852, 'longitude': -83.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37737', 'place_name': 'Friendsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.7523, 'longitude': -84.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37777', 'place_name': 'Louisville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.8375, 'longitude': -84.0089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37801', 'place_name': 'Maryville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.6884, 'longitude': -84.0769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37802', 'place_name': 'Maryville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.7565, 'longitude': -83.9705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37803', 'place_name': 'Maryville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.6539, 'longitude': -83.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37804', 'place_name': 'Maryville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.7991, 'longitude': -83.8852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37853', 'place_name': 'Rockford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.8305, 'longitude': -83.9412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37878', 'place_name': 'Tallassee', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.5844, 'longitude': -83.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37882', 'place_name': 'Townsend', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.6784, 'longitude': -83.7572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37886', 'place_name': 'Walland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Blount', 'locality_code': '9', 'latitude': 35.7533, 'longitude': -83.8243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37310', 'place_name': 'Charleston', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bradley', 'locality_code': '11', 'latitude': 35.2556, 'longitude': -84.7666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37311', 'place_name': 'Cleveland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bradley', 'locality_code': '11', 'latitude': 35.1313, 'longitude': -84.875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37312', 'place_name': 'Cleveland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bradley', 'locality_code': '11', 'latitude': 35.2023, 'longitude': -84.8476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37320', 'place_name': 'Cleveland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bradley', 'locality_code': '11', 'latitude': 35.1727, 'longitude': -84.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37323', 'place_name': 'Cleveland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bradley', 'locality_code': '11', 'latitude': 35.1361, 'longitude': -84.8457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37353', 'place_name': 'Mc Donald', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bradley', 'locality_code': '11', 'latitude': 35.0869, 'longitude': -84.9892, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37364', 'place_name': 'Cleveland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Bradley', 'locality_code': '11', 'latitude': 35.1727, 'longitude': -84.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37714', 'place_name': 'Caryville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Campbell', 'locality_code': '13', 'latitude': 36.3028, 'longitude': -84.203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37729', 'place_name': 'Duff', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Campbell', 'locality_code': '13', 'latitude': 36.5086, 'longitude': -84.0454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37757', 'place_name': 'Jacksboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Campbell', 'locality_code': '13', 'latitude': 36.3266, 'longitude': -84.1928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37762', 'place_name': 'Jellico', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Campbell', 'locality_code': '13', 'latitude': 36.577, 'longitude': -84.126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37766', 'place_name': 'La Follette', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Campbell', 'locality_code': '13', 'latitude': 36.4248, 'longitude': -84.0907, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37819', 'place_name': 'Newcomb', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Campbell', 'locality_code': '13', 'latitude': 36.5428, 'longitude': -84.1798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37847', 'place_name': 'Pioneer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Campbell', 'locality_code': '13', 'latitude': 36.4695, 'longitude': -84.2907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37016', 'place_name': 'Auburntown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cannon', 'locality_code': '15', 'latitude': 35.9338, 'longitude': -86.1126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37026', 'place_name': 'Bradyville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cannon', 'locality_code': '15', 'latitude': 35.7053, 'longitude': -86.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37149', 'place_name': 'Readyville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cannon', 'locality_code': '15', 'latitude': 35.7989, 'longitude': -86.2415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37190', 'place_name': 'Woodbury', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cannon', 'locality_code': '15', 'latitude': 35.8143, 'longitude': -86.05, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38201', 'place_name': 'Mc Kenzie', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 36.1272, 'longitude': -88.5134, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '38220', 'place_name': 'Atwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.9663, 'longitude': -88.6247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38235', 'place_name': 'Mc Lemoresville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.9778, 'longitude': -88.5744, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '38258', 'place_name': 'Trezevant', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 36.0172, 'longitude': -88.61, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38317', 'place_name': 'Bruceton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 36.0268, 'longitude': -88.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38318', 'place_name': 'Buena Vista', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.9431, 'longitude': -88.2926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38321', 'place_name': 'Cedar Grove', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.8613, 'longitude': -88.5517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38324', 'place_name': 'Clarksburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.8675, 'longitude': -88.3934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38342', 'place_name': 'Hollow Rock', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 36.0381, 'longitude': -88.2737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38344', 'place_name': 'Huntingdon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 36.0062, 'longitude': -88.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38348', 'place_name': 'Lavinia', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.8583, 'longitude': -88.6324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38387', 'place_name': 'Westport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.8845, 'longitude': -88.2892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38390', 'place_name': 'Yuma', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carroll', 'locality_code': '17', 'latitude': 35.868, 'longitude': -88.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37643', 'place_name': 'Elizabethton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carter', 'locality_code': '19', 'latitude': 36.3445, 'longitude': -82.2015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37644', 'place_name': 'Elizabethton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carter', 'locality_code': '19', 'latitude': 36.3487, 'longitude': -82.2107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37658', 'place_name': 'Hampton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carter', 'locality_code': '19', 'latitude': 36.2577, 'longitude': -82.1891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37682', 'place_name': 'Milligan College', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carter', 'locality_code': '19', 'latitude': 36.296, 'longitude': -82.3054, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37687', 'place_name': 'Roan Mountain', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carter', 'locality_code': '19', 'latitude': 36.1773, 'longitude': -82.081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37694', 'place_name': 'Watauga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Carter', 'locality_code': '19', 'latitude': 36.3702, 'longitude': -82.2683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37015', 'place_name': 'Ashland City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cheatham', 'locality_code': '21', 'latitude': 36.2731, 'longitude': -87.0447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37035', 'place_name': 'Chapmansboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cheatham', 'locality_code': '21', 'latitude': 36.3768, 'longitude': -87.1127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37082', 'place_name': 'Kingston Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cheatham', 'locality_code': '21', 'latitude': 36.0953, 'longitude': -87.1156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37143', 'place_name': 'Pegram', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cheatham', 'locality_code': '21', 'latitude': 36.1129, 'longitude': -87.0316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37146', 'place_name': 'Pleasant View', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cheatham', 'locality_code': '21', 'latitude': 36.3783, 'longitude': -87.0395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38332', 'place_name': 'Enville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Chester', 'locality_code': '23', 'latitude': 35.4393, 'longitude': -88.4206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38340', 'place_name': 'Henderson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Chester', 'locality_code': '23', 'latitude': 35.4269, 'longitude': -88.6398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38347', 'place_name': 'Jacks Creek', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Chester', 'locality_code': '23', 'latitude': 35.4782, 'longitude': -88.5019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38352', 'place_name': 'Luray', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Chester', 'locality_code': '23', 'latitude': 35.5355, 'longitude': -88.5379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37707', 'place_name': 'Arthur', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.5481, 'longitude': -83.6707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37715', 'place_name': 'Clairfield', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.565, 'longitude': -83.9397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37724', 'place_name': 'Cumberland Gap', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.5504, 'longitude': -83.681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37730', 'place_name': 'Eagan', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.552, 'longitude': -83.9769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37752', 'place_name': 'Harrogate', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.5767, 'longitude': -83.6073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37773', 'place_name': 'Lone Mountain', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.3906, 'longitude': -83.5849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37824', 'place_name': 'New Tazewell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.45, 'longitude': -83.5911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37825', 'place_name': 'New Tazewell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.4245, 'longitude': -83.6469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37851', 'place_name': 'Pruden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.5862, 'longitude': -83.901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37867', 'place_name': 'Shawanee', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.5803, 'longitude': -83.6473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37870', 'place_name': 'Speedwell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.4797, 'longitude': -83.8135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37879', 'place_name': 'Tazewell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Claiborne', 'locality_code': '25', 'latitude': 36.471, 'longitude': -83.5552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38551', 'place_name': 'Celina', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Clay', 'locality_code': '27', 'latitude': 36.5475, 'longitude': -85.4966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38575', 'place_name': 'Moss', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Clay', 'locality_code': '27', 'latitude': 36.5966, 'longitude': -85.6772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37713', 'place_name': 'Bybee', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cocke', 'locality_code': '29', 'latitude': 36.0482, 'longitude': -83.1793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37722', 'place_name': 'Cosby', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cocke', 'locality_code': '29', 'latitude': 35.8347, 'longitude': -83.2187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37727', 'place_name': 'Del Rio', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cocke', 'locality_code': '29', 'latitude': 35.883, 'longitude': -83.015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37753', 'place_name': 'Hartford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cocke', 'locality_code': '29', 'latitude': 35.8256, 'longitude': -83.0996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37821', 'place_name': 'Newport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cocke', 'locality_code': '29', 'latitude': 35.9544, 'longitude': -83.2027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37822', 'place_name': 'Newport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cocke', 'locality_code': '29', 'latitude': 35.967, 'longitude': -83.1877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37843', 'place_name': 'Parrottsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cocke', 'locality_code': '29', 'latitude': 35.9983, 'longitude': -83.0736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37018', 'place_name': 'Beechgrove', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Coffee', 'locality_code': '31', 'latitude': 35.6447, 'longitude': -86.2046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37342', 'place_name': 'Hillsboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Coffee', 'locality_code': '31', 'latitude': 35.3699, 'longitude': -85.9724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37349', 'place_name': 'Manchester', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Coffee', 'locality_code': '31', 'latitude': 35.4976, 'longitude': -86.0748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37355', 'place_name': 'Manchester', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Coffee', 'locality_code': '31', 'latitude': 35.4958, 'longitude': -86.0816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37382', 'place_name': 'Summitville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Coffee', 'locality_code': '31', 'latitude': 35.5595, 'longitude': -85.9925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37388', 'place_name': 'Tullahoma', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Coffee', 'locality_code': '31', 'latitude': 35.3468, 'longitude': -86.22, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37389', 'place_name': 'Arnold Afb', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Coffee', 'locality_code': '31', 'latitude': 35.4976, 'longitude': -86.0748, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '38001', 'place_name': 'Alamo', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Crockett', 'locality_code': '33', 'latitude': 35.8017, 'longitude': -89.1765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38006', 'place_name': 'Bells', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Crockett', 'locality_code': '33', 'latitude': 35.7198, 'longitude': -89.0729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38021', 'place_name': 'Crockett Mills', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Crockett', 'locality_code': '33', 'latitude': 35.8676, 'longitude': -89.1692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38034', 'place_name': 'Friendship', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Crockett', 'locality_code': '33', 'latitude': 35.909, 'longitude': -89.2453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38050', 'place_name': 'Maury City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Crockett', 'locality_code': '33', 'latitude': 35.8379, 'longitude': -89.2273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38336', 'place_name': 'Fruitvale', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Crockett', 'locality_code': '33', 'latitude': 35.7484, 'longitude': -89.0327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38337', 'place_name': 'Gadsden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Crockett', 'locality_code': '33', 'latitude': 35.7799, 'longitude': -88.9929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37723', 'place_name': 'Crab Orchard', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 35.9537, 'longitude': -84.8205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38555', 'place_name': 'Crossville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 35.9623, 'longitude': -85.0514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38557', 'place_name': 'Crossville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 35.9885, 'longitude': -85.0124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38558', 'place_name': 'Crossville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 36.0077, 'longitude': -84.8719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38571', 'place_name': 'Crossville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 36.0527, 'longitude': -85.0138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38572', 'place_name': 'Crossville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 35.8487, 'longitude': -85.1308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38578', 'place_name': 'Pleasant Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Cumberland', 'locality_code': '35', 'latitude': 35.9813, 'longitude': -85.1984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37011', 'place_name': 'Antioch', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.0601, 'longitude': -86.6722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37013', 'place_name': 'Antioch', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.0595, 'longitude': -86.6592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37070', 'place_name': 'Goodlettsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.3231, 'longitude': -86.7133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37072', 'place_name': 'Goodlettsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.3417, 'longitude': -86.7212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37076', 'place_name': 'Hermitage', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1848, 'longitude': -86.6002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37080', 'place_name': 'Joelton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.329, 'longitude': -86.9163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37115', 'place_name': 'Madison', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.2604, 'longitude': -86.7046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37116', 'place_name': 'Madison', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37138', 'place_name': 'Old Hickory', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.2416, 'longitude': -86.6117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37189', 'place_name': 'Whites Creek', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.2744, 'longitude': -86.8292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37201', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1657, 'longitude': -86.7781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37202', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.3403, 'longitude': -86.8273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37203', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1504, 'longitude': -86.7916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37204', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1067, 'longitude': -86.7743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37205', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1114, 'longitude': -86.869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37206', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1798, 'longitude': -86.7411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37207', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.2195, 'longitude': -86.774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37208', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1762, 'longitude': -86.8076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37209', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1546, 'longitude': -86.8602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37210', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1379, 'longitude': -86.741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37211', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.0725, 'longitude': -86.724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37212', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1337, 'longitude': -86.8006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37213', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1663, 'longitude': -86.7669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37214', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1633, 'longitude': -86.6609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37215', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.0986, 'longitude': -86.8219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37216', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.2125, 'longitude': -86.7257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37217', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1052, 'longitude': -86.6591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37218', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.2071, 'longitude': -86.8456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37219', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1678, 'longitude': -86.7837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37220', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.0641, 'longitude': -86.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37221', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.0662, 'longitude': -86.9639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37222', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1659, 'longitude': -86.7844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37224', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37227', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37228', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1901, 'longitude': -86.8053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37229', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37230', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37232', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37234', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37235', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37236', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37238', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37240', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37241', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37242', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37243', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.165, 'longitude': -86.7821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37244', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37246', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1586, 'longitude': -86.79, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37250', 'place_name': 'Nashville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Davidson', 'locality_code': '37', 'latitude': 36.1866, 'longitude': -86.7852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38311', 'place_name': 'Bath Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Decatur', 'locality_code': '39', 'latitude': 35.4521, 'longitude': -88.1286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38329', 'place_name': 'Decaturville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Decatur', 'locality_code': '39', 'latitude': 35.5585, 'longitude': -88.1334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38363', 'place_name': 'Parsons', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Decatur', 'locality_code': '39', 'latitude': 35.6664, 'longitude': -88.1195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38374', 'place_name': 'Scotts Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Decatur', 'locality_code': '39', 'latitude': 35.505, 'longitude': -88.2405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38380', 'place_name': 'Sugar Tree', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Decatur', 'locality_code': '39', 'latitude': 35.792, 'longitude': -88.0322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37012', 'place_name': 'Alexandria', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'DeKalb', 'locality_code': '41', 'latitude': 36.0711, 'longitude': -86.0372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37059', 'place_name': 'Dowelltown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'DeKalb', 'locality_code': '41', 'latitude': 35.9725, 'longitude': -85.9055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37095', 'place_name': 'Liberty', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'DeKalb', 'locality_code': '41', 'latitude': 36.0067, 'longitude': -85.9678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37166', 'place_name': 'Smithville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'DeKalb', 'locality_code': '41', 'latitude': 35.9299, 'longitude': -85.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37029', 'place_name': 'Burns', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.0471, 'longitude': -87.3061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37036', 'place_name': 'Charlotte', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.2326, 'longitude': -87.2816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37051', 'place_name': 'Cumberland Furnace', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.2721, 'longitude': -87.3914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37055', 'place_name': 'Dickson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.076, 'longitude': -87.3995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37056', 'place_name': 'Dickson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.1469, 'longitude': -87.353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37165', 'place_name': 'Slayden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.2948, 'longitude': -87.4703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37181', 'place_name': 'Vanleer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.2237, 'longitude': -87.4565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37187', 'place_name': 'White Bluff', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dickson', 'locality_code': '43', 'latitude': 36.1253, 'longitude': -87.219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38007', 'place_name': 'Bogota', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 36.164, 'longitude': -89.4384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38024', 'place_name': 'Dyersburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 36.0444, 'longitude': -89.3836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38025', 'place_name': 'Dyersburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 36.0345, 'longitude': -89.3856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38030', 'place_name': 'Finley', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 36.0169, 'longitude': -89.5134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38047', 'place_name': 'Lenox', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 36.0892, 'longitude': -89.4984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38059', 'place_name': 'Newbern', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 36.1009, 'longitude': -89.2514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38070', 'place_name': 'Tigrett', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 35.9515, 'longitude': -89.2401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38259', 'place_name': 'Trimble', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Dyer', 'locality_code': '45', 'latitude': 36.2011, 'longitude': -89.1863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38010', 'place_name': 'Braden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.2886, 'longitude': -89.488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38036', 'place_name': 'Gallaway', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.3274, 'longitude': -89.6198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38045', 'place_name': 'Laconia', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.2904, 'longitude': -89.2322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38046', 'place_name': 'La Grange', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.0454, 'longitude': -89.2437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38048', 'place_name': 'Macon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.1507, 'longitude': -89.4814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38057', 'place_name': 'Moscow', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.0588, 'longitude': -89.3595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38060', 'place_name': 'Oakland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.229, 'longitude': -89.5151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38066', 'place_name': 'Rossville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.0768, 'longitude': -89.5678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38068', 'place_name': 'Somerville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.2772, 'longitude': -89.3918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38076', 'place_name': 'Williston', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fayette', 'locality_code': '47', 'latitude': 35.1576, 'longitude': -89.3684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38504', 'place_name': 'Allardt', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fentress', 'locality_code': '49', 'latitude': 36.3818, 'longitude': -84.7756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38553', 'place_name': 'Clarkrange', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fentress', 'locality_code': '49', 'latitude': 36.2112, 'longitude': -84.9777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38556', 'place_name': 'Jamestown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fentress', 'locality_code': '49', 'latitude': 36.4245, 'longitude': -84.9357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38565', 'place_name': 'Grimsley', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fentress', 'locality_code': '49', 'latitude': 36.2598, 'longitude': -85.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38577', 'place_name': 'Pall Mall', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fentress', 'locality_code': '49', 'latitude': 36.5781, 'longitude': -85.0384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38589', 'place_name': 'Wilder', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Fentress', 'locality_code': '49', 'latitude': 36.2822, 'longitude': -85.0913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37306', 'place_name': 'Belvidere', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.1415, 'longitude': -86.1728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37318', 'place_name': 'Cowan', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.1783, 'longitude': -86.0167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37324', 'place_name': 'Decherd', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.2326, 'longitude': -86.0589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37330', 'place_name': 'Estill Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.2705, 'longitude': -86.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37345', 'place_name': 'Huntland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.0512, 'longitude': -86.2694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37375', 'place_name': 'Sewanee', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.2011, 'longitude': -85.9126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37376', 'place_name': 'Sherwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.0452, 'longitude': -85.9302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37383', 'place_name': 'Sewanee', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.1805, 'longitude': -85.9035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37398', 'place_name': 'Winchester', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Franklin', 'locality_code': '51', 'latitude': 35.1864, 'longitude': -86.113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38233', 'place_name': 'Kenton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 36.1906, 'longitude': -89.0229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38316', 'place_name': 'Bradford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 36.0645, 'longitude': -88.8046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38330', 'place_name': 'Dyer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 36.0716, 'longitude': -89.0192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38331', 'place_name': 'Eaton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 35.9693, 'longitude': -89.1319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38338', 'place_name': 'Gibson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 35.8708, 'longitude': -88.8464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38343', 'place_name': 'Humboldt', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 35.837, 'longitude': -88.9057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38346', 'place_name': 'Idlewild', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 36.0306, 'longitude': -88.8056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38355', 'place_name': 'Medina', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 35.8081, 'longitude': -88.7627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38358', 'place_name': 'Milan', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 35.9251, 'longitude': -88.7688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38369', 'place_name': 'Rutherford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 36.13, 'longitude': -88.9849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38382', 'place_name': 'Trenton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 35.9712, 'longitude': -88.9507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38389', 'place_name': 'Yorkville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Gibson', 'locality_code': '53', 'latitude': 36.1354, 'longitude': -89.1117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38449', 'place_name': 'Ardmore', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.0574, 'longitude': -86.8796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38455', 'place_name': 'Elkton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.0523, 'longitude': -86.8886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38459', 'place_name': 'Frankewing', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.1834, 'longitude': -86.85, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38460', 'place_name': 'Goodspring', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.1167, 'longitude': -87.1278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38472', 'place_name': 'Lynnville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.3792, 'longitude': -87.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38473', 'place_name': 'Minor Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.05, 'longitude': -87.1522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38477', 'place_name': 'Prospect', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.0666, 'longitude': -87.0174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38478', 'place_name': 'Pulaski', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Giles', 'locality_code': '55', 'latitude': 35.2093, 'longitude': -87.0393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37708', 'place_name': 'Bean Station', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grainger', 'locality_code': '57', 'latitude': 36.3249, 'longitude': -83.3142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37709', 'place_name': 'Blaine', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grainger', 'locality_code': '57', 'latitude': 36.1583, 'longitude': -83.6783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37848', 'place_name': 'Powder Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grainger', 'locality_code': '57', 'latitude': 36.2357, 'longitude': -83.6801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37861', 'place_name': 'Rutledge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grainger', 'locality_code': '57', 'latitude': 36.2501, 'longitude': -83.5125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37881', 'place_name': 'Thorn Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grainger', 'locality_code': '57', 'latitude': 36.3917, 'longitude': -83.366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37888', 'place_name': 'Washburn', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grainger', 'locality_code': '57', 'latitude': 36.3106, 'longitude': -83.5937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37616', 'place_name': 'Afton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.2265, 'longitude': -82.7476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37641', 'place_name': 'Chuckey', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.2569, 'longitude': -82.6905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37743', 'place_name': 'Greeneville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.1316, 'longitude': -82.8692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37744', 'place_name': 'Greeneville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.1683, 'longitude': -82.8548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37745', 'place_name': 'Greeneville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.2455, 'longitude': -82.8238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37809', 'place_name': 'Midway', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.151, 'longitude': -83.0281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37810', 'place_name': 'Mohawk', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.1869, 'longitude': -83.0902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37818', 'place_name': 'Mosheim', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Greene', 'locality_code': '59', 'latitude': 36.1839, 'longitude': -82.9674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37301', 'place_name': 'Altamont', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.4258, 'longitude': -85.7635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37305', 'place_name': 'Beersheba Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.4652, 'longitude': -85.6942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37313', 'place_name': 'Coalmont', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.3516, 'longitude': -85.7003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37339', 'place_name': 'Gruetli Laager', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.3723, 'longitude': -85.618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37356', 'place_name': 'Monteagle', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.2402, 'longitude': -85.8228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37365', 'place_name': 'Palmer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.3741, 'longitude': -85.5643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37366', 'place_name': 'Pelham', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.314, 'longitude': -85.8441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37387', 'place_name': 'Tracy City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Grundy', 'locality_code': '61', 'latitude': 35.2721, 'longitude': -85.7362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37778', 'place_name': 'Lowland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.2133, 'longitude': -83.2752, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37813', 'place_name': 'Morristown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.1957, 'longitude': -83.2755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37814', 'place_name': 'Morristown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.2248, 'longitude': -83.3119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37815', 'place_name': 'Morristown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.2133, 'longitude': -83.2752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37816', 'place_name': 'Morristown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.2133, 'longitude': -83.2752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37860', 'place_name': 'Russellville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.2567, 'longitude': -83.1914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37877', 'place_name': 'Talbott', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.16, 'longitude': -83.4129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37891', 'place_name': 'Whitesburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamblen', 'locality_code': '63', 'latitude': 36.2621, 'longitude': -83.1458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37302', 'place_name': 'Apison', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0149, 'longitude': -85.0164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37304', 'place_name': 'Bakewell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.3452, 'longitude': -85.138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37308', 'place_name': 'Birchwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.352, 'longitude': -84.9618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37315', 'place_name': 'Collegedale', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0479, 'longitude': -85.0574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37341', 'place_name': 'Harrison', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.1679, 'longitude': -85.0945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37343', 'place_name': 'Hixson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.1591, 'longitude': -85.2182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37350', 'place_name': 'Lookout Mountain', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 34.9948, 'longitude': -85.3506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37351', 'place_name': 'Lupton City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.1045, 'longitude': -85.2631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37363', 'place_name': 'Ooltewah', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0781, 'longitude': -85.0635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37373', 'place_name': 'Sale Creek', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.3858, 'longitude': -85.1023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37377', 'place_name': 'Signal Mountain', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.1494, 'longitude': -85.3362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37379', 'place_name': 'Soddy Daisy', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.2527, 'longitude': -85.163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37384', 'place_name': 'Soddy Daisy', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.2211, 'longitude': -85.2091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37401', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0456, 'longitude': -85.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37402', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0463, 'longitude': -85.3161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37403', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.045, 'longitude': -85.2965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37404', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0306, 'longitude': -85.2722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37405', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0768, 'longitude': -85.3082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37406', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0614, 'longitude': -85.2478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37407', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0024, 'longitude': -85.2849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37408', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0292, 'longitude': -85.3068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37409', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 34.9981, 'longitude': -85.331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37410', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0018, 'longitude': -85.3138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37411', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0271, 'longitude': -85.2356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37412', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0015, 'longitude': -85.2384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37414', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0456, 'longitude': -85.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37415', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.1273, 'longitude': -85.2802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37416', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0942, 'longitude': -85.1757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37419', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0331, 'longitude': -85.3687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37421', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.025, 'longitude': -85.1459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37422', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0456, 'longitude': -85.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37424', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0456, 'longitude': -85.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37450', 'place_name': 'Chattanooga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hamilton', 'locality_code': '65', 'latitude': 35.0456, 'longitude': -85.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37765', 'place_name': 'Kyles Ford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hancock', 'locality_code': '67', 'latitude': 36.5721, 'longitude': -83.0507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37869', 'place_name': 'Sneedville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hancock', 'locality_code': '67', 'latitude': 36.5275, 'longitude': -83.2529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38008', 'place_name': 'Bolivar', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.2461, 'longitude': -89.0007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38039', 'place_name': 'Grand Junction', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.049, 'longitude': -89.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38042', 'place_name': 'Hickory Valley', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.158, 'longitude': -89.1309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38044', 'place_name': 'Hornsby', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.2197, 'longitude': -88.8263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38052', 'place_name': 'Middleton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.0818, 'longitude': -88.9046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38061', 'place_name': 'Pocahontas', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.0315, 'longitude': -88.8116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38067', 'place_name': 'Saulsbury', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.0498, 'longitude': -89.0769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38075', 'place_name': 'Whiteville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.3191, 'longitude': -89.1337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38377', 'place_name': 'Silerton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.356, 'longitude': -88.8269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38381', 'place_name': 'Toone', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardeman', 'locality_code': '69', 'latitude': 35.3574, 'longitude': -88.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38326', 'place_name': 'Counce', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.0394, 'longitude': -88.2936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38327', 'place_name': 'Crump', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.2191, 'longitude': -88.3192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38361', 'place_name': 'Morris Chapel', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.3026, 'longitude': -88.3176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38365', 'place_name': 'Pickwick Dam', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.0383, 'longitude': -88.2256, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '38370', 'place_name': 'Saltillo', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.3815, 'longitude': -88.2472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38372', 'place_name': 'Savannah', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.2023, 'longitude': -88.2005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38376', 'place_name': 'Shiloh', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.1154, 'longitude': -88.3617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38475', 'place_name': 'Olivehill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hardin', 'locality_code': '71', 'latitude': 35.2667, 'longitude': -88.039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37642', 'place_name': 'Church Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hawkins', 'locality_code': '73', 'latitude': 36.5399, 'longitude': -82.7252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37645', 'place_name': 'Mount Carmel', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hawkins', 'locality_code': '73', 'latitude': 36.5629, 'longitude': -82.6532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37711', 'place_name': 'Bulls Gap', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hawkins', 'locality_code': '73', 'latitude': 36.2832, 'longitude': -83.0374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37731', 'place_name': 'Eidson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hawkins', 'locality_code': '73', 'latitude': 36.4995, 'longitude': -83.0827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37811', 'place_name': 'Mooresburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hawkins', 'locality_code': '73', 'latitude': 36.3621, 'longitude': -83.2095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37857', 'place_name': 'Rogersville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hawkins', 'locality_code': '73', 'latitude': 36.4162, 'longitude': -83.0108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37873', 'place_name': 'Surgoinsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hawkins', 'locality_code': '73', 'latitude': 36.4741, 'longitude': -82.8306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38012', 'place_name': 'Brownsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Haywood', 'locality_code': '75', 'latitude': 35.61, 'longitude': -89.2624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38069', 'place_name': 'Stanton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Haywood', 'locality_code': '75', 'latitude': 35.4482, 'longitude': -89.3326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38328', 'place_name': 'Darden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henderson', 'locality_code': '77', 'latitude': 35.663, 'longitude': -88.2177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38345', 'place_name': 'Huron', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henderson', 'locality_code': '77', 'latitude': 35.6144, 'longitude': -88.5195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38351', 'place_name': 'Lexington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henderson', 'locality_code': '77', 'latitude': 35.6512, 'longitude': -88.3927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38368', 'place_name': 'Reagan', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henderson', 'locality_code': '77', 'latitude': 35.5096, 'longitude': -88.3508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38371', 'place_name': 'Sardis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henderson', 'locality_code': '77', 'latitude': 35.4386, 'longitude': -88.3058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38388', 'place_name': 'Wildersville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henderson', 'locality_code': '77', 'latitude': 35.7698, 'longitude': -88.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38222', 'place_name': 'Buchanan', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.4146, 'longitude': -88.1515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38223', 'place_name': 'Como', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.2931, 'longitude': -88.5123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38224', 'place_name': 'Cottage Grove', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.3479, 'longitude': -88.4614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38231', 'place_name': 'Henry', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.2039, 'longitude': -88.4198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38236', 'place_name': 'Mansfield', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.1847, 'longitude': -88.2859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38242', 'place_name': 'Paris', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.3005, 'longitude': -88.3093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38251', 'place_name': 'Puryear', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.4456, 'longitude': -88.3472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38256', 'place_name': 'Springville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Henry', 'locality_code': '79', 'latitude': 36.265, 'longitude': -88.1459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37025', 'place_name': 'Bon Aqua', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hickman', 'locality_code': '81', 'latitude': 35.9471, 'longitude': -87.2996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37033', 'place_name': 'Centerville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hickman', 'locality_code': '81', 'latitude': 35.7797, 'longitude': -87.4775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37098', 'place_name': 'Lyles', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hickman', 'locality_code': '81', 'latitude': 35.8502, 'longitude': -87.3127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37137', 'place_name': 'Nunnelly', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hickman', 'locality_code': '81', 'latitude': 35.8763, 'longitude': -87.5067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37140', 'place_name': 'Only', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hickman', 'locality_code': '81', 'latitude': 35.8679, 'longitude': -87.6655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38454', 'place_name': 'Duck River', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hickman', 'locality_code': '81', 'latitude': 35.748, 'longitude': -87.3577, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '38476', 'place_name': 'Primm Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Hickman', 'locality_code': '81', 'latitude': 35.8104, 'longitude': -87.253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37061', 'place_name': 'Erin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Houston', 'locality_code': '83', 'latitude': 36.3067, 'longitude': -87.679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37175', 'place_name': 'Stewart', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Houston', 'locality_code': '83', 'latitude': 36.3241, 'longitude': -87.8725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37178', 'place_name': 'Tennessee Ridge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Houston', 'locality_code': '83', 'latitude': 36.3297, 'longitude': -87.7808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37078', 'place_name': 'Hurricane Mills', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Humphreys', 'locality_code': '85', 'latitude': 35.924, 'longitude': -87.8105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37101', 'place_name': 'Mc Ewen', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Humphreys', 'locality_code': '85', 'latitude': 36.1185, 'longitude': -87.6422, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37134', 'place_name': 'New Johnsonville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Humphreys', 'locality_code': '85', 'latitude': 36.0088, 'longitude': -87.9547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37185', 'place_name': 'Waverly', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Humphreys', 'locality_code': '85', 'latitude': 36.0997, 'longitude': -87.7991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38562', 'place_name': 'Gainesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jackson', 'locality_code': '87', 'latitude': 36.3438, 'longitude': -85.6355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38564', 'place_name': 'Granville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jackson', 'locality_code': '87', 'latitude': 36.2768, 'longitude': -85.7475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38588', 'place_name': 'Whitleyville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jackson', 'locality_code': '87', 'latitude': 36.5158, 'longitude': -85.6899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37725', 'place_name': 'Dandridge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jefferson', 'locality_code': '89', 'latitude': 36.0008, 'longitude': -83.4233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37760', 'place_name': 'Jefferson City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jefferson', 'locality_code': '89', 'latitude': 36.1163, 'longitude': -83.481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37820', 'place_name': 'New Market', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jefferson', 'locality_code': '89', 'latitude': 36.081, 'longitude': -83.5673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37871', 'place_name': 'Strawberry Plains', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jefferson', 'locality_code': '89', 'latitude': 36.0687, 'longitude': -83.6568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37890', 'place_name': 'White Pine', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Jefferson', 'locality_code': '89', 'latitude': 36.0776, 'longitude': -83.2998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37640', 'place_name': 'Butler', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Johnson', 'locality_code': '91', 'latitude': 36.3282, 'longitude': -81.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37680', 'place_name': 'Laurel Bloomery', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Johnson', 'locality_code': '91', 'latitude': 36.5793, 'longitude': -81.7254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37683', 'place_name': 'Mountain City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Johnson', 'locality_code': '91', 'latitude': 36.4657, 'longitude': -81.814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37688', 'place_name': 'Shady Valley', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Johnson', 'locality_code': '91', 'latitude': 36.5272, 'longitude': -81.9068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37691', 'place_name': 'Trade', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Johnson', 'locality_code': '91', 'latitude': 36.3683, 'longitude': -81.7572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37721', 'place_name': 'Corryton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.12, 'longitude': -83.813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37754', 'place_name': 'Heiskell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.115, 'longitude': -84.0438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37806', 'place_name': 'Mascot', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.0844, 'longitude': -83.7411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37849', 'place_name': 'Powell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.0435, 'longitude': -84.04, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37901', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.0323, 'longitude': -83.8848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37902', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9625, 'longitude': -83.9209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37909', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.946, 'longitude': -84.0235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37912', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.0055, 'longitude': -83.9773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37914', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9918, 'longitude': -83.8496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37915', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9721, 'longitude': -83.901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37916', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9556, 'longitude': -83.9336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37917', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.998, 'longitude': -83.9152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37918', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.0501, 'longitude': -83.9226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37919', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9244, 'longitude': -84.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37920', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.8929, 'longitude': -83.9387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37921', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9793, 'longitude': -84.003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37922', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.858, 'longitude': -84.1194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37923', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9331, 'longitude': -84.0761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37924', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.032, 'longitude': -83.8021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37927', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37928', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37929', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9606, 'longitude': -83.9207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37930', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9029, 'longitude': -83.9536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37931', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9924, 'longitude': -84.1201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37932', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9335, 'longitude': -84.1481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37933', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37934', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.8762, 'longitude': -84.1746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37938', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 36.1055, 'longitude': -83.946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37939', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37940', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37950', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37995', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9606, 'longitude': -83.9207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37996', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37997', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9901, 'longitude': -83.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37998', 'place_name': 'Knoxville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Knox', 'locality_code': '93', 'latitude': 35.9351, 'longitude': -83.7503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38077', 'place_name': 'Wynnburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lake', 'locality_code': '95', 'latitude': 36.3281, 'longitude': -89.4744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38079', 'place_name': 'Tiptonville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lake', 'locality_code': '95', 'latitude': 36.3846, 'longitude': -89.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38080', 'place_name': 'Ridgely', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lake', 'locality_code': '95', 'latitude': 36.2638, 'longitude': -89.4858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38037', 'place_name': 'Gates', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lauderdale', 'locality_code': '97', 'latitude': 35.796, 'longitude': -89.3938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38040', 'place_name': 'Halls', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lauderdale', 'locality_code': '97', 'latitude': 35.8862, 'longitude': -89.4147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38041', 'place_name': 'Henning', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lauderdale', 'locality_code': '97', 'latitude': 35.6593, 'longitude': -89.6962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38063', 'place_name': 'Ripley', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lauderdale', 'locality_code': '97', 'latitude': 35.7527, 'longitude': -89.535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38456', 'place_name': 'Ethridge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.3326, 'longitude': -87.3039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38457', 'place_name': 'Five Points', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.031, 'longitude': -87.2961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38463', 'place_name': 'Iron City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.0563, 'longitude': -87.6473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38464', 'place_name': 'Lawrenceburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.2507, 'longitude': -87.3526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38468', 'place_name': 'Leoma', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.1382, 'longitude': -87.3168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38469', 'place_name': 'Loretto', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.0728, 'longitude': -87.427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38481', 'place_name': 'Saint Joseph', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.0376, 'longitude': -87.5018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38483', 'place_name': 'Summertown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.4307, 'longitude': -87.3198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38486', 'place_name': 'Westpoint', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lawrence', 'locality_code': '99', 'latitude': 35.1393, 'longitude': -87.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38462', 'place_name': 'Hohenwald', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lewis', 'locality_code': '101', 'latitude': 35.5266, 'longitude': -87.4891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37144', 'place_name': 'Petersburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.2924, 'longitude': -86.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37328', 'place_name': 'Elora', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.0295, 'longitude': -86.3481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37334', 'place_name': 'Fayetteville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.1527, 'longitude': -86.5664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37335', 'place_name': 'Flintville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.0581, 'longitude': -86.413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37348', 'place_name': 'Kelso', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.1024, 'longitude': -86.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37359', 'place_name': 'Mulberry', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.1941, 'longitude': -86.4217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38453', 'place_name': 'Dellrose', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.1214, 'longitude': -86.8121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38488', 'place_name': 'Taft', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Lincoln', 'locality_code': '103', 'latitude': 35.0517, 'longitude': -86.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37742', 'place_name': 'Greenback', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Loudon', 'locality_code': '105', 'latitude': 35.6567, 'longitude': -84.171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37771', 'place_name': 'Lenoir City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Loudon', 'locality_code': '105', 'latitude': 35.8104, 'longitude': -84.2665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37772', 'place_name': 'Lenoir City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Loudon', 'locality_code': '105', 'latitude': 35.7883, 'longitude': -84.2188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37774', 'place_name': 'Loudon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Loudon', 'locality_code': '105', 'latitude': 35.7292, 'longitude': -84.3436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37846', 'place_name': 'Philadelphia', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Loudon', 'locality_code': '105', 'latitude': 35.6781, 'longitude': -84.4312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37303', 'place_name': 'Athens', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McMinn', 'locality_code': '107', 'latitude': 35.4574, 'longitude': -84.6043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37309', 'place_name': 'Calhoun', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McMinn', 'locality_code': '107', 'latitude': 35.3228, 'longitude': -84.7364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37329', 'place_name': 'Englewood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McMinn', 'locality_code': '107', 'latitude': 35.4272, 'longitude': -84.4833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37331', 'place_name': 'Etowah', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McMinn', 'locality_code': '107', 'latitude': 35.3314, 'longitude': -84.5283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37370', 'place_name': 'Riceville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McMinn', 'locality_code': '107', 'latitude': 35.3731, 'longitude': -84.6951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37371', 'place_name': 'Athens', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McMinn', 'locality_code': '107', 'latitude': 35.4429, 'longitude': -84.593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37826', 'place_name': 'Niota', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McMinn', 'locality_code': '107', 'latitude': 35.5819, 'longitude': -84.5721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38310', 'place_name': 'Adamsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.2556, 'longitude': -88.4134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38315', 'place_name': 'Bethel Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.2289, 'longitude': -88.644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38334', 'place_name': 'Finger', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.3544, 'longitude': -88.5876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38339', 'place_name': 'Guys', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.0142, 'longitude': -88.5208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38357', 'place_name': 'Michie', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.0603, 'longitude': -88.4405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38359', 'place_name': 'Milledgeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.3729, 'longitude': -88.3675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38367', 'place_name': 'Ramer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.0642, 'longitude': -88.6017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38375', 'place_name': 'Selmer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.1691, 'longitude': -88.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38379', 'place_name': 'Stantonville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 35.1809, 'longitude': -88.4364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38393', 'place_name': 'Chewalla', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'McNairy', 'locality_code': '109', 'latitude': 34.9969, 'longitude': -88.6456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37083', 'place_name': 'Lafayette', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Macon', 'locality_code': '111', 'latitude': 36.539, 'longitude': -86.0242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37150', 'place_name': 'Red Boiling Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Macon', 'locality_code': '111', 'latitude': 36.5177, 'longitude': -85.8662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38301', 'place_name': 'Jackson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.6102, 'longitude': -88.814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38302', 'place_name': 'Jackson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.6124, 'longitude': -88.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38303', 'place_name': 'Jackson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.6124, 'longitude': -88.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38305', 'place_name': 'Jackson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.6829, 'longitude': -88.8281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38308', 'place_name': 'Jackson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.6124, 'longitude': -88.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38313', 'place_name': 'Beech Bluff', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.5922, 'longitude': -88.6396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38314', 'place_name': 'Jackson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.6124, 'longitude': -88.8412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38356', 'place_name': 'Medon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.4345, 'longitude': -88.8953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38362', 'place_name': 'Oakfield', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.7242, 'longitude': -88.7801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38366', 'place_name': 'Pinson', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.4781, 'longitude': -88.7304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38378', 'place_name': 'Spring Creek', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.7668, 'longitude': -88.6839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38391', 'place_name': 'Denmark', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.5571, 'longitude': -88.9759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38392', 'place_name': 'Mercer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Madison', 'locality_code': '113', 'latitude': 35.4816, 'longitude': -89.0271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37340', 'place_name': 'Guild', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marion', 'locality_code': '115', 'latitude': 35.0178, 'longitude': -85.5116, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37347', 'place_name': 'Jasper', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marion', 'locality_code': '115', 'latitude': 35.097, 'longitude': -85.5897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37374', 'place_name': 'Sequatchie', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marion', 'locality_code': '115', 'latitude': 35.1634, 'longitude': -85.6371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37380', 'place_name': 'South Pittsburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marion', 'locality_code': '115', 'latitude': 35.028, 'longitude': -85.7225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37396', 'place_name': 'Whiteside', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marion', 'locality_code': '115', 'latitude': 34.9873, 'longitude': -85.4977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37397', 'place_name': 'Whitwell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marion', 'locality_code': '115', 'latitude': 35.1972, 'longitude': -85.5011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37019', 'place_name': 'Belfast', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marshall', 'locality_code': '117', 'latitude': 35.4069, 'longitude': -86.7095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37034', 'place_name': 'Chapel Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marshall', 'locality_code': '117', 'latitude': 35.6354, 'longitude': -86.6836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37047', 'place_name': 'Cornersville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marshall', 'locality_code': '117', 'latitude': 35.3409, 'longitude': -86.8286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37091', 'place_name': 'Lewisburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Marshall', 'locality_code': '117', 'latitude': 35.4596, 'longitude': -86.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37174', 'place_name': 'Spring Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.7173, 'longitude': -86.9048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38401', 'place_name': 'Columbia', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.6156, 'longitude': -87.038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38402', 'place_name': 'Columbia', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.6151, 'longitude': -87.0353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38451', 'place_name': 'Culleoka', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.4749, 'longitude': -87.0005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38461', 'place_name': 'Hampshire', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.5915, 'longitude': -87.3251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38474', 'place_name': 'Mount Pleasant', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.5301, 'longitude': -87.2037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38482', 'place_name': 'Santa Fe', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.7588, 'longitude': -87.1515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38487', 'place_name': 'Williamsport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Maury', 'locality_code': '119', 'latitude': 35.6494, 'longitude': -87.2257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37322', 'place_name': 'Decatur', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Meigs', 'locality_code': '121', 'latitude': 35.5072, 'longitude': -84.8081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37336', 'place_name': 'Georgetown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Meigs', 'locality_code': '121', 'latitude': 35.2932, 'longitude': -84.9127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37880', 'place_name': 'Ten Mile', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Meigs', 'locality_code': '121', 'latitude': 35.6862, 'longitude': -84.6548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37314', 'place_name': 'Cokercreek', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Monroe', 'locality_code': '123', 'latitude': 35.2467, 'longitude': -84.3031, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37354', 'place_name': 'Madisonville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Monroe', 'locality_code': '123', 'latitude': 35.4916, 'longitude': -84.3395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37385', 'place_name': 'Tellico Plains', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Monroe', 'locality_code': '123', 'latitude': 35.3562, 'longitude': -84.3068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37874', 'place_name': 'Sweetwater', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Monroe', 'locality_code': '123', 'latitude': 35.6015, 'longitude': -84.461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37885', 'place_name': 'Vonore', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Monroe', 'locality_code': '123', 'latitude': 35.5354, 'longitude': -84.1778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37040', 'place_name': 'Clarksville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.522, 'longitude': -87.349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37041', 'place_name': 'Clarksville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.4774, 'longitude': -87.3772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37042', 'place_name': 'Clarksville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.5853, 'longitude': -87.4186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37043', 'place_name': 'Clarksville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.5107, 'longitude': -87.2757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37044', 'place_name': 'Clarksville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.5314, 'longitude': -87.353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37052', 'place_name': 'Cunningham', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.3789, 'longitude': -87.4245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37142', 'place_name': 'Palmyra', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.4176, 'longitude': -87.4914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37171', 'place_name': 'Southside', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.3626, 'longitude': -87.3061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37191', 'place_name': 'Woodlawn', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Montgomery', 'locality_code': '125', 'latitude': 36.5147, 'longitude': -87.5393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37352', 'place_name': 'Lynchburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Moore', 'locality_code': '127', 'latitude': 35.2706, 'longitude': -86.372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37719', 'place_name': 'Coalfield', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.029, 'longitude': -84.4208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37726', 'place_name': 'Deer Lodge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.2176, 'longitude': -84.8191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37733', 'place_name': 'Rugby', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.3519, 'longitude': -84.7137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37770', 'place_name': 'Lancing', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.1456, 'longitude': -84.7135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37829', 'place_name': 'Oakdale', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.01, 'longitude': -84.5753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37840', 'place_name': 'Oliver Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.0366, 'longitude': -84.3486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37845', 'place_name': 'Petros', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.0959, 'longitude': -84.4424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37872', 'place_name': 'Sunbright', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.2622, 'longitude': -84.6984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37887', 'place_name': 'Wartburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Morgan', 'locality_code': '129', 'latitude': 36.1016, 'longitude': -84.5652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38232', 'place_name': 'Hornbeak', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.3596, 'longitude': -89.3056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38240', 'place_name': 'Obion', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.2657, 'longitude': -89.2805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38253', 'place_name': 'Rives', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.3108, 'longitude': -89.0731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38254', 'place_name': 'Samburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.3791, 'longitude': -89.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38257', 'place_name': 'South Fulton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.4814, 'longitude': -88.8808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38260', 'place_name': 'Troy', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.3416, 'longitude': -89.1611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38261', 'place_name': 'Union City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.4263, 'longitude': -89.0667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38271', 'place_name': 'Woodland Mills', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.4583, 'longitude': -89.2332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38281', 'place_name': 'Union City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Obion', 'locality_code': '131', 'latitude': 36.4242, 'longitude': -89.057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38541', 'place_name': 'Allons', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.497, 'longitude': -85.3197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38542', 'place_name': 'Allred', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.324, 'longitude': -85.2031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38543', 'place_name': 'Alpine', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.3803, 'longitude': -85.1522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38554', 'place_name': 'Crawford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.2361, 'longitude': -85.1688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38568', 'place_name': 'Hilham', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.4227, 'longitude': -85.4464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38570', 'place_name': 'Livingston', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.389, 'longitude': -85.3205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38573', 'place_name': 'Monroe', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.4642, 'longitude': -85.2164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38580', 'place_name': 'Rickman', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Overton', 'locality_code': '133', 'latitude': 36.2812, 'longitude': -85.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37096', 'place_name': 'Linden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Perry', 'locality_code': '135', 'latitude': 35.5944, 'longitude': -87.8567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37097', 'place_name': 'Lobelville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Perry', 'locality_code': '135', 'latitude': 35.7467, 'longitude': -87.8251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38549', 'place_name': 'Byrdstown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Pickett', 'locality_code': '137', 'latitude': 36.5709, 'longitude': -85.1456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37307', 'place_name': 'Benton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.173, 'longitude': -84.6544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37316', 'place_name': 'Conasauga', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 34.9971, 'longitude': -84.7327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37317', 'place_name': 'Copperhill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.0207, 'longitude': -84.3748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37325', 'place_name': 'Delano', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.2612, 'longitude': -84.6024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37326', 'place_name': 'Ducktown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.0339, 'longitude': -84.3792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37333', 'place_name': 'Farner', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.1449, 'longitude': -84.3209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37361', 'place_name': 'Ocoee', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.1025, 'longitude': -84.7136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37362', 'place_name': 'Old Fort', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.2829, 'longitude': -85.2568, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '37369', 'place_name': 'Reliance', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.1807, 'longitude': -84.541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37391', 'place_name': 'Turtletown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Polk', 'locality_code': '139', 'latitude': 35.1081, 'longitude': -84.3544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38501', 'place_name': 'Cookeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.2178, 'longitude': -85.5423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38502', 'place_name': 'Cookeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1628, 'longitude': -85.5016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38503', 'place_name': 'Cookeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1628, 'longitude': -85.5016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38505', 'place_name': 'Cookeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1628, 'longitude': -85.5016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38506', 'place_name': 'Cookeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1819, 'longitude': -85.4408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38544', 'place_name': 'Baxter', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1249, 'longitude': -85.6378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38545', 'place_name': 'Bloomington Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.2321, 'longitude': -85.6628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38548', 'place_name': 'Buffalo Valley', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1833, 'longitude': -85.7589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38574', 'place_name': 'Monterey', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1509, 'longitude': -85.2542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38582', 'place_name': 'Silver Point', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Putnam', 'locality_code': '141', 'latitude': 36.1006, 'longitude': -85.7338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37321', 'place_name': 'Dayton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rhea', 'locality_code': '143', 'latitude': 35.5002, 'longitude': -85.0135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37332', 'place_name': 'Evensville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rhea', 'locality_code': '143', 'latitude': 35.6153, 'longitude': -85.0228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37337', 'place_name': 'Grandview', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rhea', 'locality_code': '143', 'latitude': 35.7608, 'longitude': -84.8615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37338', 'place_name': 'Graysville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rhea', 'locality_code': '143', 'latitude': 35.4484, 'longitude': -85.179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37381', 'place_name': 'Spring City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rhea', 'locality_code': '143', 'latitude': 35.6935, 'longitude': -84.8198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37748', 'place_name': 'Harriman', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Roane', 'locality_code': '145', 'latitude': 35.9348, 'longitude': -84.5155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37763', 'place_name': 'Kingston', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Roane', 'locality_code': '145', 'latitude': 35.8528, 'longitude': -84.4971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37854', 'place_name': 'Rockwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Roane', 'locality_code': '145', 'latitude': 35.8587, 'longitude': -84.6842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37010', 'place_name': 'Adams', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.5582, 'longitude': -87.1226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37032', 'place_name': 'Cedar Hill', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.5514, 'longitude': -86.9992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37049', 'place_name': 'Cross Plains', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.5531, 'longitude': -86.6761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37073', 'place_name': 'Greenbrier', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.4229, 'longitude': -86.7914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37141', 'place_name': 'Orlinda', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.611, 'longitude': -86.699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37152', 'place_name': 'Ridgetop', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.4025, 'longitude': -86.7722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37172', 'place_name': 'Springfield', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.5018, 'longitude': -86.8769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37188', 'place_name': 'White House', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Robertson', 'locality_code': '147', 'latitude': 36.46, 'longitude': -86.6705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37037', 'place_name': 'Christiana', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.696, 'longitude': -86.368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37060', 'place_name': 'Eagleville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.7492, 'longitude': -86.6327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37063', 'place_name': 'Fosterville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.6551, 'longitude': -86.403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37085', 'place_name': 'Lascassas', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.9495, 'longitude': -86.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37086', 'place_name': 'La Vergne', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 36.0127, 'longitude': -86.56, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37089', 'place_name': 'La Vergne', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.8596, 'longitude': -86.421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37118', 'place_name': 'Milton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.9221, 'longitude': -86.1824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37127', 'place_name': 'Murfreesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.763, 'longitude': -86.3722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37128', 'place_name': 'Murfreesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.8454, 'longitude': -86.4867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37129', 'place_name': 'Murfreesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.871, 'longitude': -86.4181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37130', 'place_name': 'Murfreesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.8456, 'longitude': -86.3903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37131', 'place_name': 'Murfreesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.8596, 'longitude': -86.421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37132', 'place_name': 'Murfreesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.8596, 'longitude': -86.421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37133', 'place_name': 'Murfreesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.8456, 'longitude': -86.3903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37153', 'place_name': 'Rockvale', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.745, 'longitude': -86.5352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37167', 'place_name': 'Smyrna', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Rutherford', 'locality_code': '149', 'latitude': 35.9656, 'longitude': -86.5048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37732', 'place_name': 'Elgin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Scott', 'locality_code': '151', 'latitude': 36.3323, 'longitude': -84.6063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37755', 'place_name': 'Helenwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Scott', 'locality_code': '151', 'latitude': 36.4329, 'longitude': -84.5381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37756', 'place_name': 'Huntsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Scott', 'locality_code': '151', 'latitude': 36.3983, 'longitude': -84.4288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37841', 'place_name': 'Oneida', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Scott', 'locality_code': '151', 'latitude': 36.5053, 'longitude': -84.5293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37852', 'place_name': 'Robbins', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Scott', 'locality_code': '151', 'latitude': 36.3527, 'longitude': -84.5904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37892', 'place_name': 'Winfield', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Scott', 'locality_code': '151', 'latitude': 36.5598, 'longitude': -84.434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37327', 'place_name': 'Dunlap', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sequatchie', 'locality_code': '153', 'latitude': 35.3842, 'longitude': -85.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37738', 'place_name': 'Gatlinburg', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.729, 'longitude': -83.4874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37764', 'place_name': 'Kodak', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.9722, 'longitude': -83.6171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37862', 'place_name': 'Sevierville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.8452, 'longitude': -83.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37863', 'place_name': 'Pigeon Forge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.7922, 'longitude': -83.5638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37864', 'place_name': 'Sevierville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.8542, 'longitude': -83.6138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37865', 'place_name': 'Seymour', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.87, 'longitude': -83.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37868', 'place_name': 'Pigeon Forge', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.8809, 'longitude': -83.5561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37876', 'place_name': 'Sevierville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sevier', 'locality_code': '155', 'latitude': 35.866, 'longitude': -83.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37501', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1693, 'longitude': -89.9904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37544', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1496, 'longitude': -90.0487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38002', 'place_name': 'Arlington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2752, 'longitude': -89.7295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38014', 'place_name': 'Brunswick', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2673, 'longitude': -89.7687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38016', 'place_name': 'Cordova', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1602, 'longitude': -89.7816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38017', 'place_name': 'Collierville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0551, 'longitude': -89.6767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38018', 'place_name': 'Cordova', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1556, 'longitude': -89.7762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38027', 'place_name': 'Collierville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.042, 'longitude': -89.6645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38028', 'place_name': 'Eads', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1551, 'longitude': -89.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38029', 'place_name': 'Ellendale', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2306, 'longitude': -89.8259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38053', 'place_name': 'Millington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.3185, 'longitude': -89.9054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38054', 'place_name': 'Millington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.3341, 'longitude': -89.8706, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38055', 'place_name': 'Millington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.3415, 'longitude': -89.8973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38083', 'place_name': 'Millington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38088', 'place_name': 'Cordova', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1556, 'longitude': -89.7762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38101', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1495, 'longitude': -90.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38103', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.144, 'longitude': -90.048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38104', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1334, 'longitude': -90.0046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38105', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1497, 'longitude': -90.033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38106', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1021, 'longitude': -90.033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38107', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1831, 'longitude': -90.0201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38108', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1787, 'longitude': -89.9682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38109', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0425, 'longitude': -90.0732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38111', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1076, 'longitude': -89.9457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38112', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1483, 'longitude': -89.9729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38113', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1274, 'longitude': -89.9845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38114', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0981, 'longitude': -89.9825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38115', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0579, 'longitude': -89.864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38116', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0303, 'longitude': -90.0123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38117', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1124, 'longitude': -89.9034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38118', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0514, 'longitude': -89.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38119', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0821, 'longitude': -89.8501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38120', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1207, 'longitude': -89.8651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38122', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1572, 'longitude': -89.9268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38124', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38125', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0312, 'longitude': -89.8124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38126', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1255, 'longitude': -90.0424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38127', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.251, 'longitude': -90.0296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38128', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2213, 'longitude': -89.9413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38130', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38131', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0664, 'longitude': -89.9921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38132', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.072, 'longitude': -89.9886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38133', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2054, 'longitude': -89.8036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38134', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1845, 'longitude': -89.8574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38135', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2323, 'longitude': -89.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38136', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38137', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38138', 'place_name': 'Germantown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0883, 'longitude': -89.8053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38139', 'place_name': 'Germantown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0874, 'longitude': -89.7703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38141', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.0231, 'longitude': -89.8492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38145', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38148', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1495, 'longitude': -90.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38150', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1495, 'longitude': -90.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38151', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38152', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38157', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38159', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1495, 'longitude': -90.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38161', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38163', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38166', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38167', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38168', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38173', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.1495, 'longitude': -90.049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38174', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38175', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38177', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38181', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38182', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38183', 'place_name': 'Germantown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38184', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38186', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38187', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38188', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38190', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38193', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38194', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38197', 'place_name': 'Memphis', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Shelby', 'locality_code': '157', 'latitude': 35.2017, 'longitude': -89.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37030', 'place_name': 'Carthage', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.2763, 'longitude': -85.9517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37057', 'place_name': 'Dixon Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.4455, 'longitude': -86.0533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37145', 'place_name': 'Pleasant Shade', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.3462, 'longitude': -85.9189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37151', 'place_name': 'Riddleton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.3506, 'longitude': -86.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38547', 'place_name': 'Brush Creek', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.1107, 'longitude': -86.0203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38552', 'place_name': 'Chestnut Mound', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.2028, 'longitude': -85.8264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38560', 'place_name': 'Elmwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.2355, 'longitude': -85.8808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38563', 'place_name': 'Gordonsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.1843, 'longitude': -86.0008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38567', 'place_name': 'Hickman', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.1197, 'longitude': -85.9023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38569', 'place_name': 'Lancaster', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Smith', 'locality_code': '159', 'latitude': 36.0954, 'longitude': -85.8551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37023', 'place_name': 'Big Rock', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Stewart', 'locality_code': '161', 'latitude': 36.5716, 'longitude': -87.7378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37028', 'place_name': 'Bumpus Mills', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Stewart', 'locality_code': '161', 'latitude': 36.6226, 'longitude': -87.8614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37050', 'place_name': 'Cumberland City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Stewart', 'locality_code': '161', 'latitude': 36.3729, 'longitude': -87.6306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37058', 'place_name': 'Dover', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Stewart', 'locality_code': '161', 'latitude': 36.4942, 'longitude': -87.8787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37079', 'place_name': 'Indian Mound', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Stewart', 'locality_code': '161', 'latitude': 36.4946, 'longitude': -87.6804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37617', 'place_name': 'Blountville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5356, 'longitude': -82.3656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37618', 'place_name': 'Bluff City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.4774, 'longitude': -82.2362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37620', 'place_name': 'Bristol', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5686, 'longitude': -82.1819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37621', 'place_name': 'Bristol', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5042, 'longitude': -82.2645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37625', 'place_name': 'Bristol', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5951, 'longitude': -82.1887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37660', 'place_name': 'Kingsport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5484, 'longitude': -82.5618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37662', 'place_name': 'Kingsport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5484, 'longitude': -82.5618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37663', 'place_name': 'Kingsport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.4715, 'longitude': -82.4834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37664', 'place_name': 'Kingsport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5208, 'longitude': -82.5168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37665', 'place_name': 'Kingsport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5799, 'longitude': -82.5733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37669', 'place_name': 'Kingsport', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.5484, 'longitude': -82.5618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37686', 'place_name': 'Piney Flats', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.4461, 'longitude': -82.334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37699', 'place_name': 'Piney Flats', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sullivan', 'locality_code': '163', 'latitude': 36.4195, 'longitude': -82.304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37022', 'place_name': 'Bethpage', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.5186, 'longitude': -86.3146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37031', 'place_name': 'Castalian Springs', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.3806, 'longitude': -86.3107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37048', 'place_name': 'Cottontown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.4912, 'longitude': -86.6033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37066', 'place_name': 'Gallatin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.3834, 'longitude': -86.4512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37075', 'place_name': 'Hendersonville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.3054, 'longitude': -86.6072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37077', 'place_name': 'Hendersonville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.3047, 'longitude': -86.6211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37119', 'place_name': 'Mitchellville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.632, 'longitude': -86.539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37148', 'place_name': 'Portland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.5673, 'longitude': -86.5059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37186', 'place_name': 'Westmoreland', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Sumner', 'locality_code': '165', 'latitude': 36.5756, 'longitude': -86.2353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38004', 'place_name': 'Atoka', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.4412, 'longitude': -89.7781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38011', 'place_name': 'Brighton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.484, 'longitude': -89.7251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38015', 'place_name': 'Burlison', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.5399, 'longitude': -89.8177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38019', 'place_name': 'Covington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.5598, 'longitude': -89.6501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38023', 'place_name': 'Drummonds', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.4452, 'longitude': -89.9236, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38049', 'place_name': 'Mason', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.438, 'longitude': -89.5518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38058', 'place_name': 'Munford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.459, 'longitude': -89.8197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38071', 'place_name': 'Tipton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Tipton', 'locality_code': '167', 'latitude': 35.4143, 'longitude': -89.8188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37074', 'place_name': 'Hartsville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Trousdale', 'locality_code': '169', 'latitude': 36.3947, 'longitude': -86.1704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37650', 'place_name': 'Erwin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Unicoi', 'locality_code': '171', 'latitude': 36.1342, 'longitude': -82.4163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37657', 'place_name': 'Flag Pond', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Unicoi', 'locality_code': '171', 'latitude': 36.0085, 'longitude': -82.5623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37692', 'place_name': 'Unicoi', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Unicoi', 'locality_code': '171', 'latitude': 36.2066, 'longitude': -82.322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37779', 'place_name': 'Luttrell', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Union', 'locality_code': '173', 'latitude': 36.2001, 'longitude': -83.76, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37807', 'place_name': 'Maynardville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Union', 'locality_code': '173', 'latitude': 36.2343, 'longitude': -83.8403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37866', 'place_name': 'Sharps Chapel', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Union', 'locality_code': '173', 'latitude': 36.3685, 'longitude': -83.8127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38585', 'place_name': 'Spencer', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Van Buren', 'locality_code': '175', 'latitude': 35.7279, 'longitude': -85.4287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37110', 'place_name': 'Mcminnville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Warren', 'locality_code': '177', 'latitude': 35.6834, 'longitude': -85.77, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37111', 'place_name': 'Mcminnville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Warren', 'locality_code': '177', 'latitude': 35.6834, 'longitude': -85.77, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37357', 'place_name': 'Morrison', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Warren', 'locality_code': '177', 'latitude': 35.6029, 'longitude': -85.9197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37378', 'place_name': 'Smartt', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Warren', 'locality_code': '177', 'latitude': 35.6403, 'longitude': -85.8366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37394', 'place_name': 'Viola', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Warren', 'locality_code': '177', 'latitude': 35.5384, 'longitude': -85.8591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38550', 'place_name': 'Campaign', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Warren', 'locality_code': '177', 'latitude': 35.7734, 'longitude': -85.6192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38581', 'place_name': 'Rock Island', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Warren', 'locality_code': '177', 'latitude': 35.7668, 'longitude': -85.6788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37601', 'place_name': 'Johnson City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.3339, 'longitude': -82.3408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37602', 'place_name': 'Johnson City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.2717, 'longitude': -82.5012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37604', 'place_name': 'Johnson City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.3107, 'longitude': -82.381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37605', 'place_name': 'Johnson City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.3158, 'longitude': -82.3838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37614', 'place_name': 'Johnson City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.1571, 'longitude': -82.5626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37615', 'place_name': 'Johnson City', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.3996, 'longitude': -82.4523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37656', 'place_name': 'Fall Branch', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.4158, 'longitude': -82.6256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37659', 'place_name': 'Jonesborough', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.2954, 'longitude': -82.4902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37681', 'place_name': 'Limestone', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.254, 'longitude': -82.625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37684', 'place_name': 'Mountain Home', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.3107, 'longitude': -82.3732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37690', 'place_name': 'Telford', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Washington', 'locality_code': '179', 'latitude': 36.2451, 'longitude': -82.5369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38425', 'place_name': 'Clifton', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wayne', 'locality_code': '181', 'latitude': 35.3819, 'longitude': -87.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38450', 'place_name': 'Collinwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wayne', 'locality_code': '181', 'latitude': 35.1635, 'longitude': -87.7185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38452', 'place_name': 'Cypress Inn', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wayne', 'locality_code': '181', 'latitude': 35.0579, 'longitude': -87.7883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38471', 'place_name': 'Lutts', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wayne', 'locality_code': '181', 'latitude': 35.1138, 'longitude': -87.8923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38485', 'place_name': 'Waynesboro', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wayne', 'locality_code': '181', 'latitude': 35.322, 'longitude': -87.7395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38225', 'place_name': 'Dresden', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.295, 'longitude': -88.6963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38226', 'place_name': 'Dukedom', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.4796, 'longitude': -88.6926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38229', 'place_name': 'Gleason', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.2117, 'longitude': -88.6184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38230', 'place_name': 'Greenfield', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.1485, 'longitude': -88.7453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38237', 'place_name': 'Martin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.3425, 'longitude': -88.8554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38238', 'place_name': 'Martin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.3434, 'longitude': -88.8503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38241', 'place_name': 'Palmersville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.3948, 'longitude': -88.6142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38255', 'place_name': 'Sharon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Weakley', 'locality_code': '183', 'latitude': 36.2395, 'longitude': -88.8477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38559', 'place_name': 'Doyle', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'White', 'locality_code': '185', 'latitude': 35.8356, 'longitude': -85.5191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38579', 'place_name': 'Quebeck', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'White', 'locality_code': '185', 'latitude': 35.8303, 'longitude': -85.552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38583', 'place_name': 'Sparta', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'White', 'locality_code': '185', 'latitude': 35.9439, 'longitude': -85.4392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '38587', 'place_name': 'Walling', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'White', 'locality_code': '185', 'latitude': 35.8695, 'longitude': -85.6185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37014', 'place_name': 'Arrington', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.8566, 'longitude': -86.6633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37024', 'place_name': 'Brentwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 36.0331, 'longitude': -86.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37027', 'place_name': 'Brentwood', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 36.0063, 'longitude': -86.7909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37046', 'place_name': 'College Grove', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.7832, 'longitude': -86.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37062', 'place_name': 'Fairview', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.9755, 'longitude': -87.1321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37064', 'place_name': 'Franklin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.9328, 'longitude': -86.8788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37065', 'place_name': 'Franklin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.9251, 'longitude': -86.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37067', 'place_name': 'Franklin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.9121, 'longitude': -86.7655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37068', 'place_name': 'Franklin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.8746, 'longitude': -86.9076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37069', 'place_name': 'Franklin', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.9796, 'longitude': -86.9106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37135', 'place_name': 'Nolensville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.9307, 'longitude': -86.6829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37179', 'place_name': 'Thompsons Station', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Williamson', 'locality_code': '187', 'latitude': 35.809, 'longitude': -86.8913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37071', 'place_name': 'Gladeville', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.1562, 'longitude': -86.3049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37087', 'place_name': 'Lebanon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.2098, 'longitude': -86.3024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37088', 'place_name': 'Lebanon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.2081, 'longitude': -86.2911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37090', 'place_name': 'Lebanon', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.1185, 'longitude': -86.263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37121', 'place_name': 'Mount Juliet', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.2001, 'longitude': -86.5186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37122', 'place_name': 'Mount Juliet', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.1897, 'longitude': -86.5023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37136', 'place_name': 'Norene', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.1562, 'longitude': -86.3049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '37184', 'place_name': 'Watertown', 'state': 'Tennessee', 'state_ab': 'TN', 'county': 'Wilson', 'locality_code': '189', 'latitude': 36.0953, 'longitude': -86.1434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75763', 'place_name': 'Frankston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 32.0535, 'longitude': -95.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75779', 'place_name': 'Neches', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.8668, 'longitude': -95.4958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75801', 'place_name': 'Palestine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.7588, 'longitude': -95.6342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75802', 'place_name': 'Palestine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.7621, 'longitude': -95.6308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75803', 'place_name': 'Palestine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.7571, 'longitude': -95.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75832', 'place_name': 'Cayuga', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.9571, 'longitude': -95.9747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75839', 'place_name': 'Elkhart', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.648, 'longitude': -95.5551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75853', 'place_name': 'Montalba', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.8766, 'longitude': -95.7327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75861', 'place_name': 'Tennessee Colony', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.7929, 'longitude': -95.8998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75880', 'place_name': 'Tennessee Colony', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.8354, 'longitude': -95.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75882', 'place_name': 'Palestine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.7942, 'longitude': -95.662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75884', 'place_name': 'Tennessee Colony', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.8354, 'longitude': -95.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75886', 'place_name': 'Tennessee Colony', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Anderson', 'locality_code': '1', 'latitude': 31.8354, 'longitude': -95.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79714', 'place_name': 'Andrews', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Andrews', 'locality_code': '3', 'latitude': 32.3201, 'longitude': -102.5409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75901', 'place_name': 'Lufkin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.27, 'longitude': -94.6469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75902', 'place_name': 'Lufkin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.3623, 'longitude': -94.7611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75903', 'place_name': 'Lufkin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.2766, 'longitude': -94.5676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75904', 'place_name': 'Lufkin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.3489, 'longitude': -94.8327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75915', 'place_name': 'Lufkin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.3382, 'longitude': -94.7291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75941', 'place_name': 'Diboll', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.195, 'longitude': -94.7729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75949', 'place_name': 'Huntington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.2837, 'longitude': -94.5662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75969', 'place_name': 'Pollok', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.4291, 'longitude': -94.8254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75980', 'place_name': 'Zavalla', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Angelina', 'locality_code': '5', 'latitude': 31.1569, 'longitude': -94.3871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78358', 'place_name': 'Fulton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Aransas', 'locality_code': '7', 'latitude': 28.0614, 'longitude': -97.0411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78381', 'place_name': 'Rockport', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Aransas', 'locality_code': '7', 'latitude': 28.0131, 'longitude': -97.0936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78382', 'place_name': 'Rockport', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Aransas', 'locality_code': '7', 'latitude': 28.0308, 'longitude': -97.0688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76351', 'place_name': 'Archer City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Archer', 'locality_code': '9', 'latitude': 33.5562, 'longitude': -98.6249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76366', 'place_name': 'Holliday', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Archer', 'locality_code': '9', 'latitude': 33.8162, 'longitude': -98.6951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76370', 'place_name': 'Megargel', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Archer', 'locality_code': '9', 'latitude': 33.4533, 'longitude': -98.9297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76379', 'place_name': 'Scotland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Archer', 'locality_code': '9', 'latitude': 33.6535, 'longitude': -98.465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76389', 'place_name': 'Windthorst', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Archer', 'locality_code': '9', 'latitude': 33.5796, 'longitude': -98.4376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79019', 'place_name': 'Claude', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Armstrong', 'locality_code': '11', 'latitude': 35.0967, 'longitude': -101.3813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79094', 'place_name': 'Wayside', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Armstrong', 'locality_code': '11', 'latitude': 34.7928, 'longitude': -101.5471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78008', 'place_name': 'Campbellton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 28.767, 'longitude': -98.2566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78011', 'place_name': 'Charlotte', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 28.8649, 'longitude': -98.707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78012', 'place_name': 'Christine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 28.7858, 'longitude': -98.4886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78026', 'place_name': 'Jourdanton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 28.903, 'longitude': -98.544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78050', 'place_name': 'Leming', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 29.073, 'longitude': -98.4842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78052', 'place_name': 'Lytle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 29.2366, 'longitude': -98.7945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78062', 'place_name': 'Peggy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 28.7397, 'longitude': -98.1786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78064', 'place_name': 'Pleasanton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 28.9924, 'longitude': -98.4831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78065', 'place_name': 'Poteet', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Atascosa', 'locality_code': '13', 'latitude': 29.0994, 'longitude': -98.6241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77418', 'place_name': 'Bellville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 29.9658, 'longitude': -96.2531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77452', 'place_name': 'Kenney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 30.0477, 'longitude': -96.3269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77473', 'place_name': 'San Felipe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 29.8019, 'longitude': -96.1014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77474', 'place_name': 'Sealy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 29.7826, 'longitude': -96.1592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77485', 'place_name': 'Wallis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 29.6397, 'longitude': -96.0456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78931', 'place_name': 'Bleiblerville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 30.0292, 'longitude': -96.4448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78933', 'place_name': 'Cat Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 29.7512, 'longitude': -96.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78944', 'place_name': 'Industry', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 29.9904, 'longitude': -96.4843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78950', 'place_name': 'New Ulm', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Austin', 'locality_code': '15', 'latitude': 29.9134, 'longitude': -96.4961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79324', 'place_name': 'Enochs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bailey', 'locality_code': '17', 'latitude': 33.8731, 'longitude': -102.7599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79344', 'place_name': 'Maple', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bailey', 'locality_code': '17', 'latitude': 33.8487, 'longitude': -102.8985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79347', 'place_name': 'Muleshoe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bailey', 'locality_code': '17', 'latitude': 34.2193, 'longitude': -102.7496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78003', 'place_name': 'Bandera', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bandera', 'locality_code': '19', 'latitude': 29.7276, 'longitude': -99.0453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78055', 'place_name': 'Medina', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bandera', 'locality_code': '19', 'latitude': 29.8475, 'longitude': -99.3215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78063', 'place_name': 'Pipe Creek', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bandera', 'locality_code': '19', 'latitude': 29.6796, 'longitude': -98.9484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78883', 'place_name': 'Tarpley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bandera', 'locality_code': '19', 'latitude': 29.6455, 'longitude': -99.2469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78885', 'place_name': 'Vanderpool', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bandera', 'locality_code': '19', 'latitude': 29.7452, 'longitude': -99.5551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78602', 'place_name': 'Bastrop', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 30.1388, 'longitude': -97.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78612', 'place_name': 'Cedar Creek', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 30.0966, 'longitude': -97.4976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78621', 'place_name': 'Elgin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 30.3231, 'longitude': -97.3737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78650', 'place_name': 'Mc Dade', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 30.2968, 'longitude': -97.2386, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78659', 'place_name': 'Paige', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 30.1858, 'longitude': -97.1198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78662', 'place_name': 'Red Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 29.9906, 'longitude': -97.4081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78953', 'place_name': 'Rosanky', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 29.9241, 'longitude': -97.3119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78957', 'place_name': 'Smithville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bastrop', 'locality_code': '21', 'latitude': 30.0178, 'longitude': -97.1494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76380', 'place_name': 'Seymour', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Baylor', 'locality_code': '23', 'latitude': 33.5914, 'longitude': -99.2587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78102', 'place_name': 'Beeville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.4222, 'longitude': -97.7616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78104', 'place_name': 'Beeville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.3931, 'longitude': -97.776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78125', 'place_name': 'Mineral', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.5552, 'longitude': -97.9407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78142', 'place_name': 'Normanna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.5278, 'longitude': -97.7831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78145', 'place_name': 'Pawnee', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.6526, 'longitude': -97.9921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78146', 'place_name': 'Pettus', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.6164, 'longitude': -97.8082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78162', 'place_name': 'Tuleta', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.5708, 'longitude': -97.7972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78389', 'place_name': 'Skidmore', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.2121, 'longitude': -97.7127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78391', 'place_name': 'Tynan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bee', 'locality_code': '25', 'latitude': 28.1693, 'longitude': -97.7549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76501', 'place_name': 'Temple', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0895, 'longitude': -97.3343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76502', 'place_name': 'Temple', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.071, 'longitude': -97.3898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76503', 'place_name': 'Temple', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.054, 'longitude': -97.3203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76504', 'place_name': 'Temple', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0917, 'longitude': -97.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76508', 'place_name': 'Temple', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0363, 'longitude': -97.492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76511', 'place_name': 'Bartlett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 30.7991, 'longitude': -97.4263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76513', 'place_name': 'Belton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0723, 'longitude': -97.472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76533', 'place_name': 'Heidenheimer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0496, 'longitude': -97.4936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76534', 'place_name': 'Holland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 30.88, 'longitude': -97.3857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76540', 'place_name': 'Killeen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.1171, 'longitude': -97.7278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76541', 'place_name': 'Killeen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.1164, 'longitude': -97.7278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76542', 'place_name': 'Killeen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0376, 'longitude': -97.6809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76543', 'place_name': 'Killeen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.1172, 'longitude': -97.6651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76544', 'place_name': 'Fort Hood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.1349, 'longitude': -97.7756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76547', 'place_name': 'Killeen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.1171, 'longitude': -97.7278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76548', 'place_name': 'Harker Heights', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0286, 'longitude': -97.6115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76549', 'place_name': 'Killeen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0065, 'longitude': -97.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76554', 'place_name': 'Little River Academy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 30.9863, 'longitude': -97.3586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76559', 'place_name': 'Nolanville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.0833, 'longitude': -97.5941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76564', 'place_name': 'Pendleton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.1952, 'longitude': -97.3486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76569', 'place_name': 'Rogers', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 30.955, 'longitude': -97.2228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76571', 'place_name': 'Salado', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 30.9494, 'longitude': -97.533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76579', 'place_name': 'Troy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bell', 'locality_code': '27', 'latitude': 31.1759, 'longitude': -97.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78002', 'place_name': 'Atascosa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.2705, 'longitude': -98.7421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78015', 'place_name': 'Boerne', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.7327, 'longitude': -98.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78023', 'place_name': 'Helotes', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.6321, 'longitude': -98.7542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78054', 'place_name': 'Macdona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3258, 'longitude': -98.6911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78069', 'place_name': 'Somerset', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.2205, 'longitude': -98.6678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78073', 'place_name': 'Von Ormy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.275, 'longitude': -98.6677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78101', 'place_name': 'Adkins', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3805, 'longitude': -98.265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78109', 'place_name': 'Converse', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5173, 'longitude': -98.3217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78112', 'place_name': 'Elmendorf', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.2308, 'longitude': -98.372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78148', 'place_name': 'Universal City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5465, 'longitude': -98.2954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78150', 'place_name': 'Jbsa Randolph', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3759, 'longitude': -97.958, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78152', 'place_name': 'Saint Hedwig', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4353, 'longitude': -98.1952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78201', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4711, 'longitude': -98.5356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78202', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4275, 'longitude': -98.4601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78203', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4148, 'longitude': -98.4601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78204', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4059, 'longitude': -98.5078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78205', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4237, 'longitude': -98.4925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78206', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78207', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4229, 'longitude': -98.526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78208', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.44, 'longitude': -98.459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78209', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4821, 'longitude': -98.4554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78210', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3977, 'longitude': -98.4658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78211', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3499, 'longitude': -98.5638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78212', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4388, 'longitude': -98.4935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78213', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5234, 'longitude': -98.5273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78214', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3641, 'longitude': -98.4924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78215', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4413, 'longitude': -98.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78216', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5334, 'longitude': -98.4975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78217', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5395, 'longitude': -98.4194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78218', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4969, 'longitude': -98.4032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78219', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4492, 'longitude': -98.3446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78220', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4106, 'longitude': -98.4128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78221', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3309, 'longitude': -98.5054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78222', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3831, 'longitude': -98.396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78223', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3579, 'longitude': -98.4356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78224', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3374, 'longitude': -98.5393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78225', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3875, 'longitude': -98.5245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78226', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.393, 'longitude': -98.5511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78227', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4027, 'longitude': -98.6433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78228', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4589, 'longitude': -98.5699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78229', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5042, 'longitude': -98.5697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78230', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5407, 'longitude': -98.5521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78231', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5714, 'longitude': -98.5414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78232', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5863, 'longitude': -98.4769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78233', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5563, 'longitude': -98.3643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78234', 'place_name': 'Jbsa Ft Sam Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4241, 'longitude': -98.4936, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78235', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3494, 'longitude': -98.4422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78236', 'place_name': 'Jbsa Lackland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4241, 'longitude': -98.4936, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78237', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4208, 'longitude': -98.5645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78238', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.451, 'longitude': -98.6169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78239', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5182, 'longitude': -98.3627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78240', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5189, 'longitude': -98.6006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78241', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78242', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3509, 'longitude': -98.6109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78243', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78244', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4793, 'longitude': -98.3476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78245', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4189, 'longitude': -98.6895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78246', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78247', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5855, 'longitude': -98.4071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78248', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5894, 'longitude': -98.5201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78249', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5612, 'longitude': -98.6117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78250', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5054, 'longitude': -98.6688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78251', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4597, 'longitude': -98.6555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78252', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.346, 'longitude': -98.6464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78253', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4599, 'longitude': -98.7479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78254', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.5551, 'longitude': -98.7442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78255', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.6701, 'longitude': -98.6873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78256', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.6169, 'longitude': -98.6252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78257', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.6495, 'longitude': -98.6137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78258', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.6562, 'longitude': -98.4967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78259', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.6283, 'longitude': -98.4445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78260', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.7026, 'longitude': -98.4759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78261', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.7055, 'longitude': -98.4191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78263', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.3614, 'longitude': -98.3174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78264', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.1733, 'longitude': -98.4723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78265', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78268', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78269', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78270', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78278', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78279', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78280', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78283', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78284', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4426, 'longitude': -98.4913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78285', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78288', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4241, 'longitude': -98.4936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78289', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78291', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78292', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78293', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78294', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78295', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78296', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78297', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78298', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78299', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bexar', 'locality_code': '29', 'latitude': 29.4375, 'longitude': -98.4616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78606', 'place_name': 'Blanco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Blanco', 'locality_code': '31', 'latitude': 30.0874, 'longitude': -98.4107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78635', 'place_name': 'Hye', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Blanco', 'locality_code': '31', 'latitude': 30.2269, 'longitude': -98.5396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78636', 'place_name': 'Johnson City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Blanco', 'locality_code': '31', 'latitude': 30.2948, 'longitude': -98.3691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78663', 'place_name': 'Round Mountain', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Blanco', 'locality_code': '31', 'latitude': 30.4429, 'longitude': -98.4365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79738', 'place_name': 'Gail', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Borden', 'locality_code': '33', 'latitude': 32.7523, 'longitude': -101.45, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76634', 'place_name': 'Clifton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 31.7918, 'longitude': -97.5203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76637', 'place_name': 'Cranfills Gap', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 31.7486, 'longitude': -97.8113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76644', 'place_name': 'Laguna Park', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 31.8593, 'longitude': -97.3797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76649', 'place_name': 'Iredell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 31.9722, 'longitude': -97.8793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76652', 'place_name': 'Kopperl', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 32.1035, 'longitude': -97.5421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76665', 'place_name': 'Meridian', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 31.929, 'longitude': -97.6443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76671', 'place_name': 'Morgan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 32.0195, 'longitude': -97.5608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76689', 'place_name': 'Valley Mills', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 31.6599, 'longitude': -97.4935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76690', 'place_name': 'Walnut Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bosque', 'locality_code': '35', 'latitude': 32.0593, 'longitude': -97.7514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75501', 'place_name': 'Texarkana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4113, 'longitude': -94.1774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75503', 'place_name': 'Texarkana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4669, 'longitude': -94.0774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75504', 'place_name': 'Texarkana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4251, 'longitude': -94.0477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75505', 'place_name': 'Texarkana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4624, 'longitude': -94.0715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75507', 'place_name': 'Texarkana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4251, 'longitude': -94.0477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75559', 'place_name': 'De Kalb', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.5087, 'longitude': -94.6163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75561', 'place_name': 'Hooks', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.5253, 'longitude': -94.2657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75567', 'place_name': 'Maud', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.3409, 'longitude': -94.3175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75569', 'place_name': 'Nash', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4344, 'longitude': -94.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75570', 'place_name': 'New Boston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4619, 'longitude': -94.4375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75573', 'place_name': 'Redwater', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.358, 'longitude': -94.2571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75574', 'place_name': 'Simms', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.3359, 'longitude': -94.552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75599', 'place_name': 'Texarkana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Bowie', 'locality_code': '37', 'latitude': 33.4251, 'longitude': -94.0477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77422', 'place_name': 'Brazoria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.0236, 'longitude': -95.5867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77430', 'place_name': 'Damon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.3014, 'longitude': -95.7036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77431', 'place_name': 'Danciger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.1737, 'longitude': -95.8207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77463', 'place_name': 'Old Ocean', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.08, 'longitude': -95.7497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77480', 'place_name': 'Sweeny', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.0415, 'longitude': -95.7004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77486', 'place_name': 'West Columbia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.1408, 'longitude': -95.6694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77511', 'place_name': 'Alvin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.412, 'longitude': -95.2515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77512', 'place_name': 'Alvin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.4238, 'longitude': -95.2441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77515', 'place_name': 'Angleton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.181, 'longitude': -95.4467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77516', 'place_name': 'Angleton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.1694, 'longitude': -95.4319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77531', 'place_name': 'Clute', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.0325, 'longitude': -95.4026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77534', 'place_name': 'Danbury', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.2291, 'longitude': -95.3435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77541', 'place_name': 'Freeport', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.0357, 'longitude': -95.3379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77542', 'place_name': 'Freeport', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 28.9541, 'longitude': -95.3597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77566', 'place_name': 'Lake Jackson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.0393, 'longitude': -95.4401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77577', 'place_name': 'Liverpool', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.2667, 'longitude': -95.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77578', 'place_name': 'Manvel', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.4694, 'longitude': -95.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77581', 'place_name': 'Pearland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.5617, 'longitude': -95.2721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77583', 'place_name': 'Rosharon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.4203, 'longitude': -95.4537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77584', 'place_name': 'Pearland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.5405, 'longitude': -95.3208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77588', 'place_name': 'Pearland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazoria', 'locality_code': '39', 'latitude': 29.5127, 'longitude': -95.2542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77801', 'place_name': 'Bryan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6327, 'longitude': -96.3662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77802', 'place_name': 'Bryan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6582, 'longitude': -96.3351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77803', 'place_name': 'Bryan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6913, 'longitude': -96.3714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77805', 'place_name': 'Bryan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6521, 'longitude': -96.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77806', 'place_name': 'Bryan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6744, 'longitude': -96.37, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77807', 'place_name': 'Bryan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6711, 'longitude': -96.4799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77808', 'place_name': 'Bryan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.8202, 'longitude': -96.3059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77840', 'place_name': 'College Station', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6045, 'longitude': -96.3123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77841', 'place_name': 'College Station', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.5726, 'longitude': -96.327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77842', 'place_name': 'College Station', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6521, 'longitude': -96.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77843', 'place_name': 'College Station', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6521, 'longitude': -96.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77844', 'place_name': 'College Station', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.6521, 'longitude': -96.341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77845', 'place_name': 'College Station', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.5118, 'longitude': -96.3171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77862', 'place_name': 'Kurten', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.7871, 'longitude': -96.2641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77866', 'place_name': 'Millican', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.4491, 'longitude': -96.217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77881', 'place_name': 'Wellborn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brazos', 'locality_code': '41', 'latitude': 30.5334, 'longitude': -96.3032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79830', 'place_name': 'Alpine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brewster', 'locality_code': '43', 'latitude': 30.2631, 'longitude': -103.6541, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79831', 'place_name': 'Alpine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brewster', 'locality_code': '43', 'latitude': 30.3068, 'longitude': -103.6704, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79832', 'place_name': 'Alpine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brewster', 'locality_code': '43', 'latitude': 30.3631, 'longitude': -103.6539, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79834', 'place_name': 'Big Bend National Park', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brewster', 'locality_code': '43', 'latitude': 29.2924, 'longitude': -103.2963, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79842', 'place_name': 'Marathon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brewster', 'locality_code': '43', 'latitude': 30.1886, 'longitude': -103.2214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79852', 'place_name': 'Terlingua', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brewster', 'locality_code': '43', 'latitude': 29.3165, 'longitude': -103.5597, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79255', 'place_name': 'Quitaque', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Briscoe', 'locality_code': '45', 'latitude': 34.3796, 'longitude': -101.0465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79257', 'place_name': 'Silverton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Briscoe', 'locality_code': '45', 'latitude': 34.4641, 'longitude': -101.3169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78353', 'place_name': 'Encino', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brooks', 'locality_code': '47', 'latitude': 26.9249, 'longitude': -98.1922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78355', 'place_name': 'Falfurrias', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brooks', 'locality_code': '47', 'latitude': 27.2242, 'longitude': -98.1408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76432', 'place_name': 'Blanket', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.7882, 'longitude': -98.8311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76801', 'place_name': 'Brownwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.7754, 'longitude': -98.9915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76802', 'place_name': 'Early', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.7874, 'longitude': -98.9229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76803', 'place_name': 'Early', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.7421, 'longitude': -98.9456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76804', 'place_name': 'Brownwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.7742, 'longitude': -99.0921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76823', 'place_name': 'Bangs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.7503, 'longitude': -99.1568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76827', 'place_name': 'Brookesmith', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.5176, 'longitude': -99.1277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76857', 'place_name': 'May', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.9571, 'longitude': -98.9656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76890', 'place_name': 'Zephyr', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Brown', 'locality_code': '49', 'latitude': 31.6694, 'longitude': -98.8182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77836', 'place_name': 'Caldwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burleson', 'locality_code': '51', 'latitude': 30.5298, 'longitude': -96.7143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77838', 'place_name': 'Chriesman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burleson', 'locality_code': '51', 'latitude': 30.5994, 'longitude': -96.7708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77852', 'place_name': 'Deanville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burleson', 'locality_code': '51', 'latitude': 30.4322, 'longitude': -96.7561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77863', 'place_name': 'Lyons', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burleson', 'locality_code': '51', 'latitude': 30.3863, 'longitude': -96.5633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77878', 'place_name': 'Snook', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burleson', 'locality_code': '51', 'latitude': 30.4702, 'longitude': -96.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77879', 'place_name': 'Somerville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burleson', 'locality_code': '51', 'latitude': 30.4076, 'longitude': -96.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78605', 'place_name': 'Bertram', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burnet', 'locality_code': '53', 'latitude': 30.7411, 'longitude': -98.0529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78608', 'place_name': 'Briggs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burnet', 'locality_code': '53', 'latitude': 30.9325, 'longitude': -97.9702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78611', 'place_name': 'Burnet', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burnet', 'locality_code': '53', 'latitude': 30.7766, 'longitude': -98.2642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78654', 'place_name': 'Marble Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Burnet', 'locality_code': '53', 'latitude': 30.5784, 'longitude': -98.2751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78616', 'place_name': 'Dale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Caldwell', 'locality_code': '55', 'latitude': 29.9528, 'longitude': -97.581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78622', 'place_name': 'Fentress', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Caldwell', 'locality_code': '55', 'latitude': 29.7561, 'longitude': -97.7764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78644', 'place_name': 'Lockhart', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Caldwell', 'locality_code': '55', 'latitude': 29.8868, 'longitude': -97.6769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78648', 'place_name': 'Luling', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Caldwell', 'locality_code': '55', 'latitude': 29.6826, 'longitude': -97.6499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78655', 'place_name': 'Martindale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Caldwell', 'locality_code': '55', 'latitude': 29.8394, 'longitude': -97.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78656', 'place_name': 'Maxwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Caldwell', 'locality_code': '55', 'latitude': 29.8953, 'longitude': -97.8144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78661', 'place_name': 'Prairie Lea', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Caldwell', 'locality_code': '55', 'latitude': 29.7239, 'longitude': -97.7449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77978', 'place_name': 'Point Comfort', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Calhoun', 'locality_code': '57', 'latitude': 28.6651, 'longitude': -96.5506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77979', 'place_name': 'Port Lavaca', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Calhoun', 'locality_code': '57', 'latitude': 28.6011, 'longitude': -96.6259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77982', 'place_name': 'Port O Connor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Calhoun', 'locality_code': '57', 'latitude': 28.4483, 'longitude': -96.4058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77983', 'place_name': 'Seadrift', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Calhoun', 'locality_code': '57', 'latitude': 28.4101, 'longitude': -96.7023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76443', 'place_name': 'Cross Plains', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Callahan', 'locality_code': '59', 'latitude': 32.1482, 'longitude': -99.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76469', 'place_name': 'Putnam', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Callahan', 'locality_code': '59', 'latitude': 32.374, 'longitude': -99.1957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79504', 'place_name': 'Baird', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Callahan', 'locality_code': '59', 'latitude': 32.3916, 'longitude': -99.3777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79510', 'place_name': 'Clyde', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Callahan', 'locality_code': '59', 'latitude': 32.3803, 'longitude': -99.5184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78520', 'place_name': 'Brownsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 25.9337, 'longitude': -97.5174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78521', 'place_name': 'Brownsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 25.9221, 'longitude': -97.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78522', 'place_name': 'Brownsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 25.9017, 'longitude': -97.4975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78523', 'place_name': 'Brownsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 25.981, 'longitude': -97.5209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78526', 'place_name': 'Brownsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 25.9717, 'longitude': -97.4699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78535', 'place_name': 'Combes', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.2451, 'longitude': -97.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78550', 'place_name': 'Harlingen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.1951, 'longitude': -97.689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78551', 'place_name': 'Harlingen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.2447, 'longitude': -97.7206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78552', 'place_name': 'Harlingen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.1831, 'longitude': -97.7468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78553', 'place_name': 'Harlingen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.1906, 'longitude': -97.6961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78559', 'place_name': 'La Feria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.1666, 'longitude': -97.8261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78566', 'place_name': 'Los Fresnos', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.1158, 'longitude': -97.4107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78567', 'place_name': 'Los Indios', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.0492, 'longitude': -97.745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78568', 'place_name': 'Lozano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.1904, 'longitude': -97.5423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78575', 'place_name': 'Olmito', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.0353, 'longitude': -97.5496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78578', 'place_name': 'Port Isabel', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.0539, 'longitude': -97.3125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78583', 'place_name': 'Rio Hondo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.2339, 'longitude': -97.5513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78586', 'place_name': 'San Benito', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.1337, 'longitude': -97.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78592', 'place_name': 'Santa Maria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.0787, 'longitude': -97.8494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78593', 'place_name': 'Santa Rosa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.2555, 'longitude': -97.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78597', 'place_name': 'South Padre Island', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cameron', 'locality_code': '61', 'latitude': 26.2393, 'longitude': -97.1936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75451', 'place_name': 'Leesburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Camp', 'locality_code': '63', 'latitude': 32.9763, 'longitude': -95.1079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75686', 'place_name': 'Pittsburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Camp', 'locality_code': '63', 'latitude': 32.9623, 'longitude': -94.9603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79039', 'place_name': 'Groom', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Carson', 'locality_code': '65', 'latitude': 35.2168, 'longitude': -101.1285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79068', 'place_name': 'Panhandle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Carson', 'locality_code': '65', 'latitude': 35.3808, 'longitude': -101.4304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79080', 'place_name': 'Skellytown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Carson', 'locality_code': '65', 'latitude': 35.5685, 'longitude': -101.1721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79097', 'place_name': 'White Deer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Carson', 'locality_code': '65', 'latitude': 35.4278, 'longitude': -101.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75551', 'place_name': 'Atlanta', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 33.109, 'longitude': -94.1646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75555', 'place_name': 'Bivins', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 32.966, 'longitude': -94.1404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75556', 'place_name': 'Bloomburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 33.1339, 'longitude': -94.0647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75560', 'place_name': 'Douglassville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 33.1758, 'longitude': -94.3467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75562', 'place_name': 'Kildare', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 32.9468, 'longitude': -94.2539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75563', 'place_name': 'Linden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 33.0048, 'longitude': -94.3605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75565', 'place_name': 'Mc Leod', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 32.9511, 'longitude': -94.0808, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '75566', 'place_name': 'Marietta', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 33.1735, 'longitude': -94.5424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75572', 'place_name': 'Queen City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 33.1557, 'longitude': -94.1537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75630', 'place_name': 'Avinger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 32.8485, 'longitude': -94.5795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75656', 'place_name': 'Hughes Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cass', 'locality_code': '67', 'latitude': 33.0168, 'longitude': -94.6228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79027', 'place_name': 'Dimmitt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Castro', 'locality_code': '69', 'latitude': 34.5341, 'longitude': -102.3046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79043', 'place_name': 'Hart', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Castro', 'locality_code': '69', 'latitude': 34.3878, 'longitude': -102.1155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79063', 'place_name': 'Nazareth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Castro', 'locality_code': '69', 'latitude': 34.5444, 'longitude': -102.1069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79085', 'place_name': 'Summerfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Castro', 'locality_code': '69', 'latitude': 34.7437, 'longitude': -102.5064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77514', 'place_name': 'Anahuac', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Chambers', 'locality_code': '71', 'latitude': 29.662, 'longitude': -94.593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77523', 'place_name': 'Baytown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Chambers', 'locality_code': '71', 'latitude': 29.77, 'longitude': -94.8608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77560', 'place_name': 'Hankamer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Chambers', 'locality_code': '71', 'latitude': 29.8752, 'longitude': -94.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77580', 'place_name': 'Mont Belvieu', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Chambers', 'locality_code': '71', 'latitude': 29.8477, 'longitude': -94.8908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77597', 'place_name': 'Wallisville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Chambers', 'locality_code': '71', 'latitude': 29.8591, 'longitude': -94.6759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77661', 'place_name': 'Stowell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Chambers', 'locality_code': '71', 'latitude': 29.7809, 'longitude': -94.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77665', 'place_name': 'Winnie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Chambers', 'locality_code': '71', 'latitude': 29.8157, 'longitude': -94.3395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75759', 'place_name': 'Cuney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 32.0415, 'longitude': -95.42, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75764', 'place_name': 'Gallatin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.891, 'longitude': -95.1455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75766', 'place_name': 'Jacksonville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.9618, 'longitude': -95.2703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75772', 'place_name': 'Maydelle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.8008, 'longitude': -95.3001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75780', 'place_name': 'New Summerfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.9807, 'longitude': -95.0938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75784', 'place_name': 'Reklaw', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.8859, 'longitude': -95.0118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75785', 'place_name': 'Rusk', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.8136, 'longitude': -95.0965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75925', 'place_name': 'Alto', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.6103, 'longitude': -95.0762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75976', 'place_name': 'Wells', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cherokee', 'locality_code': '73', 'latitude': 31.4885, 'longitude': -94.9399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79201', 'place_name': 'Childress', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Childress', 'locality_code': '75', 'latitude': 34.4104, 'longitude': -100.2364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79259', 'place_name': 'Tell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Childress', 'locality_code': '75', 'latitude': 34.3759, 'longitude': -100.3948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76228', 'place_name': 'Bellevue', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Clay', 'locality_code': '77', 'latitude': 33.5879, 'longitude': -98.1574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76352', 'place_name': 'Bluegrove', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Clay', 'locality_code': '77', 'latitude': 33.674, 'longitude': -98.23, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76357', 'place_name': 'Byers', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Clay', 'locality_code': '77', 'latitude': 34.0728, 'longitude': -98.1839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76365', 'place_name': 'Henrietta', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Clay', 'locality_code': '77', 'latitude': 33.8196, 'longitude': -98.26, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76377', 'place_name': 'Petrolia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Clay', 'locality_code': '77', 'latitude': 34.0132, 'longitude': -98.2323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79314', 'place_name': 'Bledsoe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cochran', 'locality_code': '79', 'latitude': 33.5997, 'longitude': -103.0168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79346', 'place_name': 'Morton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cochran', 'locality_code': '79', 'latitude': 33.7251, 'longitude': -102.7594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79379', 'place_name': 'Whiteface', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cochran', 'locality_code': '79', 'latitude': 33.5988, 'longitude': -102.6199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76933', 'place_name': 'Bronte', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coke', 'locality_code': '81', 'latitude': 31.8789, 'longitude': -100.2988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76945', 'place_name': 'Robert Lee', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coke', 'locality_code': '81', 'latitude': 31.8951, 'longitude': -100.5104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76949', 'place_name': 'Silver', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coke', 'locality_code': '81', 'latitude': 32.0484, 'longitude': -100.6922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76953', 'place_name': 'Tennyson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coke', 'locality_code': '81', 'latitude': 31.7397, 'longitude': -100.2884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76828', 'place_name': 'Burkett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.9986, 'longitude': -99.2553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76834', 'place_name': 'Coleman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.8287, 'longitude': -99.427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76845', 'place_name': 'Gouldbusk', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.5549, 'longitude': -99.4767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76873', 'place_name': 'Rockwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.5037, 'longitude': -99.3746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76878', 'place_name': 'Santa Anna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.7215, 'longitude': -99.3212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76882', 'place_name': 'Talpa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.8034, 'longitude': -99.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76884', 'place_name': 'Valera', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.7529, 'longitude': -99.5473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76888', 'place_name': 'Voss', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.5892, 'longitude': -99.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79519', 'place_name': 'Goldsboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 32.0482, 'longitude': -99.6775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79538', 'place_name': 'Novice', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coleman', 'locality_code': '83', 'latitude': 31.9781, 'longitude': -99.6809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75002', 'place_name': 'Allen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0934, 'longitude': -96.6454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75009', 'place_name': 'Celina', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.3103, 'longitude': -96.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75013', 'place_name': 'Allen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1186, 'longitude': -96.6773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75023', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.055, 'longitude': -96.7365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75024', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0752, 'longitude': -96.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75025', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0784, 'longitude': -96.7291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75026', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0198, 'longitude': -96.6989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75033', 'place_name': 'Frisco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.2559, 'longitude': -96.8853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75034', 'place_name': 'Frisco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1499, 'longitude': -96.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75035', 'place_name': 'Frisco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1377, 'longitude': -96.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75036', 'place_name': 'Frisco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1499, 'longitude': -96.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75069', 'place_name': 'Mckinney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1976, 'longitude': -96.6153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75070', 'place_name': 'Mckinney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1976, 'longitude': -96.6153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75071', 'place_name': 'Mckinney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1976, 'longitude': -96.6153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75072', 'place_name': 'Mckinney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1976, 'longitude': -96.6153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75074', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0277, 'longitude': -96.6777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75075', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.025, 'longitude': -96.7397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75078', 'place_name': 'Prosper', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.2362, 'longitude': -96.7954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75086', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0198, 'longitude': -96.6989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75093', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0299, 'longitude': -96.7889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75094', 'place_name': 'Plano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0148, 'longitude': -96.6189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75097', 'place_name': 'Weston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.3512, 'longitude': -96.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75121', 'place_name': 'Copeville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0875, 'longitude': -96.4186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75164', 'place_name': 'Josephine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0612, 'longitude': -96.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75166', 'place_name': 'Lavon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0139, 'longitude': -96.4377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75173', 'place_name': 'Nevada', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.0593, 'longitude': -96.3877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75407', 'place_name': 'Princeton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1555, 'longitude': -96.4981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75409', 'place_name': 'Anna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.3445, 'longitude': -96.5639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75424', 'place_name': 'Blue Ridge', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.3061, 'longitude': -96.3901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75442', 'place_name': 'Farmersville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.1659, 'longitude': -96.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75454', 'place_name': 'Melissa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.2841, 'longitude': -96.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75485', 'place_name': 'Westminster', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collin', 'locality_code': '85', 'latitude': 33.3627, 'longitude': -96.4635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79077', 'place_name': 'Samnorwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collingsworth', 'locality_code': '87', 'latitude': 35.0523, 'longitude': -100.2807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79095', 'place_name': 'Wellington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collingsworth', 'locality_code': '87', 'latitude': 34.8717, 'longitude': -100.2207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79230', 'place_name': 'Dodson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collingsworth', 'locality_code': '87', 'latitude': 34.7644, 'longitude': -100.0286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79251', 'place_name': 'Quail', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Collingsworth', 'locality_code': '87', 'latitude': 34.918, 'longitude': -100.4252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77412', 'place_name': 'Altair', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.5714, 'longitude': -96.4541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77434', 'place_name': 'Eagle Lake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.5842, 'longitude': -96.3354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77442', 'place_name': 'Garwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.476, 'longitude': -96.4919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77460', 'place_name': 'Nada', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.405, 'longitude': -96.3864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77470', 'place_name': 'Rock Island', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.5311, 'longitude': -96.5752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77475', 'place_name': 'Sheridan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.4936, 'longitude': -96.6711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78934', 'place_name': 'Columbus', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.7032, 'longitude': -96.5527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78935', 'place_name': 'Alleyton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.7092, 'longitude': -96.4865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78943', 'place_name': 'Glidden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.6994, 'longitude': -96.5942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78951', 'place_name': 'Oakland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.6016, 'longitude': -96.83, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78962', 'place_name': 'Weimar', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Colorado', 'locality_code': '89', 'latitude': 29.6787, 'longitude': -96.755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78070', 'place_name': 'Spring Branch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.9238, 'longitude': -98.3788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78130', 'place_name': 'New Braunfels', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.7229, 'longitude': -98.0742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78131', 'place_name': 'New Braunfels', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.703, 'longitude': -98.1245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78132', 'place_name': 'New Braunfels', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.7565, 'longitude': -98.1983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78133', 'place_name': 'Canyon Lake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.9112, 'longitude': -98.2374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78135', 'place_name': 'New Braunfels', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.703, 'longitude': -98.1245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78163', 'place_name': 'Bulverde', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.7767, 'longitude': -98.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78266', 'place_name': 'San Antonio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.6643, 'longitude': -98.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78623', 'place_name': 'Fischer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comal', 'locality_code': '91', 'latitude': 29.9627, 'longitude': -98.2088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76442', 'place_name': 'Comanche', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comanche', 'locality_code': '93', 'latitude': 31.9116, 'longitude': -98.6082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76444', 'place_name': 'De Leon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comanche', 'locality_code': '93', 'latitude': 32.1087, 'longitude': -98.5489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76452', 'place_name': 'Energy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comanche', 'locality_code': '93', 'latitude': 31.7629, 'longitude': -98.3695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76455', 'place_name': 'Gustine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comanche', 'locality_code': '93', 'latitude': 31.8468, 'longitude': -98.4017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76468', 'place_name': 'Proctor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comanche', 'locality_code': '93', 'latitude': 31.9874, 'longitude': -98.4298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76474', 'place_name': 'Sidney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Comanche', 'locality_code': '93', 'latitude': 31.932, 'longitude': -98.768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76837', 'place_name': 'Eden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Concho', 'locality_code': '95', 'latitude': 31.2192, 'longitude': -99.8407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76855', 'place_name': 'Lowake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Concho', 'locality_code': '95', 'latitude': 31.5663, 'longitude': -100.0759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76862', 'place_name': 'Millersview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Concho', 'locality_code': '95', 'latitude': 31.4167, 'longitude': -99.7171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76866', 'place_name': 'Paint Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Concho', 'locality_code': '95', 'latitude': 31.5048, 'longitude': -99.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76937', 'place_name': 'Eola', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Concho', 'locality_code': '95', 'latitude': 31.3617, 'longitude': -100.0922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76238', 'place_name': 'Era', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.4965, 'longitude': -97.3859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76240', 'place_name': 'Gainesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.6547, 'longitude': -97.1583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76241', 'place_name': 'Gainesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.6104, 'longitude': -97.0369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76250', 'place_name': 'Lindsay', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.636, 'longitude': -97.2214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76252', 'place_name': 'Muenster', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.6595, 'longitude': -97.3624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76253', 'place_name': 'Myra', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.6178, 'longitude': -97.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76263', 'place_name': 'Rosston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.4674, 'longitude': -97.4534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76272', 'place_name': 'Valley View', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cooke', 'locality_code': '97', 'latitude': 33.5022, 'longitude': -97.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76522', 'place_name': 'Copperas Cove', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.2029, 'longitude': -97.9301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76525', 'place_name': 'Evant', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.4388, 'longitude': -98.0535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76526', 'place_name': 'Flat', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.2956, 'longitude': -97.5822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76528', 'place_name': 'Gatesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.4177, 'longitude': -97.833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76538', 'place_name': 'Jonesboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.5599, 'longitude': -97.8456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76558', 'place_name': 'Mound', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.3514, 'longitude': -97.6444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76561', 'place_name': 'Oglesby', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.4438, 'longitude': -97.5501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76566', 'place_name': 'Purmela', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.4841, 'longitude': -97.9903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76596', 'place_name': 'Gatesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.3902, 'longitude': -97.7993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76597', 'place_name': 'Gatesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.3902, 'longitude': -97.7993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76598', 'place_name': 'Gatesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.3902, 'longitude': -97.7993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76599', 'place_name': 'Gatesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Coryell', 'locality_code': '99', 'latitude': 31.4706, 'longitude': -97.7347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79223', 'place_name': 'Cee Vee', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cottle', 'locality_code': '101', 'latitude': 34.2295, 'longitude': -100.4573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79248', 'place_name': 'Paducah', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Cottle', 'locality_code': '101', 'latitude': 34.0217, 'longitude': -100.2986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79731', 'place_name': 'Crane', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Crane', 'locality_code': '103', 'latitude': 31.3969, 'longitude': -102.3544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76943', 'place_name': 'Ozona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Crockett', 'locality_code': '105', 'latitude': 30.7164, 'longitude': -101.2388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79322', 'place_name': 'Crosbyton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Crosby', 'locality_code': '107', 'latitude': 33.6562, 'longitude': -101.2287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79343', 'place_name': 'Lorenzo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Crosby', 'locality_code': '107', 'latitude': 33.6666, 'longitude': -101.5277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79357', 'place_name': 'Ralls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Crosby', 'locality_code': '107', 'latitude': 33.6851, 'longitude': -101.3836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79855', 'place_name': 'Van Horn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Culberson', 'locality_code': '109', 'latitude': 31.0391, 'longitude': -104.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79022', 'place_name': 'Dalhart', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallam', 'locality_code': '111', 'latitude': 36.0732, 'longitude': -102.5177, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79051', 'place_name': 'Kerrick', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallam', 'locality_code': '111', 'latitude': 36.4956, 'longitude': -102.2427, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79087', 'place_name': 'Texline', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallam', 'locality_code': '111', 'latitude': 36.374, 'longitude': -102.9845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75001', 'place_name': 'Addison', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.96, 'longitude': -96.8385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75006', 'place_name': 'Carrollton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9657, 'longitude': -96.8825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75011', 'place_name': 'Carrollton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9537, 'longitude': -96.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75014', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75015', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8987, 'longitude': -96.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75016', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8987, 'longitude': -96.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75017', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75019', 'place_name': 'Coppell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9673, 'longitude': -96.9805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75030', 'place_name': 'Rowlett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9029, 'longitude': -96.5639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75038', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8653, 'longitude': -96.9905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75039', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8697, 'longitude': -96.9389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75040', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9227, 'longitude': -96.6248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75041', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8794, 'longitude': -96.6411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75042', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9185, 'longitude': -96.6775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75043', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8565, 'longitude': -96.5999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75044', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9522, 'longitude': -96.6654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75045', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9137, 'longitude': -96.6271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75046', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9126, 'longitude': -96.6389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75047', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9126, 'longitude': -96.6389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75048', 'place_name': 'Sachse', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9643, 'longitude': -96.6012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75049', 'place_name': 'Garland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9126, 'longitude': -96.6389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75050', 'place_name': 'Grand Prairie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7649, 'longitude': -97.0112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75051', 'place_name': 'Grand Prairie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7115, 'longitude': -97.0069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75052', 'place_name': 'Grand Prairie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6605, 'longitude': -97.0311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75053', 'place_name': 'Grand Prairie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.746, 'longitude': -96.9978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75054', 'place_name': 'Grand Prairie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.5907, 'longitude': -97.0405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75059', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8023, 'longitude': -96.9597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75060', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8023, 'longitude': -96.9597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75061', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8267, 'longitude': -96.9633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75062', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8479, 'longitude': -96.974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75063', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9247, 'longitude': -96.9598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75064', 'place_name': 'Irving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9247, 'longitude': -96.9598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75080', 'place_name': 'Richardson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.966, 'longitude': -96.7452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75081', 'place_name': 'Richardson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9462, 'longitude': -96.7058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75082', 'place_name': 'Richardson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9865, 'longitude': -96.686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75083', 'place_name': 'Richardson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75085', 'place_name': 'Richardson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75088', 'place_name': 'Rowlett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9031, 'longitude': -96.5472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75089', 'place_name': 'Rowlett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9346, 'longitude': -96.5544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75098', 'place_name': 'Wylie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 33.0041, 'longitude': -96.5394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75099', 'place_name': 'Coppell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9546, 'longitude': -97.015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75104', 'place_name': 'Cedar Hill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.5885, 'longitude': -96.9438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75106', 'place_name': 'Cedar Hill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.5885, 'longitude': -96.9561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75115', 'place_name': 'Desoto', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6041, 'longitude': -96.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75116', 'place_name': 'Duncanville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6587, 'longitude': -96.9114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75123', 'place_name': 'Desoto', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.5899, 'longitude': -96.8569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75134', 'place_name': 'Lancaster', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6161, 'longitude': -96.783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75137', 'place_name': 'Duncanville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6347, 'longitude': -96.9113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75138', 'place_name': 'Duncanville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75141', 'place_name': 'Hutchins', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6396, 'longitude': -96.707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75146', 'place_name': 'Lancaster', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.5914, 'longitude': -96.7728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75149', 'place_name': 'Mesquite', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7678, 'longitude': -96.6082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75150', 'place_name': 'Mesquite', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8154, 'longitude': -96.6307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75159', 'place_name': 'Seagoville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6525, 'longitude': -96.558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75172', 'place_name': 'Wilmer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.5981, 'longitude': -96.6838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75180', 'place_name': 'Balch Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7287, 'longitude': -96.6228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75181', 'place_name': 'Mesquite', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7272, 'longitude': -96.5669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75182', 'place_name': 'Sunnyvale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.797, 'longitude': -96.5616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75185', 'place_name': 'Mesquite', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7403, 'longitude': -96.5618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75187', 'place_name': 'Mesquite', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75201', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7904, 'longitude': -96.8044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75202', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7781, 'longitude': -96.8054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75203', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.746, 'longitude': -96.807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75204', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8038, 'longitude': -96.7851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75205', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.826, 'longitude': -96.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75206', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.831, 'longitude': -96.7692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75207', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7939, 'longitude': -96.8319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75208', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7492, 'longitude': -96.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75209', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8456, 'longitude': -96.826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75210', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7699, 'longitude': -96.743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75211', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7319, 'longitude': -96.9057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75212', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7829, 'longitude': -96.8714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75214', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8248, 'longitude': -96.7498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75215', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7582, 'longitude': -96.7623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75216', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7086, 'longitude': -96.7955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75217', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7244, 'longitude': -96.6755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75218', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8463, 'longitude': -96.6972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75219', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8132, 'longitude': -96.8142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75220', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8681, 'longitude': -96.8622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75221', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8147, 'longitude': -96.7877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75222', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75223', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7942, 'longitude': -96.7475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75224', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7114, 'longitude': -96.8387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75225', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8628, 'longitude': -96.7918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75226', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7887, 'longitude': -96.7676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75227', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7672, 'longitude': -96.6836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75228', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.825, 'longitude': -96.6784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75229', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8958, 'longitude': -96.8588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75230', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8999, 'longitude': -96.7897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75231', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8756, 'longitude': -96.7495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75232', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6647, 'longitude': -96.8384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75233', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7046, 'longitude': -96.8725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75234', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9245, 'longitude': -96.8938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75235', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8252, 'longitude': -96.8388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75236', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.69, 'longitude': -96.9177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75237', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.659, 'longitude': -96.8765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75238', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.877, 'longitude': -96.708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75240', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9374, 'longitude': -96.7872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75241', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6722, 'longitude': -96.7774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75242', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75243', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9103, 'longitude': -96.7285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75244', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9322, 'longitude': -96.8353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75246', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7948, 'longitude': -96.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75247', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.8152, 'longitude': -96.8703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75248', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9682, 'longitude': -96.7942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75249', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.636, 'longitude': -96.9493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75250', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75251', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9189, 'longitude': -96.7751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75252', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9968, 'longitude': -96.7921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75253', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.6833, 'longitude': -96.5964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75254', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.9503, 'longitude': -96.819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75260', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75261', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75262', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75263', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75264', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75265', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75266', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75267', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75270', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7813, 'longitude': -96.8019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75275', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75277', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75283', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75284', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75285', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75287', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 33.0005, 'longitude': -96.8314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75301', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75303', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75312', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75313', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75315', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75320', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75326', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75336', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75339', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75342', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75354', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75355', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75356', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75357', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75358', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7942, 'longitude': -96.7652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75359', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75360', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75367', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75368', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75370', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75371', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75372', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75373', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75374', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75376', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75378', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75379', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75380', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75381', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75382', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75389', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75390', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75391', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75392', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75393', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75394', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75395', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75397', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75398', 'place_name': 'Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dallas', 'locality_code': '113', 'latitude': 32.7673, 'longitude': -96.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79331', 'place_name': 'Lamesa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dawson', 'locality_code': '115', 'latitude': 32.7367, 'longitude': -101.9569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79377', 'place_name': 'Welch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dawson', 'locality_code': '115', 'latitude': 32.9298, 'longitude': -102.1278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79713', 'place_name': 'Ackerly', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dawson', 'locality_code': '115', 'latitude': 32.5273, 'longitude': -101.716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79025', 'place_name': 'Dawn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Deaf Smith', 'locality_code': '117', 'latitude': 34.9106, 'longitude': -102.2002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79045', 'place_name': 'Hereford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Deaf Smith', 'locality_code': '117', 'latitude': 34.837, 'longitude': -102.405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75415', 'place_name': 'Ben Franklin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Delta', 'locality_code': '119', 'latitude': 33.4768, 'longitude': -95.7689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75432', 'place_name': 'Cooper', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Delta', 'locality_code': '119', 'latitude': 33.3812, 'longitude': -95.6623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75441', 'place_name': 'Enloe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Delta', 'locality_code': '119', 'latitude': 33.4291, 'longitude': -95.6518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75448', 'place_name': 'Klondike', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Delta', 'locality_code': '119', 'latitude': 33.3034, 'longitude': -95.8018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75450', 'place_name': 'Lake Creek', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Delta', 'locality_code': '119', 'latitude': 33.4116, 'longitude': -95.4551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75469', 'place_name': 'Pecan Gap', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Delta', 'locality_code': '119', 'latitude': 33.4196, 'longitude': -95.8262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75007', 'place_name': 'Carrollton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0033, 'longitude': -96.882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75010', 'place_name': 'Carrollton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0304, 'longitude': -96.8777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75022', 'place_name': 'Flower Mound', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0268, 'longitude': -97.1193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75027', 'place_name': 'Flower Mound', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2074, 'longitude': -97.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75028', 'place_name': 'Flower Mound', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0383, 'longitude': -97.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75029', 'place_name': 'Lewisville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0462, 'longitude': -96.9942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75056', 'place_name': 'The Colony', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.094, 'longitude': -96.8836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75057', 'place_name': 'Lewisville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0532, 'longitude': -96.9999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75065', 'place_name': 'Lake Dallas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.1219, 'longitude': -97.0237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75067', 'place_name': 'Lewisville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0198, 'longitude': -96.9925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75068', 'place_name': 'Little Elm', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.1768, 'longitude': -96.9583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75077', 'place_name': 'Lewisville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0775, 'longitude': -97.0704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76201', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2289, 'longitude': -97.1314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76202', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2255, 'longitude': -97.1085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76203', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2148, 'longitude': -97.1331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76204', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2074, 'longitude': -97.1163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76205', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.1903, 'longitude': -97.1282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76206', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.1694, 'longitude': -97.1506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76207', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2285, 'longitude': -97.1813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76208', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2117, 'longitude': -97.0612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76209', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2346, 'longitude': -97.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76210', 'place_name': 'Denton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.1428, 'longitude': -97.0727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76226', 'place_name': 'Argyle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.1062, 'longitude': -97.16, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76227', 'place_name': 'Aubrey', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.292, 'longitude': -96.9879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76247', 'place_name': 'Justin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0734, 'longitude': -97.3093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76249', 'place_name': 'Krum', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.2734, 'longitude': -97.2675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76258', 'place_name': 'Pilot Point', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.371, 'longitude': -96.9446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76259', 'place_name': 'Ponder', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.1774, 'longitude': -97.2848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76262', 'place_name': 'Roanoke', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.0211, 'longitude': -97.2127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76266', 'place_name': 'Sanger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Denton', 'locality_code': '121', 'latitude': 33.3563, 'longitude': -97.1814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77954', 'place_name': 'Cuero', 'state': 'Texas', 'state_ab': 'TX', 'county': 'DeWitt', 'locality_code': '123', 'latitude': 29.091, 'longitude': -97.2812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77967', 'place_name': 'Hochheim', 'state': 'Texas', 'state_ab': 'TX', 'county': 'DeWitt', 'locality_code': '123', 'latitude': 29.3125, 'longitude': -97.2917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77974', 'place_name': 'Meyersville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'DeWitt', 'locality_code': '123', 'latitude': 28.9229, 'longitude': -97.3042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77989', 'place_name': 'Thomaston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'DeWitt', 'locality_code': '123', 'latitude': 28.9974, 'longitude': -97.1539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77994', 'place_name': 'Westhoff', 'state': 'Texas', 'state_ab': 'TX', 'county': 'DeWitt', 'locality_code': '123', 'latitude': 29.1792, 'longitude': -97.46, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78141', 'place_name': 'Nordheim', 'state': 'Texas', 'state_ab': 'TX', 'county': 'DeWitt', 'locality_code': '123', 'latitude': 28.9142, 'longitude': -97.5946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78164', 'place_name': 'Yorktown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'DeWitt', 'locality_code': '123', 'latitude': 28.9892, 'longitude': -97.5121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79220', 'place_name': 'Afton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dickens', 'locality_code': '125', 'latitude': 33.7718, 'longitude': -100.8021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79229', 'place_name': 'Dickens', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dickens', 'locality_code': '125', 'latitude': 33.628, 'longitude': -100.8197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79243', 'place_name': 'Mcadoo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dickens', 'locality_code': '125', 'latitude': 33.7413, 'longitude': -100.9833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79370', 'place_name': 'Spur', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dickens', 'locality_code': '125', 'latitude': 33.479, 'longitude': -100.8571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78827', 'place_name': 'Asherton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dimmit', 'locality_code': '127', 'latitude': 28.4364, 'longitude': -99.7486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78830', 'place_name': 'Big Wells', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dimmit', 'locality_code': '127', 'latitude': 28.5693, 'longitude': -99.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78834', 'place_name': 'Carrizo Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dimmit', 'locality_code': '127', 'latitude': 28.5278, 'longitude': -99.8635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78836', 'place_name': 'Catarina', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Dimmit', 'locality_code': '127', 'latitude': 28.3598, 'longitude': -99.586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79226', 'place_name': 'Clarendon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Donley', 'locality_code': '129', 'latitude': 34.9529, 'longitude': -100.8952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79237', 'place_name': 'Hedley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Donley', 'locality_code': '129', 'latitude': 34.8698, 'longitude': -100.6806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79240', 'place_name': 'Lelia Lake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Donley', 'locality_code': '129', 'latitude': 34.8843, 'longitude': -100.7674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78341', 'place_name': 'Benavides', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Duval', 'locality_code': '131', 'latitude': 27.5925, 'longitude': -98.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78349', 'place_name': 'Concepcion', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Duval', 'locality_code': '131', 'latitude': 27.3849, 'longitude': -98.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78357', 'place_name': 'Freer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Duval', 'locality_code': '131', 'latitude': 27.88, 'longitude': -98.6061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78376', 'place_name': 'Realitos', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Duval', 'locality_code': '131', 'latitude': 27.4184, 'longitude': -98.514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78384', 'place_name': 'San Diego', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Duval', 'locality_code': '131', 'latitude': 27.7654, 'longitude': -98.2503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76435', 'place_name': 'Carbon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.2701, 'longitude': -98.8348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76437', 'place_name': 'Cisco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.38, 'longitude': -98.9865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76445', 'place_name': 'Desdemona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.2819, 'longitude': -98.5673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76448', 'place_name': 'Eastland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.3994, 'longitude': -98.8071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76454', 'place_name': 'Gorman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.2234, 'longitude': -98.6834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76466', 'place_name': 'Olden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.4421, 'longitude': -98.7342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76470', 'place_name': 'Ranger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.4681, 'longitude': -98.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76471', 'place_name': 'Rising Star', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Eastland', 'locality_code': '133', 'latitude': 32.128, 'longitude': -98.9859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79741', 'place_name': 'Goldsmith', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.9541, 'longitude': -102.625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79758', 'place_name': 'Gardendale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 32.0245, 'longitude': -102.3572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79759', 'place_name': 'Notrees', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.8599, 'longitude': -102.7413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79760', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.7652, 'longitude': -102.3543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79761', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.8579, 'longitude': -102.3523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79762', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.889, 'longitude': -102.3548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79763', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.8341, 'longitude': -102.4162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79764', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.8767, 'longitude': -102.4375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79765', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.9375, 'longitude': -102.3944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79766', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.7827, 'longitude': -102.3449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79768', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.8457, 'longitude': -102.3676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79769', 'place_name': 'Odessa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.8457, 'longitude': -102.3676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79776', 'place_name': 'Penwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ector', 'locality_code': '135', 'latitude': 31.7334, 'longitude': -102.5879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76883', 'place_name': 'Telegraph', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Edwards', 'locality_code': '137', 'latitude': 30.3274, 'longitude': -99.9062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78828', 'place_name': 'Barksdale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Edwards', 'locality_code': '137', 'latitude': 29.8282, 'longitude': -100.105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78880', 'place_name': 'Rocksprings', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Edwards', 'locality_code': '137', 'latitude': 30.0188, 'longitude': -100.231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75101', 'place_name': 'Bardwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.2731, 'longitude': -96.703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75119', 'place_name': 'Ennis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.3321, 'longitude': -96.6224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75120', 'place_name': 'Ennis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.3347, 'longitude': -96.6335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75125', 'place_name': 'Ferris', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.5223, 'longitude': -96.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75152', 'place_name': 'Palmer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.4387, 'longitude': -96.6794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75154', 'place_name': 'Red Oak', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.5185, 'longitude': -96.8071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75155', 'place_name': 'Rice', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.2258, 'longitude': -96.4606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75165', 'place_name': 'Waxahachie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.3808, 'longitude': -96.8374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75167', 'place_name': 'Waxahachie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.3773, 'longitude': -96.9162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75168', 'place_name': 'Waxahachie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.3749, 'longitude': -96.7166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76041', 'place_name': 'Forreston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.2486, 'longitude': -96.8232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76064', 'place_name': 'Maypearl', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.2993, 'longitude': -97.0271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76065', 'place_name': 'Midlothian', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.4757, 'longitude': -96.9936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76623', 'place_name': 'Avalon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.2054, 'longitude': -96.79, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76651', 'place_name': 'Italy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.1785, 'longitude': -96.8823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76670', 'place_name': 'Milford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ellis', 'locality_code': '139', 'latitude': 32.1482, 'longitude': -96.9612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79821', 'place_name': 'Anthony', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.9907, 'longitude': -106.5976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79835', 'place_name': 'Canutillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.9344, 'longitude': -106.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79836', 'place_name': 'Clint', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.5494, 'longitude': -106.2038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79838', 'place_name': 'Fabens', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.4745, 'longitude': -106.1589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79849', 'place_name': 'San Elizario', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.5508, 'longitude': -106.2507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79853', 'place_name': 'Tornillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.4407, 'longitude': -106.0765, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79901', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7584, 'longitude': -106.4783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79902', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7763, 'longitude': -106.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79903', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7862, 'longitude': -106.4406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79904', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8533, 'longitude': -106.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79905', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7674, 'longitude': -106.4304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79906', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8092, 'longitude': -106.4247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79907', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7089, 'longitude': -106.3293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79908', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8265, 'longitude': -106.3857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79910', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79911', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8925, 'longitude': -106.5426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79912', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8383, 'longitude': -106.5364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79913', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.9373, 'longitude': -106.5724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79914', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79915', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7432, 'longitude': -106.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79916', 'place_name': 'Fort Bliss', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8136, 'longitude': -106.4122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79917', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79918', 'place_name': 'Fort Bliss', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8136, 'longitude': -106.4122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79920', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8214, 'longitude': -106.4614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79922', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8218, 'longitude': -106.5732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79923', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79924', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.9021, 'longitude': -106.4149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79925', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7814, 'longitude': -106.3613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79926', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79927', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6446, 'longitude': -106.2737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79928', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6631, 'longitude': -106.1401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79929', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79930', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8048, 'longitude': -106.4568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79931', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79932', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8623, 'longitude': -106.5932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79934', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.9386, 'longitude': -106.4073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79935', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7718, 'longitude': -106.3303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79936', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7677, 'longitude': -106.3016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79937', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79938', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.8045, 'longitude': -105.9661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79940', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79941', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79942', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79943', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79944', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79945', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79946', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79947', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79948', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79949', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79950', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79951', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79952', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79953', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79954', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79955', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79958', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79960', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79961', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79968', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7705, 'longitude': -106.5048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79976', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79978', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.7587, 'longitude': -106.4869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79980', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79990', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79995', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79996', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79997', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79998', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79999', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88510', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88511', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88512', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88513', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88514', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88515', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88517', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88518', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88519', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88520', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88521', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88523', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88524', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88525', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88526', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88527', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88528', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88529', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88530', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88531', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88532', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88533', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88534', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88535', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88536', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88538', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88539', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88540', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88541', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88542', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88543', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88544', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88545', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88546', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88547', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88548', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88549', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88550', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88553', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88554', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88555', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88556', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88557', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88558', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88559', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88560', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88561', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88562', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88563', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88565', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88566', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88567', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88568', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88569', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88570', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88571', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88572', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88573', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88574', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88575', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88576', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88577', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88578', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88579', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88580', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88581', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88582', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88583', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88584', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88585', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88586', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88587', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88588', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88589', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88590', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '88595', 'place_name': 'El Paso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'El Paso', 'locality_code': '141', 'latitude': 31.6948, 'longitude': -106.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76401', 'place_name': 'Stephenville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Erath', 'locality_code': '143', 'latitude': 32.2214, 'longitude': -98.2224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76402', 'place_name': 'Stephenville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Erath', 'locality_code': '143', 'latitude': 32.2153, 'longitude': -98.208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76433', 'place_name': 'Bluff Dale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Erath', 'locality_code': '143', 'latitude': 32.2884, 'longitude': -98.0539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76446', 'place_name': 'Dublin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Erath', 'locality_code': '143', 'latitude': 32.0909, 'longitude': -98.3455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76461', 'place_name': 'Lingleville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Erath', 'locality_code': '143', 'latitude': 32.2446, 'longitude': -98.3775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76465', 'place_name': 'Morgan Mill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Erath', 'locality_code': '143', 'latitude': 32.3882, 'longitude': -98.1673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76570', 'place_name': 'Rosebud', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Falls', 'locality_code': '145', 'latitude': 31.0922, 'longitude': -96.9755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76632', 'place_name': 'Chilton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Falls', 'locality_code': '145', 'latitude': 31.31, 'longitude': -97.09, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76656', 'place_name': 'Lott', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Falls', 'locality_code': '145', 'latitude': 31.1925, 'longitude': -97.0581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76661', 'place_name': 'Marlin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Falls', 'locality_code': '145', 'latitude': 31.3036, 'longitude': -96.8889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76680', 'place_name': 'Reagan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Falls', 'locality_code': '145', 'latitude': 31.1871, 'longitude': -96.7998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76685', 'place_name': 'Satin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Falls', 'locality_code': '145', 'latitude': 31.3601, 'longitude': -97.0108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75413', 'place_name': 'Bailey', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.43, 'longitude': -96.1662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75418', 'place_name': 'Bonham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.5806, 'longitude': -96.1836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75438', 'place_name': 'Dodd City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.5647, 'longitude': -96.0619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75439', 'place_name': 'Ector', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.5819, 'longitude': -96.2735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75443', 'place_name': 'Gober', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.4697, 'longitude': -96.1111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75446', 'place_name': 'Honey Grove', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.5985, 'longitude': -95.9109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75447', 'place_name': 'Ivanhoe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.7612, 'longitude': -96.1193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75449', 'place_name': 'Ladonia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.4245, 'longitude': -95.9455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75452', 'place_name': 'Leonard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.3796, 'longitude': -96.2475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75475', 'place_name': 'Randolph', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.4846, 'longitude': -96.2541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75476', 'place_name': 'Ravenna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.7098, 'longitude': -96.1452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75479', 'place_name': 'Savoy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.6066, 'longitude': -96.3502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75488', 'place_name': 'Telephone', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.7979, 'longitude': -96.0449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75490', 'place_name': 'Trenton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.4235, 'longitude': -96.3398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75492', 'place_name': 'Windom', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fannin', 'locality_code': '147', 'latitude': 33.5633, 'longitude': -96.002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78932', 'place_name': 'Carmine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 30.1404, 'longitude': -96.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78938', 'place_name': 'Ellinger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.8459, 'longitude': -96.6966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78940', 'place_name': 'Fayetteville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.8868, 'longitude': -96.6463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78941', 'place_name': 'Flatonia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.7095, 'longitude': -97.0987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78945', 'place_name': 'La Grange', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.904, 'longitude': -96.886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78946', 'place_name': 'Ledbetter', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 30.2383, 'longitude': -96.7613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78949', 'place_name': 'Muldoon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.7993, 'longitude': -97.1006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78952', 'place_name': 'Plum', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.9349, 'longitude': -96.9675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78954', 'place_name': 'Round Top', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 30.0411, 'longitude': -96.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78956', 'place_name': 'Schulenburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.6882, 'longitude': -96.9106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78960', 'place_name': 'Warda', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 30.0702, 'longitude': -96.902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78961', 'place_name': 'Round Top', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 30.0652, 'longitude': -96.6961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78963', 'place_name': 'West Point', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fayette', 'locality_code': '149', 'latitude': 29.9523, 'longitude': -97.0361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79534', 'place_name': 'Mc Caulley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fisher', 'locality_code': '151', 'latitude': 32.7787, 'longitude': -100.2168, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79543', 'place_name': 'Roby', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fisher', 'locality_code': '151', 'latitude': 32.722, 'longitude': -100.4008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79546', 'place_name': 'Rotan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fisher', 'locality_code': '151', 'latitude': 32.8555, 'longitude': -100.4705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79560', 'place_name': 'Sylvester', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fisher', 'locality_code': '151', 'latitude': 32.7209, 'longitude': -100.2543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79221', 'place_name': 'Aiken', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Floyd', 'locality_code': '153', 'latitude': 34.1423, 'longitude': -101.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79231', 'place_name': 'Dougherty', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Floyd', 'locality_code': '153', 'latitude': 33.9446, 'longitude': -101.0922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79235', 'place_name': 'Floydada', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Floyd', 'locality_code': '153', 'latitude': 33.9743, 'longitude': -101.3346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79241', 'place_name': 'Lockney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Floyd', 'locality_code': '153', 'latitude': 34.1458, 'longitude': -101.4259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79258', 'place_name': 'South Plains', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Floyd', 'locality_code': '153', 'latitude': 34.2245, 'longitude': -101.3096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79227', 'place_name': 'Crowell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Foard', 'locality_code': '155', 'latitude': 33.9912, 'longitude': -99.6983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77406', 'place_name': 'Richmond', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6436, 'longitude': -95.798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77407', 'place_name': 'Richmond', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6625, 'longitude': -95.7272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77417', 'place_name': 'Beasley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.479, 'longitude': -95.9681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77441', 'place_name': 'Fulshear', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.7217, 'longitude': -95.8977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77444', 'place_name': 'Guy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.3327, 'longitude': -95.7702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77451', 'place_name': 'Kendleton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.447, 'longitude': -96.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77459', 'place_name': 'Missouri City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5704, 'longitude': -95.5423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77461', 'place_name': 'Needville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.4117, 'longitude': -95.8273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77464', 'place_name': 'Orchard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5948, 'longitude': -95.9727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77469', 'place_name': 'Richmond', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5511, 'longitude': -95.7329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77471', 'place_name': 'Rosenberg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5497, 'longitude': -95.7982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77476', 'place_name': 'Simonton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6794, 'longitude': -95.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77477', 'place_name': 'Stafford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6228, 'longitude': -95.5678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77478', 'place_name': 'Sugar Land', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6196, 'longitude': -95.607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77479', 'place_name': 'Sugar Land', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5785, 'longitude': -95.6066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77481', 'place_name': 'Thompsons', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.4683, 'longitude': -95.5776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77487', 'place_name': 'Sugar Land', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6197, 'longitude': -95.6349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77489', 'place_name': 'Missouri City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5962, 'longitude': -95.5115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77496', 'place_name': 'Sugar Land', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5255, 'longitude': -95.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77497', 'place_name': 'Stafford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6161, 'longitude': -95.5577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77498', 'place_name': 'Sugar Land', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.6396, 'longitude': -95.65, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77545', 'place_name': 'Fresno', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Fort Bend', 'locality_code': '157', 'latitude': 29.5293, 'longitude': -95.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75457', 'place_name': 'Mount Vernon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Franklin', 'locality_code': '159', 'latitude': 33.1702, 'longitude': -95.2181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75480', 'place_name': 'Scroggins', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Franklin', 'locality_code': '159', 'latitude': 33.0478, 'longitude': -95.1962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75487', 'place_name': 'Talco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Franklin', 'locality_code': '159', 'latitude': 33.3344, 'longitude': -95.0497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75838', 'place_name': 'Donie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Freestone', 'locality_code': '161', 'latitude': 31.4873, 'longitude': -96.2387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75840', 'place_name': 'Fairfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Freestone', 'locality_code': '161', 'latitude': 31.7361, 'longitude': -96.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75848', 'place_name': 'Kirvin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Freestone', 'locality_code': '161', 'latitude': 31.7666, 'longitude': -96.3303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75859', 'place_name': 'Streetman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Freestone', 'locality_code': '161', 'latitude': 31.8885, 'longitude': -96.2988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75860', 'place_name': 'Teague', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Freestone', 'locality_code': '161', 'latitude': 31.6328, 'longitude': -96.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76693', 'place_name': 'Wortham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Freestone', 'locality_code': '161', 'latitude': 31.7865, 'longitude': -96.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78005', 'place_name': 'Bigfoot', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Frio', 'locality_code': '163', 'latitude': 29.0531, 'longitude': -98.8582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78017', 'place_name': 'Dilley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Frio', 'locality_code': '163', 'latitude': 28.6782, 'longitude': -99.1747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78057', 'place_name': 'Moore', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Frio', 'locality_code': '163', 'latitude': 29.0595, 'longitude': -99.0204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78061', 'place_name': 'Pearsall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Frio', 'locality_code': '163', 'latitude': 28.8923, 'longitude': -99.0944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79342', 'place_name': 'Loop', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gaines', 'locality_code': '165', 'latitude': 32.9162, 'longitude': -102.4221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79359', 'place_name': 'Seagraves', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gaines', 'locality_code': '165', 'latitude': 32.9317, 'longitude': -102.5781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79360', 'place_name': 'Seminole', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gaines', 'locality_code': '165', 'latitude': 32.721, 'longitude': -102.6828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77510', 'place_name': 'Santa Fe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.4032, 'longitude': -95.0734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77517', 'place_name': 'Santa Fe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.3673, 'longitude': -95.1361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77518', 'place_name': 'Bacliff', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.5055, 'longitude': -94.9893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77539', 'place_name': 'Dickinson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.4585, 'longitude': -95.0345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77546', 'place_name': 'Friendswood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.5224, 'longitude': -95.1879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77549', 'place_name': 'Friendswood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.5294, 'longitude': -95.201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77550', 'place_name': 'Galveston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.2983, 'longitude': -94.793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77551', 'place_name': 'Galveston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.2766, 'longitude': -94.8303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77552', 'place_name': 'Galveston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.2205, 'longitude': -94.9444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77553', 'place_name': 'Galveston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.3322, 'longitude': -94.8002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77554', 'place_name': 'Galveston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.2243, 'longitude': -94.9637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77555', 'place_name': 'Galveston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.3305, 'longitude': -94.8002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77563', 'place_name': 'Hitchcock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.3398, 'longitude': -94.9926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77565', 'place_name': 'Kemah', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.5236, 'longitude': -95.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77568', 'place_name': 'La Marque', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.3676, 'longitude': -94.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77573', 'place_name': 'League City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.5173, 'longitude': -95.0963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77574', 'place_name': 'League City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.5116, 'longitude': -95.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77590', 'place_name': 'Texas City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.397, 'longitude': -94.9203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77591', 'place_name': 'Texas City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.3891, 'longitude': -94.9942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77592', 'place_name': 'Texas City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.3305, 'longitude': -94.8002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77617', 'place_name': 'Gilchrist', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.523, 'longitude': -94.4755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77623', 'place_name': 'High Island', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.5472, 'longitude': -94.4267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77650', 'place_name': 'Port Bolivar', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Galveston', 'locality_code': '167', 'latitude': 29.4266, 'longitude': -94.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79330', 'place_name': 'Justiceburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Garza', 'locality_code': '169', 'latitude': 33.0594, 'longitude': -101.1881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79356', 'place_name': 'Post', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Garza', 'locality_code': '169', 'latitude': 33.2017, 'longitude': -101.3922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78618', 'place_name': 'Doss', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gillespie', 'locality_code': '171', 'latitude': 30.4613, 'longitude': -99.1707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78624', 'place_name': 'Fredericksburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gillespie', 'locality_code': '171', 'latitude': 30.2817, 'longitude': -98.8799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78631', 'place_name': 'Harper', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gillespie', 'locality_code': '171', 'latitude': 30.2816, 'longitude': -99.241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78671', 'place_name': 'Stonewall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gillespie', 'locality_code': '171', 'latitude': 30.2088, 'longitude': -98.6131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78675', 'place_name': 'Willow City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gillespie', 'locality_code': '171', 'latitude': 30.4549, 'longitude': -98.6646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79739', 'place_name': 'Garden City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Glasscock', 'locality_code': '173', 'latitude': 31.8491, 'longitude': -101.5269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77960', 'place_name': 'Fannin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Goliad', 'locality_code': '175', 'latitude': 28.6955, 'longitude': -97.2358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77963', 'place_name': 'Goliad', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Goliad', 'locality_code': '175', 'latitude': 28.6993, 'longitude': -97.3783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77993', 'place_name': 'Weesatche', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Goliad', 'locality_code': '175', 'latitude': 28.8472, 'longitude': -97.448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78107', 'place_name': 'Berclair', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Goliad', 'locality_code': '175', 'latitude': 28.5295, 'longitude': -97.5925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78122', 'place_name': 'Leesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.3961, 'longitude': -97.7566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78140', 'place_name': 'Nixon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.3016, 'longitude': -97.7529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78159', 'place_name': 'Smiley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.2655, 'longitude': -97.6227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78604', 'place_name': 'Belmont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.5233, 'longitude': -97.6839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78614', 'place_name': 'Cost', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.4321, 'longitude': -97.5531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78629', 'place_name': 'Gonzales', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.5086, 'longitude': -97.4495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78632', 'place_name': 'Harwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.6661, 'longitude': -97.4906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78658', 'place_name': 'Ottine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.5952, 'longitude': -97.5911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78677', 'place_name': 'Wrightsboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.3739, 'longitude': -97.565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78959', 'place_name': 'Waelder', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gonzales', 'locality_code': '177', 'latitude': 29.6868, 'longitude': -97.2958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79002', 'place_name': 'Alanreed', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gray', 'locality_code': '179', 'latitude': 35.2273, 'longitude': -100.7592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79054', 'place_name': 'Lefors', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gray', 'locality_code': '179', 'latitude': 35.4391, 'longitude': -100.8059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79057', 'place_name': 'Mclean', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gray', 'locality_code': '179', 'latitude': 35.2312, 'longitude': -100.6008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79065', 'place_name': 'Pampa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gray', 'locality_code': '179', 'latitude': 35.538, 'longitude': -100.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79066', 'place_name': 'Pampa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gray', 'locality_code': '179', 'latitude': 35.5334, 'longitude': -100.956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75020', 'place_name': 'Denison', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.745, 'longitude': -96.5496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75021', 'place_name': 'Denison', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.7169, 'longitude': -96.5235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75058', 'place_name': 'Gunter', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.4495, 'longitude': -96.7341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75076', 'place_name': 'Pottsboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.8095, 'longitude': -96.6906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75090', 'place_name': 'Sherman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.6435, 'longitude': -96.6075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75091', 'place_name': 'Sherman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.6357, 'longitude': -96.6089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75092', 'place_name': 'Sherman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.6372, 'longitude': -96.6184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75414', 'place_name': 'Bells', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.6178, 'longitude': -96.4237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75459', 'place_name': 'Howe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.5311, 'longitude': -96.6777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75489', 'place_name': 'Tom Bean', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.5193, 'longitude': -96.4843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75491', 'place_name': 'Whitewright', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.519, 'longitude': -96.451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75495', 'place_name': 'Van Alstyne', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.4292, 'longitude': -96.5486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76233', 'place_name': 'Collinsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.558, 'longitude': -96.9014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76245', 'place_name': 'Gordonville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.8343, 'longitude': -96.8403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76264', 'place_name': 'Sadler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.731, 'longitude': -96.84, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76268', 'place_name': 'Southmayd', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.6304, 'longitude': -96.7692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76271', 'place_name': 'Tioga', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.4675, 'longitude': -96.9097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76273', 'place_name': 'Whitesboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grayson', 'locality_code': '181', 'latitude': 33.659, 'longitude': -96.879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75601', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5178, 'longitude': -94.7303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75602', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.4724, 'longitude': -94.7101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75603', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.4264, 'longitude': -94.7117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75604', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5251, 'longitude': -94.799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75605', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5547, 'longitude': -94.7767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75606', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5007, 'longitude': -94.7405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75607', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5112, 'longitude': -94.7835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75608', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5701, 'longitude': -94.8481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75615', 'place_name': 'Longview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5112, 'longitude': -94.7835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75641', 'place_name': 'Easton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.3874, 'longitude': -94.583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75647', 'place_name': 'Gladewater', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5559, 'longitude': -94.932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75660', 'place_name': 'Judson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5826, 'longitude': -94.7535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75662', 'place_name': 'Kilgore', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.3836, 'longitude': -94.8653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75663', 'place_name': 'Kilgore', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.387, 'longitude': -94.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75693', 'place_name': 'White Oak', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Gregg', 'locality_code': '183', 'latitude': 32.5383, 'longitude': -94.8622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77363', 'place_name': 'Plantersville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.2969, 'longitude': -95.8498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77830', 'place_name': 'Anderson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.5443, 'longitude': -96.0018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77831', 'place_name': 'Bedias', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.7065, 'longitude': -95.9546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77861', 'place_name': 'Iola', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.7326, 'longitude': -96.0911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77868', 'place_name': 'Navasota', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.3576, 'longitude': -96.0594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77873', 'place_name': 'Richards', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.5796, 'longitude': -95.8959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77875', 'place_name': 'Roans Prairie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.6075, 'longitude': -95.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77876', 'place_name': 'Shiro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Grimes', 'locality_code': '185', 'latitude': 30.6133, 'longitude': -95.8883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78108', 'place_name': 'Cibolo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.575, 'longitude': -98.228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78115', 'place_name': 'Geronimo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.5451, 'longitude': -98.0408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78123', 'place_name': 'Mc Queeney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.6023, 'longitude': -98.0492, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78124', 'place_name': 'Marion', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.5683, 'longitude': -98.1517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78154', 'place_name': 'Schertz', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.579, 'longitude': -98.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78155', 'place_name': 'Seguin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.5613, 'longitude': -97.9628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78156', 'place_name': 'Seguin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.6118, 'longitude': -97.9712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78638', 'place_name': 'Kingsbury', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.6726, 'longitude': -97.8306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78670', 'place_name': 'Staples', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Guadalupe', 'locality_code': '187', 'latitude': 29.7706, 'longitude': -97.8186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79021', 'place_name': 'Cotton Center', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hale', 'locality_code': '189', 'latitude': 33.9753, 'longitude': -102.0314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79032', 'place_name': 'Edmonson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hale', 'locality_code': '189', 'latitude': 34.2789, 'longitude': -101.8941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79041', 'place_name': 'Hale Center', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hale', 'locality_code': '189', 'latitude': 34.0669, 'longitude': -101.8736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79072', 'place_name': 'Plainview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hale', 'locality_code': '189', 'latitude': 34.1962, 'longitude': -101.7259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79073', 'place_name': 'Plainview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hale', 'locality_code': '189', 'latitude': 34.0689, 'longitude': -101.827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79250', 'place_name': 'Petersburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hale', 'locality_code': '189', 'latitude': 33.8768, 'longitude': -101.6046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79311', 'place_name': 'Abernathy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hale', 'locality_code': '189', 'latitude': 33.85, 'longitude': -101.8611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79233', 'place_name': 'Estelline', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hall', 'locality_code': '191', 'latitude': 34.5303, 'longitude': -100.4455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79239', 'place_name': 'Lakeview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hall', 'locality_code': '191', 'latitude': 34.6724, 'longitude': -100.7259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79245', 'place_name': 'Memphis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hall', 'locality_code': '191', 'latitude': 34.7122, 'longitude': -100.5347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79261', 'place_name': 'Turkey', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hall', 'locality_code': '191', 'latitude': 34.4036, 'longitude': -100.8449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76436', 'place_name': 'Carlton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hamilton', 'locality_code': '193', 'latitude': 31.8949, 'longitude': -98.1842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76457', 'place_name': 'Hico', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hamilton', 'locality_code': '193', 'latitude': 31.9597, 'longitude': -98.0249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76531', 'place_name': 'Hamilton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hamilton', 'locality_code': '193', 'latitude': 31.6781, 'longitude': -98.1131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76565', 'place_name': 'Pottsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hamilton', 'locality_code': '193', 'latitude': 31.6732, 'longitude': -98.3256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79040', 'place_name': 'Gruver', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hansford', 'locality_code': '195', 'latitude': 36.2868, 'longitude': -101.4089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79062', 'place_name': 'Morse', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hansford', 'locality_code': '195', 'latitude': 36.0596, 'longitude': -101.4729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79081', 'place_name': 'Spearman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hansford', 'locality_code': '195', 'latitude': 36.1927, 'longitude': -101.1952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79225', 'place_name': 'Chillicothe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardeman', 'locality_code': '197', 'latitude': 34.2439, 'longitude': -99.5157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79252', 'place_name': 'Quanah', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardeman', 'locality_code': '197', 'latitude': 34.2955, 'longitude': -99.7494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77374', 'place_name': 'Thicket', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.3765, 'longitude': -94.6361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77376', 'place_name': 'Votaw', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.4334, 'longitude': -94.6804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77519', 'place_name': 'Batson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.225, 'longitude': -94.6096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77585', 'place_name': 'Saratoga', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.2841, 'longitude': -94.5294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77625', 'place_name': 'Kountze', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.3703, 'longitude': -94.3259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77656', 'place_name': 'Silsbee', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.3244, 'longitude': -94.1907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77657', 'place_name': 'Lumberton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.2818, 'longitude': -94.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77659', 'place_name': 'Sour Lake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.1491, 'longitude': -94.3733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77663', 'place_name': 'Village Mills', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hardin', 'locality_code': '199', 'latitude': 30.5185, 'longitude': -94.4458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77001', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8131, 'longitude': -95.3098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77002', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7594, 'longitude': -95.3594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77003', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7489, 'longitude': -95.3391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77004', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7247, 'longitude': -95.3625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77005', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7179, 'longitude': -95.4263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77006', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7409, 'longitude': -95.3923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77007', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7736, 'longitude': -95.4034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77008', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7991, 'longitude': -95.4118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77009', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7936, 'longitude': -95.3675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77010', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7543, 'longitude': -95.3609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77011', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.742, 'longitude': -95.3073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77012', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7149, 'longitude': -95.2819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77013', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7842, 'longitude': -95.2301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77014', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9796, 'longitude': -95.4625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77015', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7853, 'longitude': -95.1852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77016', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8579, 'longitude': -95.3032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77017', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6863, 'longitude': -95.2555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77018', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8272, 'longitude': -95.4266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77019', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7517, 'longitude': -95.4054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77020', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7758, 'longitude': -95.3121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77021', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6954, 'longitude': -95.3562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77022', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8299, 'longitude': -95.3769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77023', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7242, 'longitude': -95.3178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77024', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7696, 'longitude': -95.5201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77025', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6889, 'longitude': -95.4341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77026', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7972, 'longitude': -95.3288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77027', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7396, 'longitude': -95.446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77028', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8297, 'longitude': -95.2879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77029', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.763, 'longitude': -95.2567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77030', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7041, 'longitude': -95.401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77031', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6581, 'longitude': -95.5413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77032', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9368, 'longitude': -95.3299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77033', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6686, 'longitude': -95.3382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77034', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6364, 'longitude': -95.2216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77035', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6518, 'longitude': -95.4854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77036', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6984, 'longitude': -95.5405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77037', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8892, 'longitude': -95.3935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77038', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9196, 'longitude': -95.4386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77039', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9067, 'longitude': -95.3334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77040', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8744, 'longitude': -95.5278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77041', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8602, 'longitude': -95.5817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77042', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7404, 'longitude': -95.5589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77043', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8052, 'longitude': -95.5607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77044', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8635, 'longitude': -95.1976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77045', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6297, 'longitude': -95.4382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77046', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.733, 'longitude': -95.4306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77047', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6254, 'longitude': -95.375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77048', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6321, 'longitude': -95.3416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77049', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8235, 'longitude': -95.1848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77050', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9015, 'longitude': -95.2848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77051', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6579, 'longitude': -95.3688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77052', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77053', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.5962, 'longitude': -95.4587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77054', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6852, 'longitude': -95.4017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77055', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7971, 'longitude': -95.4958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77056', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7446, 'longitude': -95.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77057', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7422, 'longitude': -95.4903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77058', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.5716, 'longitude': -95.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77059', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.5975, 'longitude': -95.1134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77060', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9335, 'longitude': -95.3981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77061', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6652, 'longitude': -95.279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77062', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.5721, 'longitude': -95.1303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77063', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7348, 'longitude': -95.522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77064', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.919, 'longitude': -95.5569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77065', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9319, 'longitude': -95.6106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77066', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.961, 'longitude': -95.4947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77067', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9547, 'longitude': -95.4522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77068', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0069, 'longitude': -95.4897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77069', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9863, 'longitude': -95.5208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77070', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9781, 'longitude': -95.5803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77071', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6518, 'longitude': -95.5176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77072', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.699, 'longitude': -95.5862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77073', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0198, 'longitude': -95.4087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77074', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6896, 'longitude': -95.5106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77075', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6223, 'longitude': -95.26, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77076', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.858, 'longitude': -95.3834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77077', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7477, 'longitude': -95.603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77078', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8497, 'longitude': -95.2582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77079', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7738, 'longitude': -95.598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77080', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8159, 'longitude': -95.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77081', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7119, 'longitude': -95.4845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77082', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7223, 'longitude': -95.6285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77083', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6947, 'longitude': -95.6511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77084', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.844, 'longitude': -95.6623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77085', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6218, 'longitude': -95.4819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77086', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9227, 'longitude': -95.4939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77087', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6876, 'longitude': -95.3011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77088', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8817, 'longitude': -95.4539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77089', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.594, 'longitude': -95.2218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77090', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0167, 'longitude': -95.447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77091', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8534, 'longitude': -95.4435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77092', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8324, 'longitude': -95.472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77093', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8617, 'longitude': -95.3403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77094', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7705, 'longitude': -95.7107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77095', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8941, 'longitude': -95.6481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77096', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6722, 'longitude': -95.4861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77098', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.735, 'longitude': -95.4118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77099', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6709, 'longitude': -95.5866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77201', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77202', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77203', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77204', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77205', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77206', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77207', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77208', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77209', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77210', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77212', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77213', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77215', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77216', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77217', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77218', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77219', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77220', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77221', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77222', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77223', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77224', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77225', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77226', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77227', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77228', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77229', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77230', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77231', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77233', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77234', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77235', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77236', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77237', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77238', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77240', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77241', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77242', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77243', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77244', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77245', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77248', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77249', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77251', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77252', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77253', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77254', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77255', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77256', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77257', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77258', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77259', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77261', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77262', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77263', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77265', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77266', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77267', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77268', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77269', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77270', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77271', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77272', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77273', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77274', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77275', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77277', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77279', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77280', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77282', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77284', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77287', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77288', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77289', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77290', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77291', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77292', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7443, 'longitude': -95.3326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77293', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77297', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7633, 'longitude': -95.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77299', 'place_name': 'Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77315', 'place_name': 'North Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77325', 'place_name': 'Kingwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0569, 'longitude': -95.1835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77336', 'place_name': 'Huffman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0565, 'longitude': -95.1051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77337', 'place_name': 'Hufsmith', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.1222, 'longitude': -95.5966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77338', 'place_name': 'Humble', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0041, 'longitude': -95.2825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77339', 'place_name': 'Kingwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0569, 'longitude': -95.1835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77345', 'place_name': 'Kingwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0336, 'longitude': -95.261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77346', 'place_name': 'Humble', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0042, 'longitude': -95.1728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77347', 'place_name': 'Humble', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9988, 'longitude': -95.2622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77373', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0532, 'longitude': -95.3773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77375', 'place_name': 'Tomball', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0739, 'longitude': -95.6201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77377', 'place_name': 'Tomball', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0615, 'longitude': -95.6821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77379', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0377, 'longitude': -95.5326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77382', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.2106, 'longitude': -95.5257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77383', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0799, 'longitude': -95.4172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77388', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0505, 'longitude': -95.4695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77389', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.1044, 'longitude': -95.5066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77391', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0799, 'longitude': -95.4172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77396', 'place_name': 'Humble', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9507, 'longitude': -95.2622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77401', 'place_name': 'Bellaire', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7023, 'longitude': -95.4611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77402', 'place_name': 'Bellaire', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.834, 'longitude': -95.4342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77410', 'place_name': 'Cypress', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9691, 'longitude': -95.6972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77411', 'place_name': 'Alief', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7111, 'longitude': -95.5963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77413', 'place_name': 'Barker', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7844, 'longitude': -95.6849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77429', 'place_name': 'Cypress', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9766, 'longitude': -95.6358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77433', 'place_name': 'Cypress', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8836, 'longitude': -95.7025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77447', 'place_name': 'Hockley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 30.0729, 'longitude': -95.8104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77449', 'place_name': 'Katy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8323, 'longitude': -95.736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77450', 'place_name': 'Katy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.745, 'longitude': -95.7326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77491', 'place_name': 'Katy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7858, 'longitude': -95.8244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77492', 'place_name': 'Katy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7858, 'longitude': -95.8244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77493', 'place_name': 'Katy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8678, 'longitude': -95.8298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77494', 'place_name': 'Katy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7404, 'longitude': -95.8304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77501', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6911, 'longitude': -95.2091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77502', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6789, 'longitude': -95.1982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77503', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6877, 'longitude': -95.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77504', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6501, 'longitude': -95.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77505', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6518, 'longitude': -95.1464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77506', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7009, 'longitude': -95.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77507', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6224, 'longitude': -95.0545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77508', 'place_name': 'Pasadena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.5699, 'longitude': -95.1066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77520', 'place_name': 'Baytown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7461, 'longitude': -94.9653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77521', 'place_name': 'Baytown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7705, 'longitude': -94.9695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77522', 'place_name': 'Baytown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7355, 'longitude': -94.9774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77530', 'place_name': 'Channelview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7914, 'longitude': -95.1317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77532', 'place_name': 'Crosby', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.9249, 'longitude': -95.0578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77536', 'place_name': 'Deer Park', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6826, 'longitude': -95.1222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77547', 'place_name': 'Galena Park', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.7392, 'longitude': -95.24, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77562', 'place_name': 'Highlands', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.8296, 'longitude': -95.0393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77571', 'place_name': 'La Porte', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6884, 'longitude': -95.0513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77572', 'place_name': 'La Porte', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6658, 'longitude': -95.0194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77586', 'place_name': 'Seabrook', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.5832, 'longitude': -95.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77587', 'place_name': 'South Houston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.6601, 'longitude': -95.2258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77598', 'place_name': 'Webster', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harris', 'locality_code': '201', 'latitude': 29.5564, 'longitude': -95.144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75642', 'place_name': 'Elysian Fields', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.3685, 'longitude': -94.183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75650', 'place_name': 'Hallsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.5073, 'longitude': -94.5333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75651', 'place_name': 'Harleton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.6579, 'longitude': -94.4652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75659', 'place_name': 'Jonesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.5075, 'longitude': -94.1106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75661', 'place_name': 'Karnack', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.6205, 'longitude': -94.2001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75670', 'place_name': 'Marshall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.5338, 'longitude': -94.3619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75671', 'place_name': 'Marshall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.5449, 'longitude': -94.3674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75672', 'place_name': 'Marshall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.5165, 'longitude': -94.3251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75688', 'place_name': 'Scottsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.554, 'longitude': -94.2394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75692', 'place_name': 'Waskom', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.5184, 'longitude': -94.1355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75694', 'place_name': 'Woodlawn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Harrison', 'locality_code': '203', 'latitude': 32.6537, 'longitude': -94.3427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79018', 'place_name': 'Channing', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hartley', 'locality_code': '205', 'latitude': 35.6837, 'longitude': -102.3302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79044', 'place_name': 'Hartley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hartley', 'locality_code': '205', 'latitude': 35.8856, 'longitude': -102.3969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76388', 'place_name': 'Weinert', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Haskell', 'locality_code': '207', 'latitude': 33.3249, 'longitude': -99.6664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79521', 'place_name': 'Haskell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Haskell', 'locality_code': '207', 'latitude': 33.158, 'longitude': -99.7309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79539', 'place_name': 'O Brien', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Haskell', 'locality_code': '207', 'latitude': 33.3749, 'longitude': -99.8473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79544', 'place_name': 'Rochester', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Haskell', 'locality_code': '207', 'latitude': 33.3105, 'longitude': -99.8594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79547', 'place_name': 'Rule', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Haskell', 'locality_code': '207', 'latitude': 33.1842, 'longitude': -99.8894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79548', 'place_name': 'Rule', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Haskell', 'locality_code': '207', 'latitude': 33.0771, 'longitude': -99.959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78610', 'place_name': 'Buda', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hays', 'locality_code': '209', 'latitude': 30.0918, 'longitude': -97.8534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78619', 'place_name': 'Driftwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hays', 'locality_code': '209', 'latitude': 30.1072, 'longitude': -98.0327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78620', 'place_name': 'Dripping Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hays', 'locality_code': '209', 'latitude': 30.2268, 'longitude': -98.1029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78640', 'place_name': 'Kyle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hays', 'locality_code': '209', 'latitude': 29.9966, 'longitude': -97.8335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78666', 'place_name': 'San Marcos', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hays', 'locality_code': '209', 'latitude': 29.8754, 'longitude': -97.9404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78667', 'place_name': 'San Marcos', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hays', 'locality_code': '209', 'latitude': 30.0544, 'longitude': -98.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78676', 'place_name': 'Wimberley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hays', 'locality_code': '209', 'latitude': 30.0265, 'longitude': -98.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79014', 'place_name': 'Canadian', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hemphill', 'locality_code': '211', 'latitude': 35.9045, 'longitude': -100.3841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75124', 'place_name': 'Eustace', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.2965, 'longitude': -96.0137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75143', 'place_name': 'Kemp', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.2486, 'longitude': -96.2161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75148', 'place_name': 'Malakoff', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.1705, 'longitude': -96.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75163', 'place_name': 'Trinidad', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.1383, 'longitude': -96.0831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75751', 'place_name': 'Athens', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.1935, 'longitude': -95.8432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75752', 'place_name': 'Athens', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.2151, 'longitude': -95.79, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75756', 'place_name': 'Brownsboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.304, 'longitude': -95.6, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75758', 'place_name': 'Chandler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.2572, 'longitude': -95.5393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75770', 'place_name': 'Larue', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.1608, 'longitude': -95.5927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75778', 'place_name': 'Murchison', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.3257, 'longitude': -95.7737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75782', 'place_name': 'Poynor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Henderson', 'locality_code': '213', 'latitude': 32.0797, 'longitude': -95.5938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78501', 'place_name': 'Mcallen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2154, 'longitude': -98.2359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78502', 'place_name': 'Mcallen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2567, 'longitude': -98.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78503', 'place_name': 'Mcallen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1771, 'longitude': -98.252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78504', 'place_name': 'Mcallen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2556, 'longitude': -98.2303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78505', 'place_name': 'Mcallen', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2034, 'longitude': -98.23, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78516', 'place_name': 'Alamo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1906, 'longitude': -98.1164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78537', 'place_name': 'Donna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1671, 'longitude': -98.0529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78538', 'place_name': 'Edcouch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.3328, 'longitude': -97.9622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78539', 'place_name': 'Edinburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2792, 'longitude': -98.1832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78540', 'place_name': 'Edinburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.3017, 'longitude': -98.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78541', 'place_name': 'Edinburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.4481, 'longitude': -98.2842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78542', 'place_name': 'Edinburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.4661, 'longitude': -98.0695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78543', 'place_name': 'Elsa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2974, 'longitude': -97.9884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78549', 'place_name': 'Hargill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.4671, 'longitude': -98.0393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78557', 'place_name': 'Hidalgo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1028, 'longitude': -98.2536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78558', 'place_name': 'La Blanca', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2928, 'longitude': -98.0378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78560', 'place_name': 'La Joya', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2426, 'longitude': -98.4747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78562', 'place_name': 'La Villa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2999, 'longitude': -97.9247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78563', 'place_name': 'Linn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.6279, 'longitude': -98.2498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78565', 'place_name': 'Los Ebanos', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2434, 'longitude': -98.5617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78570', 'place_name': 'Mercedes', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1513, 'longitude': -97.9185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78572', 'place_name': 'Mission', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2159, 'longitude': -98.3253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78573', 'place_name': 'Mission', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2937, 'longitude': -98.3008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78576', 'place_name': 'Penitas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.278, 'longitude': -98.4469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78577', 'place_name': 'Pharr', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1771, 'longitude': -98.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78579', 'place_name': 'Progreso', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.0922, 'longitude': -97.9533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78589', 'place_name': 'San Juan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.2044, 'longitude': -98.1537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78595', 'place_name': 'Sullivan City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.272, 'longitude': -98.5627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78596', 'place_name': 'Weslaco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1694, 'longitude': -97.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78599', 'place_name': 'Weslaco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hidalgo', 'locality_code': '215', 'latitude': 26.1595, 'longitude': -97.9908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76055', 'place_name': 'Itasca', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 32.1636, 'longitude': -97.146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76621', 'place_name': 'Abbott', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.8916, 'longitude': -97.0671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76622', 'place_name': 'Aquilla', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.8589, 'longitude': -97.2258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76627', 'place_name': 'Blum', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 32.1052, 'longitude': -97.3652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76628', 'place_name': 'Brandon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 32.0457, 'longitude': -96.9606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76631', 'place_name': 'Bynum', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.9907, 'longitude': -96.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76636', 'place_name': 'Covington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 32.1595, 'longitude': -97.2591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76645', 'place_name': 'Hillsboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 32.0149, 'longitude': -97.1198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76648', 'place_name': 'Hubbard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.8436, 'longitude': -96.8, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76650', 'place_name': 'Irene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.9921, 'longitude': -96.8714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76660', 'place_name': 'Malone', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.924, 'longitude': -96.8907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76666', 'place_name': 'Mertens', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 32.0275, 'longitude': -96.8981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76673', 'place_name': 'Mount Calm', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.7575, 'longitude': -96.8944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76676', 'place_name': 'Penelope', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.8551, 'longitude': -96.9372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76692', 'place_name': 'Whitney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hill', 'locality_code': '217', 'latitude': 31.9713, 'longitude': -97.3463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79313', 'place_name': 'Anton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.8043, 'longitude': -102.1652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79336', 'place_name': 'Levelland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.5788, 'longitude': -102.3676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79338', 'place_name': 'Levelland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.5932, 'longitude': -102.3627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79353', 'place_name': 'Pep', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.8104, 'longitude': -102.5656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79358', 'place_name': 'Ropesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.4575, 'longitude': -102.1584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79367', 'place_name': 'Smyer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.5918, 'longitude': -102.1692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79372', 'place_name': 'Sundown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.4482, 'longitude': -102.4898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79380', 'place_name': 'Whitharral', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hockley', 'locality_code': '219', 'latitude': 33.7354, 'longitude': -102.3419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76035', 'place_name': 'Cresson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hood', 'locality_code': '221', 'latitude': 32.5343, 'longitude': -97.6158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76048', 'place_name': 'Granbury', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hood', 'locality_code': '221', 'latitude': 32.425, 'longitude': -97.7742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76049', 'place_name': 'Granbury', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hood', 'locality_code': '221', 'latitude': 32.4488, 'longitude': -97.7285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76462', 'place_name': 'Lipan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hood', 'locality_code': '221', 'latitude': 32.5072, 'longitude': -97.9536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76467', 'place_name': 'Paluxy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hood', 'locality_code': '221', 'latitude': 32.2707, 'longitude': -97.9075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76476', 'place_name': 'Tolar', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hood', 'locality_code': '221', 'latitude': 32.3772, 'longitude': -97.8802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75420', 'place_name': 'Brashear', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.1155, 'longitude': -95.7345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75431', 'place_name': 'Como', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.0107, 'longitude': -95.4734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75433', 'place_name': 'Cumby', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.1118, 'longitude': -95.7945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75437', 'place_name': 'Dike', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.2648, 'longitude': -95.4423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75471', 'place_name': 'Pickton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.0519, 'longitude': -95.3851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75478', 'place_name': 'Saltillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.1767, 'longitude': -95.3433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75481', 'place_name': 'Sulphur Bluff', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.3334, 'longitude': -95.374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75482', 'place_name': 'Sulphur Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.1345, 'longitude': -95.5922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75483', 'place_name': 'Sulphur Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hopkins', 'locality_code': '223', 'latitude': 33.1384, 'longitude': -95.6011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75835', 'place_name': 'Crockett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Houston', 'locality_code': '225', 'latitude': 31.3208, 'longitude': -95.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75844', 'place_name': 'Grapeland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Houston', 'locality_code': '225', 'latitude': 31.4972, 'longitude': -95.4447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75847', 'place_name': 'Kennard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Houston', 'locality_code': '225', 'latitude': 31.3384, 'longitude': -95.1541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75849', 'place_name': 'Latexo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Houston', 'locality_code': '225', 'latitude': 31.3952, 'longitude': -95.4741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75851', 'place_name': 'Lovelady', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Houston', 'locality_code': '225', 'latitude': 31.0564, 'longitude': -95.5501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75858', 'place_name': 'Ratcliff', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Houston', 'locality_code': '225', 'latitude': 31.3916, 'longitude': -95.1397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79511', 'place_name': 'Coahoma', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Howard', 'locality_code': '227', 'latitude': 32.2942, 'longitude': -101.3197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79720', 'place_name': 'Big Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Howard', 'locality_code': '227', 'latitude': 32.2787, 'longitude': -101.4578, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79721', 'place_name': 'Big Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Howard', 'locality_code': '227', 'latitude': 32.2733, 'longitude': -101.374, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79733', 'place_name': 'Forsan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Howard', 'locality_code': '227', 'latitude': 32.1105, 'longitude': -101.3669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79748', 'place_name': 'Knott', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Howard', 'locality_code': '227', 'latitude': 32.4125, 'longitude': -101.6517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79837', 'place_name': 'Dell City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hudspeth', 'locality_code': '229', 'latitude': 31.924, 'longitude': -105.2099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79839', 'place_name': 'Fort Hancock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hudspeth', 'locality_code': '229', 'latitude': 31.2985, 'longitude': -105.8452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79847', 'place_name': 'Salt Flat', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hudspeth', 'locality_code': '229', 'latitude': 31.8244, 'longitude': -105.2212, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79851', 'place_name': 'Sierra Blanca', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hudspeth', 'locality_code': '229', 'latitude': 31.1938, 'longitude': -105.3219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75135', 'place_name': 'Caddo Mills', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.0683, 'longitude': -96.2391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75401', 'place_name': 'Greenville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.1854, 'longitude': -96.1304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75402', 'place_name': 'Greenville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.1047, 'longitude': -96.0927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75403', 'place_name': 'Greenville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.2185, 'longitude': -96.0487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75404', 'place_name': 'Greenville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.0563, 'longitude': -96.081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75422', 'place_name': 'Campbell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.151, 'longitude': -95.9439, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75423', 'place_name': 'Celeste', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.2649, 'longitude': -96.2076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75428', 'place_name': 'Commerce', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.2493, 'longitude': -95.9097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75429', 'place_name': 'Commerce', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.2377, 'longitude': -95.9089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75453', 'place_name': 'Lone Oak', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 32.9916, 'longitude': -95.9434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75458', 'place_name': 'Merit', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.2427, 'longitude': -96.2916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75474', 'place_name': 'Quinlan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 32.8983, 'longitude': -96.1261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75496', 'place_name': 'Wolfe City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hunt', 'locality_code': '231', 'latitude': 33.3605, 'longitude': -96.0691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79007', 'place_name': 'Borger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hutchinson', 'locality_code': '233', 'latitude': 35.6678, 'longitude': -101.3974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79008', 'place_name': 'Borger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hutchinson', 'locality_code': '233', 'latitude': 35.6678, 'longitude': -101.3974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79036', 'place_name': 'Fritch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hutchinson', 'locality_code': '233', 'latitude': 35.6441, 'longitude': -101.5845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79078', 'place_name': 'Sanford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hutchinson', 'locality_code': '233', 'latitude': 35.702, 'longitude': -101.5346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79083', 'place_name': 'Stinnett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Hutchinson', 'locality_code': '233', 'latitude': 35.8377, 'longitude': -101.45, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76930', 'place_name': 'Barnhart', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Irion', 'locality_code': '235', 'latitude': 31.1596, 'longitude': -101.1918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76941', 'place_name': 'Mertzon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Irion', 'locality_code': '235', 'latitude': 31.2829, 'longitude': -100.8221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76427', 'place_name': 'Bryson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jack', 'locality_code': '237', 'latitude': 33.1615, 'longitude': -98.3874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76458', 'place_name': 'Jacksboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jack', 'locality_code': '237', 'latitude': 33.2347, 'longitude': -98.1681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76459', 'place_name': 'Jermyn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jack', 'locality_code': '237', 'latitude': 33.2636, 'longitude': -98.3931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76486', 'place_name': 'Perrin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jack', 'locality_code': '237', 'latitude': 33.034, 'longitude': -98.0692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77957', 'place_name': 'Edna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jackson', 'locality_code': '239', 'latitude': 28.9527, 'longitude': -96.6488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77961', 'place_name': 'Francitas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jackson', 'locality_code': '239', 'latitude': 28.8597, 'longitude': -96.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77962', 'place_name': 'Ganado', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jackson', 'locality_code': '239', 'latitude': 29.0308, 'longitude': -96.5031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77969', 'place_name': 'La Salle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jackson', 'locality_code': '239', 'latitude': 28.7671, 'longitude': -96.6492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77970', 'place_name': 'La Ward', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jackson', 'locality_code': '239', 'latitude': 28.8439, 'longitude': -96.4641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77971', 'place_name': 'Lolita', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jackson', 'locality_code': '239', 'latitude': 28.7724, 'longitude': -96.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77991', 'place_name': 'Vanderbilt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jackson', 'locality_code': '239', 'latitude': 28.8068, 'longitude': -96.6042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75951', 'place_name': 'Jasper', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jasper', 'locality_code': '241', 'latitude': 30.8673, 'longitude': -93.9977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75956', 'place_name': 'Kirbyville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jasper', 'locality_code': '241', 'latitude': 30.6583, 'longitude': -93.8984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77612', 'place_name': 'Buna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jasper', 'locality_code': '241', 'latitude': 30.4132, 'longitude': -93.9913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77615', 'place_name': 'Evadale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jasper', 'locality_code': '241', 'latitude': 30.3129, 'longitude': -94.0731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79734', 'place_name': 'Fort Davis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jeff Davis', 'locality_code': '243', 'latitude': 30.6131, 'longitude': -103.9364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79854', 'place_name': 'Valentine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jeff Davis', 'locality_code': '243', 'latitude': 30.62, 'longitude': -104.4811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77613', 'place_name': 'China', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.0108, 'longitude': -94.363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77619', 'place_name': 'Groves', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.9448, 'longitude': -93.9152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77622', 'place_name': 'Hamshire', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.8668, 'longitude': -94.3187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77627', 'place_name': 'Nederland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.9716, 'longitude': -94.0012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77629', 'place_name': 'Nome', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.0015, 'longitude': -94.4189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77640', 'place_name': 'Port Arthur', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.8709, 'longitude': -93.9643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77641', 'place_name': 'Port Arthur', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.8476, 'longitude': -94.1297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77642', 'place_name': 'Port Arthur', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.9212, 'longitude': -93.927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77643', 'place_name': 'Port Arthur', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.9621, 'longitude': -93.8679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77651', 'place_name': 'Port Neches', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.977, 'longitude': -93.9626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77655', 'place_name': 'Sabine Pass', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 29.7336, 'longitude': -93.8943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77701', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.0688, 'longitude': -94.1039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77702', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.0871, 'longitude': -94.1254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77703', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.1132, 'longitude': -94.1197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77704', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.1236, 'longitude': -94.1539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77705', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.0211, 'longitude': -94.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77706', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.0948, 'longitude': -94.1648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77707', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.0686, 'longitude': -94.1755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77708', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.14, 'longitude': -94.1604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77710', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.086, 'longitude': -94.1018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77713', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.085, 'longitude': -94.2607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77720', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.086, 'longitude': -94.1018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77725', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.086, 'longitude': -94.1018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77726', 'place_name': 'Beaumont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jefferson', 'locality_code': '245', 'latitude': 30.1118, 'longitude': -94.1901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78360', 'place_name': 'Guerra', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Hogg', 'locality_code': '247', 'latitude': 26.8831, 'longitude': -98.8936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78361', 'place_name': 'Hebbronville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Hogg', 'locality_code': '247', 'latitude': 27.2997, 'longitude': -98.6829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78332', 'place_name': 'Alice', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Wells', 'locality_code': '249', 'latitude': 27.7432, 'longitude': -98.0836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78333', 'place_name': 'Alice', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Wells', 'locality_code': '249', 'latitude': 27.7522, 'longitude': -98.0697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78342', 'place_name': 'Ben Bolt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Wells', 'locality_code': '249', 'latitude': 27.6475, 'longitude': -98.0814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78372', 'place_name': 'Orange Grove', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Wells', 'locality_code': '249', 'latitude': 27.9487, 'longitude': -97.9838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78375', 'place_name': 'Premont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Wells', 'locality_code': '249', 'latitude': 27.3544, 'longitude': -98.133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78383', 'place_name': 'Sandia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jim Wells', 'locality_code': '249', 'latitude': 28.025, 'longitude': -97.8705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76009', 'place_name': 'Alvarado', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.4395, 'longitude': -97.213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76028', 'place_name': 'Burleson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.5316, 'longitude': -97.309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76031', 'place_name': 'Cleburne', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.3485, 'longitude': -97.3311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76033', 'place_name': 'Cleburne', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.3509, 'longitude': -97.4103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76044', 'place_name': 'Godley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.4282, 'longitude': -97.5349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76050', 'place_name': 'Grandview', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.2704, 'longitude': -97.1792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76058', 'place_name': 'Joshua', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.4663, 'longitude': -97.4011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76059', 'place_name': 'Keene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.3937, 'longitude': -97.3287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76061', 'place_name': 'Lillian', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.5065, 'longitude': -97.1875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76084', 'place_name': 'Venus', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.433, 'longitude': -97.1087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76093', 'place_name': 'Rio Vista', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.2532, 'longitude': -97.3678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76097', 'place_name': 'Burleson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Johnson', 'locality_code': '251', 'latitude': 32.5421, 'longitude': -97.3208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79501', 'place_name': 'Anson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jones', 'locality_code': '253', 'latitude': 32.7489, 'longitude': -99.8953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79503', 'place_name': 'Avoca', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jones', 'locality_code': '253', 'latitude': 32.8832, 'longitude': -99.6964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79520', 'place_name': 'Hamlin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jones', 'locality_code': '253', 'latitude': 32.8799, 'longitude': -100.128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79525', 'place_name': 'Hawley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jones', 'locality_code': '253', 'latitude': 32.6423, 'longitude': -99.9239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79533', 'place_name': 'Lueders', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jones', 'locality_code': '253', 'latitude': 32.8712, 'longitude': -99.5783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79553', 'place_name': 'Stamford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Jones', 'locality_code': '253', 'latitude': 32.9453, 'longitude': -99.7859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78111', 'place_name': 'Ecleto', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 29.0464, 'longitude': -97.7514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78113', 'place_name': 'Falls City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 28.9814, 'longitude': -98.0156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78116', 'place_name': 'Gillett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 29.0514, 'longitude': -97.8343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78117', 'place_name': 'Hobson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 28.9445, 'longitude': -97.9707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78118', 'place_name': 'Karnes City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 28.8828, 'longitude': -97.9071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78119', 'place_name': 'Kenedy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 28.8046, 'longitude': -97.8456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78144', 'place_name': 'Panna Maria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 28.9562, 'longitude': -97.8982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78151', 'place_name': 'Runge', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Karnes', 'locality_code': '255', 'latitude': 28.8876, 'longitude': -97.7138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75114', 'place_name': 'Crandall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.6279, 'longitude': -96.4558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75118', 'place_name': 'Elmo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.5996, 'longitude': -96.3027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75126', 'place_name': 'Forney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.7491, 'longitude': -96.4598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75142', 'place_name': 'Kaufman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.546, 'longitude': -96.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75147', 'place_name': 'Mabank', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.3685, 'longitude': -96.0685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75156', 'place_name': 'Mabank', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.2972, 'longitude': -96.1184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75157', 'place_name': 'Rosser', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.4626, 'longitude': -96.4533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75158', 'place_name': 'Scurry', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.4818, 'longitude': -96.3925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75160', 'place_name': 'Terrell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.7515, 'longitude': -96.2831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75161', 'place_name': 'Terrell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kaufman', 'locality_code': '257', 'latitude': 32.7332, 'longitude': -96.195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78004', 'place_name': 'Bergheim', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kendall', 'locality_code': '259', 'latitude': 29.8274, 'longitude': -98.5753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78006', 'place_name': 'Boerne', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kendall', 'locality_code': '259', 'latitude': 29.8931, 'longitude': -98.6857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78013', 'place_name': 'Comfort', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kendall', 'locality_code': '259', 'latitude': 29.9677, 'longitude': -98.905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78027', 'place_name': 'Kendalia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kendall', 'locality_code': '259', 'latitude': 29.9406, 'longitude': -98.5166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78074', 'place_name': 'Waring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kendall', 'locality_code': '259', 'latitude': 29.9523, 'longitude': -98.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78338', 'place_name': 'Armstrong', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kenedy', 'locality_code': '261', 'latitude': 26.8698, 'longitude': -97.7698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78385', 'place_name': 'Sarita', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kenedy', 'locality_code': '261', 'latitude': 27.1496, 'longitude': -97.8576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79518', 'place_name': 'Girard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kent', 'locality_code': '263', 'latitude': 33.3632, 'longitude': -100.6937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79528', 'place_name': 'Jayton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kent', 'locality_code': '263', 'latitude': 33.2518, 'longitude': -100.5825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78010', 'place_name': 'Center Point', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kerr', 'locality_code': '265', 'latitude': 29.9441, 'longitude': -99.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78024', 'place_name': 'Hunt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kerr', 'locality_code': '265', 'latitude': 30.0027, 'longitude': -99.4823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78025', 'place_name': 'Ingram', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kerr', 'locality_code': '265', 'latitude': 30.0731, 'longitude': -99.269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78028', 'place_name': 'Kerrville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kerr', 'locality_code': '265', 'latitude': 30.0416, 'longitude': -99.1408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78029', 'place_name': 'Kerrville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kerr', 'locality_code': '265', 'latitude': 30.0332, 'longitude': -99.141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78058', 'place_name': 'Mountain Home', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kerr', 'locality_code': '265', 'latitude': 30.1725, 'longitude': -99.485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76849', 'place_name': 'Junction', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kimble', 'locality_code': '267', 'latitude': 30.4754, 'longitude': -99.7473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76854', 'place_name': 'London', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kimble', 'locality_code': '267', 'latitude': 30.6768, 'longitude': -99.5765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76874', 'place_name': 'Roosevelt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kimble', 'locality_code': '267', 'latitude': 30.47, 'longitude': -100.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79236', 'place_name': 'Guthrie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'King', 'locality_code': '269', 'latitude': 33.6206, 'longitude': -100.3229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78832', 'place_name': 'Brackettville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kinney', 'locality_code': '271', 'latitude': 29.3096, 'longitude': -100.4155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78363', 'place_name': 'Kingsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kleberg', 'locality_code': '273', 'latitude': 27.4229, 'longitude': -97.8407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78364', 'place_name': 'Kingsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kleberg', 'locality_code': '273', 'latitude': 27.5159, 'longitude': -97.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78379', 'place_name': 'Riviera', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Kleberg', 'locality_code': '273', 'latitude': 27.3217, 'longitude': -97.7787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76363', 'place_name': 'Goree', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Knox', 'locality_code': '275', 'latitude': 33.4748, 'longitude': -99.5258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76371', 'place_name': 'Munday', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Knox', 'locality_code': '275', 'latitude': 33.4561, 'longitude': -99.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79505', 'place_name': 'Benjamin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Knox', 'locality_code': '275', 'latitude': 33.584, 'longitude': -99.7923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79529', 'place_name': 'Knox City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Knox', 'locality_code': '275', 'latitude': 33.4183, 'longitude': -99.8137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75411', 'place_name': 'Arthur City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.8643, 'longitude': -95.6111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75416', 'place_name': 'Blossom', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.6945, 'longitude': -95.3823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75421', 'place_name': 'Brookston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.6246, 'longitude': -95.6888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75425', 'place_name': 'Chicota', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.869, 'longitude': -95.5711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75434', 'place_name': 'Cunningham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.409, 'longitude': -95.3711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75435', 'place_name': 'Deport', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.5221, 'longitude': -95.3654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75460', 'place_name': 'Paris', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.6581, 'longitude': -95.5379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75461', 'place_name': 'Paris', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.6609, 'longitude': -95.5555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75462', 'place_name': 'Paris', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.6805, 'longitude': -95.4905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75468', 'place_name': 'Pattonville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.5702, 'longitude': -95.3908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75470', 'place_name': 'Petty', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.6098, 'longitude': -95.7891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75473', 'place_name': 'Powderly', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.7779, 'longitude': -95.5307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75477', 'place_name': 'Roxton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.5429, 'longitude': -95.7416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75486', 'place_name': 'Sumner', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamar', 'locality_code': '277', 'latitude': 33.7589, 'longitude': -95.6807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79031', 'place_name': 'Earth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 34.2415, 'longitude': -102.4213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79064', 'place_name': 'Olton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 34.1844, 'longitude': -102.1414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79082', 'place_name': 'Springlake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 34.2393, 'longitude': -102.309, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79312', 'place_name': 'Amherst', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 33.9976, 'longitude': -102.4416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79326', 'place_name': 'Fieldton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 34.053, 'longitude': -102.206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79339', 'place_name': 'Littlefield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 33.9212, 'longitude': -102.3207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79369', 'place_name': 'Spade', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 33.9256, 'longitude': -102.1564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79371', 'place_name': 'Sudan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lamb', 'locality_code': '279', 'latitude': 34.0697, 'longitude': -102.5255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76539', 'place_name': 'Kempner', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lampasas', 'locality_code': '281', 'latitude': 31.0887, 'longitude': -98.0099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76550', 'place_name': 'Lampasas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lampasas', 'locality_code': '281', 'latitude': 31.068, 'longitude': -98.1834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76824', 'place_name': 'Bend', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lampasas', 'locality_code': '281', 'latitude': 31.1123, 'longitude': -98.4821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76853', 'place_name': 'Lometa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lampasas', 'locality_code': '281', 'latitude': 31.2167, 'longitude': -98.4006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78001', 'place_name': 'Artesia Wells', 'state': 'Texas', 'state_ab': 'TX', 'county': 'La Salle', 'locality_code': '283', 'latitude': 28.2639, 'longitude': -99.2802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78014', 'place_name': 'Cotulla', 'state': 'Texas', 'state_ab': 'TX', 'county': 'La Salle', 'locality_code': '283', 'latitude': 28.4398, 'longitude': -99.2328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78019', 'place_name': 'Encinal', 'state': 'Texas', 'state_ab': 'TX', 'county': 'La Salle', 'locality_code': '283', 'latitude': 28.0405, 'longitude': -99.3563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78021', 'place_name': 'Fowlerton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'La Salle', 'locality_code': '283', 'latitude': 28.4887, 'longitude': -98.8518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77964', 'place_name': 'Hallettsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lavaca', 'locality_code': '285', 'latitude': 29.4426, 'longitude': -96.9234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77975', 'place_name': 'Moulton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lavaca', 'locality_code': '285', 'latitude': 29.57, 'longitude': -97.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77984', 'place_name': 'Shiner', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lavaca', 'locality_code': '285', 'latitude': 29.428, 'longitude': -97.164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77986', 'place_name': 'Sublime', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lavaca', 'locality_code': '285', 'latitude': 29.4876, 'longitude': -96.7946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77987', 'place_name': 'Sweet Home', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lavaca', 'locality_code': '285', 'latitude': 29.3426, 'longitude': -97.0756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77995', 'place_name': 'Yoakum', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lavaca', 'locality_code': '285', 'latitude': 29.284, 'longitude': -97.1306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77853', 'place_name': 'Dime Box', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lee', 'locality_code': '287', 'latitude': 30.3579, 'longitude': -96.8248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78942', 'place_name': 'Giddings', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lee', 'locality_code': '287', 'latitude': 30.1777, 'longitude': -96.9332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78947', 'place_name': 'Lexington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lee', 'locality_code': '287', 'latitude': 30.4191, 'longitude': -97.0524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78948', 'place_name': 'Lincoln', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lee', 'locality_code': '287', 'latitude': 30.3177, 'longitude': -96.9702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75831', 'place_name': 'Buffalo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.4121, 'longitude': -95.9904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75833', 'place_name': 'Centerville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.272, 'longitude': -95.9213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75846', 'place_name': 'Jewett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.3739, 'longitude': -96.1918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75850', 'place_name': 'Leona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.1421, 'longitude': -95.9284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75855', 'place_name': 'Oakwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.5849, 'longitude': -95.8491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77850', 'place_name': 'Concord', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.3138, 'longitude': -95.9935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77855', 'place_name': 'Flynn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.1593, 'longitude': -96.1234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77865', 'place_name': 'Marquez', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.2309, 'longitude': -96.2375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77871', 'place_name': 'Normangee', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Leon', 'locality_code': '289', 'latitude': 31.0705, 'longitude': -96.125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77327', 'place_name': 'Cleveland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.33, 'longitude': -95.0202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77328', 'place_name': 'Cleveland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.3963, 'longitude': -95.194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77368', 'place_name': 'Romayor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.4513, 'longitude': -94.8433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77369', 'place_name': 'Rye', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.4596, 'longitude': -94.7436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77533', 'place_name': 'Daisetta', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.1133, 'longitude': -94.643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77535', 'place_name': 'Dayton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.0102, 'longitude': -94.8787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77538', 'place_name': 'Devers', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 29.9978, 'longitude': -94.5746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77561', 'place_name': 'Hardin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.151, 'longitude': -94.7338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77564', 'place_name': 'Hull', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.1463, 'longitude': -94.6424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77575', 'place_name': 'Liberty', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.0946, 'longitude': -94.7378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77582', 'place_name': 'Raywood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Liberty', 'locality_code': '291', 'latitude': 30.0542, 'longitude': -94.6764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76635', 'place_name': 'Coolidge', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Limestone', 'locality_code': '293', 'latitude': 31.7438, 'longitude': -96.6577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76642', 'place_name': 'Groesbeck', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Limestone', 'locality_code': '293', 'latitude': 31.5357, 'longitude': -96.5234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76653', 'place_name': 'Kosse', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Limestone', 'locality_code': '293', 'latitude': 31.3147, 'longitude': -96.6195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76667', 'place_name': 'Mexia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Limestone', 'locality_code': '293', 'latitude': 31.6784, 'longitude': -96.4952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76678', 'place_name': 'Prairie Hill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Limestone', 'locality_code': '293', 'latitude': 31.6591, 'longitude': -96.8094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76686', 'place_name': 'Tehuacana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Limestone', 'locality_code': '293', 'latitude': 31.7504, 'longitude': -96.5416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76687', 'place_name': 'Thornton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Limestone', 'locality_code': '293', 'latitude': 31.4083, 'longitude': -96.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79005', 'place_name': 'Booker', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lipscomb', 'locality_code': '295', 'latitude': 36.4429, 'longitude': -100.5238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79024', 'place_name': 'Darrouzett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lipscomb', 'locality_code': '295', 'latitude': 36.4453, 'longitude': -100.3254, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79034', 'place_name': 'Follett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lipscomb', 'locality_code': '295', 'latitude': 36.4309, 'longitude': -100.2068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79046', 'place_name': 'Higgins', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lipscomb', 'locality_code': '295', 'latitude': 36.1365, 'longitude': -100.0952, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79056', 'place_name': 'Lipscomb', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lipscomb', 'locality_code': '295', 'latitude': 36.223, 'longitude': -100.2702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78022', 'place_name': 'George West', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Live Oak', 'locality_code': '297', 'latitude': 28.3204, 'longitude': -98.1162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78060', 'place_name': 'Oakville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Live Oak', 'locality_code': '297', 'latitude': 28.4492, 'longitude': -98.1019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78071', 'place_name': 'Three Rivers', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Live Oak', 'locality_code': '297', 'latitude': 28.4756, 'longitude': -98.1782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78075', 'place_name': 'Whitsett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Live Oak', 'locality_code': '297', 'latitude': 28.6373, 'longitude': -98.2565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78350', 'place_name': 'Dinero', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Live Oak', 'locality_code': '297', 'latitude': 28.2264, 'longitude': -97.9617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76831', 'place_name': 'Castell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.701, 'longitude': -98.9564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76885', 'place_name': 'Valley Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.866, 'longitude': -98.8357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78607', 'place_name': 'Bluffton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.8256, 'longitude': -98.515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78609', 'place_name': 'Buchanan Dam', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.7538, 'longitude': -98.4295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78639', 'place_name': 'Kingsland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.6662, 'longitude': -98.4475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78643', 'place_name': 'Llano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.7151, 'longitude': -98.6109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78657', 'place_name': 'Horseshoe Bay', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.5443, 'longitude': -98.3739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78672', 'place_name': 'Tow', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Llano', 'locality_code': '299', 'latitude': 30.8609, 'longitude': -98.4596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79754', 'place_name': 'Mentone', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Loving', 'locality_code': '301', 'latitude': 31.7068, 'longitude': -103.5988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79329', 'place_name': 'Idalou', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.6504, 'longitude': -101.6786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79350', 'place_name': 'New Deal', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.7296, 'longitude': -101.8355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79363', 'place_name': 'Shallowater', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.6919, 'longitude': -101.9836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79364', 'place_name': 'Slaton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.4373, 'longitude': -101.6435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79366', 'place_name': 'Ransom Canyon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5334, 'longitude': -101.6796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79382', 'place_name': 'Wolfforth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5059, 'longitude': -102.0091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79401', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5865, 'longitude': -101.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79402', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5922, 'longitude': -101.8511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79403', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.6196, 'longitude': -101.8098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79404', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.526, 'longitude': -101.8333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79406', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5819, 'longitude': -101.8778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79407', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5684, 'longitude': -101.9423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79408', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5659, 'longitude': -101.9267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79409', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5779, 'longitude': -101.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79410', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5693, 'longitude': -101.8904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79411', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5704, 'longitude': -101.8626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79412', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5463, 'longitude': -101.8577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79413', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5466, 'longitude': -101.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79414', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5497, 'longitude': -101.9187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79415', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.6021, 'longitude': -101.876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79416', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5924, 'longitude': -101.9367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79423', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5146, 'longitude': -101.8795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79424', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5159, 'longitude': -101.9344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79430', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.61, 'longitude': -101.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79452', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.61, 'longitude': -101.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79453', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5779, 'longitude': -101.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79457', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.5779, 'longitude': -101.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79464', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.4896, 'longitude': -102.0109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79490', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.61, 'longitude': -101.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79491', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.61, 'longitude': -101.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79493', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.61, 'longitude': -101.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79499', 'place_name': 'Lubbock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lubbock', 'locality_code': '303', 'latitude': 33.61, 'longitude': -101.8213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79351', 'place_name': 'Odonnell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lynn', 'locality_code': '305', 'latitude': 32.9773, 'longitude': -101.8271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79373', 'place_name': 'Tahoka', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lynn', 'locality_code': '305', 'latitude': 33.1988, 'longitude': -101.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79381', 'place_name': 'Wilson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lynn', 'locality_code': '305', 'latitude': 33.3299, 'longitude': -101.7122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79383', 'place_name': 'New Home', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Lynn', 'locality_code': '305', 'latitude': 33.3451, 'longitude': -101.9203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76825', 'place_name': 'Brady', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McCulloch', 'locality_code': '307', 'latitude': 31.1509, 'longitude': -99.3372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76836', 'place_name': 'Doole', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McCulloch', 'locality_code': '307', 'latitude': 31.3957, 'longitude': -99.599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76852', 'place_name': 'Lohn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McCulloch', 'locality_code': '307', 'latitude': 31.3173, 'longitude': -99.3833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76858', 'place_name': 'Melvin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McCulloch', 'locality_code': '307', 'latitude': 31.1952, 'longitude': -99.5798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76872', 'place_name': 'Rochelle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McCulloch', 'locality_code': '307', 'latitude': 31.3, 'longitude': -99.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76887', 'place_name': 'Voca', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McCulloch', 'locality_code': '307', 'latitude': 30.9959, 'longitude': -99.1682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76524', 'place_name': 'Eddy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.3088, 'longitude': -97.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76557', 'place_name': 'Moody', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.2533, 'longitude': -97.41, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76624', 'place_name': 'Axtell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.661, 'longitude': -96.9882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76630', 'place_name': 'Bruceville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.3267, 'longitude': -97.2342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76633', 'place_name': 'China Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.6673, 'longitude': -97.3002, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '76638', 'place_name': 'Crawford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5598, 'longitude': -97.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76640', 'place_name': 'Elm Mott', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.6725, 'longitude': -97.1138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76643', 'place_name': 'Hewitt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.4582, 'longitude': -97.1966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76654', 'place_name': 'Leroy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.7316, 'longitude': -97.0178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76655', 'place_name': 'Lorena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.4093, 'longitude': -97.2302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76657', 'place_name': 'Mc Gregor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.4431, 'longitude': -97.3943, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '76664', 'place_name': 'Mart', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5458, 'longitude': -96.8381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76682', 'place_name': 'Riesel', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5002, 'longitude': -96.9476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76684', 'place_name': 'Ross', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.7173, 'longitude': -97.1188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76691', 'place_name': 'West', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.7754, 'longitude': -97.1258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76701', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5525, 'longitude': -97.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76702', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5475, 'longitude': -97.1443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76703', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5536, 'longitude': -97.2032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76704', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5773, 'longitude': -97.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76705', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.6403, 'longitude': -97.0963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76706', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5171, 'longitude': -97.1198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76707', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5527, 'longitude': -97.1588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76708', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5765, 'longitude': -97.1786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76710', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.535, 'longitude': -97.1899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76711', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5175, 'longitude': -97.1547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76712', 'place_name': 'Woodway', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5051, 'longitude': -97.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76714', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5536, 'longitude': -97.2032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76715', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5536, 'longitude': -97.2032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76716', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5536, 'longitude': -97.2032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76797', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5536, 'longitude': -97.2032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76798', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.547, 'longitude': -97.1203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76799', 'place_name': 'Waco', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McLennan', 'locality_code': '309', 'latitude': 31.5411, 'longitude': -97.1615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78007', 'place_name': 'Calliham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McMullen', 'locality_code': '311', 'latitude': 28.4805, 'longitude': -98.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78072', 'place_name': 'Tilden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'McMullen', 'locality_code': '311', 'latitude': 28.4198, 'longitude': -98.5693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75852', 'place_name': 'Midway', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Madison', 'locality_code': '313', 'latitude': 30.9806, 'longitude': -95.7089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77864', 'place_name': 'Madisonville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Madison', 'locality_code': '313', 'latitude': 30.9533, 'longitude': -95.9091, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77872', 'place_name': 'North Zulch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Madison', 'locality_code': '313', 'latitude': 30.9285, 'longitude': -96.0925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75564', 'place_name': 'Lodi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Marion', 'locality_code': '315', 'latitude': 32.8718, 'longitude': -94.2729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75657', 'place_name': 'Jefferson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Marion', 'locality_code': '315', 'latitude': 32.8059, 'longitude': -94.3655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79749', 'place_name': 'Lenorah', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Martin', 'locality_code': '317', 'latitude': 32.3046, 'longitude': -101.8762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79782', 'place_name': 'Stanton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Martin', 'locality_code': '317', 'latitude': 32.14, 'longitude': -101.8099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79783', 'place_name': 'Tarzan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Martin', 'locality_code': '317', 'latitude': 32.3575, 'longitude': -101.9607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76820', 'place_name': 'Art', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mason', 'locality_code': '319', 'latitude': 30.767, 'longitude': -99.0486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76842', 'place_name': 'Fredonia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mason', 'locality_code': '319', 'latitude': 30.9214, 'longitude': -99.1216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76856', 'place_name': 'Mason', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mason', 'locality_code': '319', 'latitude': 30.7434, 'longitude': -99.2261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76869', 'place_name': 'Pontotoc', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mason', 'locality_code': '319', 'latitude': 30.8906, 'longitude': -99.0212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77404', 'place_name': 'Bay City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.9828, 'longitude': -95.9694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77414', 'place_name': 'Bay City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.8636, 'longitude': -95.9173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77415', 'place_name': 'Cedar Lane', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.9386, 'longitude': -95.7366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77419', 'place_name': 'Blessing', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.8649, 'longitude': -96.218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77428', 'place_name': 'Collegeport', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.7253, 'longitude': -96.175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77440', 'place_name': 'Elmaton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.8864, 'longitude': -96.14, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77456', 'place_name': 'Markham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.9547, 'longitude': -96.0928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77457', 'place_name': 'Matagorda', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.6908, 'longitude': -95.9675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77458', 'place_name': 'Midfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.9362, 'longitude': -96.2265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77465', 'place_name': 'Palacios', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.715, 'longitude': -96.2154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77468', 'place_name': 'Pledger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 29.1825, 'longitude': -95.9086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77482', 'place_name': 'Van Vleck', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 29.016, 'longitude': -95.8905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77483', 'place_name': 'Wadsworth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Matagorda', 'locality_code': '321', 'latitude': 28.8259, 'longitude': -95.9046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78852', 'place_name': 'Eagle Pass', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Maverick', 'locality_code': '323', 'latitude': 28.7028, 'longitude': -100.4818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78853', 'place_name': 'Eagle Pass', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Maverick', 'locality_code': '323', 'latitude': 28.679, 'longitude': -100.4784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78860', 'place_name': 'El Indio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Maverick', 'locality_code': '323', 'latitude': 28.5119, 'longitude': -100.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78877', 'place_name': 'Quemado', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Maverick', 'locality_code': '323', 'latitude': 28.9256, 'longitude': -100.5912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78009', 'place_name': 'Castroville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.3553, 'longitude': -98.8824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78016', 'place_name': 'Devine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.1521, 'longitude': -98.909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78039', 'place_name': 'La Coste', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.3082, 'longitude': -98.8125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78056', 'place_name': 'Mico', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.5441, 'longitude': -98.9231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78059', 'place_name': 'Natalia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.2117, 'longitude': -98.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78066', 'place_name': 'Rio Medina', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.4612, 'longitude': -98.8694, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78850', 'place_name': 'D Hanis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.3398, 'longitude': -99.2835, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78861', 'place_name': 'Hondo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.3475, 'longitude': -99.1414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78886', 'place_name': 'Yancey', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Medina', 'locality_code': '325', 'latitude': 29.1404, 'longitude': -99.1428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76841', 'place_name': 'Fort Mc Kavett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Menard', 'locality_code': '327', 'latitude': 30.829, 'longitude': -100.0809, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '76848', 'place_name': 'Hext', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Menard', 'locality_code': '327', 'latitude': 30.8816, 'longitude': -99.554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76859', 'place_name': 'Menard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Menard', 'locality_code': '327', 'latitude': 30.9119, 'longitude': -99.7847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79701', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.9896, 'longitude': -102.0626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79702', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.9637, 'longitude': -102.0801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79703', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.9721, 'longitude': -102.1369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79704', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.8693, 'longitude': -102.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79705', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 32.0295, 'longitude': -102.0915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79706', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.8816, 'longitude': -102.0134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79707', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 32.0199, 'longitude': -102.1476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79708', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.8693, 'longitude': -102.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79710', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.8693, 'longitude': -102.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79711', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.9973, 'longitude': -102.0779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79712', 'place_name': 'Midland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Midland', 'locality_code': '329', 'latitude': 31.8693, 'longitude': -102.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76518', 'place_name': 'Buckholts', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.8858, 'longitude': -97.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76519', 'place_name': 'Burlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.9736, 'longitude': -96.9642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76520', 'place_name': 'Cameron', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.8527, 'longitude': -96.9766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76523', 'place_name': 'Davilla', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.7857, 'longitude': -97.275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76556', 'place_name': 'Milano', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.7304, 'longitude': -96.8807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76567', 'place_name': 'Rockdale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.6583, 'longitude': -97.0079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76577', 'place_name': 'Thorndale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.6082, 'longitude': -97.1764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77857', 'place_name': 'Gause', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Milam', 'locality_code': '331', 'latitude': 30.7833, 'longitude': -96.7237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76844', 'place_name': 'Goldthwaite', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mills', 'locality_code': '333', 'latitude': 31.4458, 'longitude': -98.5744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76864', 'place_name': 'Mullin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mills', 'locality_code': '333', 'latitude': 31.5748, 'longitude': -98.6635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76870', 'place_name': 'Priddy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mills', 'locality_code': '333', 'latitude': 31.641, 'longitude': -98.5276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76880', 'place_name': 'Star', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mills', 'locality_code': '333', 'latitude': 31.4685, 'longitude': -98.3161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79512', 'place_name': 'Colorado City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mitchell', 'locality_code': '335', 'latitude': 32.3987, 'longitude': -100.8609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79532', 'place_name': 'Loraine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mitchell', 'locality_code': '335', 'latitude': 32.4112, 'longitude': -100.7123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79565', 'place_name': 'Westbrook', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Mitchell', 'locality_code': '335', 'latitude': 32.3627, 'longitude': -101.043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76230', 'place_name': 'Bowie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montague', 'locality_code': '337', 'latitude': 33.5568, 'longitude': -97.8373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76239', 'place_name': 'Forestburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montague', 'locality_code': '337', 'latitude': 33.5398, 'longitude': -97.5848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76251', 'place_name': 'Montague', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montague', 'locality_code': '337', 'latitude': 33.6639, 'longitude': -97.7282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76255', 'place_name': 'Nocona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montague', 'locality_code': '337', 'latitude': 33.7982, 'longitude': -97.727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76261', 'place_name': 'Ringgold', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montague', 'locality_code': '337', 'latitude': 33.8164, 'longitude': -97.944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76265', 'place_name': 'Saint Jo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montague', 'locality_code': '337', 'latitude': 33.744, 'longitude': -97.5568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76270', 'place_name': 'Sunset', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montague', 'locality_code': '337', 'latitude': 33.4539, 'longitude': -97.7709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77301', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.3125, 'longitude': -95.4527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77302', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.2238, 'longitude': -95.3577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77303', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.3814, 'longitude': -95.3749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77304', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.3217, 'longitude': -95.5285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77305', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.2906, 'longitude': -95.3832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77306', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.2277, 'longitude': -95.2851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77316', 'place_name': 'Montgomery', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.3587, 'longitude': -95.6857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77318', 'place_name': 'Willis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.4416, 'longitude': -95.5394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77333', 'place_name': 'Dobbin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.3365, 'longitude': -95.7723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77353', 'place_name': 'Magnolia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.2094, 'longitude': -95.7508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77354', 'place_name': 'Magnolia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.2333, 'longitude': -95.5502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77355', 'place_name': 'Magnolia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1598, 'longitude': -95.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77356', 'place_name': 'Montgomery', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.4411, 'longitude': -95.7097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77357', 'place_name': 'New Caney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1579, 'longitude': -95.198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77362', 'place_name': 'Pinehurst', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1581, 'longitude': -95.6814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77365', 'place_name': 'Porter', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1237, 'longitude': -95.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77372', 'place_name': 'Splendora', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.2326, 'longitude': -95.1993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77378', 'place_name': 'Willis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.4441, 'longitude': -95.4506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77380', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1441, 'longitude': -95.4703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77381', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1716, 'longitude': -95.4985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77384', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.2257, 'longitude': -95.4924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77385', 'place_name': 'Conroe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1877, 'longitude': -95.4288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77386', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1288, 'longitude': -95.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77387', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.1199, 'longitude': -95.4247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77393', 'place_name': 'Spring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Montgomery', 'locality_code': '339', 'latitude': 30.329, 'longitude': -95.4635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79013', 'place_name': 'Cactus', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Moore', 'locality_code': '341', 'latitude': 36.0412, 'longitude': -102.0007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79029', 'place_name': 'Dumas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Moore', 'locality_code': '341', 'latitude': 35.8823, 'longitude': -101.968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79058', 'place_name': 'Masterson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Moore', 'locality_code': '341', 'latitude': 35.6359, 'longitude': -101.9602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79086', 'place_name': 'Sunray', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Moore', 'locality_code': '341', 'latitude': 36.0097, 'longitude': -101.8123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75568', 'place_name': 'Naples', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Morris', 'locality_code': '343', 'latitude': 33.1912, 'longitude': -94.6891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75571', 'place_name': 'Omaha', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Morris', 'locality_code': '343', 'latitude': 33.1808, 'longitude': -94.7639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75636', 'place_name': 'Cason', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Morris', 'locality_code': '343', 'latitude': 33.024, 'longitude': -94.8249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75638', 'place_name': 'Daingerfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Morris', 'locality_code': '343', 'latitude': 33.0313, 'longitude': -94.7359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75668', 'place_name': 'Lone Star', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Morris', 'locality_code': '343', 'latitude': 32.9252, 'longitude': -94.7049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79234', 'place_name': 'Flomot', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Motley', 'locality_code': '345', 'latitude': 34.2321, 'longitude': -101.0038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79244', 'place_name': 'Matador', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Motley', 'locality_code': '345', 'latitude': 34.0525, 'longitude': -100.8361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79256', 'place_name': 'Roaring Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Motley', 'locality_code': '345', 'latitude': 33.8977, 'longitude': -100.8528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75760', 'place_name': 'Cushing', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.7978, 'longitude': -94.8539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75788', 'place_name': 'Sacul', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.8254, 'longitude': -94.9189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75937', 'place_name': 'Chireno', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.5119, 'longitude': -94.4302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75943', 'place_name': 'Douglass', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.6578, 'longitude': -94.8696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75944', 'place_name': 'Etoile', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.3601, 'longitude': -94.4064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75946', 'place_name': 'Garrison', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.8111, 'longitude': -94.5266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75958', 'place_name': 'Martinsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.6427, 'longitude': -94.4141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75961', 'place_name': 'Nacogdoches', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.5611, 'longitude': -94.5, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75962', 'place_name': 'Nacogdoches', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.6995, 'longitude': -94.6074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75963', 'place_name': 'Nacogdoches', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.6046, 'longitude': -94.6641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75964', 'place_name': 'Nacogdoches', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.6737, 'longitude': -94.6932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75965', 'place_name': 'Nacogdoches', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.7195, 'longitude': -94.6168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75978', 'place_name': 'Woden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nacogdoches', 'locality_code': '347', 'latitude': 31.5037, 'longitude': -94.525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75102', 'place_name': 'Barry', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.1014, 'longitude': -96.6251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75105', 'place_name': 'Chatfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.2954, 'longitude': -96.3887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75109', 'place_name': 'Corsicana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 31.9937, 'longitude': -96.4199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75110', 'place_name': 'Corsicana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.0868, 'longitude': -96.4762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75144', 'place_name': 'Kerens', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.1275, 'longitude': -96.2298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75151', 'place_name': 'Corsicana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.0624, 'longitude': -96.4735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75153', 'place_name': 'Powell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.1196, 'longitude': -96.3327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76626', 'place_name': 'Blooming Grove', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.0758, 'longitude': -96.701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76639', 'place_name': 'Dawson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 31.8974, 'longitude': -96.7085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76641', 'place_name': 'Frost', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 32.0275, 'longitude': -96.7684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76679', 'place_name': 'Purdon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 31.9483, 'longitude': -96.5856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76681', 'place_name': 'Richland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Navarro', 'locality_code': '349', 'latitude': 31.9018, 'longitude': -96.4373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75928', 'place_name': 'Bon Wier', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Newton', 'locality_code': '351', 'latitude': 30.6876, 'longitude': -93.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75932', 'place_name': 'Burkeville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Newton', 'locality_code': '351', 'latitude': 31.0099, 'longitude': -93.6585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75933', 'place_name': 'Call', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Newton', 'locality_code': '351', 'latitude': 30.5741, 'longitude': -93.8334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75966', 'place_name': 'Newton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Newton', 'locality_code': '351', 'latitude': 30.8351, 'longitude': -93.7497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75977', 'place_name': 'Wiergate', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Newton', 'locality_code': '351', 'latitude': 31.0414, 'longitude': -93.8039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77614', 'place_name': 'Deweyville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Newton', 'locality_code': '351', 'latitude': 30.2894, 'longitude': -93.7488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79506', 'place_name': 'Blackwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nolan', 'locality_code': '353', 'latitude': 32.082, 'longitude': -100.3111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79535', 'place_name': 'Maryneal', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nolan', 'locality_code': '353', 'latitude': 32.2026, 'longitude': -100.4972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79537', 'place_name': 'Nolan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nolan', 'locality_code': '353', 'latitude': 32.2919, 'longitude': -100.2107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79545', 'place_name': 'Roscoe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nolan', 'locality_code': '353', 'latitude': 32.4276, 'longitude': -100.5391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79556', 'place_name': 'Sweetwater', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nolan', 'locality_code': '353', 'latitude': 32.4726, 'longitude': -100.3979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78330', 'place_name': 'Agua Dulce', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7817, 'longitude': -97.9086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78339', 'place_name': 'Banquete', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.8051, 'longitude': -97.7922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78343', 'place_name': 'Bishop', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.5886, 'longitude': -97.783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78347', 'place_name': 'Chapman Ranch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.5988, 'longitude': -97.462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78351', 'place_name': 'Driscoll', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.6745, 'longitude': -97.7486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78373', 'place_name': 'Port Aransas', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7707, 'longitude': -97.1051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78380', 'place_name': 'Robstown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7984, 'longitude': -97.6995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78401', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7941, 'longitude': -97.403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78402', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.8262, 'longitude': -97.3857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78403', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78404', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7683, 'longitude': -97.4013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78405', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7762, 'longitude': -97.4271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78406', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7684, 'longitude': -97.5144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78407', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.8042, 'longitude': -97.4356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78408', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7945, 'longitude': -97.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78409', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.8146, 'longitude': -97.527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78410', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.8458, 'longitude': -97.596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78411', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7311, 'longitude': -97.3877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78412', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7061, 'longitude': -97.3537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78413', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.691, 'longitude': -97.3983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78414', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.677, 'longitude': -97.365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78415', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7262, 'longitude': -97.4078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78416', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7536, 'longitude': -97.4347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78417', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.729, 'longitude': -97.4494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78418', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.6349, 'longitude': -97.3103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78419', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.6952, 'longitude': -97.2694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78426', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78427', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.8006, 'longitude': -97.3964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78460', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.8006, 'longitude': -97.3964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78463', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78465', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78466', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78467', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78468', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78469', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78472', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.7402, 'longitude': -97.5792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78480', 'place_name': 'Corpus Christi', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Nueces', 'locality_code': '355', 'latitude': 27.777, 'longitude': -97.4632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79033', 'place_name': 'Farnsworth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ochiltree', 'locality_code': '357', 'latitude': 36.2963, 'longitude': -100.9843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79070', 'place_name': 'Perryton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ochiltree', 'locality_code': '357', 'latitude': 36.3748, 'longitude': -100.8156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79093', 'place_name': 'Waka', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ochiltree', 'locality_code': '357', 'latitude': 36.2716, 'longitude': -101.0443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79001', 'place_name': 'Adrian', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Oldham', 'locality_code': '359', 'latitude': 35.2748, 'longitude': -102.6652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79010', 'place_name': 'Boys Ranch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Oldham', 'locality_code': '359', 'latitude': 35.5314, 'longitude': -102.2541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79092', 'place_name': 'Vega', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Oldham', 'locality_code': '359', 'latitude': 35.2241, 'longitude': -102.4214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79098', 'place_name': 'Wildorado', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Oldham', 'locality_code': '359', 'latitude': 35.1916, 'longitude': -102.2118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77611', 'place_name': 'Bridge City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.0192, 'longitude': -93.8326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77626', 'place_name': 'Mauriceville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.204, 'longitude': -93.8866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77630', 'place_name': 'Orange', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.0709, 'longitude': -93.8659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77631', 'place_name': 'Orange', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.093, 'longitude': -93.7366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77632', 'place_name': 'Orange', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.1775, 'longitude': -93.8409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77639', 'place_name': 'Orangefield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.0631, 'longitude': -93.8599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77662', 'place_name': 'Vidor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.1502, 'longitude': -94.0008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77670', 'place_name': 'Vidor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Orange', 'locality_code': '361', 'latitude': 30.1316, 'longitude': -94.0155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76067', 'place_name': 'Mineral Wells', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.8085, 'longitude': -98.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76068', 'place_name': 'Mineral Wells', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.8085, 'longitude': -98.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76449', 'place_name': 'Graford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.9242, 'longitude': -98.337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76453', 'place_name': 'Gordon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.5478, 'longitude': -98.3632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76463', 'place_name': 'Mingus', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.5381, 'longitude': -98.4219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76472', 'place_name': 'Santo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.5979, 'longitude': -98.1797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76475', 'place_name': 'Strawn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.5945, 'longitude': -98.4995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76484', 'place_name': 'Palo Pinto', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Palo Pinto', 'locality_code': '363', 'latitude': 32.7673, 'longitude': -98.2987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75631', 'place_name': 'Beckville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Panola', 'locality_code': '365', 'latitude': 32.2452, 'longitude': -94.4555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75633', 'place_name': 'Carthage', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Panola', 'locality_code': '365', 'latitude': 32.1544, 'longitude': -94.3527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75637', 'place_name': 'Clayton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Panola', 'locality_code': '365', 'latitude': 32.1027, 'longitude': -94.4935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75639', 'place_name': 'De Berry', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Panola', 'locality_code': '365', 'latitude': 32.2543, 'longitude': -94.1356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75643', 'place_name': 'Gary', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Panola', 'locality_code': '365', 'latitude': 32.0334, 'longitude': -94.38, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75669', 'place_name': 'Long Branch', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Panola', 'locality_code': '365', 'latitude': 32.0449, 'longitude': -94.5381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75685', 'place_name': 'Panola', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Panola', 'locality_code': '365', 'latitude': 32.3579, 'longitude': -94.0913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76008', 'place_name': 'Aledo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.7004, 'longitude': -97.6039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76066', 'place_name': 'Millsap', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.7457, 'longitude': -97.9561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76082', 'place_name': 'Springtown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.966, 'longitude': -97.6836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76085', 'place_name': 'Weatherford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.7676, 'longitude': -97.7516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76086', 'place_name': 'Weatherford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.7549, 'longitude': -97.7899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76087', 'place_name': 'Weatherford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.7495, 'longitude': -97.6894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76088', 'place_name': 'Weatherford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.8478, 'longitude': -97.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76098', 'place_name': 'Azle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.8957, 'longitude': -97.5636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76439', 'place_name': 'Dennis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.6187, 'longitude': -97.9267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76485', 'place_name': 'Peaster', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.8721, 'longitude': -97.8667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76487', 'place_name': 'Poolville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.968, 'longitude': -97.8472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76490', 'place_name': 'Whitt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parker', 'locality_code': '367', 'latitude': 32.9555, 'longitude': -98.021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79009', 'place_name': 'Bovina', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parmer', 'locality_code': '369', 'latitude': 34.5137, 'longitude': -102.883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79035', 'place_name': 'Friona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parmer', 'locality_code': '369', 'latitude': 34.6417, 'longitude': -102.7241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79053', 'place_name': 'Lazbuddie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parmer', 'locality_code': '369', 'latitude': 34.3847, 'longitude': -102.587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79325', 'place_name': 'Farwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Parmer', 'locality_code': '369', 'latitude': 34.386, 'longitude': -102.9901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79730', 'place_name': 'Coyanosa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Pecos', 'locality_code': '371', 'latitude': 31.2295, 'longitude': -103.0538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79735', 'place_name': 'Fort Stockton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Pecos', 'locality_code': '371', 'latitude': 30.8908, 'longitude': -102.8799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79740', 'place_name': 'Girvin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Pecos', 'locality_code': '371', 'latitude': 31.0629, 'longitude': -102.3885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79743', 'place_name': 'Imperial', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Pecos', 'locality_code': '371', 'latitude': 31.2729, 'longitude': -102.6926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79744', 'place_name': 'Iraan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Pecos', 'locality_code': '371', 'latitude': 30.9156, 'longitude': -101.9152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79781', 'place_name': 'Sheffield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Pecos', 'locality_code': '371', 'latitude': 30.6935, 'longitude': -101.86, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75934', 'place_name': 'Camden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.9, 'longitude': -94.7547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75939', 'place_name': 'Corrigan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 31.0408, 'longitude': -94.8124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75960', 'place_name': 'Moscow', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.9179, 'longitude': -94.8544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77326', 'place_name': 'Ace', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.5209, 'longitude': -94.8221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77332', 'place_name': 'Dallardsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.6285, 'longitude': -94.6319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77335', 'place_name': 'Goodrich', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.6079, 'longitude': -94.9592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77350', 'place_name': 'Leggett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.8568, 'longitude': -94.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77351', 'place_name': 'Livingston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.6829, 'longitude': -94.8976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77360', 'place_name': 'Onalaska', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.8225, 'longitude': -95.1056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77399', 'place_name': 'Livingston', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Polk', 'locality_code': '373', 'latitude': 30.8179, 'longitude': -94.8691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79012', 'place_name': 'Bushland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.2664, 'longitude': -102.0978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79101', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.2032, 'longitude': -101.8421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79102', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.1999, 'longitude': -101.8496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79103', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.1751, 'longitude': -101.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79104', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.1939, 'longitude': -101.7975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79105', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79106', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.1977, 'longitude': -101.8949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79107', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.2309, 'longitude': -101.806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79108', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.2779, 'longitude': -101.83, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79111', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.2286, 'longitude': -101.6703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79116', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.2454, 'longitude': -101.999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79117', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.3089, 'longitude': -101.843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79120', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.1964, 'longitude': -101.8034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79124', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.2703, 'longitude': -101.943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79159', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.222, 'longitude': -101.8313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79166', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79168', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79172', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79174', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79178', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79185', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79189', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Potter', 'locality_code': '375', 'latitude': 35.4015, 'longitude': -101.8951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79843', 'place_name': 'Marfa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Presidio', 'locality_code': '377', 'latitude': 30.293, 'longitude': -104.0848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79845', 'place_name': 'Presidio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Presidio', 'locality_code': '377', 'latitude': 29.5573, 'longitude': -104.3551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79846', 'place_name': 'Redford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Presidio', 'locality_code': '377', 'latitude': 29.4702, 'longitude': -104.0055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75410', 'place_name': 'Alba', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rains', 'locality_code': '379', 'latitude': 32.7652, 'longitude': -95.5971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75440', 'place_name': 'Emory', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rains', 'locality_code': '379', 'latitude': 32.875, 'longitude': -95.7418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75472', 'place_name': 'Point', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rains', 'locality_code': '379', 'latitude': 32.9007, 'longitude': -95.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79015', 'place_name': 'Canyon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 34.9772, 'longitude': -101.9247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79016', 'place_name': 'Canyon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 34.9803, 'longitude': -101.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79091', 'place_name': 'Umbarger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 34.901, 'longitude': -102.0788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79109', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 35.1663, 'longitude': -101.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79110', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 35.1545, 'longitude': -101.8641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79114', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 35.05, 'longitude': -101.8175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79118', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 35.0763, 'longitude': -101.8349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79119', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 35.0642, 'longitude': -101.9743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79121', 'place_name': 'Amarillo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Randall', 'locality_code': '381', 'latitude': 35.1697, 'longitude': -101.9266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76932', 'place_name': 'Big Lake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Reagan', 'locality_code': '383', 'latitude': 31.417, 'longitude': -101.5423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78833', 'place_name': 'Camp Wood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Real', 'locality_code': '385', 'latitude': 29.6795, 'longitude': -100.0084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78873', 'place_name': 'Leakey', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Real', 'locality_code': '385', 'latitude': 29.769, 'longitude': -99.7479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78879', 'place_name': 'Rio Frio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Real', 'locality_code': '385', 'latitude': 29.6495, 'longitude': -99.7165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75412', 'place_name': 'Bagwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Red River', 'locality_code': '387', 'latitude': 33.8361, 'longitude': -95.1487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75417', 'place_name': 'Bogata', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Red River', 'locality_code': '387', 'latitude': 33.4699, 'longitude': -95.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75426', 'place_name': 'Clarksville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Red River', 'locality_code': '387', 'latitude': 33.6236, 'longitude': -95.0461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75436', 'place_name': 'Detroit', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Red River', 'locality_code': '387', 'latitude': 33.6627, 'longitude': -95.2385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75550', 'place_name': 'Annona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Red River', 'locality_code': '387', 'latitude': 33.5535, 'longitude': -94.8992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75554', 'place_name': 'Avery', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Red River', 'locality_code': '387', 'latitude': 33.5339, 'longitude': -94.7867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79718', 'place_name': 'Balmorhea', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Reeves', 'locality_code': '389', 'latitude': 30.9843, 'longitude': -103.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79770', 'place_name': 'Orla', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Reeves', 'locality_code': '389', 'latitude': 31.864, 'longitude': -103.9297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79772', 'place_name': 'Pecos', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Reeves', 'locality_code': '389', 'latitude': 31.4467, 'longitude': -103.5791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79780', 'place_name': 'Saragosa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Reeves', 'locality_code': '389', 'latitude': 31.0428, 'longitude': -103.6364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79785', 'place_name': 'Toyah', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Reeves', 'locality_code': '389', 'latitude': 31.282, 'longitude': -103.8057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79786', 'place_name': 'Toyahvale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Reeves', 'locality_code': '389', 'latitude': 30.9443, 'longitude': -103.7893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77950', 'place_name': 'Austwell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Refugio', 'locality_code': '391', 'latitude': 28.4023, 'longitude': -96.853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77990', 'place_name': 'Tivoli', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Refugio', 'locality_code': '391', 'latitude': 28.4587, 'longitude': -96.8928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78340', 'place_name': 'Bayside', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Refugio', 'locality_code': '391', 'latitude': 28.0968, 'longitude': -97.2106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78377', 'place_name': 'Refugio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Refugio', 'locality_code': '391', 'latitude': 28.3169, 'longitude': -97.2767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78393', 'place_name': 'Woodsboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Refugio', 'locality_code': '391', 'latitude': 28.2232, 'longitude': -97.3192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79059', 'place_name': 'Miami', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Roberts', 'locality_code': '393', 'latitude': 35.7193, 'longitude': -100.7027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76629', 'place_name': 'Bremond', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Robertson', 'locality_code': '395', 'latitude': 31.156, 'longitude': -96.6697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77837', 'place_name': 'Calvert', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Robertson', 'locality_code': '395', 'latitude': 30.9782, 'longitude': -96.6711, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77856', 'place_name': 'Franklin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Robertson', 'locality_code': '395', 'latitude': 31.0001, 'longitude': -96.5171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77859', 'place_name': 'Hearne', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Robertson', 'locality_code': '395', 'latitude': 30.8669, 'longitude': -96.5843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77867', 'place_name': 'Mumford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Robertson', 'locality_code': '395', 'latitude': 30.7344, 'longitude': -96.565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77870', 'place_name': 'New Baden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Robertson', 'locality_code': '395', 'latitude': 31.051, 'longitude': -96.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77882', 'place_name': 'Wheelock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Robertson', 'locality_code': '395', 'latitude': 30.8977, 'longitude': -96.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75032', 'place_name': 'Rockwall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rockwall', 'locality_code': '397', 'latitude': 32.886, 'longitude': -96.4095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75087', 'place_name': 'Rockwall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rockwall', 'locality_code': '397', 'latitude': 32.9492, 'longitude': -96.4418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75132', 'place_name': 'Fate', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rockwall', 'locality_code': '397', 'latitude': 32.9415, 'longitude': -96.3814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75189', 'place_name': 'Royse City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rockwall', 'locality_code': '397', 'latitude': 32.9628, 'longitude': -96.3648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76821', 'place_name': 'Ballinger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Runnels', 'locality_code': '399', 'latitude': 31.7468, 'longitude': -99.9589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76861', 'place_name': 'Miles', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Runnels', 'locality_code': '399', 'latitude': 31.6121, 'longitude': -100.1823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76865', 'place_name': 'Norton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Runnels', 'locality_code': '399', 'latitude': 31.8795, 'longitude': -100.1315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76875', 'place_name': 'Rowena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Runnels', 'locality_code': '399', 'latitude': 31.6436, 'longitude': -100.0191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79566', 'place_name': 'Wingate', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Runnels', 'locality_code': '399', 'latitude': 32.0318, 'longitude': -100.1183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79567', 'place_name': 'Winters', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Runnels', 'locality_code': '399', 'latitude': 31.962, 'longitude': -99.9551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75652', 'place_name': 'Henderson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.2131, 'longitude': -94.7834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75653', 'place_name': 'Henderson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.1532, 'longitude': -94.7994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75654', 'place_name': 'Henderson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.126, 'longitude': -94.7488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75658', 'place_name': 'Joinerville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.1959, 'longitude': -94.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75666', 'place_name': 'Laird Hill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.3532, 'longitude': -94.9055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75667', 'place_name': 'Laneville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 31.9508, 'longitude': -94.866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75680', 'place_name': 'Minden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.0028, 'longitude': -94.7129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75681', 'place_name': 'Mount Enterprise', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 31.9125, 'longitude': -94.6235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75682', 'place_name': 'New London', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.2542, 'longitude': -94.9322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75684', 'place_name': 'Overton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.269, 'longitude': -94.9529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75687', 'place_name': 'Price', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.1518, 'longitude': -94.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75689', 'place_name': 'Selman City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.1826, 'longitude': -94.9355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75691', 'place_name': 'Tatum', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Rusk', 'locality_code': '401', 'latitude': 32.3266, 'longitude': -94.596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75930', 'place_name': 'Bronson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sabine', 'locality_code': '403', 'latitude': 31.3391, 'longitude': -93.9993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75931', 'place_name': 'Brookeland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sabine', 'locality_code': '403', 'latitude': 31.0922, 'longitude': -93.9684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75948', 'place_name': 'Hemphill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sabine', 'locality_code': '403', 'latitude': 31.3161, 'longitude': -93.7905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75959', 'place_name': 'Milam', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sabine', 'locality_code': '403', 'latitude': 31.4324, 'longitude': -93.8457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75968', 'place_name': 'Pineland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sabine', 'locality_code': '403', 'latitude': 31.2418, 'longitude': -93.9754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75929', 'place_name': 'Broaddus', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Augustine', 'locality_code': '405', 'latitude': 31.2952, 'longitude': -94.2156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75972', 'place_name': 'San Augustine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Augustine', 'locality_code': '405', 'latitude': 31.5152, 'longitude': -94.1326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77331', 'place_name': 'Coldspring', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Jacinto', 'locality_code': '407', 'latitude': 30.6027, 'longitude': -95.1086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77359', 'place_name': 'Oakhurst', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Jacinto', 'locality_code': '407', 'latitude': 30.7126, 'longitude': -95.3095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77364', 'place_name': 'Pointblank', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Jacinto', 'locality_code': '407', 'latitude': 30.7593, 'longitude': -95.2295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77371', 'place_name': 'Shepherd', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Jacinto', 'locality_code': '407', 'latitude': 30.498, 'longitude': -94.9966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78335', 'place_name': 'Aransas Pass', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.9125, 'longitude': -97.1884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78336', 'place_name': 'Aransas Pass', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.9095, 'longitude': -97.1591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78352', 'place_name': 'Edroy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.9736, 'longitude': -97.6761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78359', 'place_name': 'Gregory', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.9222, 'longitude': -97.29, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78362', 'place_name': 'Ingleside', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.8682, 'longitude': -97.2069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78368', 'place_name': 'Mathis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 28.0802, 'longitude': -97.8097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78370', 'place_name': 'Odem', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.9403, 'longitude': -97.5838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78374', 'place_name': 'Portland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.8935, 'longitude': -97.3169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78387', 'place_name': 'Sinton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 28.0339, 'longitude': -97.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78390', 'place_name': 'Taft', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Patricio', 'locality_code': '409', 'latitude': 27.9765, 'longitude': -97.3966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76832', 'place_name': 'Cherokee', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Saba', 'locality_code': '411', 'latitude': 30.9806, 'longitude': -98.6633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76871', 'place_name': 'Richland Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Saba', 'locality_code': '411', 'latitude': 31.3003, 'longitude': -98.9128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76877', 'place_name': 'San Saba', 'state': 'Texas', 'state_ab': 'TX', 'county': 'San Saba', 'locality_code': '411', 'latitude': 31.1627, 'longitude': -98.7309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76936', 'place_name': 'Eldorado', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Schleicher', 'locality_code': '413', 'latitude': 30.8667, 'longitude': -100.5889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79516', 'place_name': 'Dunn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Scurry', 'locality_code': '415', 'latitude': 32.5671, 'longitude': -100.8854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79517', 'place_name': 'Fluvanna', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Scurry', 'locality_code': '415', 'latitude': 32.853, 'longitude': -101.103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79526', 'place_name': 'Hermleigh', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Scurry', 'locality_code': '415', 'latitude': 32.6294, 'longitude': -100.7547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79527', 'place_name': 'Ira', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Scurry', 'locality_code': '415', 'latitude': 32.5821, 'longitude': -101.0021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79549', 'place_name': 'Snyder', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Scurry', 'locality_code': '415', 'latitude': 32.7451, 'longitude': -100.9175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79550', 'place_name': 'Snyder', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Scurry', 'locality_code': '415', 'latitude': 32.7179, 'longitude': -100.9176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76430', 'place_name': 'Albany', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Shackelford', 'locality_code': '417', 'latitude': 32.719, 'longitude': -99.3196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76464', 'place_name': 'Moran', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Shackelford', 'locality_code': '417', 'latitude': 32.5549, 'longitude': -99.1656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75935', 'place_name': 'Center', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Shelby', 'locality_code': '419', 'latitude': 31.7865, 'longitude': -94.1869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75954', 'place_name': 'Joaquin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Shelby', 'locality_code': '419', 'latitude': 31.944, 'longitude': -94.0608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75973', 'place_name': 'Shelbyville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Shelby', 'locality_code': '419', 'latitude': 31.7131, 'longitude': -93.9698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75974', 'place_name': 'Tenaha', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Shelby', 'locality_code': '419', 'latitude': 31.9408, 'longitude': -94.2488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75975', 'place_name': 'Timpson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Shelby', 'locality_code': '419', 'latitude': 31.8841, 'longitude': -94.3967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73960', 'place_name': 'Texhoma', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sherman', 'locality_code': '421', 'latitude': 36.5055, 'longitude': -101.7829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79084', 'place_name': 'Stratford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sherman', 'locality_code': '421', 'latitude': 36.3335, 'longitude': -101.9886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75701', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.3254, 'longitude': -95.2922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75702', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.362, 'longitude': -95.3117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75703', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.2768, 'longitude': -95.3031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75704', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.3738, 'longitude': -95.407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75705', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.3766, 'longitude': -95.1252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75706', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.4441, 'longitude': -95.331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75707', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.3038, 'longitude': -95.1927, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75708', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.419, 'longitude': -95.2106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75709', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.3078, 'longitude': -95.3956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75710', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.3475, 'longitude': -95.3065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75711', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.3513, 'longitude': -95.3011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75712', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.4112, 'longitude': -95.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75713', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.4112, 'longitude': -95.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75750', 'place_name': 'Arp', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.2418, 'longitude': -95.0639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75757', 'place_name': 'Bullard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.1095, 'longitude': -95.3342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75762', 'place_name': 'Flint', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.2079, 'longitude': -95.3948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75771', 'place_name': 'Lindale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.5062, 'longitude': -95.4006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75789', 'place_name': 'Troup', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.1117, 'longitude': -95.1155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75791', 'place_name': 'Whitehouse', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.222, 'longitude': -95.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75792', 'place_name': 'Winona', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.4662, 'longitude': -95.1246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75798', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.4112, 'longitude': -95.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75799', 'place_name': 'Tyler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Smith', 'locality_code': '423', 'latitude': 32.4112, 'longitude': -95.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76043', 'place_name': 'Glen Rose', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Somervell', 'locality_code': '425', 'latitude': 32.2298, 'longitude': -97.7629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76070', 'place_name': 'Nemo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Somervell', 'locality_code': '425', 'latitude': 32.2713, 'longitude': -97.6567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76077', 'place_name': 'Rainbow', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Somervell', 'locality_code': '425', 'latitude': 32.2812, 'longitude': -97.7065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78536', 'place_name': 'Delmita', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.6801, 'longitude': -98.4125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78545', 'place_name': 'Falcon Heights', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.562, 'longitude': -99.1335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78547', 'place_name': 'Garciasville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.3396, 'longitude': -98.6876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78548', 'place_name': 'Grulla', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.2897, 'longitude': -98.6479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78582', 'place_name': 'Rio Grande City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.3942, 'longitude': -98.8104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78584', 'place_name': 'Roma', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.4215, 'longitude': -99.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78585', 'place_name': 'Salineno', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.5164, 'longitude': -99.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78588', 'place_name': 'San Isidro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.7167, 'longitude': -98.4539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78591', 'place_name': 'Santa Elena', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Starr', 'locality_code': '427', 'latitude': 26.5808, 'longitude': -98.5138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76424', 'place_name': 'Breckenridge', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Stephens', 'locality_code': '429', 'latitude': 32.7532, 'longitude': -98.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76429', 'place_name': 'Caddo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Stephens', 'locality_code': '429', 'latitude': 32.6886, 'longitude': -98.659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76951', 'place_name': 'Sterling City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sterling', 'locality_code': '431', 'latitude': 31.8351, 'longitude': -101.0017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79502', 'place_name': 'Aspermont', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Stonewall', 'locality_code': '433', 'latitude': 33.1301, 'longitude': -100.2344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79540', 'place_name': 'Old Glory', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Stonewall', 'locality_code': '433', 'latitude': 33.1298, 'longitude': -100.0559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76950', 'place_name': 'Sonora', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Sutton', 'locality_code': '435', 'latitude': 30.5558, 'longitude': -100.6307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79042', 'place_name': 'Happy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Swisher', 'locality_code': '437', 'latitude': 34.7219, 'longitude': -101.8256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79052', 'place_name': 'Kress', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Swisher', 'locality_code': '437', 'latitude': 34.3737, 'longitude': -101.737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79088', 'place_name': 'Tulia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Swisher', 'locality_code': '437', 'latitude': 34.5583, 'longitude': -101.8039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76001', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6289, 'longitude': -97.1517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76002', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6255, 'longitude': -97.0784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76003', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7417, 'longitude': -97.2253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76004', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7357, 'longitude': -97.1081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76005', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76006', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7785, 'longitude': -97.0834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76007', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76010', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7204, 'longitude': -97.0826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76011', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7582, 'longitude': -97.1003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76012', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.754, 'longitude': -97.1348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76013', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7199, 'longitude': -97.1442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76014', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6954, 'longitude': -97.0876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76015', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6931, 'longitude': -97.1347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76016', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6889, 'longitude': -97.1905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76017', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6555, 'longitude': -97.1599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76018', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6548, 'longitude': -97.092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76019', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7357, 'longitude': -97.1081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76020', 'place_name': 'Azle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9035, 'longitude': -97.5412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76021', 'place_name': 'Bedford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8536, 'longitude': -97.1358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76022', 'place_name': 'Bedford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8297, 'longitude': -97.1454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76034', 'place_name': 'Colleyville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8872, 'longitude': -97.146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76036', 'place_name': 'Crowley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.5814, 'longitude': -97.3703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76039', 'place_name': 'Euless', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8582, 'longitude': -97.0832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76040', 'place_name': 'Euless', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8264, 'longitude': -97.0972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76051', 'place_name': 'Grapevine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9328, 'longitude': -97.0808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76052', 'place_name': 'Haslet', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9557, 'longitude': -97.3372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76053', 'place_name': 'Hurst', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8211, 'longitude': -97.1756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76054', 'place_name': 'Hurst', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8558, 'longitude': -97.1755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76060', 'place_name': 'Kennedale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6432, 'longitude': -97.2139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76063', 'place_name': 'Mansfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.5773, 'longitude': -97.1416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76092', 'place_name': 'Southlake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9485, 'longitude': -97.1524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76094', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76095', 'place_name': 'Bedford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.844, 'longitude': -97.1431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76096', 'place_name': 'Arlington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76099', 'place_name': 'Grapevine', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9343, 'longitude': -97.0781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76101', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76102', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7589, 'longitude': -97.328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76103', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.747, 'longitude': -97.2604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76104', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7256, 'longitude': -97.3184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76105', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7233, 'longitude': -97.269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76106', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7968, 'longitude': -97.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76107', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7392, 'longitude': -97.3852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76108', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7822, 'longitude': -97.4969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76109', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7002, 'longitude': -97.3789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76110', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7065, 'longitude': -97.3375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76111', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7824, 'longitude': -97.3003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76112', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7493, 'longitude': -97.2181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76113', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76114', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7796, 'longitude': -97.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76115', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6796, 'longitude': -97.3336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76116', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.723, 'longitude': -97.4483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76117', 'place_name': 'Haltom City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8087, 'longitude': -97.2709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76118', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8013, 'longitude': -97.1952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76119', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6914, 'longitude': -97.2675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76120', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7639, 'longitude': -97.1781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76121', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76122', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76123', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6254, 'longitude': -97.3658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76124', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76126', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.64, 'longitude': -97.5448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76127', 'place_name': 'Naval Air Station Jrb', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7254, 'longitude': -97.3208, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '76129', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76130', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76131', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8632, 'longitude': -97.3377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76132', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6711, 'longitude': -97.4056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76133', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6526, 'longitude': -97.3758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76134', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6469, 'longitude': -97.3325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76135', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8248, 'longitude': -97.4519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76136', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76137', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8664, 'longitude': -97.2891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76140', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.6192, 'longitude': -97.2735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76147', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76148', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8621, 'longitude': -97.2508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76150', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76155', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8247, 'longitude': -97.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76161', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76162', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76163', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76164', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7811, 'longitude': -97.3546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76166', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7539, 'longitude': -97.3362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76177', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9448, 'longitude': -97.3124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76179', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9074, 'longitude': -97.4257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76180', 'place_name': 'North Richland Hills', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.84, 'longitude': -97.225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76181', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76182', 'place_name': 'North Richland Hills', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.8828, 'longitude': -97.2098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76185', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76190', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7423, 'longitude': -97.3315, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '76191', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76192', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76193', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76195', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7254, 'longitude': -97.3208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76196', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76197', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76198', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76199', 'place_name': 'Fort Worth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.7714, 'longitude': -97.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76244', 'place_name': 'Keller', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.931, 'longitude': -97.2843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76248', 'place_name': 'Keller', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tarrant', 'locality_code': '439', 'latitude': 32.9276, 'longitude': -97.2489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79508', 'place_name': 'Buffalo Gap', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.2894, 'longitude': -99.8103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79530', 'place_name': 'Lawn', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.136, 'longitude': -99.7351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79536', 'place_name': 'Merkel', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4444, 'longitude': -99.9924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79541', 'place_name': 'Ovalo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.1553, 'longitude': -99.8229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79561', 'place_name': 'Trent', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4898, 'longitude': -100.1195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79562', 'place_name': 'Tuscola', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.235, 'longitude': -99.8244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79563', 'place_name': 'Tye', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4477, 'longitude': -99.8684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79601', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4682, 'longitude': -99.7182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79602', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4178, 'longitude': -99.7214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79603', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4679, 'longitude': -99.7619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79604', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4487, 'longitude': -99.7331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79605', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.432, 'longitude': -99.7724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79606', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.392, 'longitude': -99.7746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79607', 'place_name': 'Dyess Afb', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.419, 'longitude': -99.8221, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79608', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4487, 'longitude': -99.7331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79697', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4487, 'longitude': -99.7331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79698', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4751, 'longitude': -99.7348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79699', 'place_name': 'Abilene', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Taylor', 'locality_code': '441', 'latitude': 32.4665, 'longitude': -99.7117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78851', 'place_name': 'Dryden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Terrell', 'locality_code': '443', 'latitude': 30.0446, 'longitude': -102.1146, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79848', 'place_name': 'Sanderson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Terrell', 'locality_code': '443', 'latitude': 30.1221, 'longitude': -102.3974, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79316', 'place_name': 'Brownfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Terry', 'locality_code': '445', 'latitude': 33.1698, 'longitude': -102.2762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79345', 'place_name': 'Meadow', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Terry', 'locality_code': '445', 'latitude': 33.3321, 'longitude': -102.2492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79378', 'place_name': 'Wellman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Terry', 'locality_code': '445', 'latitude': 33.0473, 'longitude': -102.4282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76483', 'place_name': 'Throckmorton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Throckmorton', 'locality_code': '447', 'latitude': 33.1794, 'longitude': -99.1838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76491', 'place_name': 'Woodson', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Throckmorton', 'locality_code': '447', 'latitude': 33.0741, 'longitude': -99.0546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75455', 'place_name': 'Mount Pleasant', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Titus', 'locality_code': '449', 'latitude': 33.1733, 'longitude': -94.9695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75456', 'place_name': 'Mount Pleasant', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Titus', 'locality_code': '449', 'latitude': 33.1568, 'longitude': -94.9683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75493', 'place_name': 'Winfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Titus', 'locality_code': '449', 'latitude': 33.1673, 'longitude': -95.1119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75558', 'place_name': 'Cookville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Titus', 'locality_code': '449', 'latitude': 33.2432, 'longitude': -94.8747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76886', 'place_name': 'Veribest', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4766, 'longitude': -100.2595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76901', 'place_name': 'San Angelo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4782, 'longitude': -100.4818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76902', 'place_name': 'San Angelo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4638, 'longitude': -100.437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76903', 'place_name': 'San Angelo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4707, 'longitude': -100.4386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76904', 'place_name': 'San Angelo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4194, 'longitude': -100.48, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76905', 'place_name': 'San Angelo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4647, 'longitude': -100.39, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76906', 'place_name': 'San Angelo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4638, 'longitude': -100.437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76908', 'place_name': 'Goodfellow Afb', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4321, 'longitude': -100.4022, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '76909', 'place_name': 'San Angelo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4638, 'longitude': -100.437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76934', 'place_name': 'Carlsbad', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.6266, 'longitude': -100.6694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76935', 'place_name': 'Christoval', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.2346, 'longitude': -100.5203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76939', 'place_name': 'Knickerbocker', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.2501, 'longitude': -100.592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76940', 'place_name': 'Mereta', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.4518, 'longitude': -100.1349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76955', 'place_name': 'Vancourt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.3132, 'longitude': -100.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76957', 'place_name': 'Wall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.3741, 'longitude': -100.3076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76958', 'place_name': 'Water Valley', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tom Green', 'locality_code': '451', 'latitude': 31.6453, 'longitude': -100.716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73301', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '73344', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78617', 'place_name': 'Del Valle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.1745, 'longitude': -97.6134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78645', 'place_name': 'Leander', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.449, 'longitude': -97.9669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78651', 'place_name': 'Mc Neil', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78652', 'place_name': 'Manchaca', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.1238, 'longitude': -97.8393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78653', 'place_name': 'Manor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3388, 'longitude': -97.5323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78660', 'place_name': 'Pflugerville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.4421, 'longitude': -97.6299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78669', 'place_name': 'Spicewood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3899, 'longitude': -98.0539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78691', 'place_name': 'Pflugerville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.4394, 'longitude': -97.62, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78701', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2713, 'longitude': -97.7426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78702', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2638, 'longitude': -97.7166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78703', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2907, 'longitude': -97.7648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78704', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2428, 'longitude': -97.7658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78705', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2896, 'longitude': -97.7396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78708', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78709', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78710', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.352, 'longitude': -97.7151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78711', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78712', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2852, 'longitude': -97.7354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78713', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2672, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78714', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2672, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78715', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2672, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78716', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3162, 'longitude': -97.8588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78718', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78719', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.1802, 'longitude': -97.6667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78720', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78721', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2721, 'longitude': -97.6868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78722', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2893, 'longitude': -97.715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78723', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3085, 'longitude': -97.6849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78724', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.296, 'longitude': -97.6396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78725', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2562, 'longitude': -97.6243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78726', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.43, 'longitude': -97.8326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78727', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.4254, 'longitude': -97.7195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78728', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.4417, 'longitude': -97.6811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78730', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3607, 'longitude': -97.8241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78731', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3471, 'longitude': -97.7609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78732', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3752, 'longitude': -97.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78733', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3314, 'longitude': -97.8666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78734', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3705, 'longitude': -97.9427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78735', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.249, 'longitude': -97.8414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78736', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2444, 'longitude': -97.916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78737', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2107, 'longitude': -97.9427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78738', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3337, 'longitude': -97.9824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78739', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.172, 'longitude': -97.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78741', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2315, 'longitude': -97.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78742', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2313, 'longitude': -97.6703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78744', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.1876, 'longitude': -97.7472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78745', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2063, 'longitude': -97.7956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78746', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2971, 'longitude': -97.8181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78747', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.1204, 'longitude': -97.7433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78748', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.1743, 'longitude': -97.8225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78749', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2166, 'longitude': -97.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78750', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.4224, 'longitude': -97.7967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78751', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3093, 'longitude': -97.7242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78752', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3316, 'longitude': -97.7004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78753', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3649, 'longitude': -97.6827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78754', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3423, 'longitude': -97.6673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78755', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78756', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3223, 'longitude': -97.739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78757', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3437, 'longitude': -97.7316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78758', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3764, 'longitude': -97.7078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78759', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.4036, 'longitude': -97.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78760', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78761', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78762', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78763', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3354, 'longitude': -97.5598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78764', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.4455, 'longitude': -97.6595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78765', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78766', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2672, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78767', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2672, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78768', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2672, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78769', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78772', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78773', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78774', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78778', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78779', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78783', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.3264, 'longitude': -97.7713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78799', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Travis', 'locality_code': '453', 'latitude': 30.2672, 'longitude': -97.7431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75834', 'place_name': 'Centralia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Trinity', 'locality_code': '455', 'latitude': 31.258, 'longitude': -95.0399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75845', 'place_name': 'Groveton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Trinity', 'locality_code': '455', 'latitude': 31.0651, 'longitude': -95.0969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75856', 'place_name': 'Pennington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Trinity', 'locality_code': '455', 'latitude': 31.1953, 'longitude': -95.2469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75862', 'place_name': 'Trinity', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Trinity', 'locality_code': '455', 'latitude': 30.942, 'longitude': -95.3403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75865', 'place_name': 'Woodlake', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Trinity', 'locality_code': '455', 'latitude': 31.0288, 'longitude': -95.033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75926', 'place_name': 'Apple Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Trinity', 'locality_code': '455', 'latitude': 31.2269, 'longitude': -94.9812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75936', 'place_name': 'Chester', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.9447, 'longitude': -94.5554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75938', 'place_name': 'Colmesneil', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.9007, 'longitude': -94.3916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75942', 'place_name': 'Doucette', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.8183, 'longitude': -94.4288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75979', 'place_name': 'Woodville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.7752, 'longitude': -94.4155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75990', 'place_name': 'Woodville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.7752, 'longitude': -94.4155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77616', 'place_name': 'Fred', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.5678, 'longitude': -94.18, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77624', 'place_name': 'Hillister', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.675, 'longitude': -94.3534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77660', 'place_name': 'Spurger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.6387, 'longitude': -94.1663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77664', 'place_name': 'Warren', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Tyler', 'locality_code': '457', 'latitude': 30.5978, 'longitude': -94.412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75640', 'place_name': 'Diana', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upshur', 'locality_code': '459', 'latitude': 32.7698, 'longitude': -94.7032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75644', 'place_name': 'Gilmer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upshur', 'locality_code': '459', 'latitude': 32.7246, 'longitude': -94.9714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75645', 'place_name': 'Gilmer', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upshur', 'locality_code': '459', 'latitude': 32.6044, 'longitude': -94.8491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75683', 'place_name': 'Ore City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upshur', 'locality_code': '459', 'latitude': 32.7856, 'longitude': -94.7514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75755', 'place_name': 'Big Sandy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upshur', 'locality_code': '459', 'latitude': 32.6168, 'longitude': -95.088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75797', 'place_name': 'Big Sandy', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upshur', 'locality_code': '459', 'latitude': 32.5765, 'longitude': -95.1313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79752', 'place_name': 'Mc Camey', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upton', 'locality_code': '461', 'latitude': 31.1319, 'longitude': -102.2153, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '79755', 'place_name': 'Midkiff', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upton', 'locality_code': '461', 'latitude': 31.5424, 'longitude': -101.9244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79778', 'place_name': 'Rankin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Upton', 'locality_code': '461', 'latitude': 31.2266, 'longitude': -101.9441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78801', 'place_name': 'Uvalde', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Uvalde', 'locality_code': '463', 'latitude': 29.2172, 'longitude': -99.7931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78802', 'place_name': 'Uvalde', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Uvalde', 'locality_code': '463', 'latitude': 29.2237, 'longitude': -99.7794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78838', 'place_name': 'Concan', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Uvalde', 'locality_code': '463', 'latitude': 29.4952, 'longitude': -99.7126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78870', 'place_name': 'Knippa', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Uvalde', 'locality_code': '463', 'latitude': 29.2911, 'longitude': -99.6372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78881', 'place_name': 'Sabinal', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Uvalde', 'locality_code': '463', 'latitude': 29.3267, 'longitude': -99.4781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78884', 'place_name': 'Utopia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Uvalde', 'locality_code': '463', 'latitude': 29.5972, 'longitude': -99.5585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78837', 'place_name': 'Comstock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Val Verde', 'locality_code': '465', 'latitude': 29.7484, 'longitude': -101.2628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78840', 'place_name': 'Del Rio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Val Verde', 'locality_code': '465', 'latitude': 29.4102, 'longitude': -100.8932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78841', 'place_name': 'Del Rio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Val Verde', 'locality_code': '465', 'latitude': 29.3465, 'longitude': -100.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78842', 'place_name': 'Del Rio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Val Verde', 'locality_code': '465', 'latitude': 29.412, 'longitude': -100.9342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78843', 'place_name': 'Laughlin Afb', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Val Verde', 'locality_code': '465', 'latitude': 29.3627, 'longitude': -100.8968, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78847', 'place_name': 'Del Rio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Val Verde', 'locality_code': '465', 'latitude': 29.3627, 'longitude': -100.8968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78871', 'place_name': 'Langtry', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Val Verde', 'locality_code': '465', 'latitude': 29.8085, 'longitude': -101.5587, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '75103', 'place_name': 'Canton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Van Zandt', 'locality_code': '467', 'latitude': 32.5143, 'longitude': -95.9047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75117', 'place_name': 'Edgewood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Van Zandt', 'locality_code': '467', 'latitude': 32.7003, 'longitude': -95.878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75127', 'place_name': 'Fruitvale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Van Zandt', 'locality_code': '467', 'latitude': 32.677, 'longitude': -95.7899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75140', 'place_name': 'Grand Saline', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Van Zandt', 'locality_code': '467', 'latitude': 32.6635, 'longitude': -95.7064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75169', 'place_name': 'Wills Point', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Van Zandt', 'locality_code': '467', 'latitude': 32.7283, 'longitude': -96.0079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75754', 'place_name': 'Ben Wheeler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Van Zandt', 'locality_code': '467', 'latitude': 32.4126, 'longitude': -95.6371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75790', 'place_name': 'Van', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Van Zandt', 'locality_code': '467', 'latitude': 32.5283, 'longitude': -95.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77901', 'place_name': 'Victoria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.809, 'longitude': -96.9993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77902', 'place_name': 'Victoria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.9255, 'longitude': -97.1006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77903', 'place_name': 'Victoria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.8053, 'longitude': -97.0036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77904', 'place_name': 'Victoria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.8675, 'longitude': -96.999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77905', 'place_name': 'Victoria', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.7525, 'longitude': -97.0338, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77951', 'place_name': 'Bloomington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.6495, 'longitude': -96.8945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77968', 'place_name': 'Inez', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.8994, 'longitude': -96.8003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77973', 'place_name': 'Mcfaddin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.5511, 'longitude': -97.0099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77976', 'place_name': 'Nursery', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.9543, 'longitude': -97.0906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77977', 'place_name': 'Placedo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.6923, 'longitude': -96.8254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77988', 'place_name': 'Telferner', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Victoria', 'locality_code': '469', 'latitude': 28.8489, 'longitude': -96.8905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77320', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.847, 'longitude': -95.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77334', 'place_name': 'Dodge', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.772, 'longitude': -95.3838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77340', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.6448, 'longitude': -95.5798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77341', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.7142, 'longitude': -95.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77342', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.7813, 'longitude': -95.5953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77343', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.7235, 'longitude': -95.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77344', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.7235, 'longitude': -95.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77348', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.7235, 'longitude': -95.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77349', 'place_name': 'Huntsville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.7235, 'longitude': -95.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77358', 'place_name': 'New Waverly', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.5354, 'longitude': -95.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77367', 'place_name': 'Riverside', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Walker', 'locality_code': '471', 'latitude': 30.853, 'longitude': -95.4036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77423', 'place_name': 'Brookshire', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Waller', 'locality_code': '473', 'latitude': 29.8072, 'longitude': -95.9755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77445', 'place_name': 'Hempstead', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Waller', 'locality_code': '473', 'latitude': 30.092, 'longitude': -96.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77446', 'place_name': 'Prairie View', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Waller', 'locality_code': '473', 'latitude': 30.0836, 'longitude': -95.9866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77466', 'place_name': 'Pattison', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Waller', 'locality_code': '473', 'latitude': 29.8173, 'longitude': -96.0073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77484', 'place_name': 'Waller', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Waller', 'locality_code': '473', 'latitude': 30.071, 'longitude': -95.9253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79719', 'place_name': 'Barstow', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ward', 'locality_code': '475', 'latitude': 31.4639, 'longitude': -103.3971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79742', 'place_name': 'Grandfalls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ward', 'locality_code': '475', 'latitude': 31.3459, 'longitude': -102.8568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79756', 'place_name': 'Monahans', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ward', 'locality_code': '475', 'latitude': 31.5813, 'longitude': -102.9003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79777', 'place_name': 'Pyote', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ward', 'locality_code': '475', 'latitude': 31.5387, 'longitude': -103.1267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79788', 'place_name': 'Wickett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Ward', 'locality_code': '475', 'latitude': 31.5692, 'longitude': -103.0067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77426', 'place_name': 'Chappell Hill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Washington', 'locality_code': '477', 'latitude': 30.1833, 'longitude': -96.2347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77833', 'place_name': 'Brenham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Washington', 'locality_code': '477', 'latitude': 30.1774, 'longitude': -96.4028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77834', 'place_name': 'Brenham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Washington', 'locality_code': '477', 'latitude': 30.1669, 'longitude': -96.3977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77835', 'place_name': 'Burton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Washington', 'locality_code': '477', 'latitude': 30.1767, 'longitude': -96.5925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77880', 'place_name': 'Washington', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Washington', 'locality_code': '477', 'latitude': 30.3182, 'longitude': -96.2249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78040', 'place_name': 'Laredo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.5155, 'longitude': -99.4986, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78041', 'place_name': 'Laredo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.5569, 'longitude': -99.4907, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78042', 'place_name': 'Laredo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.5655, 'longitude': -99.4768, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78043', 'place_name': 'Laredo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.5879, 'longitude': -99.2176, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78044', 'place_name': 'Laredo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.3637, 'longitude': -99.4819, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78045', 'place_name': 'Laredo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.6357, 'longitude': -99.5923, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78046', 'place_name': 'Laredo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.4047, 'longitude': -99.4743, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78344', 'place_name': 'Bruni', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.4295, 'longitude': -98.8385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78369', 'place_name': 'Mirando City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.445, 'longitude': -99.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78371', 'place_name': 'Oilton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Webb', 'locality_code': '479', 'latitude': 27.4685, 'longitude': -98.9586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77420', 'place_name': 'Boling', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.2529, 'longitude': -95.974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77432', 'place_name': 'Danevang', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.0575, 'longitude': -96.2075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77435', 'place_name': 'East Bernard', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.4705, 'longitude': -96.1211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77436', 'place_name': 'Egypt', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.405, 'longitude': -96.2369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77437', 'place_name': 'El Campo', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.2008, 'longitude': -96.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77443', 'place_name': 'Glen Flora', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.3475, 'longitude': -96.1933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77448', 'place_name': 'Hungerford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.4137, 'longitude': -96.0929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77453', 'place_name': 'Lane City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.2161, 'longitude': -96.0263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77454', 'place_name': 'Lissie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.5353, 'longitude': -96.2303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77455', 'place_name': 'Louise', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.1114, 'longitude': -96.4033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77467', 'place_name': 'Pierce', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.2052, 'longitude': -96.1369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '77488', 'place_name': 'Wharton', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wharton', 'locality_code': '481', 'latitude': 29.3205, 'longitude': -96.0858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79003', 'place_name': 'Allison', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wheeler', 'locality_code': '483', 'latitude': 35.6059, 'longitude': -100.1007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79011', 'place_name': 'Briscoe', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wheeler', 'locality_code': '483', 'latitude': 35.5855, 'longitude': -100.1679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79061', 'place_name': 'Mobeetie', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wheeler', 'locality_code': '483', 'latitude': 35.5297, 'longitude': -100.4242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79079', 'place_name': 'Shamrock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wheeler', 'locality_code': '483', 'latitude': 35.2142, 'longitude': -100.249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79096', 'place_name': 'Wheeler', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wheeler', 'locality_code': '483', 'latitude': 35.4319, 'longitude': -100.2568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76301', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.9053, 'longitude': -98.4976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76302', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.8643, 'longitude': -98.494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76305', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.9995, 'longitude': -98.3938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76306', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.9519, 'longitude': -98.5145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76307', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.9137, 'longitude': -98.4934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76308', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.8633, 'longitude': -98.534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76309', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.8931, 'longitude': -98.5343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76310', 'place_name': 'Wichita Falls', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.8581, 'longitude': -98.5755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76311', 'place_name': 'Sheppard Afb', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.9824, 'longitude': -98.5088, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '76354', 'place_name': 'Burkburnett', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 34.086, 'longitude': -98.5708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76360', 'place_name': 'Electra', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 34.0362, 'longitude': -98.9155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76367', 'place_name': 'Iowa Park', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.9423, 'longitude': -98.6745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76369', 'place_name': 'Kamay', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wichita', 'locality_code': '485', 'latitude': 33.8579, 'longitude': -98.8081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76364', 'place_name': 'Harrold', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilbarger', 'locality_code': '487', 'latitude': 34.0806, 'longitude': -99.0323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76373', 'place_name': 'Oklaunion', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilbarger', 'locality_code': '487', 'latitude': 34.1295, 'longitude': -99.1429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76384', 'place_name': 'Vernon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilbarger', 'locality_code': '487', 'latitude': 34.1491, 'longitude': -99.303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76385', 'place_name': 'Vernon', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilbarger', 'locality_code': '487', 'latitude': 34.1554, 'longitude': -99.2663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79247', 'place_name': 'Odell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilbarger', 'locality_code': '487', 'latitude': 34.3452, 'longitude': -99.4196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78561', 'place_name': 'Lasara', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Willacy', 'locality_code': '489', 'latitude': 26.4648, 'longitude': -97.9111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78569', 'place_name': 'Lyford', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Willacy', 'locality_code': '489', 'latitude': 26.4089, 'longitude': -97.7817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78574', 'place_name': 'Mission', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Willacy', 'locality_code': '489', 'latitude': 26.3189, 'longitude': -98.3701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78580', 'place_name': 'Raymondville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Willacy', 'locality_code': '489', 'latitude': 26.4792, 'longitude': -97.7967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78590', 'place_name': 'San Perlita', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Willacy', 'locality_code': '489', 'latitude': 26.5012, 'longitude': -97.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78594', 'place_name': 'Sebastian', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Willacy', 'locality_code': '489', 'latitude': 26.344, 'longitude': -97.8123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78598', 'place_name': 'Port Mansfield', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Willacy', 'locality_code': '489', 'latitude': 26.5548, 'longitude': -97.425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76527', 'place_name': 'Florence', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.8076, 'longitude': -97.7812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76530', 'place_name': 'Granger', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.7398, 'longitude': -97.4451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76537', 'place_name': 'Jarrell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.8119, 'longitude': -97.5942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76573', 'place_name': 'Schwertner', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.8155, 'longitude': -97.5142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76574', 'place_name': 'Taylor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5708, 'longitude': -97.4094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76578', 'place_name': 'Thrall', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.592, 'longitude': -97.2893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78613', 'place_name': 'Cedar Park', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5052, 'longitude': -97.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78615', 'place_name': 'Coupland', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.4872, 'longitude': -97.3676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78626', 'place_name': 'Georgetown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.633, 'longitude': -97.6707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78627', 'place_name': 'Georgetown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.6327, 'longitude': -97.6772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78628', 'place_name': 'Georgetown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.6411, 'longitude': -97.7511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78630', 'place_name': 'Cedar Park', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5052, 'longitude': -97.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78633', 'place_name': 'Georgetown', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.7177, 'longitude': -97.7543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78634', 'place_name': 'Hutto', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5257, 'longitude': -97.5672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78641', 'place_name': 'Leander', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5835, 'longitude': -97.8575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78642', 'place_name': 'Liberty Hill', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.663, 'longitude': -97.9316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78646', 'place_name': 'Leander', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5788, 'longitude': -97.8531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78664', 'place_name': 'Round Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5145, 'longitude': -97.668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78665', 'place_name': 'Round Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5145, 'longitude': -97.668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78673', 'place_name': 'Walburg', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.7415, 'longitude': -97.5891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78674', 'place_name': 'Weir', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.6747, 'longitude': -97.5929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78680', 'place_name': 'Round Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.6568, 'longitude': -97.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78681', 'place_name': 'Round Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.5083, 'longitude': -97.6789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78682', 'place_name': 'Round Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.6568, 'longitude': -97.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78683', 'place_name': 'Round Rock', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.6568, 'longitude': -97.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78717', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.506, 'longitude': -97.7472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78729', 'place_name': 'Austin', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Williamson', 'locality_code': '491', 'latitude': 30.4521, 'longitude': -97.7688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78114', 'place_name': 'Floresville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilson', 'locality_code': '493', 'latitude': 29.1693, 'longitude': -98.1936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78121', 'place_name': 'La Vernia', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilson', 'locality_code': '493', 'latitude': 29.3509, 'longitude': -98.113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78143', 'place_name': 'Pandora', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilson', 'locality_code': '493', 'latitude': 29.2484, 'longitude': -97.8287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78147', 'place_name': 'Poth', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilson', 'locality_code': '493', 'latitude': 29.0619, 'longitude': -98.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78160', 'place_name': 'Stockdale', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilson', 'locality_code': '493', 'latitude': 29.2319, 'longitude': -97.9351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78161', 'place_name': 'Sutherland Springs', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wilson', 'locality_code': '493', 'latitude': 29.2888, 'longitude': -98.0509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79745', 'place_name': 'Kermit', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Winkler', 'locality_code': '495', 'latitude': 31.855, 'longitude': -103.0913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79789', 'place_name': 'Wink', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Winkler', 'locality_code': '495', 'latitude': 31.7527, 'longitude': -103.1561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76023', 'place_name': 'Boyd', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.0594, 'longitude': -97.5868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76071', 'place_name': 'Newark', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.007, 'longitude': -97.4923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76073', 'place_name': 'Paradise', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.0826, 'longitude': -97.6974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76078', 'place_name': 'Rhome', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.054, 'longitude': -97.4817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76225', 'place_name': 'Alvord', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.3698, 'longitude': -97.6885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76234', 'place_name': 'Decatur', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.2351, 'longitude': -97.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76246', 'place_name': 'Greenwood', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.407, 'longitude': -97.4716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76267', 'place_name': 'Slidell', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.378, 'longitude': -97.3922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76426', 'place_name': 'Bridgeport', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.187, 'longitude': -97.781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76431', 'place_name': 'Chico', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wise', 'locality_code': '497', 'latitude': 33.3193, 'longitude': -97.8031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75444', 'place_name': 'Golden', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wood', 'locality_code': '499', 'latitude': 32.7299, 'longitude': -95.5636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75494', 'place_name': 'Winnsboro', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wood', 'locality_code': '499', 'latitude': 32.9146, 'longitude': -95.2726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75497', 'place_name': 'Yantis', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wood', 'locality_code': '499', 'latitude': 32.9257, 'longitude': -95.5311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75765', 'place_name': 'Hawkins', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wood', 'locality_code': '499', 'latitude': 32.6439, 'longitude': -95.222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75773', 'place_name': 'Mineola', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wood', 'locality_code': '499', 'latitude': 32.6661, 'longitude': -95.487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '75783', 'place_name': 'Quitman', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Wood', 'locality_code': '499', 'latitude': 32.8049, 'longitude': -95.4302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79323', 'place_name': 'Denver City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Yoakum', 'locality_code': '501', 'latitude': 32.9711, 'longitude': -102.8313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79355', 'place_name': 'Plains', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Yoakum', 'locality_code': '501', 'latitude': 33.1894, 'longitude': -102.8294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '79376', 'place_name': 'Tokio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Yoakum', 'locality_code': '501', 'latitude': 33.1826, 'longitude': -102.5768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76372', 'place_name': 'Newcastle', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Young', 'locality_code': '503', 'latitude': 33.1901, 'longitude': -98.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76374', 'place_name': 'Olney', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Young', 'locality_code': '503', 'latitude': 33.3601, 'longitude': -98.7427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76450', 'place_name': 'Graham', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Young', 'locality_code': '503', 'latitude': 33.0993, 'longitude': -98.5832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76460', 'place_name': 'Loving', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Young', 'locality_code': '503', 'latitude': 33.2689, 'longitude': -98.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '76481', 'place_name': 'South Bend', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Young', 'locality_code': '503', 'latitude': 33.0052, 'longitude': -98.6892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78067', 'place_name': 'San Ygnacio', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Zapata', 'locality_code': '505', 'latitude': 27.0425, 'longitude': -99.44, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78076', 'place_name': 'Zapata', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Zapata', 'locality_code': '505', 'latitude': 26.8897, 'longitude': -99.2506, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '78564', 'place_name': 'Lopeno', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Zapata', 'locality_code': '505', 'latitude': 26.7114, 'longitude': -99.11, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78829', 'place_name': 'Batesville', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Zavala', 'locality_code': '507', 'latitude': 28.9286, 'longitude': -99.6115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78839', 'place_name': 'Crystal City', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Zavala', 'locality_code': '507', 'latitude': 28.687, 'longitude': -99.8264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '78872', 'place_name': 'La Pryor', 'state': 'Texas', 'state_ab': 'TX', 'county': 'Zavala', 'locality_code': '507', 'latitude': 28.9488, 'longitude': -99.8507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84713', 'place_name': 'Beaver', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Beaver', 'locality_code': '1', 'latitude': 38.2807, 'longitude': -112.6299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84731', 'place_name': 'Greenville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Beaver', 'locality_code': '1', 'latitude': 38.2544, 'longitude': -112.7124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84751', 'place_name': 'Milford', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Beaver', 'locality_code': '1', 'latitude': 38.3311, 'longitude': -112.9934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84752', 'place_name': 'Minersville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Beaver', 'locality_code': '1', 'latitude': 38.2149, 'longitude': -112.9231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84301', 'place_name': 'Bear River City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.6093, 'longitude': -112.1241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84302', 'place_name': 'Brigham City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.5079, 'longitude': -112.0152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84306', 'place_name': 'Collinston', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.7813, 'longitude': -112.0666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84307', 'place_name': 'Corinne', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.545, 'longitude': -112.1514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84309', 'place_name': 'Deweyville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.6972, 'longitude': -112.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84311', 'place_name': 'Fielding', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.8118, 'longitude': -112.119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84312', 'place_name': 'Garland', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.7413, 'longitude': -112.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84313', 'place_name': 'Grouse Creek', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.7094, 'longitude': -113.8833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84314', 'place_name': 'Honeyville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.652, 'longitude': -112.105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84316', 'place_name': 'Howell', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.7733, 'longitude': -112.3968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84324', 'place_name': 'Mantua', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.4975, 'longitude': -111.9416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84329', 'place_name': 'Park Valley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.8551, 'longitude': -113.3478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84330', 'place_name': 'Plymouth', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.8831, 'longitude': -112.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84331', 'place_name': 'Portage', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.9757, 'longitude': -112.2384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84334', 'place_name': 'Riverside', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.7868, 'longitude': -112.1467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84336', 'place_name': 'Snowville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.966, 'longitude': -112.7269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84337', 'place_name': 'Tremonton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.7016, 'longitude': -112.1813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84340', 'place_name': 'Willard', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Box Elder', 'locality_code': '3', 'latitude': 41.3989, 'longitude': -112.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84304', 'place_name': 'Cache Junction', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.8169, 'longitude': -111.9982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84305', 'place_name': 'Clarkston', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.9188, 'longitude': -112.0486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84308', 'place_name': 'Cornish', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.9443, 'longitude': -111.9733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84318', 'place_name': 'Hyde Park', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.8, 'longitude': -111.8123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84319', 'place_name': 'Hyrum', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.6311, 'longitude': -111.849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84320', 'place_name': 'Lewiston', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.9701, 'longitude': -111.8768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84321', 'place_name': 'Logan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.747, 'longitude': -111.8226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84322', 'place_name': 'Logan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.6412, 'longitude': -111.8966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84323', 'place_name': 'Logan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.7355, 'longitude': -111.8344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84325', 'place_name': 'Mendon', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.71, 'longitude': -111.9817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84326', 'place_name': 'Millville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.6759, 'longitude': -111.8185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84327', 'place_name': 'Newton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.8627, 'longitude': -111.9908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84328', 'place_name': 'Paradise', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.56, 'longitude': -111.8297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84332', 'place_name': 'Providence', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.7, 'longitude': -111.8123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84333', 'place_name': 'Richmond', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.9282, 'longitude': -111.8069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84335', 'place_name': 'Smithfield', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.8403, 'longitude': -111.8528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84338', 'place_name': 'Trenton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.9105, 'longitude': -111.934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84339', 'place_name': 'Wellsville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.6343, 'longitude': -111.9317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84341', 'place_name': 'Logan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Cache', 'locality_code': '5', 'latitude': 41.7759, 'longitude': -111.8068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84501', 'place_name': 'Price', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Carbon', 'locality_code': '7', 'latitude': 39.602, 'longitude': -110.8081, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84520', 'place_name': 'East Carbon', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Carbon', 'locality_code': '7', 'latitude': 39.5461, 'longitude': -110.4113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84526', 'place_name': 'Helper', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Carbon', 'locality_code': '7', 'latitude': 39.6737, 'longitude': -110.856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84529', 'place_name': 'Kenilworth', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Carbon', 'locality_code': '7', 'latitude': 39.6884, 'longitude': -110.8073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84539', 'place_name': 'Sunnyside', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Carbon', 'locality_code': '7', 'latitude': 39.5514, 'longitude': -110.3879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84542', 'place_name': 'Wellington', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Carbon', 'locality_code': '7', 'latitude': 39.5423, 'longitude': -110.735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84023', 'place_name': 'Dutch John', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Daggett', 'locality_code': '9', 'latitude': 40.9291, 'longitude': -109.391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84046', 'place_name': 'Manila', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Daggett', 'locality_code': '9', 'latitude': 40.9685, 'longitude': -109.7235, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84010', 'place_name': 'Bountiful', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 40.8775, 'longitude': -111.8727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84011', 'place_name': 'Bountiful', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 40.8894, 'longitude': -111.8808, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84014', 'place_name': 'Centerville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 40.9268, 'longitude': -111.877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84015', 'place_name': 'Clearfield', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 41.1294, 'longitude': -112.0482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84016', 'place_name': 'Clearfield', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 41.1108, 'longitude': -112.0261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84025', 'place_name': 'Farmington', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 40.9889, 'longitude': -111.8938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84037', 'place_name': 'Kaysville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 41.0375, 'longitude': -111.9326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84040', 'place_name': 'Layton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 41.0846, 'longitude': -111.9274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84041', 'place_name': 'Layton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 41.0879, 'longitude': -111.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84054', 'place_name': 'North Salt Lake', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 40.8446, 'longitude': -111.9191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84056', 'place_name': 'Hill Afb', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 41.1202, 'longitude': -111.9898, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84075', 'place_name': 'Syracuse', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 41.0864, 'longitude': -112.0451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84087', 'place_name': 'Woods Cross', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 40.8874, 'longitude': -111.9027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84089', 'place_name': 'Clearfield', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Davis', 'locality_code': '11', 'latitude': 40.9635, 'longitude': -112.116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84001', 'place_name': 'Altamont', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.3514, 'longitude': -110.2754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84002', 'place_name': 'Altonah', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.4013, 'longitude': -110.2938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84007', 'place_name': 'Bluebell', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.3594, 'longitude': -110.2174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84021', 'place_name': 'Duchesne', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.1633, 'longitude': -110.4029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84027', 'place_name': 'Fruitland', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.1575, 'longitude': -110.8226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84031', 'place_name': 'Hanna', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.4501, 'longitude': -110.8097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84051', 'place_name': 'Mountain Home', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.3922, 'longitude': -110.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84052', 'place_name': 'Myton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.194, 'longitude': -110.0481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84053', 'place_name': 'Neola', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.45, 'longitude': -110.0181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84066', 'place_name': 'Roosevelt', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.3102, 'longitude': -110.0108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84072', 'place_name': 'Tabiona', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.3827, 'longitude': -110.7021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84073', 'place_name': 'Talmage', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Duchesne', 'locality_code': '13', 'latitude': 40.3207, 'longitude': -110.436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84513', 'place_name': 'Castle Dale', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.2122, 'longitude': -111.0196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84516', 'place_name': 'Clawson', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.1198, 'longitude': -111.1008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84518', 'place_name': 'Cleveland', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.3489, 'longitude': -110.8516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84521', 'place_name': 'Elmo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.4033, 'longitude': -110.81, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84522', 'place_name': 'Emery', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 38.9226, 'longitude': -111.2512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84523', 'place_name': 'Ferron', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.0692, 'longitude': -111.1467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84525', 'place_name': 'Green River', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.0002, 'longitude': -110.1598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84528', 'place_name': 'Huntington', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.3266, 'longitude': -110.9646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84537', 'place_name': 'Orangeville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Emery', 'locality_code': '15', 'latitude': 39.2302, 'longitude': -111.0518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84712', 'place_name': 'Antimony', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 38.1015, 'longitude': -111.993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84716', 'place_name': 'Boulder', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.9166, 'longitude': -111.4266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84718', 'place_name': 'Cannonville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.5396, 'longitude': -112.0451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84726', 'place_name': 'Escalante', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.7698, 'longitude': -111.6037, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84735', 'place_name': 'Hatch', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.6497, 'longitude': -112.4344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84736', 'place_name': 'Henrieville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.5503, 'longitude': -111.9961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84759', 'place_name': 'Panguitch', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.8078, 'longitude': -112.4369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84764', 'place_name': 'Bryce', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.6184, 'longitude': -112.1735, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84776', 'place_name': 'Tropic', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Garfield', 'locality_code': '17', 'latitude': 37.6261, 'longitude': -112.0836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84515', 'place_name': 'Cisco', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Grand', 'locality_code': '19', 'latitude': 38.97, 'longitude': -109.3207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84532', 'place_name': 'Moab', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Grand', 'locality_code': '19', 'latitude': 38.5677, 'longitude': -109.5271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84540', 'place_name': 'Thompson', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Grand', 'locality_code': '19', 'latitude': 38.9711, 'longitude': -109.7137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84714', 'place_name': 'Beryl', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.8958, 'longitude': -113.6614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84719', 'place_name': 'Brian Head', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.6985, 'longitude': -112.8437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84720', 'place_name': 'Cedar City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.6775, 'longitude': -113.0619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84721', 'place_name': 'Cedar City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.6775, 'longitude': -113.0619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84742', 'place_name': 'Kanarraville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.5389, 'longitude': -113.1841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84753', 'place_name': 'Modena', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.7995, 'longitude': -113.9193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84756', 'place_name': 'Newcastle', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.6924, 'longitude': -113.6272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84760', 'place_name': 'Paragonah', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.8917, 'longitude': -112.774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84761', 'place_name': 'Parowan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.8449, 'longitude': -112.8323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84772', 'place_name': 'Summit', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Iron', 'locality_code': '21', 'latitude': 37.8011, 'longitude': -112.9363, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84628', 'place_name': 'Eureka', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Juab', 'locality_code': '23', 'latitude': 39.9541, 'longitude': -112.1174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84639', 'place_name': 'Levan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Juab', 'locality_code': '23', 'latitude': 39.5215, 'longitude': -111.9438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84645', 'place_name': 'Mona', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Juab', 'locality_code': '23', 'latitude': 39.8382, 'longitude': -111.848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84648', 'place_name': 'Nephi', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Juab', 'locality_code': '23', 'latitude': 39.6923, 'longitude': -111.8359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84710', 'place_name': 'Alton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Kane', 'locality_code': '25', 'latitude': 37.4699, 'longitude': -112.5484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84729', 'place_name': 'Glendale', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Kane', 'locality_code': '25', 'latitude': 37.3219, 'longitude': -112.6035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84741', 'place_name': 'Kanab', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Kane', 'locality_code': '25', 'latitude': 37.0475, 'longitude': -112.5263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84755', 'place_name': 'Mount Carmel', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Kane', 'locality_code': '25', 'latitude': 37.2472, 'longitude': -112.6644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84758', 'place_name': 'Orderville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Kane', 'locality_code': '25', 'latitude': 37.2744, 'longitude': -112.642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84762', 'place_name': 'Duck Creek Village', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Kane', 'locality_code': '25', 'latitude': 37.5169, 'longitude': -112.6636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84624', 'place_name': 'Delta', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 39.3755, 'longitude': -112.5319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84631', 'place_name': 'Fillmore', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 38.9805, 'longitude': -112.3313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84635', 'place_name': 'Hinckley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 39.3308, 'longitude': -112.6716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84636', 'place_name': 'Holden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 39.0964, 'longitude': -112.2834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84637', 'place_name': 'Kanosh', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 38.8318, 'longitude': -112.4561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84638', 'place_name': 'Leamington', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 39.5302, 'longitude': -112.2952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84640', 'place_name': 'Lynndyl', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 39.4943, 'longitude': -112.3979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84644', 'place_name': 'Meadow', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 38.8858, 'longitude': -112.4105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84649', 'place_name': 'Oak City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 39.3729, 'longitude': -112.3288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84656', 'place_name': 'Scipio', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 39.2495, 'longitude': -112.1064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84728', 'place_name': 'Garrison', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Millard', 'locality_code': '27', 'latitude': 38.9344, 'longitude': -114.033, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84018', 'place_name': 'Croydon', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Morgan', 'locality_code': '29', 'latitude': 41.0689, 'longitude': -111.5231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84050', 'place_name': 'Morgan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Morgan', 'locality_code': '29', 'latitude': 41.0678, 'longitude': -111.7163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84723', 'place_name': 'Circleville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Piute', 'locality_code': '31', 'latitude': 38.1827, 'longitude': -112.2329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84732', 'place_name': 'Greenwich', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Piute', 'locality_code': '31', 'latitude': 38.4454, 'longitude': -111.9023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84740', 'place_name': 'Junction', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Piute', 'locality_code': '31', 'latitude': 38.2439, 'longitude': -112.2237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84743', 'place_name': 'Kingston', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Piute', 'locality_code': '31', 'latitude': 38.2158, 'longitude': -112.2049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84750', 'place_name': 'Marysvale', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Piute', 'locality_code': '31', 'latitude': 38.4449, 'longitude': -112.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84028', 'place_name': 'Garden City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Rich', 'locality_code': '33', 'latitude': 41.9376, 'longitude': -111.407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84038', 'place_name': 'Laketown', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Rich', 'locality_code': '33', 'latitude': 41.8107, 'longitude': -111.2689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84064', 'place_name': 'Randolph', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Rich', 'locality_code': '33', 'latitude': 41.6563, 'longitude': -111.1856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84086', 'place_name': 'Woodruff', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Rich', 'locality_code': '33', 'latitude': 41.4888, 'longitude': -111.1868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84006', 'place_name': 'Bingham Canyon', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5646, 'longitude': -112.0977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84009', 'place_name': 'South Jordan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5622, 'longitude': -111.9297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84020', 'place_name': 'Draper', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5046, 'longitude': -111.881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84044', 'place_name': 'Magna', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7009, 'longitude': -112.0809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84047', 'place_name': 'Midvale', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6152, 'longitude': -111.8851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84065', 'place_name': 'Riverton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.4954, 'longitude': -111.9444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84070', 'place_name': 'Sandy', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5794, 'longitude': -111.8816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84081', 'place_name': 'West Jordan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6037, 'longitude': -112.0411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84084', 'place_name': 'West Jordan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6254, 'longitude': -111.9677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84088', 'place_name': 'West Jordan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5959, 'longitude': -111.9644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84090', 'place_name': 'Sandy', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84091', 'place_name': 'Sandy', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84092', 'place_name': 'Sandy', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5834, 'longitude': -111.7467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84093', 'place_name': 'Sandy', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5927, 'longitude': -111.831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84094', 'place_name': 'Sandy', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5688, 'longitude': -111.8617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84095', 'place_name': 'South Jordan', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5541, 'longitude': -111.9539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84096', 'place_name': 'Herriman', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.5144, 'longitude': -112.0325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84101', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7559, 'longitude': -111.8967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84102', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.76, 'longitude': -111.8627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84103', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7776, 'longitude': -111.8749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84104', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7499, 'longitude': -111.926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84105', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7372, 'longitude': -111.8581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84106', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7056, 'longitude': -111.8548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84107', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6568, 'longitude': -111.8904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84108', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7371, 'longitude': -111.8258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84109', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7043, 'longitude': -111.8142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84110', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84111', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7548, 'longitude': -111.881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84112', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7659, 'longitude': -111.8403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84113', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7658, 'longitude': -111.8364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84114', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84115', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7145, 'longitude': -111.8931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84116', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7857, 'longitude': -111.9291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84117', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6551, 'longitude': -111.834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84118', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6504, 'longitude': -112.0054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84119', 'place_name': 'West Valley City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6916, 'longitude': -112.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84120', 'place_name': 'West Valley City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6916, 'longitude': -112.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84121', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6226, 'longitude': -111.7777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84122', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84123', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6596, 'longitude': -111.9193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84124', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6772, 'longitude': -111.8133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84125', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84126', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84127', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84128', 'place_name': 'West Valley City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6916, 'longitude': -112.0011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84129', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6531, 'longitude': -111.9674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84130', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84131', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84132', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7727, 'longitude': -111.8385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84133', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.769, 'longitude': -111.8893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84134', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84136', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7685, 'longitude': -111.8879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84138', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7608, 'longitude': -111.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84139', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7608, 'longitude': -111.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84141', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84143', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7869, 'longitude': -111.9008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84145', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84147', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7608, 'longitude': -111.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84148', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7568, 'longitude': -111.8376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84150', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84151', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84152', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7608, 'longitude': -111.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84157', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84158', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.769, 'longitude': -111.7621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84165', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84170', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84171', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84180', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.769, 'longitude': -111.9008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84184', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6768, 'longitude': -111.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84189', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7608, 'longitude': -111.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84190', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.6681, 'longitude': -111.9083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84199', 'place_name': 'Salt Lake City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Salt Lake', 'locality_code': '35', 'latitude': 40.7259, 'longitude': -111.9394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84510', 'place_name': 'Aneth', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.2161, 'longitude': -109.1871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84511', 'place_name': 'Blanding', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.5863, 'longitude': -109.4866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84512', 'place_name': 'Bluff', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.2844, 'longitude': -109.5518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84530', 'place_name': 'La Sal', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 38.3122, 'longitude': -109.2482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84531', 'place_name': 'Mexican Hat', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.1184, 'longitude': -109.9919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84533', 'place_name': 'Lake Powell', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.7489, 'longitude': -110.2269, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84534', 'place_name': 'Montezuma Creek', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.2539, 'longitude': -109.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84535', 'place_name': 'Monticello', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.9217, 'longitude': -109.3153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84536', 'place_name': 'Monument Valley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'San Juan', 'locality_code': '37', 'latitude': 37.0614, 'longitude': -110.4273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84621', 'place_name': 'Axtell', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.0532, 'longitude': -111.8243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84622', 'place_name': 'Centerfield', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.1251, 'longitude': -111.8185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84623', 'place_name': 'Chester', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.4761, 'longitude': -111.563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84627', 'place_name': 'Ephraim', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.36, 'longitude': -111.5823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84629', 'place_name': 'Fairview', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.6264, 'longitude': -111.4396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84630', 'place_name': 'Fayette', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.2315, 'longitude': -111.8497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84632', 'place_name': 'Fountain Green', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.63, 'longitude': -111.6352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84634', 'place_name': 'Gunnison', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.1545, 'longitude': -111.8167, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84642', 'place_name': 'Manti', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.2683, 'longitude': -111.6369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84643', 'place_name': 'Mayfield', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.1154, 'longitude': -111.6905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84646', 'place_name': 'Moroni', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.525, 'longitude': -111.5905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84647', 'place_name': 'Mount Pleasant', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.5232, 'longitude': -111.5039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84662', 'place_name': 'Spring City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.4671, 'longitude': -111.4661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84665', 'place_name': 'Sterling', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.1936, 'longitude': -111.6924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84667', 'place_name': 'Wales', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sanpete', 'locality_code': '39', 'latitude': 39.4884, 'longitude': -111.6341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84620', 'place_name': 'Aurora', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.9222, 'longitude': -111.9341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84652', 'place_name': 'Redmond', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 39.0061, 'longitude': -111.8619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84654', 'place_name': 'Salina', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.956, 'longitude': -111.8811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84657', 'place_name': 'Sigurd', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.8482, 'longitude': -111.9737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84701', 'place_name': 'Richfield', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.7388, 'longitude': -112.0744, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84711', 'place_name': 'Annabella', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.7168, 'longitude': -112.0657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84724', 'place_name': 'Elsinore', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.6753, 'longitude': -112.1489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84730', 'place_name': 'Glenwood', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.7633, 'longitude': -111.9902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84739', 'place_name': 'Joseph', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.6221, 'longitude': -112.2251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84744', 'place_name': 'Koosharem', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.5103, 'longitude': -111.8813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84754', 'place_name': 'Monroe', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.6578, 'longitude': -112.1261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84766', 'place_name': 'Sevier', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Sevier', 'locality_code': '41', 'latitude': 38.5785, 'longitude': -112.3108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84017', 'place_name': 'Coalville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.8405, 'longitude': -111.3228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84024', 'place_name': 'Echo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.9892, 'longitude': -111.451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84033', 'place_name': 'Henefer', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 41.0186, 'longitude': -111.5011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84036', 'place_name': 'Kamas', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.6414, 'longitude': -111.2619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84055', 'place_name': 'Oakley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.7243, 'longitude': -111.2456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84060', 'place_name': 'Park City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.6524, 'longitude': -111.5018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84061', 'place_name': 'Peoa', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.7247, 'longitude': -111.3419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84068', 'place_name': 'Park City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.668, 'longitude': -111.5054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84098', 'place_name': 'Park City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Summit', 'locality_code': '43', 'latitude': 40.7029, 'longitude': -111.5481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84022', 'place_name': 'Dugway', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.2708, 'longitude': -112.6898, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84029', 'place_name': 'Grantsville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.6005, 'longitude': -112.4618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84034', 'place_name': 'Ibapah', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.0366, 'longitude': -113.9853, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84069', 'place_name': 'Rush Valley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.3566, 'longitude': -112.4659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84071', 'place_name': 'Stockton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.4415, 'longitude': -112.3559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84074', 'place_name': 'Tooele', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.5454, 'longitude': -112.3002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84080', 'place_name': 'Vernon', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.0826, 'longitude': -112.426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84083', 'place_name': 'Wendover', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Tooele', 'locality_code': '45', 'latitude': 40.7372, 'longitude': -114.0375, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84008', 'place_name': 'Bonanza', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.0211, 'longitude': -109.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84026', 'place_name': 'Fort Duchesne', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.3014, 'longitude': -109.8637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84035', 'place_name': 'Jensen', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.3787, 'longitude': -109.351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84039', 'place_name': 'Lapoint', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.4003, 'longitude': -109.8041, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84063', 'place_name': 'Randlett', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.2186, 'longitude': -109.7301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84076', 'place_name': 'Tridell', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.4436, 'longitude': -109.8359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84078', 'place_name': 'Vernal', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.4406, 'longitude': -109.5469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84079', 'place_name': 'Vernal', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.4555, 'longitude': -109.5287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84085', 'place_name': 'Whiterocks', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Uintah', 'locality_code': '47', 'latitude': 40.468, 'longitude': -109.9307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84003', 'place_name': 'American Fork', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.3928, 'longitude': -111.7941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84004', 'place_name': 'Alpine', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.4616, 'longitude': -111.7689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84005', 'place_name': 'Eagle Mountain', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.3802, 'longitude': -111.991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84013', 'place_name': 'Cedar Valley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.2959, 'longitude': -112.0923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84042', 'place_name': 'Lindon', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.3412, 'longitude': -111.7144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84043', 'place_name': 'Lehi', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.3958, 'longitude': -111.8506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84045', 'place_name': 'Saratoga Springs', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.3495, 'longitude': -111.9043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84057', 'place_name': 'Orem', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.3134, 'longitude': -111.6953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84058', 'place_name': 'Orem', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.2818, 'longitude': -111.7209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84059', 'place_name': 'Orem', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.177, 'longitude': -111.536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84062', 'place_name': 'Pleasant Grove', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.372, 'longitude': -111.7333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84097', 'place_name': 'Orem', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.2972, 'longitude': -111.6705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84601', 'place_name': 'Provo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.2319, 'longitude': -111.6755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84602', 'place_name': 'Provo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.3563, 'longitude': -111.7325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84603', 'place_name': 'Provo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.2039, 'longitude': -111.6261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84604', 'place_name': 'Provo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.2607, 'longitude': -111.6549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84605', 'place_name': 'Provo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.177, 'longitude': -111.536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84606', 'place_name': 'Provo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.2347, 'longitude': -111.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84626', 'place_name': 'Elberta', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 39.9739, 'longitude': -111.9554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84633', 'place_name': 'Goshen', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 39.953, 'longitude': -111.9008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84651', 'place_name': 'Payson', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.0449, 'longitude': -111.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84653', 'place_name': 'Salem', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.0113, 'longitude': -111.5998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84655', 'place_name': 'Santaquin', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 39.9737, 'longitude': -111.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84660', 'place_name': 'Spanish Fork', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.1099, 'longitude': -111.6462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84663', 'place_name': 'Springville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.1625, 'longitude': -111.5987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84664', 'place_name': 'Mapleton', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Utah', 'locality_code': '49', 'latitude': 40.1337, 'longitude': -111.5801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84032', 'place_name': 'Heber City', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wasatch', 'locality_code': '51', 'latitude': 40.4947, 'longitude': -111.4051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84049', 'place_name': 'Midway', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wasatch', 'locality_code': '51', 'latitude': 40.5093, 'longitude': -111.4776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84082', 'place_name': 'Wallsburg', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wasatch', 'locality_code': '51', 'latitude': 40.3657, 'longitude': -111.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84722', 'place_name': 'Central', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.4166, 'longitude': -113.6244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84725', 'place_name': 'Enterprise', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.5797, 'longitude': -113.6894, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84733', 'place_name': 'Gunlock', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.2877, 'longitude': -113.7606, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84737', 'place_name': 'Hurricane', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1454, 'longitude': -113.3675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84738', 'place_name': 'Ivins', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.179, 'longitude': -113.7066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84745', 'place_name': 'La Verkin', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.2316, 'longitude': -113.2446, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84746', 'place_name': 'Leeds', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.2386, 'longitude': -113.3591, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84757', 'place_name': 'New Harmony', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.455, 'longitude': -113.268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84763', 'place_name': 'Rockville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1601, 'longitude': -113.0425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84765', 'place_name': 'Santa Clara', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1282, 'longitude': -113.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84767', 'place_name': 'Springdale', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1862, 'longitude': -113.0139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84770', 'place_name': 'Saint George', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1041, 'longitude': -113.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84771', 'place_name': 'Saint George', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1041, 'longitude': -113.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84774', 'place_name': 'Toquerville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.2533, 'longitude': -113.2847, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '84779', 'place_name': 'Virgin', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.2022, 'longitude': -113.1854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84780', 'place_name': 'Washington', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1364, 'longitude': -113.505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84781', 'place_name': 'Pine Valley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.3898, 'longitude': -113.5177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84782', 'place_name': 'Veyo', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.359, 'longitude': -113.6668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84783', 'place_name': 'Dammeron Valley', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.2849, 'longitude': -113.6586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84784', 'place_name': 'Hildale', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.0044, 'longitude': -112.9784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84790', 'place_name': 'Saint George', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.0831, 'longitude': -113.5581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84791', 'place_name': 'Saint George', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Washington', 'locality_code': '53', 'latitude': 37.1041, 'longitude': -113.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84715', 'place_name': 'Bicknell', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wayne', 'locality_code': '55', 'latitude': 38.3278, 'longitude': -111.5264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84734', 'place_name': 'Hanksville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wayne', 'locality_code': '55', 'latitude': 38.2521, 'longitude': -110.8137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84747', 'place_name': 'Loa', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wayne', 'locality_code': '55', 'latitude': 38.4415, 'longitude': -111.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84749', 'place_name': 'Lyman', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wayne', 'locality_code': '55', 'latitude': 38.3969, 'longitude': -111.5896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84773', 'place_name': 'Teasdale', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wayne', 'locality_code': '55', 'latitude': 38.2853, 'longitude': -111.4335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84775', 'place_name': 'Torrey', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Wayne', 'locality_code': '55', 'latitude': 38.2969, 'longitude': -111.4138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84067', 'place_name': 'Roy', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.1724, 'longitude': -112.0382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84201', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2443, 'longitude': -112.0079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84244', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2553, 'longitude': -111.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84310', 'place_name': 'Eden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.3303, 'longitude': -111.8558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84315', 'place_name': 'Hooper', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.1668, 'longitude': -112.1364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84317', 'place_name': 'Huntsville', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2721, 'longitude': -111.7618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84401', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2215, 'longitude': -111.9621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84402', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2553, 'longitude': -111.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84403', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.1894, 'longitude': -111.9489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84404', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2627, 'longitude': -111.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84405', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.1739, 'longitude': -111.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84407', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2385, 'longitude': -111.9659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84408', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.1956, 'longitude': -111.9485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84409', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2553, 'longitude': -111.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84412', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2553, 'longitude': -111.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84414', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.3112, 'longitude': -111.9689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '84415', 'place_name': 'Ogden', 'state': 'Utah', 'state_ab': 'UT', 'county': 'Weber', 'locality_code': '57', 'latitude': 41.2553, 'longitude': -111.9567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23301', 'place_name': 'Accomac', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.7159, 'longitude': -75.6803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23302', 'place_name': 'Assawoman', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.8658, 'longitude': -75.5277, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23303', 'place_name': 'Atlantic', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9073, 'longitude': -75.5089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23306', 'place_name': 'Belle Haven', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.5645, 'longitude': -75.8694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23308', 'place_name': 'Bloxom', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.8273, 'longitude': -75.6156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23336', 'place_name': 'Chincoteague Island', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9299, 'longitude': -75.3624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23337', 'place_name': 'Wallops Island', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9186, 'longitude': -75.4905, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23341', 'place_name': 'Craddockville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.5773, 'longitude': -75.8646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23345', 'place_name': 'Davis Wharf', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.5529, 'longitude': -75.878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23356', 'place_name': 'Greenbackville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 38.0064, 'longitude': -75.4029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23357', 'place_name': 'Greenbush', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.7681, 'longitude': -75.6664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23358', 'place_name': 'Hacksneck', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6393, 'longitude': -75.865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23359', 'place_name': 'Hallwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.8837, 'longitude': -75.6041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23389', 'place_name': 'Harborton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6618, 'longitude': -75.8305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23395', 'place_name': 'Horntown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9699, 'longitude': -75.4716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23396', 'place_name': 'Oak Hall', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9237, 'longitude': -75.5551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23399', 'place_name': 'Jenkins Bridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9162, 'longitude': -75.6168, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23401', 'place_name': 'Keller', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6193, 'longitude': -75.7638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23404', 'place_name': 'Locustville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6534, 'longitude': -75.6735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23407', 'place_name': 'Mappsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.846, 'longitude': -75.5666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23409', 'place_name': 'Mears', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.8692, 'longitude': -75.6354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23410', 'place_name': 'Melfa', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6407, 'longitude': -75.7454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23412', 'place_name': 'Modest Town', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.7904, 'longitude': -75.6035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23414', 'place_name': 'Nelsonia', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.8169, 'longitude': -75.5832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23415', 'place_name': 'New Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9525, 'longitude': -75.5112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23416', 'place_name': 'Oak Hall', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9229, 'longitude': -75.5386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23417', 'place_name': 'Onancock', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.7102, 'longitude': -75.7528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23418', 'place_name': 'Onley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6704, 'longitude': -75.6992, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23420', 'place_name': 'Painter', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.5828, 'longitude': -75.8066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23421', 'place_name': 'Parksley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.7744, 'longitude': -75.6386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23422', 'place_name': 'Pungoteague', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6304, 'longitude': -75.8135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23423', 'place_name': 'Quinby', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.5423, 'longitude': -75.7412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23426', 'place_name': 'Sanford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9229, 'longitude': -75.6781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23427', 'place_name': 'Saxis', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9264, 'longitude': -75.722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23440', 'place_name': 'Tangier', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.8245, 'longitude': -75.993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23441', 'place_name': 'Tasley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.7104, 'longitude': -75.7005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23442', 'place_name': 'Temperanceville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.8954, 'longitude': -75.5528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23480', 'place_name': 'Wachapreague', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.6044, 'longitude': -75.6925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23483', 'place_name': 'Wattsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9437, 'longitude': -75.5023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23488', 'place_name': 'Withams', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Accomack', 'locality_code': '1', 'latitude': 37.9482, 'longitude': -75.6019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22901', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.0936, 'longitude': -78.5611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22909', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.0245, 'longitude': -78.4482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22911', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.0995, 'longitude': -78.4085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22924', 'place_name': 'Batesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.0013, 'longitude': -78.7271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22931', 'place_name': 'Covesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 37.908, 'longitude': -78.7127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22932', 'place_name': 'Crozet', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.1296, 'longitude': -78.7106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22936', 'place_name': 'Earlysville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.1578, 'longitude': -78.4919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22937', 'place_name': 'Esmont', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 37.8125, 'longitude': -78.6106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22940', 'place_name': 'Free Union', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.1944, 'longitude': -78.5849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22943', 'place_name': 'Greenwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.0415, 'longitude': -78.7833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22945', 'place_name': 'Ivy', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.0654, 'longitude': -78.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22946', 'place_name': 'Keene', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 37.856, 'longitude': -78.5699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22947', 'place_name': 'Keswick', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.0531, 'longitude': -78.3396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22959', 'place_name': 'North Garden', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 37.9336, 'longitude': -78.6351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22987', 'place_name': 'White Hall', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 38.1179, 'longitude': -78.6614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24562', 'place_name': 'Howardsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 37.7511, 'longitude': -78.6313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24590', 'place_name': 'Scottsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Albemarle', 'locality_code': '3', 'latitude': 37.8049, 'longitude': -78.474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24422', 'place_name': 'Clifton Forge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 37.8203, 'longitude': -79.8054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24448', 'place_name': 'Iron Gate', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 37.7965, 'longitude': -79.786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24457', 'place_name': 'Low Moor', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 37.7887, 'longitude': -79.8837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24474', 'place_name': 'Selma', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Alleghany', 'locality_code': '5', 'latitude': 37.8062, 'longitude': -79.8404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23002', 'place_name': 'Amelia Court House', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amelia', 'locality_code': '7', 'latitude': 37.3428, 'longitude': -77.9841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23083', 'place_name': 'Jetersville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amelia', 'locality_code': '7', 'latitude': 37.3176, 'longitude': -78.104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23105', 'place_name': 'Mannboro', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amelia', 'locality_code': '7', 'latitude': 37.345, 'longitude': -77.9449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24521', 'place_name': 'Amherst', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amherst', 'locality_code': '9', 'latitude': 37.6027, 'longitude': -79.0506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24533', 'place_name': 'Clifford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amherst', 'locality_code': '9', 'latitude': 37.538, 'longitude': -78.9463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24572', 'place_name': 'Madison Heights', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amherst', 'locality_code': '9', 'latitude': 37.4531, 'longitude': -79.1141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24574', 'place_name': 'Monroe', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amherst', 'locality_code': '9', 'latitude': 37.5414, 'longitude': -79.1703, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24595', 'place_name': 'Sweet Briar', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Amherst', 'locality_code': '9', 'latitude': 37.5529, 'longitude': -79.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23939', 'place_name': 'Evergreen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Appomattox', 'locality_code': '11', 'latitude': 37.3185, 'longitude': -78.7658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23958', 'place_name': 'Pamplin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Appomattox', 'locality_code': '11', 'latitude': 37.2653, 'longitude': -78.6517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24522', 'place_name': 'Appomattox', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Appomattox', 'locality_code': '11', 'latitude': 37.353, 'longitude': -78.8224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24593', 'place_name': 'Spout Spring', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Appomattox', 'locality_code': '11', 'latitude': 37.3643, 'longitude': -78.9059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22201', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8871, 'longitude': -77.0932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22202', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8565, 'longitude': -77.0592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22203', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8738, 'longitude': -77.1142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22204', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.859, 'longitude': -77.0997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22205', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8836, 'longitude': -77.1395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22206', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8415, 'longitude': -77.0905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22207', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.9033, 'longitude': -77.1263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22209', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8926, 'longitude': -77.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22210', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22211', 'place_name': 'Fort Myer', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8921, 'longitude': -77.0794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22212', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22213', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8954, 'longitude': -77.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22214', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8688, 'longitude': -77.0739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22215', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22216', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22217', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22219', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22225', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22226', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8834, 'longitude': -77.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22227', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22230', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8797, 'longitude': -77.1108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22240', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8566, 'longitude': -77.0518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22241', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22242', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8509, 'longitude': -77.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22243', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8605, 'longitude': -77.0516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22244', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8545, 'longitude': -77.052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22245', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8518, 'longitude': -77.0523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22246', 'place_name': 'Arlington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Arlington', 'locality_code': '13', 'latitude': 38.8808, 'longitude': -77.1129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22843', 'place_name': 'Mount Solon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.3328, 'longitude': -79.1028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22939', 'place_name': 'Fishersville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.0964, 'longitude': -78.9929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22952', 'place_name': 'Lyndhurst', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 37.9744, 'longitude': -78.9361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24411', 'place_name': 'Augusta Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.1025, 'longitude': -79.3195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24421', 'place_name': 'Churchville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.2346, 'longitude': -79.1791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24430', 'place_name': 'Craigsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.0768, 'longitude': -79.3619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24431', 'place_name': 'Crimora', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.1684, 'longitude': -78.8413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24432', 'place_name': 'Deerfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.1842, 'longitude': -79.4152, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24437', 'place_name': 'Fort Defiance', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.2109, 'longitude': -78.9326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24440', 'place_name': 'Greenville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.0018, 'longitude': -79.1359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24459', 'place_name': 'Middlebrook', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.0242, 'longitude': -79.2812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24463', 'place_name': 'Mint Spring', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.1797, 'longitude': -79.1413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24467', 'place_name': 'Mount Sidney', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.2612, 'longitude': -78.973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24469', 'place_name': 'New Hope', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.1979, 'longitude': -78.9059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24476', 'place_name': 'Steeles Tavern', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 37.9705, 'longitude': -79.2233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24477', 'place_name': 'Stuarts Draft', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.0144, 'longitude': -79.0298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24479', 'place_name': 'Swoope', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.1591, 'longitude': -79.1873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24482', 'place_name': 'Verona', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.2037, 'longitude': -79.0059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24485', 'place_name': 'West Augusta', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.2744, 'longitude': -79.3201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24486', 'place_name': 'Weyers Cave', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Augusta', 'locality_code': '15', 'latitude': 38.2931, 'longitude': -78.9235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24412', 'place_name': 'Bacova', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bath', 'locality_code': '17', 'latitude': 38.054, 'longitude': -79.8437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24445', 'place_name': 'Hot Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bath', 'locality_code': '17', 'latitude': 37.9638, 'longitude': -79.8717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24460', 'place_name': 'Millboro', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bath', 'locality_code': '17', 'latitude': 38.0553, 'longitude': -79.7464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24484', 'place_name': 'Warm Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bath', 'locality_code': '17', 'latitude': 38.1437, 'longitude': -79.8207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24487', 'place_name': 'Williamsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bath', 'locality_code': '17', 'latitude': 38.1898, 'longitude': -79.5879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24095', 'place_name': 'Goodview', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.2123, 'longitude': -79.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24101', 'place_name': 'Hardy', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.2145, 'longitude': -79.8127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24104', 'place_name': 'Huddleston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.1442, 'longitude': -79.491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24121', 'place_name': 'Moneta', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.1784, 'longitude': -79.6521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24122', 'place_name': 'Montvale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.407, 'longitude': -79.7175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24174', 'place_name': 'Thaxton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.36, 'longitude': -79.6522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24178', 'place_name': 'Villamont', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.3105, 'longitude': -79.7898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24526', 'place_name': 'Big Island', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.5306, 'longitude': -79.3827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24536', 'place_name': 'Coleman Falls', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.4887, 'longitude': -79.3158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24551', 'place_name': 'Forest', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.3379, 'longitude': -79.2791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24556', 'place_name': 'Goode', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.3755, 'longitude': -79.4039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24570', 'place_name': 'Lowry', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford', 'locality_code': '19', 'latitude': 37.3484, 'longitude': -79.4271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24314', 'place_name': 'Bastian', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bland', 'locality_code': '21', 'latitude': 37.1574, 'longitude': -81.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24315', 'place_name': 'Bland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bland', 'locality_code': '21', 'latitude': 37.1376, 'longitude': -81.0201, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24318', 'place_name': 'Ceres', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bland', 'locality_code': '21', 'latitude': 37.0046, 'longitude': -81.3643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24366', 'place_name': 'Rocky Gap', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bland', 'locality_code': '21', 'latitude': 37.2578, 'longitude': -81.1159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24019', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.3515, 'longitude': -79.9052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24050', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.5551, 'longitude': -79.7862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24064', 'place_name': 'Blue Ridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.3885, 'longitude': -79.8172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24066', 'place_name': 'Buchanan', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.5479, 'longitude': -79.7123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24077', 'place_name': 'Cloverdale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.3651, 'longitude': -79.9056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24083', 'place_name': 'Daleville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.4125, 'longitude': -79.9211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24085', 'place_name': 'Eagle Rock', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.6667, 'longitude': -79.8172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24090', 'place_name': 'Fincastle', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.4911, 'longitude': -79.8511, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24130', 'place_name': 'Oriskany', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.6165, 'longitude': -79.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24175', 'place_name': 'Troutville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.4019, 'longitude': -79.8786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24438', 'place_name': 'Glen Wilton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Botetourt', 'locality_code': '23', 'latitude': 37.7529, 'longitude': -79.8189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23821', 'place_name': 'Alberta', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.8806, 'longitude': -77.9055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23843', 'place_name': 'Dolphin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.8318, 'longitude': -77.7887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23845', 'place_name': 'Ebony', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.5722, 'longitude': -77.9888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23856', 'place_name': 'Freeman', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.7893, 'longitude': -77.7208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23857', 'place_name': 'Gasburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.5856, 'longitude': -77.8836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23868', 'place_name': 'Lawrenceville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.7342, 'longitude': -77.8136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23873', 'place_name': 'Meredithville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.8088, 'longitude': -77.9544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23876', 'place_name': 'Rawlings', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.953, 'longitude': -77.8237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23887', 'place_name': 'Valentines', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.565, 'longitude': -77.8384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23889', 'place_name': 'Warfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.9011, 'longitude': -77.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23893', 'place_name': 'White Plains', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.6335, 'longitude': -77.9592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23920', 'place_name': 'Brodnax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Brunswick', 'locality_code': '25', 'latitude': 36.7319, 'longitude': -77.9898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24239', 'place_name': 'Davenport', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.1134, 'longitude': -82.1501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24603', 'place_name': 'Big Rock', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.3532, 'longitude': -82.1968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24614', 'place_name': 'Grundy', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.2967, 'longitude': -82.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24620', 'place_name': 'Hurley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.4017, 'longitude': -82.0262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24624', 'place_name': 'Keen Mountain', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.2023, 'longitude': -81.9862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24627', 'place_name': 'Mavisdale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.288, 'longitude': -82.0274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24628', 'place_name': 'Maxie', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.3012, 'longitude': -82.1743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24631', 'place_name': 'Oakwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.2138, 'longitude': -81.9917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24634', 'place_name': 'Pilgrims Knob', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.2746, 'longitude': -81.9024, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24639', 'place_name': 'Raven', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.1481, 'longitude': -81.8896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24646', 'place_name': 'Rowe', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.1276, 'longitude': -82.0274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24647', 'place_name': 'Shortt Gap', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.1573, 'longitude': -81.8729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24656', 'place_name': 'Vansant', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.1738, 'longitude': -82.1277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24657', 'place_name': 'Whitewood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.2251, 'longitude': -81.8605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24658', 'place_name': 'Wolford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buchanan', 'locality_code': '27', 'latitude': 37.288, 'longitude': -82.0274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23004', 'place_name': 'Arvonia', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buckingham', 'locality_code': '29', 'latitude': 37.6714, 'longitude': -78.3889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23123', 'place_name': 'New Canton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buckingham', 'locality_code': '29', 'latitude': 37.6645, 'longitude': -78.3112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23921', 'place_name': 'Buckingham', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buckingham', 'locality_code': '29', 'latitude': 37.5833, 'longitude': -78.5985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23936', 'place_name': 'Dillwyn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buckingham', 'locality_code': '29', 'latitude': 37.4124, 'longitude': -78.4349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24513', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.2458, 'longitude': -79.1335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24517', 'place_name': 'Altavista', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.1222, 'longitude': -79.2911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24528', 'place_name': 'Brookneal', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.0827, 'longitude': -78.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24538', 'place_name': 'Concord', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.337, 'longitude': -78.9804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24550', 'place_name': 'Evington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.261, 'longitude': -79.2317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24554', 'place_name': 'Gladys', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.1386, 'longitude': -79.1048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24569', 'place_name': 'Long Island', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.0644, 'longitude': -79.1219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24571', 'place_name': 'Lynch Station', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.1528, 'longitude': -79.3297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24576', 'place_name': 'Naruna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.2458, 'longitude': -79.1335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24588', 'place_name': 'Rustburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Campbell', 'locality_code': '31', 'latitude': 37.2545, 'longitude': -79.1215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22427', 'place_name': 'Bowling Green', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.0137, 'longitude': -77.1802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22428', 'place_name': 'Bowling Green', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.0496, 'longitude': -77.3466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22446', 'place_name': 'Corbin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.1996, 'longitude': -77.3889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22501', 'place_name': 'Ladysmith', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.0176, 'longitude': -77.5153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22514', 'place_name': 'Milford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.0058, 'longitude': -77.3185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22535', 'place_name': 'Port Royal', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.1621, 'longitude': -77.1837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22538', 'place_name': 'Rappahannock Academy', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.2079, 'longitude': -77.2502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22546', 'place_name': 'Ruther Glen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 37.9451, 'longitude': -77.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22552', 'place_name': 'Sparta', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.0094, 'longitude': -77.2251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22580', 'place_name': 'Woodford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Caroline', 'locality_code': '33', 'latitude': 38.0847, 'longitude': -77.4399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24317', 'place_name': 'Cana', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Carroll', 'locality_code': '35', 'latitude': 36.5957, 'longitude': -80.6705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24325', 'place_name': 'Dugspur', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Carroll', 'locality_code': '35', 'latitude': 36.8145, 'longitude': -80.6123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24328', 'place_name': 'Fancy Gap', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Carroll', 'locality_code': '35', 'latitude': 36.664, 'longitude': -80.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24343', 'place_name': 'Hillsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Carroll', 'locality_code': '35', 'latitude': 36.7442, 'longitude': -80.7197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24351', 'place_name': 'Lambsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Carroll', 'locality_code': '35', 'latitude': 36.5775, 'longitude': -80.7601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24352', 'place_name': 'Laurel Fork', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Carroll', 'locality_code': '35', 'latitude': 36.7073, 'longitude': -80.5148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24381', 'place_name': 'Woodlawn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Carroll', 'locality_code': '35', 'latitude': 36.7879, 'longitude': -80.8824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23030', 'place_name': 'Charles City', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charles City', 'locality_code': '36', 'latitude': 37.3663, 'longitude': -77.1082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23147', 'place_name': 'Ruthville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charles City', 'locality_code': '36', 'latitude': 37.3796, 'longitude': -77.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23923', 'place_name': 'Charlotte Court House', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 37.0879, 'longitude': -78.6378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23934', 'place_name': 'Cullen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 37.1552, 'longitude': -78.6459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23937', 'place_name': 'Drakes Branch', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 36.9688, 'longitude': -78.5615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23947', 'place_name': 'Keysville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 37.0411, 'longitude': -78.4699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23959', 'place_name': 'Phenix', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 37.0925, 'longitude': -78.7912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23962', 'place_name': 'Randolph', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 36.9515, 'longitude': -78.7054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23963', 'place_name': 'Red House', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 37.1914, 'longitude': -78.8145, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23964', 'place_name': 'Red Oak', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 36.7724, 'longitude': -78.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23967', 'place_name': 'Saxe', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 36.9053, 'longitude': -78.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23976', 'place_name': 'Wylliesburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlotte', 'locality_code': '37', 'latitude': 36.8391, 'longitude': -78.5982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23112', 'place_name': 'Midlothian', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.431, 'longitude': -77.6545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23113', 'place_name': 'Midlothian', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.5109, 'longitude': -77.6429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23114', 'place_name': 'Midlothian', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.4815, 'longitude': -77.6419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23120', 'place_name': 'Moseley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.426, 'longitude': -77.7585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23234', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.4373, 'longitude': -77.4788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23235', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.5133, 'longitude': -77.5646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23236', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.4782, 'longitude': -77.5854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23237', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.4011, 'longitude': -77.4615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23297', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.3897, 'longitude': -77.5613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23831', 'place_name': 'Chester', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.3429, 'longitude': -77.4156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23832', 'place_name': 'Chesterfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.3923, 'longitude': -77.5668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23836', 'place_name': 'Chester', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.3475, 'longitude': -77.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23838', 'place_name': 'Chesterfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesterfield', 'locality_code': '41', 'latitude': 37.3333, 'longitude': -77.6343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22611', 'place_name': 'Berryville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Clarke', 'locality_code': '43', 'latitude': 39.1532, 'longitude': -77.9688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22620', 'place_name': 'Boyce', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Clarke', 'locality_code': '43', 'latitude': 39.0698, 'longitude': -78.0203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22646', 'place_name': 'Millwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Clarke', 'locality_code': '43', 'latitude': 39.0696, 'longitude': -78.0378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22663', 'place_name': 'White Post', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Clarke', 'locality_code': '43', 'latitude': 39.058, 'longitude': -78.1105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24127', 'place_name': 'New Castle', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Craig', 'locality_code': '45', 'latitude': 37.4871, 'longitude': -80.1704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24131', 'place_name': 'Paint Bank', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Craig', 'locality_code': '45', 'latitude': 37.5745, 'longitude': -80.2544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22701', 'place_name': 'Culpeper', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.5117, 'longitude': -77.9928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22713', 'place_name': 'Boston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.5382, 'longitude': -78.1423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22714', 'place_name': 'Brandy Station', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.511, 'longitude': -77.9037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22718', 'place_name': 'Elkwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.4652, 'longitude': -77.817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22724', 'place_name': 'Jeffersonton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.6256, 'longitude': -77.9069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22726', 'place_name': 'Lignum', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.3956, 'longitude': -77.83, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22729', 'place_name': 'Mitchells', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.3744, 'longitude': -78.0105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22733', 'place_name': 'Rapidan', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.3392, 'longitude': -78.0476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22735', 'place_name': 'Reva', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.4604, 'longitude': -78.1572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22736', 'place_name': 'Richardsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.3924, 'longitude': -77.7195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22737', 'place_name': 'Rixeyville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.5852, 'longitude': -78.0282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22741', 'place_name': 'Stevensburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Culpeper', 'locality_code': '47', 'latitude': 38.4441, 'longitude': -77.8842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23027', 'place_name': 'Cartersville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Cumberland', 'locality_code': '49', 'latitude': 37.6479, 'longitude': -78.1389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23040', 'place_name': 'Cumberland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Cumberland', 'locality_code': '49', 'latitude': 37.5019, 'longitude': -78.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24217', 'place_name': 'Bee', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.1014, 'longitude': -82.1856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24220', 'place_name': 'Birchleaf', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.1394, 'longitude': -82.2433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24226', 'place_name': 'Clinchco', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.1406, 'longitude': -82.3425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24228', 'place_name': 'Clintwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.1592, 'longitude': -82.4453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24256', 'place_name': 'Haysi', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.2206, 'longitude': -82.2853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24269', 'place_name': 'Mc Clure', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.0814, 'longitude': -82.3806, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24272', 'place_name': 'Nora', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.0182, 'longitude': -82.35, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24607', 'place_name': 'Breaks', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dickenson', 'locality_code': '51', 'latitude': 37.2959, 'longitude': -82.281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23822', 'place_name': 'Ammon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.0724, 'longitude': -77.6475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23830', 'place_name': 'Carson', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.0393, 'longitude': -77.4351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23833', 'place_name': 'Church Road', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.195, 'longitude': -77.6646, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23840', 'place_name': 'Dewitt', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.0535, 'longitude': -77.6426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23841', 'place_name': 'Dinwiddie', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.0833, 'longitude': -77.5585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23850', 'place_name': 'Ford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.1349, 'longitude': -77.7364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23872', 'place_name': 'Mc Kenney', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 36.9986, 'longitude': -77.7396, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23885', 'place_name': 'Sutherland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.1901, 'longitude': -77.5655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23894', 'place_name': 'Wilsons', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Dinwiddie', 'locality_code': '53', 'latitude': 37.1157, 'longitude': -77.8352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22436', 'place_name': 'Caret', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 37.9826, 'longitude': -76.9614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22437', 'place_name': 'Center Cross', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 37.7929, 'longitude': -76.7548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22438', 'place_name': 'Champlain', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 38.0214, 'longitude': -76.9719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22454', 'place_name': 'Dunnsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 37.8527, 'longitude': -76.8475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22476', 'place_name': 'Hustle', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 38.0329, 'longitude': -77.0633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22504', 'place_name': 'Laneview', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 37.7681, 'longitude': -76.7117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22509', 'place_name': 'Loretto', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 38.0789, 'longitude': -77.0485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22560', 'place_name': 'Tappahannock', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 37.9146, 'longitude': -76.9125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23115', 'place_name': 'Millers Tavern', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Essex', 'locality_code': '57', 'latitude': 37.8282, 'longitude': -76.945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20120', 'place_name': 'Centreville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8448, 'longitude': -77.467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20121', 'place_name': 'Centreville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8195, 'longitude': -77.4558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20122', 'place_name': 'Centreville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20124', 'place_name': 'Clifton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7818, 'longitude': -77.3818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20151', 'place_name': 'Chantilly', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8867, 'longitude': -77.4457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20153', 'place_name': 'Chantilly', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20170', 'place_name': 'Herndon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9839, 'longitude': -77.3675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20171', 'place_name': 'Herndon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9252, 'longitude': -77.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20172', 'place_name': 'Herndon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9696, 'longitude': -77.3861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20190', 'place_name': 'Reston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9615, 'longitude': -77.3418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20191', 'place_name': 'Reston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9318, 'longitude': -77.3527, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20192', 'place_name': 'Herndon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20194', 'place_name': 'Reston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9807, 'longitude': -77.3419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20195', 'place_name': 'Reston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20196', 'place_name': 'Reston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22003', 'place_name': 'Annandale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8307, 'longitude': -77.2142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22009', 'place_name': 'Burke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22015', 'place_name': 'Burke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7894, 'longitude': -77.2818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22027', 'place_name': 'Dunn Loring', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8954, 'longitude': -77.2214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22032', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8177, 'longitude': -77.2925, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22033', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8776, 'longitude': -77.3885, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22034', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22035', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8557, 'longitude': -77.3616, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22036', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7351, 'longitude': -77.0797, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22037', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22039', 'place_name': 'Fairfax Station', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7602, 'longitude': -77.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22041', 'place_name': 'Falls Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8502, 'longitude': -77.1448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22042', 'place_name': 'Falls Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8635, 'longitude': -77.1939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22043', 'place_name': 'Falls Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8994, 'longitude': -77.1895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22044', 'place_name': 'Falls Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8589, 'longitude': -77.1548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22060', 'place_name': 'Fort Belvoir', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.6947, 'longitude': -77.1433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22066', 'place_name': 'Great Falls', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 39.0039, 'longitude': -77.3083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22067', 'place_name': 'Greenway', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9645, 'longitude': -77.2331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22079', 'place_name': 'Lorton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.6929, 'longitude': -77.204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22081', 'place_name': 'Merrifield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8739, 'longitude': -77.2345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22082', 'place_name': 'Merrifield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8743, 'longitude': -77.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22095', 'place_name': 'Herndon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9696, 'longitude': -77.3861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22096', 'place_name': 'Reston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22101', 'place_name': 'Mc Lean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9326, 'longitude': -77.1706, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22102', 'place_name': 'Mc Lean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.953, 'longitude': -77.2295, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22103', 'place_name': 'West Mclean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22106', 'place_name': 'Mc Lean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9335, 'longitude': -77.1797, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22107', 'place_name': 'Mc Lean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9321, 'longitude': -77.1841, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22108', 'place_name': 'Mc Lean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9321, 'longitude': -77.1841, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22109', 'place_name': 'Mc Lean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.9335, 'longitude': -77.1797, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22116', 'place_name': 'Merrifield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8715, 'longitude': -77.2344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22118', 'place_name': 'Merrifield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22119', 'place_name': 'Merrifield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22121', 'place_name': 'Mount Vernon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7192, 'longitude': -77.1073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22122', 'place_name': 'Newington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7384, 'longitude': -77.185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22124', 'place_name': 'Oakton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8852, 'longitude': -77.3233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22150', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7797, 'longitude': -77.1866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22151', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8029, 'longitude': -77.2116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22152', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7757, 'longitude': -77.2337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22153', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7449, 'longitude': -77.237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22156', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22158', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22159', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22160', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22161', 'place_name': 'Springfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7893, 'longitude': -77.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22180', 'place_name': 'Vienna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8935, 'longitude': -77.2532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22181', 'place_name': 'Vienna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8977, 'longitude': -77.288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22182', 'place_name': 'Vienna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.928, 'longitude': -77.2649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22183', 'place_name': 'Vienna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22185', 'place_name': 'Vienna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8318, 'longitude': -77.2888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22199', 'place_name': 'Lorton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7043, 'longitude': -77.2278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22303', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7912, 'longitude': -77.0814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22306', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7589, 'longitude': -77.0873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22307', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7714, 'longitude': -77.0657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22308', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7316, 'longitude': -77.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22309', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7192, 'longitude': -77.1073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22310', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7794, 'longitude': -77.1194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22312', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.8191, 'longitude': -77.1484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22315', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax', 'locality_code': '59', 'latitude': 38.7596, 'longitude': -77.1485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20115', 'place_name': 'Marshall', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.8405, 'longitude': -77.8911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20116', 'place_name': 'Marshall', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.8537, 'longitude': -77.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20119', 'place_name': 'Catlett', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.637, 'longitude': -77.6383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20128', 'place_name': 'Orlean', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.7416, 'longitude': -77.9774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20130', 'place_name': 'Paris', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 39.0048, 'longitude': -77.9546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20137', 'place_name': 'Broad Run', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.8237, 'longitude': -77.713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20138', 'place_name': 'Calverton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.6338, 'longitude': -77.6869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20139', 'place_name': 'Casanova', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.6543, 'longitude': -77.7025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20140', 'place_name': 'Rectortown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.9163, 'longitude': -77.8648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20144', 'place_name': 'Delaplane', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.9113, 'longitude': -77.9674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20184', 'place_name': 'Upperville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.9627, 'longitude': -77.8847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20185', 'place_name': 'Upperville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.993, 'longitude': -77.8799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20186', 'place_name': 'Warrenton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.6898, 'longitude': -77.8361, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20187', 'place_name': 'Warrenton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.7153, 'longitude': -77.7417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20188', 'place_name': 'Warrenton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.7656, 'longitude': -77.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20198', 'place_name': 'The Plains', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.8707, 'longitude': -77.7608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22639', 'place_name': 'Hume', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.8273, 'longitude': -77.9949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22643', 'place_name': 'Markham', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.904, 'longitude': -78.0019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22712', 'place_name': 'Bealeton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.5453, 'longitude': -77.7561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22720', 'place_name': 'Goldvein', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.4725, 'longitude': -77.6423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22728', 'place_name': 'Midland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.5671, 'longitude': -77.7127, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22734', 'place_name': 'Remington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.5309, 'longitude': -77.8037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22739', 'place_name': 'Somerville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.5059, 'longitude': -77.5956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22742', 'place_name': 'Sumerduck', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fauquier', 'locality_code': '61', 'latitude': 38.4674, 'longitude': -77.7044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24072', 'place_name': 'Check', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Floyd', 'locality_code': '63', 'latitude': 37.0446, 'longitude': -80.228, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24079', 'place_name': 'Copper Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Floyd', 'locality_code': '63', 'latitude': 37.0556, 'longitude': -80.1525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24091', 'place_name': 'Floyd', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Floyd', 'locality_code': '63', 'latitude': 36.8957, 'longitude': -80.3275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24105', 'place_name': 'Indian Valley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Floyd', 'locality_code': '63', 'latitude': 36.899, 'longitude': -80.5757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24380', 'place_name': 'Willis', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Floyd', 'locality_code': '63', 'latitude': 36.8749, 'longitude': -80.4909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22963', 'place_name': 'Palmyra', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fluvanna', 'locality_code': '65', 'latitude': 37.8931, 'longitude': -78.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22974', 'place_name': 'Troy', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fluvanna', 'locality_code': '65', 'latitude': 37.9636, 'longitude': -78.2535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23022', 'place_name': 'Bremo Bluff', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fluvanna', 'locality_code': '65', 'latitude': 37.7453, 'longitude': -78.2672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23055', 'place_name': 'Fork Union', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fluvanna', 'locality_code': '65', 'latitude': 37.7715, 'longitude': -78.2355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23084', 'place_name': 'Kents Store', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fluvanna', 'locality_code': '65', 'latitude': 37.8942, 'longitude': -78.1208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24065', 'place_name': 'Boones Mill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 37.1331, 'longitude': -79.9556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24067', 'place_name': 'Callaway', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 37.0285, 'longitude': -80.0496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24088', 'place_name': 'Ferrum', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 36.9168, 'longitude': -80.0349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24092', 'place_name': 'Glade Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 36.9859, 'longitude': -79.773, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24102', 'place_name': 'Henry', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 36.8393, 'longitude': -79.9904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24137', 'place_name': 'Penhook', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 36.9201, 'longitude': -79.6645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24146', 'place_name': 'Redwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 37.0069, 'longitude': -79.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24151', 'place_name': 'Rocky Mount', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 36.9891, 'longitude': -79.884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24176', 'place_name': 'Union Hall', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 37.0131, 'longitude': -79.6864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24184', 'place_name': 'Wirtz', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin', 'locality_code': '67', 'latitude': 37.0818, 'longitude': -79.7573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22602', 'place_name': 'Winchester', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.1501, 'longitude': -78.269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22603', 'place_name': 'Winchester', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.264, 'longitude': -78.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22622', 'place_name': 'Brucetown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.2543, 'longitude': -78.0664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22624', 'place_name': 'Clear Brook', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.2655, 'longitude': -78.0988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22625', 'place_name': 'Cross Junction', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.3744, 'longitude': -78.3081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22637', 'place_name': 'Gore', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.2887, 'longitude': -78.3417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22645', 'place_name': 'Middletown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.0367, 'longitude': -78.2815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22654', 'place_name': 'Star Tannery', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.0908, 'longitude': -78.4343, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22655', 'place_name': 'Stephens City', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.0834, 'longitude': -78.1907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22656', 'place_name': 'Stephenson', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Frederick', 'locality_code': '69', 'latitude': 39.1973, 'longitude': -78.0941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24086', 'place_name': 'Eggleston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.2743, 'longitude': -80.6343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24093', 'place_name': 'Glen Lyn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.3669, 'longitude': -80.8634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24124', 'place_name': 'Narrows', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.3198, 'longitude': -80.8548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24128', 'place_name': 'Newport', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.3069, 'longitude': -80.5099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24134', 'place_name': 'Pearisburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.3041, 'longitude': -80.7267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24136', 'place_name': 'Pembroke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.3312, 'longitude': -80.5975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24147', 'place_name': 'Rich Creek', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.385, 'longitude': -80.8227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24150', 'place_name': 'Ripplemead', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.3665, 'longitude': -80.6717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24167', 'place_name': 'Staffordsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Giles', 'locality_code': '71', 'latitude': 37.2491, 'longitude': -80.7344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23001', 'place_name': 'Achilles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.2882, 'longitude': -76.426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23003', 'place_name': 'Ark', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.4323, 'longitude': -76.6016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23018', 'place_name': 'Bena', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.271, 'longitude': -76.4555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23050', 'place_name': 'Dutton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.5001, 'longitude': -76.454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23061', 'place_name': 'Gloucester', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.4126, 'longitude': -76.5464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23062', 'place_name': 'Gloucester Point', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.2585, 'longitude': -76.4959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23072', 'place_name': 'Hayes', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.2916, 'longitude': -76.4905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23107', 'place_name': 'Maryus', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.2864, 'longitude': -76.4048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23131', 'place_name': 'Ordinary', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.3122, 'longitude': -76.5188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23154', 'place_name': 'Schley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.3896, 'longitude': -76.4549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23155', 'place_name': 'Severn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.4182, 'longitude': -76.5084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23178', 'place_name': 'Ware Neck', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.4004, 'longitude': -76.4529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23183', 'place_name': 'White Marsh', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.3632, 'longitude': -76.5325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23184', 'place_name': 'Wicomico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.291, 'longitude': -76.5094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23190', 'place_name': 'Woods Cross Roads', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Gloucester', 'locality_code': '73', 'latitude': 37.482, 'longitude': -76.6362, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23014', 'place_name': 'Beaumont', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.7338, 'longitude': -77.8881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23038', 'place_name': 'Columbia', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.7147, 'longitude': -78.1794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23039', 'place_name': 'Crozier', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.6718, 'longitude': -77.794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23063', 'place_name': 'Goochland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.7688, 'longitude': -78.0112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23065', 'place_name': 'Gum Spring', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.7982, 'longitude': -77.9375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23067', 'place_name': 'Hadensville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.8252, 'longitude': -77.9899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23102', 'place_name': 'Maidens', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.7126, 'longitude': -77.8315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23103', 'place_name': 'Manakin Sabot', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.638, 'longitude': -77.7077, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23129', 'place_name': 'Oilville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.704, 'longitude': -77.7853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23153', 'place_name': 'Sandy Hook', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.7526, 'longitude': -77.9125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23160', 'place_name': 'State Farm', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Goochland', 'locality_code': '75', 'latitude': 37.6454, 'longitude': -77.8283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24292', 'place_name': 'Whitetop', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Grayson', 'locality_code': '77', 'latitude': 36.6106, 'longitude': -81.5839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24326', 'place_name': 'Elk Creek', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Grayson', 'locality_code': '77', 'latitude': 36.7306, 'longitude': -81.1915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24330', 'place_name': 'Fries', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Grayson', 'locality_code': '77', 'latitude': 36.7247, 'longitude': -81.0042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24348', 'place_name': 'Independence', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Grayson', 'locality_code': '77', 'latitude': 36.6294, 'longitude': -81.1582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24363', 'place_name': 'Mouth Of Wilson', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Grayson', 'locality_code': '77', 'latitude': 36.6104, 'longitude': -81.3955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24378', 'place_name': 'Troutdale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Grayson', 'locality_code': '77', 'latitude': 36.8611, 'longitude': -81.4929, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22935', 'place_name': 'Dyke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Greene', 'locality_code': '79', 'latitude': 38.2705, 'longitude': -78.5578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22965', 'place_name': 'Quinque', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Greene', 'locality_code': '79', 'latitude': 38.3301, 'longitude': -78.475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22968', 'place_name': 'Ruckersville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Greene', 'locality_code': '79', 'latitude': 38.2586, 'longitude': -78.4074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22973', 'place_name': 'Stanardsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Greene', 'locality_code': '79', 'latitude': 38.3121, 'longitude': -78.482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23870', 'place_name': 'Jarratt', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Greensville', 'locality_code': '81', 'latitude': 36.8143, 'longitude': -77.4683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23879', 'place_name': 'Skippers', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Greensville', 'locality_code': '81', 'latitude': 36.5958, 'longitude': -77.5921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24520', 'place_name': 'Alton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.5894, 'longitude': -79.0202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24534', 'place_name': 'Clover', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.8637, 'longitude': -78.7862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24535', 'place_name': 'Cluster Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.6113, 'longitude': -78.9455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24539', 'place_name': 'Crystal Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.8513, 'longitude': -78.9179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24558', 'place_name': 'Halifax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.7626, 'longitude': -78.9415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24577', 'place_name': 'Nathalie', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.9356, 'longitude': -78.972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24589', 'place_name': 'Scottsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.7862, 'longitude': -78.7866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24592', 'place_name': 'South Boston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.6963, 'longitude': -78.9188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24597', 'place_name': 'Vernon Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.7853, 'longitude': -79.1095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24598', 'place_name': 'Virgilina', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Halifax', 'locality_code': '83', 'latitude': 36.6062, 'longitude': -78.7605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23005', 'place_name': 'Ashland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.7395, 'longitude': -77.4784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23015', 'place_name': 'Beaverdam', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.9038, 'longitude': -77.6308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23047', 'place_name': 'Doswell', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.8417, 'longitude': -77.5125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23059', 'place_name': 'Glen Allen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.7284, 'longitude': -77.5544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23069', 'place_name': 'Hanover', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.7701, 'longitude': -77.3216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23111', 'place_name': 'Mechanicsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.6281, 'longitude': -77.3395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23116', 'place_name': 'Mechanicsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.6691, 'longitude': -77.3294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23146', 'place_name': 'Rockville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.7337, 'longitude': -77.7, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23162', 'place_name': 'Studley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.6757, 'longitude': -77.2908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23192', 'place_name': 'Montpelier', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hanover', 'locality_code': '85', 'latitude': 37.8177, 'longitude': -77.6924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23058', 'place_name': 'Glen Allen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.5313, 'longitude': -77.4161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23060', 'place_name': 'Glen Allen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.6628, 'longitude': -77.534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23075', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.546, 'longitude': -77.3278, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23150', 'place_name': 'Sandston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.5157, 'longitude': -77.2758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23226', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.5825, 'longitude': -77.5197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23227', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.6247, 'longitude': -77.4351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23228', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.4638, 'longitude': -77.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23229', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.4638, 'longitude': -77.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23230', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.5921, 'longitude': -77.4952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23231', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.4638, 'longitude': -77.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23233', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.4638, 'longitude': -77.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23238', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.52, 'longitude': -77.4369, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23242', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.4638, 'longitude': -77.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23250', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.5075, 'longitude': -77.3329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23255', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.4638, 'longitude': -77.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23288', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.4638, 'longitude': -77.398, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23289', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.5313, 'longitude': -77.4161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23294', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henrico', 'locality_code': '87', 'latitude': 37.631, 'longitude': -77.546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24054', 'place_name': 'Axton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henry', 'locality_code': '89', 'latitude': 36.6596, 'longitude': -79.712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24055', 'place_name': 'Bassett', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henry', 'locality_code': '89', 'latitude': 36.7534, 'longitude': -80.0055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24078', 'place_name': 'Collinsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henry', 'locality_code': '89', 'latitude': 36.7238, 'longitude': -79.9142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24089', 'place_name': 'Fieldale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henry', 'locality_code': '89', 'latitude': 36.7064, 'longitude': -79.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24148', 'place_name': 'Ridgeway', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henry', 'locality_code': '89', 'latitude': 36.5874, 'longitude': -79.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24165', 'place_name': 'Spencer', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henry', 'locality_code': '89', 'latitude': 36.5968, 'longitude': -80.0373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24168', 'place_name': 'Stanleytown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Henry', 'locality_code': '89', 'latitude': 36.7348, 'longitude': -79.9465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24413', 'place_name': 'Blue Grass', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Highland', 'locality_code': '91', 'latitude': 38.5152, 'longitude': -79.5613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24433', 'place_name': 'Doe Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Highland', 'locality_code': '91', 'latitude': 38.4321, 'longitude': -79.4445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24442', 'place_name': 'Head Waters', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Highland', 'locality_code': '91', 'latitude': 38.2946, 'longitude': -79.4353, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24458', 'place_name': 'Mc Dowell', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Highland', 'locality_code': '91', 'latitude': 38.3266, 'longitude': -79.4988, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24465', 'place_name': 'Monterey', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Highland', 'locality_code': '91', 'latitude': 38.4058, 'longitude': -79.5941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24468', 'place_name': 'Mustoe', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Highland', 'locality_code': '91', 'latitude': 38.386, 'longitude': -79.5592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23304', 'place_name': 'Battery Park', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.9965, 'longitude': -76.5741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23314', 'place_name': 'Carrollton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.955, 'longitude': -76.543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23315', 'place_name': 'Carrsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.7454, 'longitude': -76.8365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23397', 'place_name': 'Isle Of Wight', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.8989, 'longitude': -76.6877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23424', 'place_name': 'Rescue', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.9969, 'longitude': -76.5645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23430', 'place_name': 'Smithfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.9811, 'longitude': -76.6368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23431', 'place_name': 'Smithfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.8989, 'longitude': -76.6877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23487', 'place_name': 'Windsor', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.8369, 'longitude': -76.7324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23898', 'place_name': 'Zuni', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Isle of Wight', 'locality_code': '93', 'latitude': 36.8437, 'longitude': -76.811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23081', 'place_name': 'Jamestown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'James City', 'locality_code': '95', 'latitude': 37.2235, 'longitude': -76.7833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23127', 'place_name': 'Norge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'James City', 'locality_code': '95', 'latitude': 37.3688, 'longitude': -76.7705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23168', 'place_name': 'Toano', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'James City', 'locality_code': '95', 'latitude': 37.3901, 'longitude': -76.8253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23185', 'place_name': 'Williamsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'James City', 'locality_code': '95', 'latitude': 37.2732, 'longitude': -76.7324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23188', 'place_name': 'Williamsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'James City', 'locality_code': '95', 'latitude': 37.3178, 'longitude': -76.7634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23023', 'place_name': 'Bruington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.7801, 'longitude': -76.9402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23085', 'place_name': 'King And Queen Court House', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.6699, 'longitude': -76.8775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23091', 'place_name': 'Little Plymouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.6642, 'longitude': -76.8255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23108', 'place_name': 'Mascot', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.6271, 'longitude': -76.7072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23110', 'place_name': 'Mattaponi', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.6135, 'longitude': -76.8101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23126', 'place_name': 'Newtown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.9226, 'longitude': -77.1449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23148', 'place_name': 'Saint Stephens Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.8479, 'longitude': -77.055, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23156', 'place_name': 'Shacklefords', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.5213, 'longitude': -76.7099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23161', 'place_name': 'Stevensville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.7146, 'longitude': -76.9352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23177', 'place_name': 'Walkerton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King and Queen', 'locality_code': '97', 'latitude': 37.7554, 'longitude': -77.0185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22448', 'place_name': 'Dahlgren', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King George', 'locality_code': '99', 'latitude': 38.3375, 'longitude': -77.0429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22451', 'place_name': 'Dogue', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King George', 'locality_code': '99', 'latitude': 38.2321, 'longitude': -77.2158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22481', 'place_name': 'Jersey', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King George', 'locality_code': '99', 'latitude': 38.2115, 'longitude': -77.1394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22485', 'place_name': 'King George', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King George', 'locality_code': '99', 'latitude': 38.2811, 'longitude': -77.126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22526', 'place_name': 'Ninde', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King George', 'locality_code': '99', 'latitude': 38.2712, 'longitude': -77.0561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22544', 'place_name': 'Rollins Fork', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King George', 'locality_code': '99', 'latitude': 38.1849, 'longitude': -77.0622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22547', 'place_name': 'Sealston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King George', 'locality_code': '99', 'latitude': 38.2711, 'longitude': -77.1726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23009', 'place_name': 'Aylett', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King William', 'locality_code': '101', 'latitude': 37.8221, 'longitude': -77.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23086', 'place_name': 'King William', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King William', 'locality_code': '101', 'latitude': 37.7202, 'longitude': -77.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23106', 'place_name': 'Manquin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King William', 'locality_code': '101', 'latitude': 37.7184, 'longitude': -77.186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23181', 'place_name': 'West Point', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'King William', 'locality_code': '101', 'latitude': 37.5556, 'longitude': -76.8237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22480', 'place_name': 'Irvington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.6645, 'longitude': -76.416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22482', 'place_name': 'Kilmarnock', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.7162, 'longitude': -76.382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22503', 'place_name': 'Lancaster', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.7395, 'longitude': -76.5002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22507', 'place_name': 'Lively', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.7572, 'longitude': -76.5118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22513', 'place_name': 'Merry Point', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.7338, 'longitude': -76.4825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22517', 'place_name': 'Mollusk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.7301, 'longitude': -76.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22523', 'place_name': 'Morattico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.7928, 'longitude': -76.6093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22528', 'place_name': 'Nuttsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.7935, 'longitude': -76.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22576', 'place_name': 'Weems', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.6847, 'longitude': -76.4313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22578', 'place_name': 'White Stone', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lancaster', 'locality_code': '103', 'latitude': 37.6886, 'longitude': -76.3616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24218', 'place_name': 'Ben Hur', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.7435, 'longitude': -83.2234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24221', 'place_name': 'Blackwater', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.639, 'longitude': -82.9866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24243', 'place_name': 'Dryden', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.7818, 'longitude': -82.9305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24248', 'place_name': 'Ewing', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.6237, 'longitude': -83.5047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24263', 'place_name': 'Jonesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.6896, 'longitude': -83.1362, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24265', 'place_name': 'Keokee', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.8239, 'longitude': -82.9772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24277', 'place_name': 'Pennington Gap', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.7508, 'longitude': -83.0223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24281', 'place_name': 'Rose Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.6583, 'longitude': -83.3486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24282', 'place_name': 'Saint Charles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lee', 'locality_code': '105', 'latitude': 36.8315, 'longitude': -83.0518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20101', 'place_name': 'Dulles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0021, 'longitude': -77.4421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20102', 'place_name': 'Dulles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0853, 'longitude': -77.6452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20103', 'place_name': 'Dulles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 38.9962, 'longitude': -77.45, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20104', 'place_name': 'Dulles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0853, 'longitude': -77.6452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20105', 'place_name': 'Aldie', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 38.9577, 'longitude': -77.6038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20117', 'place_name': 'Middleburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 38.9687, 'longitude': -77.7355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20118', 'place_name': 'Middleburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 38.9687, 'longitude': -77.7355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20129', 'place_name': 'Paeonian Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1603, 'longitude': -77.6097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20131', 'place_name': 'Philomont', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.058, 'longitude': -77.7434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20132', 'place_name': 'Purcellville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1436, 'longitude': -77.7342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20134', 'place_name': 'Purcellville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1522, 'longitude': -77.7026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20135', 'place_name': 'Bluemont', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0823, 'longitude': -77.8467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20141', 'place_name': 'Round Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1164, 'longitude': -77.7802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20142', 'place_name': 'Round Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1307, 'longitude': -77.7747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20146', 'place_name': 'Ashburn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0853, 'longitude': -77.6452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20147', 'place_name': 'Ashburn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0373, 'longitude': -77.4805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20148', 'place_name': 'Ashburn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0142, 'longitude': -77.5285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20149', 'place_name': 'Ashburn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0437, 'longitude': -77.4875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20152', 'place_name': 'Chantilly', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 38.8976, 'longitude': -77.5092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20158', 'place_name': 'Hamilton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1383, 'longitude': -77.6573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20159', 'place_name': 'Hamilton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1339, 'longitude': -77.6621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20160', 'place_name': 'Lincoln', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0985, 'longitude': -77.6883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20163', 'place_name': 'Sterling', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0062, 'longitude': -77.4286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20164', 'place_name': 'Sterling', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.023, 'longitude': -77.3994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20165', 'place_name': 'Sterling', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0472, 'longitude': -77.3866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20166', 'place_name': 'Sterling', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 38.9814, 'longitude': -77.4723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20167', 'place_name': 'Sterling', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.0062, 'longitude': -77.4286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20175', 'place_name': 'Leesburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.042, 'longitude': -77.6054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20176', 'place_name': 'Leesburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1821, 'longitude': -77.5359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20177', 'place_name': 'Leesburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1157, 'longitude': -77.5636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20178', 'place_name': 'Leesburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1157, 'longitude': -77.5636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20180', 'place_name': 'Lovettsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.2204, 'longitude': -77.6596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20189', 'place_name': 'Dulles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.009, 'longitude': -77.4421, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20197', 'place_name': 'Waterford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 39.1882, 'longitude': -77.63, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20598', 'place_name': 'Dhs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Loudoun', 'locality_code': '107', 'latitude': 38.9904, 'longitude': -77.4477, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23024', 'place_name': 'Bumpass', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Louisa', 'locality_code': '109', 'latitude': 37.8984, 'longitude': -77.7966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23093', 'place_name': 'Louisa', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Louisa', 'locality_code': '109', 'latitude': 38.0132, 'longitude': -78.0347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23117', 'place_name': 'Mineral', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Louisa', 'locality_code': '109', 'latitude': 37.9986, 'longitude': -77.8781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23170', 'place_name': 'Trevilians', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Louisa', 'locality_code': '109', 'latitude': 38.0515, 'longitude': -78.0728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23938', 'place_name': 'Dundas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lunenburg', 'locality_code': '111', 'latitude': 36.9053, 'longitude': -78.01, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23941', 'place_name': 'Fort Mitchell', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lunenburg', 'locality_code': '111', 'latitude': 36.9182, 'longitude': -78.4861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23944', 'place_name': 'Kenbridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lunenburg', 'locality_code': '111', 'latitude': 36.933, 'longitude': -78.1242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23952', 'place_name': 'Lunenburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lunenburg', 'locality_code': '111', 'latitude': 36.9291, 'longitude': -78.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23974', 'place_name': 'Victoria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lunenburg', 'locality_code': '111', 'latitude': 36.9835, 'longitude': -78.2372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22709', 'place_name': 'Aroda', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3256, 'longitude': -78.2366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22711', 'place_name': 'Banco', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.4512, 'longitude': -78.2817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22715', 'place_name': 'Brightwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.4114, 'longitude': -78.1698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22719', 'place_name': 'Etlan', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.5095, 'longitude': -78.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22722', 'place_name': 'Haywood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.4535, 'longitude': -78.2522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22723', 'place_name': 'Hood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3549, 'longitude': -78.3828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22725', 'place_name': 'Leon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.4285, 'longitude': -78.2678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22727', 'place_name': 'Madison', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.37, 'longitude': -78.2976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22730', 'place_name': 'Oakpark', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3674, 'longitude': -78.1628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22731', 'place_name': 'Pratts', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3366, 'longitude': -78.2573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22732', 'place_name': 'Radiant', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3146, 'longitude': -78.1899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22738', 'place_name': 'Rochelle', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3215, 'longitude': -78.3042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22743', 'place_name': 'Syria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.4972, 'longitude': -78.3229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22748', 'place_name': 'Wolftown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3557, 'longitude': -78.3475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22948', 'place_name': 'Locust Dale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.3572, 'longitude': -78.1229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22989', 'place_name': 'Woodberry Forest', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Madison', 'locality_code': '113', 'latitude': 38.2912, 'longitude': -78.1225, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23021', 'place_name': 'Bohannon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.3905, 'longitude': -76.3614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23025', 'place_name': 'Cardinal', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4128, 'longitude': -76.3616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23035', 'place_name': 'Cobbs Creek', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4959, 'longitude': -76.3863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23045', 'place_name': 'Diggs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4296, 'longitude': -76.2629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23056', 'place_name': 'Foster', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4529, 'longitude': -76.3849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23064', 'place_name': 'Grimstead', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4961, 'longitude': -76.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23066', 'place_name': 'Gwynn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.5043, 'longitude': -76.2886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23068', 'place_name': 'Hallieford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4937, 'longitude': -76.3402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23076', 'place_name': 'Hudgins', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4766, 'longitude': -76.3089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23109', 'place_name': 'Mathews', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4383, 'longitude': -76.3544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23119', 'place_name': 'Moon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4487, 'longitude': -76.2766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23125', 'place_name': 'New Point', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.3438, 'longitude': -76.2878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23128', 'place_name': 'North', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.4401, 'longitude': -76.4238, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23130', 'place_name': 'Onemo', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.3985, 'longitude': -76.2941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23138', 'place_name': 'Port Haywood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.386, 'longitude': -76.3172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23163', 'place_name': 'Susan', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mathews', 'locality_code': '115', 'latitude': 37.3508, 'longitude': -76.3161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23915', 'place_name': 'Baskerville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.7236, 'longitude': -78.279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23917', 'place_name': 'Boydton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.6544, 'longitude': -78.3752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23919', 'place_name': 'Bracey', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.5763, 'longitude': -78.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23924', 'place_name': 'Chase City', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.8053, 'longitude': -78.4553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23927', 'place_name': 'Clarksville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.624, 'longitude': -78.5569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23950', 'place_name': 'La Crosse', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.6613, 'longitude': -78.0754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23968', 'place_name': 'Skipwith', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.7317, 'longitude': -78.5306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23970', 'place_name': 'South Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.7124, 'longitude': -78.1534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24529', 'place_name': 'Buffalo Junction', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.6168, 'longitude': -78.6093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24580', 'place_name': 'Nelson', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Mecklenburg', 'locality_code': '117', 'latitude': 36.5586, 'longitude': -78.671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23031', 'place_name': 'Christchurch', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.5984, 'longitude': -76.4476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23032', 'place_name': 'Church View', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.675, 'longitude': -76.6629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23043', 'place_name': 'Deltaville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.5549, 'longitude': -76.3468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23070', 'place_name': 'Hardyville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.5512, 'longitude': -76.3844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23071', 'place_name': 'Hartfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.5594, 'longitude': -76.4769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23079', 'place_name': 'Jamaica', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.73, 'longitude': -76.689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23092', 'place_name': 'Locust Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.5826, 'longitude': -76.4984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23149', 'place_name': 'Saluda', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.5949, 'longitude': -76.5921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23169', 'place_name': 'Topping', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.6009, 'longitude': -76.4575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23175', 'place_name': 'Urbanna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.6356, 'longitude': -76.5918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23176', 'place_name': 'Wake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.5681, 'longitude': -76.4323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23180', 'place_name': 'Water View', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Middlesex', 'locality_code': '119', 'latitude': 37.7105, 'longitude': -76.6227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24023', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.271, 'longitude': -79.9414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24060', 'place_name': 'Blacksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.2563, 'longitude': -80.4347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24061', 'place_name': 'Blacksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.1791, 'longitude': -80.3515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24062', 'place_name': 'Blacksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.2296, 'longitude': -80.4139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24063', 'place_name': 'Blacksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.2296, 'longitude': -80.4139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24068', 'place_name': 'Christiansburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.1548, 'longitude': -80.4184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24073', 'place_name': 'Christiansburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.1353, 'longitude': -80.4188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24111', 'place_name': 'Mc Coy', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.1742, 'longitude': -80.3957, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24138', 'place_name': 'Pilot', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.0565, 'longitude': -80.3229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24149', 'place_name': 'Riner', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.0322, 'longitude': -80.4353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24162', 'place_name': 'Shawsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Montgomery', 'locality_code': '121', 'latitude': 37.1466, 'longitude': -80.2715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22920', 'place_name': 'Afton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.9626, 'longitude': -78.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22922', 'place_name': 'Arrington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.6902, 'longitude': -78.9479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22938', 'place_name': 'Faber', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.8475, 'longitude': -78.7565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22949', 'place_name': 'Lovingston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.7924, 'longitude': -78.8684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22958', 'place_name': 'Nellysford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.902, 'longitude': -78.9004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22964', 'place_name': 'Piney River', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.7051, 'longitude': -79.0231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22967', 'place_name': 'Roseland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.8077, 'longitude': -78.9712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22969', 'place_name': 'Schuyler', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.7976, 'longitude': -78.6925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22971', 'place_name': 'Shipman', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.76, 'longitude': -78.8105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22976', 'place_name': 'Tyro', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.8391, 'longitude': -79.0693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24464', 'place_name': 'Montebello', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.8654, 'longitude': -79.0804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24553', 'place_name': 'Gladstone', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.5473, 'longitude': -78.8508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24581', 'place_name': 'Norwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.6432, 'longitude': -78.8089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24599', 'place_name': 'Wingina', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nelson', 'locality_code': '125', 'latitude': 37.6399, 'longitude': -78.7239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23011', 'place_name': 'Barhamsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'New Kent', 'locality_code': '127', 'latitude': 37.4617, 'longitude': -76.8321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23089', 'place_name': 'Lanexa', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'New Kent', 'locality_code': '127', 'latitude': 37.4194, 'longitude': -76.9027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23124', 'place_name': 'New Kent', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'New Kent', 'locality_code': '127', 'latitude': 37.553, 'longitude': -77.0742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23140', 'place_name': 'Providence Forge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'New Kent', 'locality_code': '127', 'latitude': 37.4418, 'longitude': -77.0436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23141', 'place_name': 'Quinton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'New Kent', 'locality_code': '127', 'latitude': 37.5185, 'longitude': -77.1486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23307', 'place_name': 'Birdsnest', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.439, 'longitude': -75.881, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23310', 'place_name': 'Cape Charles', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.2799, 'longitude': -75.9721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23313', 'place_name': 'Capeville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.2019, 'longitude': -75.9524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23316', 'place_name': 'Cheriton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.2896, 'longitude': -75.9713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23347', 'place_name': 'Eastville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.3526, 'longitude': -75.9458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23350', 'place_name': 'Exmore', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.5117, 'longitude': -75.8526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23354', 'place_name': 'Franktown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.4588, 'longitude': -75.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23398', 'place_name': 'Jamesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.5151, 'longitude': -75.9305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23405', 'place_name': 'Machipongo', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.4014, 'longitude': -75.9082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23408', 'place_name': 'Marionville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.4556, 'longitude': -75.8473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23413', 'place_name': 'Nassawadox', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.4728, 'longitude': -75.858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23419', 'place_name': 'Oyster', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.3074, 'longitude': -75.9269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23429', 'place_name': 'Seaview', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.2711, 'longitude': -75.9536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23443', 'place_name': 'Townsend', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.1882, 'longitude': -75.969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23482', 'place_name': 'Wardtown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.5349, 'longitude': -75.8769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23486', 'place_name': 'Willis Wharf', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northampton', 'locality_code': '131', 'latitude': 37.5157, 'longitude': -75.8066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22432', 'place_name': 'Burgess', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.8687, 'longitude': -76.3542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22435', 'place_name': 'Callao', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.9773, 'longitude': -76.5732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22456', 'place_name': 'Edwardsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.9065, 'longitude': -76.3652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22473', 'place_name': 'Heathsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.9072, 'longitude': -76.4178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22511', 'place_name': 'Lottsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.9792, 'longitude': -76.5018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22530', 'place_name': 'Ophelia', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.9094, 'longitude': -76.2934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22539', 'place_name': 'Reedville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.857, 'longitude': -76.2829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22579', 'place_name': 'Wicomico Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Northumberland', 'locality_code': '133', 'latitude': 37.8025, 'longitude': -76.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23824', 'place_name': 'Blackstone', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nottoway', 'locality_code': '135', 'latitude': 37.0916, 'longitude': -77.9851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23922', 'place_name': 'Burkeville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nottoway', 'locality_code': '135', 'latitude': 37.1952, 'longitude': -78.1961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23930', 'place_name': 'Crewe', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nottoway', 'locality_code': '135', 'latitude': 37.1657, 'longitude': -78.1059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23955', 'place_name': 'Nottoway', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Nottoway', 'locality_code': '135', 'latitude': 37.1161, 'longitude': -78.0578, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22433', 'place_name': 'Burr Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.3446, 'longitude': -77.8719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22508', 'place_name': 'Locust Grove', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.3352, 'longitude': -77.7709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22542', 'place_name': 'Rhoadesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.2863, 'longitude': -77.923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22567', 'place_name': 'Unionville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.2383, 'longitude': -77.9193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22923', 'place_name': 'Barboursville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.2095, 'longitude': -78.3098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22942', 'place_name': 'Gordonsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.1759, 'longitude': -78.1815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22957', 'place_name': 'Montpelier Station', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.227, 'longitude': -78.1768, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22960', 'place_name': 'Orange', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.2192, 'longitude': -78.0461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22972', 'place_name': 'Somerset', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Orange', 'locality_code': '137', 'latitude': 38.1997, 'longitude': -78.2394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22650', 'place_name': 'Rileyville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Page', 'locality_code': '139', 'latitude': 38.7564, 'longitude': -78.3873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22835', 'place_name': 'Luray', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Page', 'locality_code': '139', 'latitude': 38.6548, 'longitude': -78.4596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22849', 'place_name': 'Shenandoah', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Page', 'locality_code': '139', 'latitude': 38.501, 'longitude': -78.609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22851', 'place_name': 'Stanley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Page', 'locality_code': '139', 'latitude': 38.566, 'longitude': -78.5093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24053', 'place_name': 'Ararat', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.6139, 'longitude': -80.5093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24076', 'place_name': 'Claudville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.5896, 'longitude': -80.4184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24082', 'place_name': 'Critz', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.6211, 'longitude': -80.1298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24120', 'place_name': 'Meadows Of Dan', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.725, 'longitude': -80.4022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24133', 'place_name': 'Patrick Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.6744, 'longitude': -80.1388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24171', 'place_name': 'Stuart', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.6517, 'longitude': -80.2392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24177', 'place_name': 'Vesta', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.7241, 'longitude': -80.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24185', 'place_name': 'Woolwine', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Patrick', 'locality_code': '141', 'latitude': 36.7921, 'longitude': -80.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24069', 'place_name': 'Cascade', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.5927, 'longitude': -79.6574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24139', 'place_name': 'Pittsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.9716, 'longitude': -79.4794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24161', 'place_name': 'Sandy Level', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.991, 'longitude': -79.5614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24527', 'place_name': 'Blairs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.6799, 'longitude': -79.3731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24530', 'place_name': 'Callands', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.7647, 'longitude': -79.6288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24531', 'place_name': 'Chatham', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.831, 'longitude': -79.4297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24549', 'place_name': 'Dry Fork', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.743, 'longitude': -79.458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24557', 'place_name': 'Gretna', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.9695, 'longitude': -79.3389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24563', 'place_name': 'Hurt', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 37.0798, 'longitude': -79.3, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24565', 'place_name': 'Java', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.8586, 'longitude': -79.187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24566', 'place_name': 'Keeling', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.7156, 'longitude': -79.2783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24586', 'place_name': 'Ringgold', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.6035, 'longitude': -79.2988, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24594', 'place_name': 'Sutherlin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pittsylvania', 'locality_code': '143', 'latitude': 36.6258, 'longitude': -79.195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23139', 'place_name': 'Powhatan', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Powhatan', 'locality_code': '145', 'latitude': 37.5421, 'longitude': -77.9189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23901', 'place_name': 'Farmville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince Edward', 'locality_code': '147', 'latitude': 37.3027, 'longitude': -78.4076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23909', 'place_name': 'Farmville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince Edward', 'locality_code': '147', 'latitude': 37.3016, 'longitude': -78.3949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23942', 'place_name': 'Green Bay', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince Edward', 'locality_code': '147', 'latitude': 37.1234, 'longitude': -78.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23943', 'place_name': 'Hampden Sydney', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince Edward', 'locality_code': '147', 'latitude': 37.2381, 'longitude': -78.4618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23954', 'place_name': 'Meherrin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince Edward', 'locality_code': '147', 'latitude': 37.1013, 'longitude': -78.3874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23960', 'place_name': 'Prospect', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince Edward', 'locality_code': '147', 'latitude': 37.3058, 'longitude': -78.5462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23966', 'place_name': 'Rice', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince Edward', 'locality_code': '147', 'latitude': 37.2721, 'longitude': -78.2793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23801', 'place_name': 'Fort Lee', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince George', 'locality_code': '149', 'latitude': 37.2447, 'longitude': -77.3341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23842', 'place_name': 'Disputanta', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince George', 'locality_code': '149', 'latitude': 37.1483, 'longitude': -77.2732, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23875', 'place_name': 'Prince George', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince George', 'locality_code': '149', 'latitude': 37.2333, 'longitude': -77.2747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20136', 'place_name': 'Bristow', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.7343, 'longitude': -77.5474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20143', 'place_name': 'Catharpin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.8543, 'longitude': -77.5719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20155', 'place_name': 'Gainesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.8157, 'longitude': -77.6216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20156', 'place_name': 'Gainesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.7219, 'longitude': -77.4669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20168', 'place_name': 'Haymarket', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.8121, 'longitude': -77.6364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20169', 'place_name': 'Haymarket', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.8674, 'longitude': -77.6445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20181', 'place_name': 'Nokesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.7, 'longitude': -77.5483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20182', 'place_name': 'Nokesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.7009, 'longitude': -77.5857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22025', 'place_name': 'Dumfries', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.5993, 'longitude': -77.3403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22026', 'place_name': 'Dumfries', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.5669, 'longitude': -77.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22125', 'place_name': 'Occoquan', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.6816, 'longitude': -77.2605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22134', 'place_name': 'Quantico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.531, 'longitude': -77.3358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22135', 'place_name': 'Quantico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.5223, 'longitude': -77.2936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22172', 'place_name': 'Triangle', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.5509, 'longitude': -77.3229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22191', 'place_name': 'Woodbridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.6356, 'longitude': -77.2683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22192', 'place_name': 'Woodbridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.676, 'longitude': -77.3163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22193', 'place_name': 'Woodbridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.6438, 'longitude': -77.3451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22194', 'place_name': 'Woodbridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.6582, 'longitude': -77.2497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22195', 'place_name': 'Woodbridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Prince William', 'locality_code': '153', 'latitude': 38.6582, 'longitude': -77.2497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24058', 'place_name': 'Belspring', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 37.1982, 'longitude': -80.6151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24084', 'place_name': 'Dublin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 37.1057, 'longitude': -80.6853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24126', 'place_name': 'Newbern', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 37.0692, 'longitude': -80.6891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24129', 'place_name': 'New River', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 37.0964, 'longitude': -80.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24132', 'place_name': 'Parrott', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 37.2048, 'longitude': -80.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24301', 'place_name': 'Pulaski', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 37.0567, 'longitude': -80.771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24324', 'place_name': 'Draper', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 36.9697, 'longitude': -80.8188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24347', 'place_name': 'Hiwassee', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Pulaski', 'locality_code': '155', 'latitude': 36.9756, 'longitude': -80.6695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20106', 'place_name': 'Amissville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.6842, 'longitude': -78.0168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22623', 'place_name': 'Chester Gap', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.8537, 'longitude': -78.1412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22627', 'place_name': 'Flint Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.7629, 'longitude': -78.1, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22640', 'place_name': 'Huntly', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.8129, 'longitude': -78.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22716', 'place_name': 'Castleton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.6032, 'longitude': -78.1208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22740', 'place_name': 'Sperryville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.6203, 'longitude': -78.2466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22746', 'place_name': 'Viewtown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.6457, 'longitude': -78.0258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22747', 'place_name': 'Washington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.7078, 'longitude': -78.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22749', 'place_name': 'Woodville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rappahannock', 'locality_code': '157', 'latitude': 38.6482, 'longitude': -78.1739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22460', 'place_name': 'Farnham', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Richmond', 'locality_code': '159', 'latitude': 37.874, 'longitude': -76.605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22472', 'place_name': 'Haynesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Richmond', 'locality_code': '159', 'latitude': 37.9505, 'longitude': -76.6367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22548', 'place_name': 'Sharps', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Richmond', 'locality_code': '159', 'latitude': 37.824, 'longitude': -76.7008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22570', 'place_name': 'Village', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Richmond', 'locality_code': '159', 'latitude': 37.9472, 'longitude': -76.6154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22572', 'place_name': 'Warsaw', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Richmond', 'locality_code': '159', 'latitude': 37.9695, 'longitude': -76.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24018', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke', 'locality_code': '161', 'latitude': 37.2503, 'longitude': -80.0525, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24020', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke', 'locality_code': '161', 'latitude': 37.3589, 'longitude': -79.9448, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24059', 'place_name': 'Bent Mountain', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke', 'locality_code': '161', 'latitude': 37.1549, 'longitude': -80.1215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24070', 'place_name': 'Catawba', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke', 'locality_code': '161', 'latitude': 37.3696, 'longitude': -80.1284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24087', 'place_name': 'Elliston', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke', 'locality_code': '161', 'latitude': 37.2165, 'longitude': -80.2325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24179', 'place_name': 'Vinton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke', 'locality_code': '161', 'latitude': 37.2757, 'longitude': -79.8775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24415', 'place_name': 'Brownsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.9285, 'longitude': -79.3192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24435', 'place_name': 'Fairfield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.8778, 'longitude': -79.2979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24439', 'place_name': 'Goshen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.9878, 'longitude': -79.4773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24472', 'place_name': 'Raphine', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.9374, 'longitude': -79.2219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24473', 'place_name': 'Rockbridge Baths', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.8965, 'longitude': -79.3874, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24483', 'place_name': 'Vesuvius', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.8378, 'longitude': -79.2135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24555', 'place_name': 'Glasgow', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.643, 'longitude': -79.459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24578', 'place_name': 'Natural Bridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.6606, 'longitude': -79.533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24579', 'place_name': 'Natural Bridge Station', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockbridge', 'locality_code': '163', 'latitude': 37.598, 'longitude': -79.525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22802', 'place_name': 'Harrisonburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.4905, 'longitude': -78.8179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22811', 'place_name': 'Bergton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.7925, 'longitude': -78.9668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22812', 'place_name': 'Bridgewater', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.3859, 'longitude': -78.9937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22815', 'place_name': 'Broadway', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.6083, 'longitude': -78.7875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22820', 'place_name': 'Criders', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.7497, 'longitude': -78.9974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22821', 'place_name': 'Dayton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.4707, 'longitude': -79.085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22827', 'place_name': 'Elkton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.4025, 'longitude': -78.6321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22830', 'place_name': 'Fulks Run', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.6339, 'longitude': -78.9358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22831', 'place_name': 'Hinton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.5689, 'longitude': -79.0885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22832', 'place_name': 'Keezletown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.4659, 'longitude': -78.7499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22833', 'place_name': 'Lacey Spring', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.5284, 'longitude': -78.8552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22834', 'place_name': 'Linville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.5557, 'longitude': -78.8961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22840', 'place_name': 'Mc Gaheysville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.3712, 'longitude': -78.7411, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22841', 'place_name': 'Mount Crawford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.3457, 'longitude': -78.8957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22846', 'place_name': 'Penn Laird', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.375, 'longitude': -78.7795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22848', 'place_name': 'Pleasant Valley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.3847, 'longitude': -78.8914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22850', 'place_name': 'Singers Glen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.5574, 'longitude': -78.9227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22853', 'place_name': 'Timberville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.6476, 'longitude': -78.7717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24441', 'place_name': 'Grottoes', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.2484, 'longitude': -78.8255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24471', 'place_name': 'Port Republic', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Rockingham', 'locality_code': '165', 'latitude': 38.3226, 'longitude': -78.7886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24224', 'place_name': 'Castlewood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Russell', 'locality_code': '167', 'latitude': 36.8764, 'longitude': -82.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24225', 'place_name': 'Cleveland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Russell', 'locality_code': '167', 'latitude': 36.9502, 'longitude': -82.1318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24237', 'place_name': 'Dante', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Russell', 'locality_code': '167', 'latitude': 37.0054, 'longitude': -82.2815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24260', 'place_name': 'Honaker', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Russell', 'locality_code': '167', 'latitude': 37.0395, 'longitude': -82.0246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24266', 'place_name': 'Lebanon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Russell', 'locality_code': '167', 'latitude': 36.8809, 'longitude': -82.0956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24280', 'place_name': 'Rosedale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Russell', 'locality_code': '167', 'latitude': 36.9593, 'longitude': -81.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24649', 'place_name': 'Swords Creek', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Russell', 'locality_code': '167', 'latitude': 37.0738, 'longitude': -81.9084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24244', 'place_name': 'Duffield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Scott', 'locality_code': '169', 'latitude': 36.7114, 'longitude': -82.8337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24245', 'place_name': 'Dungannon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Scott', 'locality_code': '169', 'latitude': 36.8242, 'longitude': -82.496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24250', 'place_name': 'Fort Blackmore', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Scott', 'locality_code': '169', 'latitude': 36.7438, 'longitude': -82.6102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24251', 'place_name': 'Gate City', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Scott', 'locality_code': '169', 'latitude': 36.646, 'longitude': -82.6112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24258', 'place_name': 'Hiltons', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Scott', 'locality_code': '169', 'latitude': 36.6498, 'longitude': -82.4299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24271', 'place_name': 'Nickelsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Scott', 'locality_code': '169', 'latitude': 36.7502, 'longitude': -82.4202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24290', 'place_name': 'Weber City', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Scott', 'locality_code': '169', 'latitude': 36.6137, 'longitude': -82.5618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22626', 'place_name': 'Fishers Hill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.9834, 'longitude': -78.4038, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22641', 'place_name': 'Strasburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 39.0808, 'longitude': -78.3913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22644', 'place_name': 'Maurertown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.9441, 'longitude': -78.4658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22652', 'place_name': 'Fort Valley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.8407, 'longitude': -78.4276, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '22657', 'place_name': 'Strasburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.9884, 'longitude': -78.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22660', 'place_name': 'Toms Brook', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.9476, 'longitude': -78.4331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22664', 'place_name': 'Woodstock', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.887, 'longitude': -78.5217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22810', 'place_name': 'Basye', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.8089, 'longitude': -78.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22824', 'place_name': 'Edinburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.8432, 'longitude': -78.6003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22842', 'place_name': 'Mount Jackson', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.7857, 'longitude': -78.6803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22844', 'place_name': 'New Market', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.6606, 'longitude': -78.6714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22845', 'place_name': 'Orkney Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.7937, 'longitude': -78.8111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22847', 'place_name': 'Quicksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Shenandoah', 'locality_code': '171', 'latitude': 38.7201, 'longitude': -78.7213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24311', 'place_name': 'Atkins', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Smyth', 'locality_code': '173', 'latitude': 36.8665, 'longitude': -81.4048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24316', 'place_name': 'Broadford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Smyth', 'locality_code': '173', 'latitude': 36.9546, 'longitude': -81.673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24319', 'place_name': 'Chilhowie', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Smyth', 'locality_code': '173', 'latitude': 36.7719, 'longitude': -81.6651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24354', 'place_name': 'Marion', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Smyth', 'locality_code': '173', 'latitude': 36.8273, 'longitude': -81.5349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24370', 'place_name': 'Saltville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Smyth', 'locality_code': '173', 'latitude': 36.8927, 'longitude': -81.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24375', 'place_name': 'Sugar Grove', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Smyth', 'locality_code': '173', 'latitude': 36.7736, 'longitude': -81.4084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23827', 'place_name': 'Boykins', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.5951, 'longitude': -77.1975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23828', 'place_name': 'Branchville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.5787, 'longitude': -77.2704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23829', 'place_name': 'Capron', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.7243, 'longitude': -77.2394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23837', 'place_name': 'Courtland', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.7225, 'longitude': -77.0783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23844', 'place_name': 'Drewryville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.6854, 'longitude': -77.3591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23866', 'place_name': 'Ivor', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.9071, 'longitude': -76.8861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23874', 'place_name': 'Newsoms', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.6148, 'longitude': -77.1069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23878', 'place_name': 'Sedley', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Southampton', 'locality_code': '175', 'latitude': 36.776, 'longitude': -76.9841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22407', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Spotsylvania', 'locality_code': '177', 'latitude': 38.2688, 'longitude': -77.5476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22408', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Spotsylvania', 'locality_code': '177', 'latitude': 38.2481, 'longitude': -77.4681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22412', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Spotsylvania', 'locality_code': '177', 'latitude': 38.1847, 'longitude': -77.6626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22534', 'place_name': 'Partlow', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Spotsylvania', 'locality_code': '177', 'latitude': 38.0641, 'longitude': -77.6586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22551', 'place_name': 'Spotsylvania', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Spotsylvania', 'locality_code': '177', 'latitude': 38.162, 'longitude': -77.6854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22553', 'place_name': 'Spotsylvania', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Spotsylvania', 'locality_code': '177', 'latitude': 38.271, 'longitude': -77.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22565', 'place_name': 'Thornburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Spotsylvania', 'locality_code': '177', 'latitude': 38.1372, 'longitude': -77.5189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22403', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.4173, 'longitude': -77.4608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22405', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.3365, 'longitude': -77.4366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22406', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.3796, 'longitude': -77.5349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22430', 'place_name': 'Brooke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.3857, 'longitude': -77.3743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22463', 'place_name': 'Garrisonville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.4684, 'longitude': -77.4612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22471', 'place_name': 'Hartwood', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.3993, 'longitude': -77.5814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22545', 'place_name': 'Ruby', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.5086, 'longitude': -77.543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22554', 'place_name': 'Stafford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.4586, 'longitude': -77.4306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22555', 'place_name': 'Stafford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.4221, 'longitude': -77.4083, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22556', 'place_name': 'Stafford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Stafford', 'locality_code': '179', 'latitude': 38.4718, 'longitude': -77.5102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23839', 'place_name': 'Dendron', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Surry', 'locality_code': '181', 'latitude': 37.0981, 'longitude': -76.8966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23846', 'place_name': 'Elberon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Surry', 'locality_code': '181', 'latitude': 37.0701, 'longitude': -76.8337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23881', 'place_name': 'Spring Grove', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Surry', 'locality_code': '181', 'latitude': 37.1901, 'longitude': -76.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23883', 'place_name': 'Surry', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Surry', 'locality_code': '181', 'latitude': 37.126, 'longitude': -76.7651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23899', 'place_name': 'Claremont', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Surry', 'locality_code': '181', 'latitude': 37.2279, 'longitude': -76.9641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23867', 'place_name': 'Jarratt', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Sussex', 'locality_code': '183', 'latitude': 36.8191, 'longitude': -77.4832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23882', 'place_name': 'Stony Creek', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Sussex', 'locality_code': '183', 'latitude': 36.9361, 'longitude': -77.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23884', 'place_name': 'Sussex', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Sussex', 'locality_code': '183', 'latitude': 36.9151, 'longitude': -77.2791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23888', 'place_name': 'Wakefield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Sussex', 'locality_code': '183', 'latitude': 36.9757, 'longitude': -76.979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23890', 'place_name': 'Waverly', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Sussex', 'locality_code': '183', 'latitude': 37.025, 'longitude': -77.1055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23891', 'place_name': 'Waverly', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Sussex', 'locality_code': '183', 'latitude': 37.0508, 'longitude': -77.2124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23897', 'place_name': 'Yale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Sussex', 'locality_code': '183', 'latitude': 36.8373, 'longitude': -77.287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24377', 'place_name': 'Tannersville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 36.9763, 'longitude': -81.628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24601', 'place_name': 'Amonate', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.1909, 'longitude': -81.6387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24602', 'place_name': 'Bandy', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.1661, 'longitude': -81.6508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24604', 'place_name': 'Bishop', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.2033, 'longitude': -81.5575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24605', 'place_name': 'Bluefield', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.2526, 'longitude': -81.2712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24606', 'place_name': 'Boissevain', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.2818, 'longitude': -81.3804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24608', 'place_name': 'Burkes Garden', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.0982, 'longitude': -81.3409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24609', 'place_name': 'Cedar Bluff', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.0876, 'longitude': -81.759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24612', 'place_name': 'Doran', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.0926, 'longitude': -81.8335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24613', 'place_name': 'Falls Mills', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.271, 'longitude': -81.3182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24619', 'place_name': 'Horsepen', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.1355, 'longitude': -81.5634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24622', 'place_name': 'Jewell Ridge', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.2094, 'longitude': -81.7956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24630', 'place_name': 'North Tazewell', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.1756, 'longitude': -81.5399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24635', 'place_name': 'Pocahontas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.3054, 'longitude': -81.3425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24637', 'place_name': 'Pounding Mill', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.0596, 'longitude': -81.7301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24640', 'place_name': 'Red Ash', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.1134, 'longitude': -81.871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24641', 'place_name': 'Richlands', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.0941, 'longitude': -81.8123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24651', 'place_name': 'Tazewell', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Tazewell', 'locality_code': '185', 'latitude': 37.1078, 'longitude': -81.51, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22610', 'place_name': 'Bentonville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Warren', 'locality_code': '187', 'latitude': 38.8187, 'longitude': -78.2757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22630', 'place_name': 'Front Royal', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Warren', 'locality_code': '187', 'latitude': 38.9268, 'longitude': -78.1796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22642', 'place_name': 'Linden', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Warren', 'locality_code': '187', 'latitude': 38.8812, 'longitude': -78.0478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22649', 'place_name': 'Middletown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Warren', 'locality_code': '187', 'latitude': 39.0048, 'longitude': -78.2478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24210', 'place_name': 'Abingdon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.6916, 'longitude': -82.02, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24211', 'place_name': 'Abingdon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.6673, 'longitude': -81.9648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24212', 'place_name': 'Abingdon', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.6909, 'longitude': -81.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24236', 'place_name': 'Damascus', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.6403, 'longitude': -81.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24270', 'place_name': 'Mendota', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.7223, 'longitude': -82.2649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24327', 'place_name': 'Emory', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.78, 'longitude': -81.8171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24340', 'place_name': 'Glade Spring', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.7779, 'longitude': -81.7676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24361', 'place_name': 'Meadowview', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Washington', 'locality_code': '191', 'latitude': 36.7612, 'longitude': -81.8512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22442', 'place_name': 'Coles Point', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.1437, 'longitude': -76.6355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22443', 'place_name': 'Colonial Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.1792, 'longitude': -76.9959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22469', 'place_name': 'Hague', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.0573, 'longitude': -76.6616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22488', 'place_name': 'Kinsale', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.0505, 'longitude': -76.5855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22520', 'place_name': 'Montross', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.1105, 'longitude': -76.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22524', 'place_name': 'Mount Holly', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.1182, 'longitude': -76.6805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22529', 'place_name': 'Oldhams', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.0181, 'longitude': -76.6861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22558', 'place_name': 'Stratford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.1484, 'longitude': -76.8413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22577', 'place_name': 'Sandy Point', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.0673, 'longitude': -76.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22581', 'place_name': 'Zacata', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Westmoreland', 'locality_code': '193', 'latitude': 38.1218, 'longitude': -76.7903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24215', 'place_name': 'Andover', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 36.9234, 'longitude': -82.7964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24216', 'place_name': 'Appalachia', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 36.9438, 'longitude': -82.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24219', 'place_name': 'Big Stone Gap', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 36.8581, 'longitude': -82.7627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24230', 'place_name': 'Coeburn', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 36.9605, 'longitude': -82.4735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24246', 'place_name': 'East Stone Gap', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 36.8668, 'longitude': -82.7424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24279', 'place_name': 'Pound', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 37.0927, 'longitude': -82.6016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24283', 'place_name': 'Saint Paul', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 36.9323, 'longitude': -82.3418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24293', 'place_name': 'Wise', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wise', 'locality_code': '195', 'latitude': 36.975, 'longitude': -82.5947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24312', 'place_name': 'Austinville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.8195, 'longitude': -80.8583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24313', 'place_name': 'Barren Springs', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.9078, 'longitude': -80.809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24322', 'place_name': 'Cripple Creek', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.8086, 'longitude': -81.1039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24323', 'place_name': 'Crockett', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.8768, 'longitude': -81.2089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24350', 'place_name': 'Ivanhoe', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.8272, 'longitude': -80.9779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24360', 'place_name': 'Max Meadows', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.9056, 'longitude': -80.9244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24368', 'place_name': 'Rural Retreat', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.8836, 'longitude': -81.2879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24374', 'place_name': 'Speedwell', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.7998, 'longitude': -81.1834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24382', 'place_name': 'Wytheville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Wythe', 'locality_code': '197', 'latitude': 36.9407, 'longitude': -81.0941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23090', 'place_name': 'Lightfoot', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'York', 'locality_code': '199', 'latitude': 37.3407, 'longitude': -76.7544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23690', 'place_name': 'Yorktown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'York', 'locality_code': '199', 'latitude': 37.2287, 'longitude': -76.5423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23691', 'place_name': 'Yorktown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'York', 'locality_code': '199', 'latitude': 37.2517, 'longitude': -76.552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23692', 'place_name': 'Yorktown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'York', 'locality_code': '199', 'latitude': 37.1686, 'longitude': -76.4581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23693', 'place_name': 'Yorktown', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'York', 'locality_code': '199', 'latitude': 37.1256, 'longitude': -76.4469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23694', 'place_name': 'Lackey', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'York', 'locality_code': '199', 'latitude': 37.2232, 'longitude': -76.559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23696', 'place_name': 'Seaford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'York', 'locality_code': '199', 'latitude': 37.1885, 'longitude': -76.429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22301', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.82, 'longitude': -77.0589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22302', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8276, 'longitude': -77.0896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22304', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8149, 'longitude': -77.121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22305', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8372, 'longitude': -77.064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22311', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.832, 'longitude': -77.12, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22313', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8158, 'longitude': -77.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22314', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.806, 'longitude': -77.0529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22320', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8044, 'longitude': -77.0467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22331', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8013, 'longitude': -77.0707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22332', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8031, 'longitude': -77.0727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22333', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8158, 'longitude': -77.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22334', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8158, 'longitude': -77.0901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22350', 'place_name': 'Alexandria', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Alexandria', 'locality_code': '510', 'latitude': 38.8045, 'longitude': -77.0509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24523', 'place_name': 'Bedford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bedford (city)', 'locality_code': '515', 'latitude': 37.3153, 'longitude': -79.5331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24201', 'place_name': 'Bristol', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bristol (city)', 'locality_code': '520', 'latitude': 36.6181, 'longitude': -82.1823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24202', 'place_name': 'Bristol', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bristol (city)', 'locality_code': '520', 'latitude': 36.6609, 'longitude': -82.2126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24203', 'place_name': 'Bristol', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bristol (city)', 'locality_code': '520', 'latitude': 36.5965, 'longitude': -82.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24205', 'place_name': 'Bristol', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bristol (city)', 'locality_code': '520', 'latitude': 36.595, 'longitude': -82.1819, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24209', 'place_name': 'Bristol', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Bristol (city)', 'locality_code': '520', 'latitude': 36.5965, 'longitude': -82.1885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24416', 'place_name': 'Buena Vista', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Buena Vista (city)', 'locality_code': '530', 'latitude': 37.7396, 'longitude': -79.3523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22902', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0266, 'longitude': -78.4805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22903', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0339, 'longitude': -78.4924, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22904', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0401, 'longitude': -78.4851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22905', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0401, 'longitude': -78.4851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22906', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0401, 'longitude': -78.4851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22907', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0401, 'longitude': -78.4851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22908', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0401, 'longitude': -78.4851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22910', 'place_name': 'Charlottesville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Charlottesville (city)', 'locality_code': '540', 'latitude': 38.0401, 'longitude': -78.4851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23320', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.7352, 'longitude': -76.2384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23321', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.8012, 'longitude': -76.423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23322', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.6434, 'longitude': -76.242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23323', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.7634, 'longitude': -76.3397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23324', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.8056, 'longitude': -76.2666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23325', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.814, 'longitude': -76.2406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23326', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.777, 'longitude': -76.2394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23327', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.7085, 'longitude': -76.2785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23328', 'place_name': 'Chesapeake', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Chesapeake (city)', 'locality_code': '550', 'latitude': 36.7085, 'longitude': -76.2785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23834', 'place_name': 'Colonial Heights', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Colonial Heights (city', 'locality_code': '570', 'latitude': 37.27, 'longitude': -77.4038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24426', 'place_name': 'Covington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Covington (city)', 'locality_code': '580', 'latitude': 37.7802, 'longitude': -79.987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24540', 'place_name': 'Danville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Danville (city)', 'locality_code': '590', 'latitude': 36.6218, 'longitude': -79.4124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24541', 'place_name': 'Danville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Danville (city)', 'locality_code': '590', 'latitude': 36.5779, 'longitude': -79.4411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24543', 'place_name': 'Danville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Danville (city)', 'locality_code': '590', 'latitude': 36.5927, 'longitude': -79.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23847', 'place_name': 'Emporia', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Emporia (city)', 'locality_code': '595', 'latitude': 36.6857, 'longitude': -77.563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22030', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax (city)', 'locality_code': '600', 'latitude': 38.8458, 'longitude': -77.3242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22031', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax (city)', 'locality_code': '600', 'latitude': 38.8604, 'longitude': -77.2649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22038', 'place_name': 'Fairfax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fairfax (city)', 'locality_code': '600', 'latitude': 38.8528, 'longitude': -77.302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22040', 'place_name': 'Falls Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Falls Church (city)', 'locality_code': '610', 'latitude': 38.8842, 'longitude': -77.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22046', 'place_name': 'Falls Church', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Falls Church (city)', 'locality_code': '610', 'latitude': 38.8856, 'longitude': -77.1802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23851', 'place_name': 'Franklin', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Franklin (city)', 'locality_code': '620', 'latitude': 36.6786, 'longitude': -76.9391, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22401', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fredericksburg (city)', 'locality_code': '630', 'latitude': 38.2995, 'longitude': -77.4772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22402', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fredericksburg (city)', 'locality_code': '630', 'latitude': 38.2996, 'longitude': -77.4897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22404', 'place_name': 'Fredericksburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Fredericksburg (city)', 'locality_code': '630', 'latitude': 38.3032, 'longitude': -77.4605, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24333', 'place_name': 'Galax', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Galax (city)', 'locality_code': '640', 'latitude': 36.6565, 'longitude': -80.9117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23630', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0727, 'longitude': -76.3899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23651', 'place_name': 'Fort Monroe', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.018, 'longitude': -76.3044, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23661', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0074, 'longitude': -76.3801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23663', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0318, 'longitude': -76.3199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23664', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0566, 'longitude': -76.2966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23665', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0831, 'longitude': -76.36, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23666', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0462, 'longitude': -76.4096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23667', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0193, 'longitude': -76.3318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23668', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0206, 'longitude': -76.3377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23669', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0436, 'longitude': -76.3426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23670', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0727, 'longitude': -76.3899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23681', 'place_name': 'Hampton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hampton (city)', 'locality_code': '650', 'latitude': 37.0727, 'longitude': -76.3899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22801', 'place_name': 'Harrisonburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Harrisonburg', 'locality_code': '660', 'latitude': 38.4489, 'longitude': -78.8714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22803', 'place_name': 'Harrisonburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Harrisonburg', 'locality_code': '660', 'latitude': 38.4496, 'longitude': -78.8689, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22807', 'place_name': 'Harrisonburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Harrisonburg', 'locality_code': '660', 'latitude': 38.4409, 'longitude': -78.8742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23860', 'place_name': 'Hopewell', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Hopewell (city)', 'locality_code': '670', 'latitude': 37.2876, 'longitude': -77.295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24450', 'place_name': 'Lexington', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lexington (city)', 'locality_code': '678', 'latitude': 37.7885, 'longitude': -79.4581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24501', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.353, 'longitude': -79.1557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24502', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.3825, 'longitude': -79.2181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24503', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.4376, 'longitude': -79.205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24504', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.361, 'longitude': -79.0544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24505', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.4138, 'longitude': -79.1422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24506', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.3817, 'longitude': -79.161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24514', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.4009, 'longitude': -79.1785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24515', 'place_name': 'Lynchburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Lynchburg (city)', 'locality_code': '680', 'latitude': 37.4009, 'longitude': -79.1785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20108', 'place_name': 'Manassas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Manassas (city)', 'locality_code': '683', 'latitude': 38.7447, 'longitude': -77.4872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20109', 'place_name': 'Manassas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Manassas (city)', 'locality_code': '683', 'latitude': 38.793, 'longitude': -77.5266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20110', 'place_name': 'Manassas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Manassas (city)', 'locality_code': '683', 'latitude': 38.7492, 'longitude': -77.4878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20111', 'place_name': 'Manassas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Manassas Park (city)', 'locality_code': '685', 'latitude': 38.7707, 'longitude': -77.4494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20112', 'place_name': 'Manassas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Manassas Park (city)', 'locality_code': '685', 'latitude': 38.6665, 'longitude': -77.4248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '20113', 'place_name': 'Manassas', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Manassas Park (city)', 'locality_code': '685', 'latitude': 38.7709, 'longitude': -77.4494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24112', 'place_name': 'Martinsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Martinsville (city)', 'locality_code': '690', 'latitude': 36.6871, 'longitude': -79.8691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24113', 'place_name': 'Martinsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Martinsville (city)', 'locality_code': '690', 'latitude': 36.6796, 'longitude': -79.8652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24114', 'place_name': 'Martinsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Martinsville (city)', 'locality_code': '690', 'latitude': 36.6796, 'longitude': -79.8652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24115', 'place_name': 'Martinsville', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Martinsville (city)', 'locality_code': '690', 'latitude': 36.6796, 'longitude': -79.8652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23601', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.058, 'longitude': -76.4607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23602', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.1132, 'longitude': -76.5179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23603', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.1989, 'longitude': -76.5821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23604', 'place_name': 'Fort Eustis', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.1574, 'longitude': -76.5845, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23605', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.0156, 'longitude': -76.4332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23606', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.0768, 'longitude': -76.4967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23607', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 36.9864, 'longitude': -76.4165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23608', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.1526, 'longitude': -76.542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23609', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.1959, 'longitude': -76.5248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23612', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.1959, 'longitude': -76.5248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23628', 'place_name': 'Newport News', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Newport News (city)', 'locality_code': '700', 'latitude': 37.1959, 'longitude': -76.5248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23501', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8959, 'longitude': -76.2085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23502', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8546, 'longitude': -76.2143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23503', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9442, 'longitude': -76.252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23504', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8586, 'longitude': -76.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23505', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9168, 'longitude': -76.2875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23506', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9312, 'longitude': -76.2397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23507', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8645, 'longitude': -76.3004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23508', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8859, 'longitude': -76.3004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23509', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8787, 'longitude': -76.2604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23510', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8529, 'longitude': -76.2878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23511', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9356, 'longitude': -76.3034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23513', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8914, 'longitude': -76.2396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23514', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8468, 'longitude': -76.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23515', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9312, 'longitude': -76.2397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23517', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8695, 'longitude': -76.2945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23518', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9202, 'longitude': -76.216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23519', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9312, 'longitude': -76.2397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23523', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.8294, 'longitude': -76.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23529', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9312, 'longitude': -76.2397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23541', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9312, 'longitude': -76.2397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23551', 'place_name': 'Norfolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norfolk (city)', 'locality_code': '710', 'latitude': 36.9312, 'longitude': -76.2397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24273', 'place_name': 'Norton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Norton (city)', 'locality_code': '720', 'latitude': 36.9378, 'longitude': -82.6249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23803', 'place_name': 'Petersburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Petersburg (city)', 'locality_code': '730', 'latitude': 37.2123, 'longitude': -77.4814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23804', 'place_name': 'Petersburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Petersburg (city)', 'locality_code': '730', 'latitude': 37.2048, 'longitude': -77.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23805', 'place_name': 'Petersburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Petersburg (city)', 'locality_code': '730', 'latitude': 37.1819, 'longitude': -77.3854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23806', 'place_name': 'Virginia State University', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Petersburg (city)', 'locality_code': '730', 'latitude': 37.2327, 'longitude': -77.385, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '23662', 'place_name': 'Poquoson', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Poquoson (city)', 'locality_code': '735', 'latitude': 37.1313, 'longitude': -76.3807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23701', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8089, 'longitude': -76.3671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23702', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8035, 'longitude': -76.327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23703', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8695, 'longitude': -76.3869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23704', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8298, 'longitude': -76.3146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23705', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8686, 'longitude': -76.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23707', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8362, 'longitude': -76.344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23708', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8354, 'longitude': -76.2983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23709', 'place_name': 'Portsmouth', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Portsmouth (city)', 'locality_code': '740', 'latitude': 36.8686, 'longitude': -76.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24141', 'place_name': 'Radford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Radford (city)', 'locality_code': '750', 'latitude': 37.1197, 'longitude': -80.5565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24142', 'place_name': 'Radford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Radford (city)', 'locality_code': '750', 'latitude': 37.1387, 'longitude': -80.548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24143', 'place_name': 'Radford', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Radford (city)', 'locality_code': '750', 'latitude': 37.1226, 'longitude': -80.5629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23173', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5538, 'longitude': -77.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23218', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23219', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5463, 'longitude': -77.4378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23220', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5498, 'longitude': -77.4588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23221', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5583, 'longitude': -77.4845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23222', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5748, 'longitude': -77.4267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23223', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5477, 'longitude': -77.3948, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23224', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.4955, 'longitude': -77.471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23225', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5158, 'longitude': -77.5047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23232', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5202, 'longitude': -77.4084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23241', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23249', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23260', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5538, 'longitude': -77.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23261', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5538, 'longitude': -77.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23269', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5538, 'longitude': -77.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23273', 'place_name': 'Henrico', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5302, 'longitude': -77.4753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23274', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23276', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23278', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23279', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23282', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5538, 'longitude': -77.4603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23284', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5494, 'longitude': -77.4512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23285', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23286', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23290', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23291', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23292', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23293', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5242, 'longitude': -77.4932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23295', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5532, 'longitude': -77.4621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23298', 'place_name': 'Richmond', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Richmond', 'locality_code': '760', 'latitude': 37.5406, 'longitude': -77.4316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24001', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24002', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24003', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24004', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24005', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24006', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24007', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24008', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24009', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24010', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24011', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.269, 'longitude': -79.942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24012', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.3029, 'longitude': -79.9322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24013', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2677, 'longitude': -79.9247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24014', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2327, 'longitude': -79.9463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24015', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2584, 'longitude': -79.9807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24016', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2704, 'longitude': -79.9535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24017', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2937, 'longitude': -79.9902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24022', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2784, 'longitude': -79.9332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24024', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24025', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24026', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24027', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24028', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24029', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24030', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24031', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24032', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24033', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24034', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24035', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24036', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24037', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24038', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24040', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2742, 'longitude': -79.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24042', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2717, 'longitude': -79.9392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24043', 'place_name': 'Roanoke', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Roanoke (city)', 'locality_code': '770', 'latitude': 37.2692, 'longitude': -79.9399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24153', 'place_name': 'Salem', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Salem (city)', 'locality_code': '775', 'latitude': 37.2853, 'longitude': -80.0692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24155', 'place_name': 'Salem', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Salem (city)', 'locality_code': '775', 'latitude': 37.2884, 'longitude': -80.0671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24157', 'place_name': 'Salem', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Salem (city)', 'locality_code': '775', 'latitude': 37.2884, 'longitude': -80.0671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24401', 'place_name': 'Staunton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Staunton (city)', 'locality_code': '790', 'latitude': 38.1574, 'longitude': -79.0651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24402', 'place_name': 'Staunton', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Staunton (city)', 'locality_code': '790', 'latitude': 38.1593, 'longitude': -79.0629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23432', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.8668, 'longitude': -76.5598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23433', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.909, 'longitude': -76.4929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23434', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.7304, 'longitude': -76.5931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23435', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.8544, 'longitude': -76.4664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23436', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.8926, 'longitude': -76.5142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23437', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.6526, 'longitude': -76.792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23438', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.5913, 'longitude': -76.6871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23439', 'place_name': 'Suffolk', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.7461, 'longitude': -76.6653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23453', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'City of Suffolk', 'locality_code': '800', 'latitude': 36.776, 'longitude': -76.0766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23450', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.844, 'longitude': -76.1204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23451', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.8585, 'longitude': -76.0019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23452', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.8348, 'longitude': -76.0961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23454', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.8282, 'longitude': -76.0237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23455', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.8881, 'longitude': -76.1446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23456', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7341, 'longitude': -76.0359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23457', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.6224, 'longitude': -76.0249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23458', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.8529, 'longitude': -75.978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23459', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.9216, 'longitude': -76.0171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23460', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.808, 'longitude': -76.0284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23461', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7754, 'longitude': -75.9633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23462', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.8392, 'longitude': -76.1522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23463', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7957, 'longitude': -76.0126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23464', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7978, 'longitude': -76.1759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23465', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.8512, 'longitude': -76.1692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23466', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7957, 'longitude': -76.0126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23467', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7957, 'longitude': -76.0126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23471', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7957, 'longitude': -76.0126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23479', 'place_name': 'Virginia Beach', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Virginia Beach (city)', 'locality_code': '810', 'latitude': 36.7957, 'longitude': -76.0126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22980', 'place_name': 'Waynesboro', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Waynesboro (city)', 'locality_code': '820', 'latitude': 38.0774, 'longitude': -78.9035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23186', 'place_name': 'Williamsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Williamsburg (city)', 'locality_code': '830', 'latitude': 37.3105, 'longitude': -76.7468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '23187', 'place_name': 'Williamsburg', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Williamsburg (city)', 'locality_code': '830', 'latitude': 37.3105, 'longitude': -76.7468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22601', 'place_name': 'Winchester', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Winchester (city)', 'locality_code': '840', 'latitude': 39.1858, 'longitude': -78.1827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '22604', 'place_name': 'Winchester', 'state': 'Virginia', 'state_ab': 'VA', 'county': 'Winchester (city)', 'locality_code': '840', 'latitude': 39.1676, 'longitude': -78.1686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5443', 'place_name': 'Bristol', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.146, 'longitude': -73.0717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5456', 'place_name': 'Ferrisburgh', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.2056, 'longitude': -73.2462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5469', 'place_name': 'Monkton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.2404, 'longitude': -73.1347, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5472', 'place_name': 'New Haven', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.1126, 'longitude': -73.1735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5473', 'place_name': 'North Ferrisburgh', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.2595, 'longitude': -73.2112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5487', 'place_name': 'Starksboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.2261, 'longitude': -73.0157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5491', 'place_name': 'Vergennes', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.1326, 'longitude': -73.2793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5669', 'place_name': 'Roxbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 44.0846, 'longitude': -72.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5734', 'place_name': 'Bridport', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.9538, 'longitude': -73.3476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5740', 'place_name': 'East Middlebury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.9734, 'longitude': -73.1062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5747', 'place_name': 'Granville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.9849, 'longitude': -72.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5748', 'place_name': 'Hancock', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.9125, 'longitude': -72.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5753', 'place_name': 'Middlebury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.9919, 'longitude': -73.1716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5760', 'place_name': 'Orwell', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.7837, 'longitude': -73.2949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5766', 'place_name': 'Ripton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.9929, 'longitude': -73.0187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5769', 'place_name': 'Salisbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.9017, 'longitude': -73.1008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5770', 'place_name': 'Shoreham', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.8862, 'longitude': -73.3054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5778', 'place_name': 'Whiting', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Addison', 'locality_code': '1', 'latitude': 43.894, 'longitude': -73.203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5152', 'place_name': 'Peru', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.2565, 'longitude': -72.8868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5201', 'place_name': 'Bennington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 42.8827, 'longitude': -73.1923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5250', 'place_name': 'Arlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.0857, 'longitude': -73.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5251', 'place_name': 'Dorset', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.2636, 'longitude': -73.0766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5252', 'place_name': 'East Arlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.0668, 'longitude': -73.0611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5253', 'place_name': 'East Dorset', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.237, 'longitude': -73.0081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5254', 'place_name': 'Manchester', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.1637, 'longitude': -73.0723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5255', 'place_name': 'Manchester Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.1693, 'longitude': -73.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5257', 'place_name': 'North Bennington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 42.9304, 'longitude': -73.2426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5260', 'place_name': 'North Pownal', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 42.8098, 'longitude': -73.2534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5261', 'place_name': 'Pownal', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 42.788, 'longitude': -73.2162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5262', 'place_name': 'Shaftsbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 42.9614, 'longitude': -73.2166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5340', 'place_name': 'Bondville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.1618, 'longitude': -72.9128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5350', 'place_name': 'Readsboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 42.7837, 'longitude': -72.9609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5352', 'place_name': 'Stamford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 42.7562, 'longitude': -73.0679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5768', 'place_name': 'Rupert', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.2598, 'longitude': -73.2229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5776', 'place_name': 'West Rupert', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Bennington', 'locality_code': '3', 'latitude': 43.2636, 'longitude': -73.1905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5042', 'place_name': 'East Ryegate', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.2275, 'longitude': -72.0996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5046', 'place_name': 'Groton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.2204, 'longitude': -72.2175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5050', 'place_name': 'Mc Indoe Falls', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.4624, 'longitude': -72.1358, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5069', 'place_name': 'South Ryegate', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.1978, 'longitude': -72.1104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5819', 'place_name': 'Saint Johnsbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.4272, 'longitude': -72.0051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5821', 'place_name': 'Barnet', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.3179, 'longitude': -72.0783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5828', 'place_name': 'Danville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.4332, 'longitude': -72.1133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5832', 'place_name': 'East Burke', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.6078, 'longitude': -71.9357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5836', 'place_name': 'East Hardwick', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.5288, 'longitude': -72.3034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5838', 'place_name': 'East Saint Johnsbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.4387, 'longitude': -71.9456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5843', 'place_name': 'Hardwick', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.507, 'longitude': -72.3638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5848', 'place_name': 'Lower Waterford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.3821, 'longitude': -71.9195, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5849', 'place_name': 'Lyndon', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.4976, 'longitude': -71.9505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5850', 'place_name': 'Lyndon Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.5416, 'longitude': -72.0175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5851', 'place_name': 'Lyndonville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.5555, 'longitude': -72.0715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5861', 'place_name': 'Passumpsic', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.3767, 'longitude': -72.0276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5862', 'place_name': 'Peacham', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.3289, 'longitude': -72.169, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5863', 'place_name': 'Saint Johnsbury Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.4567, 'longitude': -72.0157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5866', 'place_name': 'Sheffield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.6178, 'longitude': -72.1239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5867', 'place_name': 'Sutton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.6465, 'longitude': -72.0211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5871', 'place_name': 'West Burke', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.6636, 'longitude': -71.9572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5873', 'place_name': 'West Danville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Caledonia', 'locality_code': '5', 'latitude': 44.4465, 'longitude': -72.2198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5401', 'place_name': 'Burlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.484, 'longitude': -73.2199, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5402', 'place_name': 'Burlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4421, 'longitude': -73.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5403', 'place_name': 'South Burlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4513, 'longitude': -73.1796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5404', 'place_name': 'Winooski', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4949, 'longitude': -73.1874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5405', 'place_name': 'Burlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4421, 'longitude': -73.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5406', 'place_name': 'Burlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4421, 'longitude': -73.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5407', 'place_name': 'South Burlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4421, 'longitude': -73.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5408', 'place_name': 'Burlington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.512, 'longitude': -73.2492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5439', 'place_name': 'Colchester', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4952, 'longitude': -73.1651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5445', 'place_name': 'Charlotte', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.3113, 'longitude': -73.228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5446', 'place_name': 'Colchester', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.536, 'longitude': -73.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5449', 'place_name': 'Colchester', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.5439, 'longitude': -73.1479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5451', 'place_name': 'Essex', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.5084, 'longitude': -73.0503, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5452', 'place_name': 'Essex Junction', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.5035, 'longitude': -73.0906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5453', 'place_name': 'Essex Junction', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4421, 'longitude': -73.0825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5461', 'place_name': 'Hinesburg', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.3346, 'longitude': -73.098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5462', 'place_name': 'Huntington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.3227, 'longitude': -72.9964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5465', 'place_name': 'Jericho', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.459, 'longitude': -72.9552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5466', 'place_name': 'Jonesville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.3839, 'longitude': -72.9376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5468', 'place_name': 'Milton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.6483, 'longitude': -73.1317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5477', 'place_name': 'Richmond', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.3873, 'longitude': -72.9533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5482', 'place_name': 'Shelburne', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.39, 'longitude': -73.2171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5489', 'place_name': 'Underhill', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.5391, 'longitude': -72.9258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5490', 'place_name': 'Underhill Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.5047, 'longitude': -72.8853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5494', 'place_name': 'Westford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.6182, 'longitude': -73.006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5495', 'place_name': 'Williston', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Chittenden', 'locality_code': '7', 'latitude': 44.4367, 'longitude': -73.0957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5824', 'place_name': 'Concord', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.4461, 'longitude': -71.8676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5837', 'place_name': 'East Haven', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.6517, 'longitude': -71.8675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5840', 'place_name': 'Granby', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.6808, 'longitude': -71.7194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5846', 'place_name': 'Island Pond', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.8095, 'longitude': -71.884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5858', 'place_name': 'North Concord', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.5501, 'longitude': -71.7867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5901', 'place_name': 'Averill', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.9981, 'longitude': -71.7104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5902', 'place_name': 'Beecher Falls', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 45.0085, 'longitude': -71.4907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5903', 'place_name': 'Canaan', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.9764, 'longitude': -71.5602, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5904', 'place_name': 'Gilman', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.414, 'longitude': -71.7179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5905', 'place_name': 'Guildhall', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.6902, 'longitude': -71.5991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5906', 'place_name': 'Lunenburg', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.4663, 'longitude': -71.693, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5907', 'place_name': 'Norton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Essex', 'locality_code': '9', 'latitude': 44.9888, 'longitude': -71.7884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5441', 'place_name': 'Bakersfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.7914, 'longitude': -72.7697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5447', 'place_name': 'East Berkshire', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.931, 'longitude': -72.7028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5448', 'place_name': 'East Fairfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.7412, 'longitude': -72.8827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5450', 'place_name': 'Enosburg Falls', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.8985, 'longitude': -72.791, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5454', 'place_name': 'Fairfax', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.6924, 'longitude': -73.0241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5455', 'place_name': 'Fairfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.7841, 'longitude': -73.0222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5457', 'place_name': 'Franklin', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.9614, 'longitude': -72.9037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5459', 'place_name': 'Highgate Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.9404, 'longitude': -73.0155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5460', 'place_name': 'Highgate Springs', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.9748, 'longitude': -73.1052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5470', 'place_name': 'Montgomery', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.9025, 'longitude': -72.6382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5471', 'place_name': 'Montgomery Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.8781, 'longitude': -72.6023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5476', 'place_name': 'Richford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.9715, 'longitude': -72.6905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5478', 'place_name': 'Saint Albans', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.8111, 'longitude': -73.089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5479', 'place_name': 'Saint Albans', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.8109, 'longitude': -73.0832, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5481', 'place_name': 'Saint Albans Bay', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.8078, 'longitude': -73.1393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5483', 'place_name': 'Sheldon', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.8872, 'longitude': -72.953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5485', 'place_name': 'Sheldon Springs', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.9062, 'longitude': -72.9776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5488', 'place_name': 'Swanton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Franklin', 'locality_code': '11', 'latitude': 44.9168, 'longitude': -73.1211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5440', 'place_name': 'Alburgh', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Grand Isle', 'locality_code': '13', 'latitude': 44.6031, 'longitude': -72.9527, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5458', 'place_name': 'Grand Isle', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Grand Isle', 'locality_code': '13', 'latitude': 44.7197, 'longitude': -73.3056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5463', 'place_name': 'Isle La Motte', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Grand Isle', 'locality_code': '13', 'latitude': 44.8781, 'longitude': -73.3386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5474', 'place_name': 'North Hero', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Grand Isle', 'locality_code': '13', 'latitude': 44.8353, 'longitude': -73.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5486', 'place_name': 'South Hero', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Grand Isle', 'locality_code': '13', 'latitude': 44.64, 'longitude': -73.3113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5442', 'place_name': 'Belvidere Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.7248, 'longitude': -72.7016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5444', 'place_name': 'Cambridge', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.6222, 'longitude': -72.8812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5464', 'place_name': 'Jeffersonville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.6388, 'longitude': -72.822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5492', 'place_name': 'Waterville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.7124, 'longitude': -72.7596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5652', 'place_name': 'Eden', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.7343, 'longitude': -72.5863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5653', 'place_name': 'Eden Mills', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.6931, 'longitude': -72.5134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5655', 'place_name': 'Hyde Park', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.6225, 'longitude': -72.595, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5656', 'place_name': 'Johnson', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.642, 'longitude': -72.6712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5657', 'place_name': 'Lake Elmore', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.5426, 'longitude': -72.5254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5661', 'place_name': 'Morrisville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.5543, 'longitude': -72.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5662', 'place_name': 'Moscow', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.442, 'longitude': -72.7188, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5665', 'place_name': 'North Hyde Park', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.6731, 'longitude': -72.5971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5672', 'place_name': 'Stowe', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.4695, 'longitude': -72.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5680', 'place_name': 'Wolcott', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Lamoille', 'locality_code': '15', 'latitude': 44.5558, 'longitude': -72.4844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5033', 'place_name': 'Bradford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0006, 'longitude': -72.1406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5036', 'place_name': 'Brookfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0321, 'longitude': -72.5953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5038', 'place_name': 'Chelsea', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0039, 'longitude': -72.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5039', 'place_name': 'Corinth', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0325, 'longitude': -72.2822, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5040', 'place_name': 'East Corinth', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0619, 'longitude': -72.2151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5041', 'place_name': 'East Randolph', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.9553, 'longitude': -72.5487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5043', 'place_name': 'East Thetford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.8073, 'longitude': -72.2147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5045', 'place_name': 'Fairlee', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.901, 'longitude': -72.1902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5051', 'place_name': 'Newbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0683, 'longitude': -72.1187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5054', 'place_name': 'North Thetford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.8431, 'longitude': -72.1856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5058', 'place_name': 'Post Mills', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.8858, 'longitude': -72.27, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5060', 'place_name': 'Randolph', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.9444, 'longitude': -72.6726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5061', 'place_name': 'Randolph Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.9379, 'longitude': -72.597, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5070', 'place_name': 'South Strafford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.8282, 'longitude': -72.37, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5072', 'place_name': 'Strafford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.8723, 'longitude': -72.3636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5074', 'place_name': 'Thetford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.996, 'longitude': -72.4114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5075', 'place_name': 'Thetford Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.8149, 'longitude': -72.2662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5076', 'place_name': 'Topsham', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.7982, 'longitude': -72.4008, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5077', 'place_name': 'Tunbridge', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.9169, 'longitude': -72.4786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5079', 'place_name': 'Vershire', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.9618, 'longitude': -72.319, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5081', 'place_name': 'Wells River', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.1524, 'longitude': -72.053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5083', 'place_name': 'West Fairlee', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 43.9189, 'longitude': -72.2681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5085', 'place_name': 'West Newbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0645, 'longitude': -72.1248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5086', 'place_name': 'West Topsham', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.1199, 'longitude': -72.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5675', 'place_name': 'Washington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.0782, 'longitude': -72.4263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5679', 'place_name': 'Williamstown', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orange', 'locality_code': '17', 'latitude': 44.1182, 'longitude': -72.5381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5820', 'place_name': 'Albany', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.7417, 'longitude': -72.3646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5822', 'place_name': 'Barton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.7395, 'longitude': -72.16, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5823', 'place_name': 'Beebe Plain', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 45.0058, 'longitude': -72.1383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5825', 'place_name': 'Coventry', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.8656, 'longitude': -72.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5826', 'place_name': 'Craftsbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.6434, 'longitude': -72.366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5827', 'place_name': 'Craftsbury Common', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.6788, 'longitude': -72.3594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5829', 'place_name': 'Derby', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.9502, 'longitude': -72.1376, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5830', 'place_name': 'Derby Line', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.9902, 'longitude': -72.0824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5833', 'place_name': 'East Charleston', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.8299, 'longitude': -71.9763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5839', 'place_name': 'Glover', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.6747, 'longitude': -72.2131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5841', 'place_name': 'Greensboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.5951, 'longitude': -72.285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5842', 'place_name': 'Greensboro Bend', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.5489, 'longitude': -72.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5845', 'place_name': 'Irasburg', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.8081, 'longitude': -72.2763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5847', 'place_name': 'Lowell', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.7961, 'longitude': -72.4501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5853', 'place_name': 'Morgan', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.8787, 'longitude': -71.9714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5855', 'place_name': 'Newport', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.9393, 'longitude': -72.2065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5857', 'place_name': 'Newport Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.9442, 'longitude': -72.2974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5859', 'place_name': 'North Troy', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.9378, 'longitude': -72.4334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5860', 'place_name': 'Orleans', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.8238, 'longitude': -72.102, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5868', 'place_name': 'Troy', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.9014, 'longitude': -72.4015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5872', 'place_name': 'West Charleston', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.8729, 'longitude': -72.0521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5874', 'place_name': 'Westfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.8825, 'longitude': -72.4396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5875', 'place_name': 'Barton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Orleans', 'locality_code': '19', 'latitude': 44.7481, 'longitude': -72.1762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5701', 'place_name': 'Rutland', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6141, 'longitude': -72.9708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5702', 'place_name': 'Rutland', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6106, 'longitude': -72.9726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5730', 'place_name': 'Belmont', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.4284, 'longitude': -72.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5731', 'place_name': 'Benson', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6877, 'longitude': -73.2919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5732', 'place_name': 'Bomoseen', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6437, 'longitude': -73.2094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5733', 'place_name': 'Brandon', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.8065, 'longitude': -73.0882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5735', 'place_name': 'Castleton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6223, 'longitude': -73.1708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5736', 'place_name': 'Center Rutland', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6023, 'longitude': -73.017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5737', 'place_name': 'Chittenden', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.7132, 'longitude': -72.9252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5738', 'place_name': 'Cuttingsville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.5221, 'longitude': -72.8691, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5739', 'place_name': 'Danby', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.3583, 'longitude': -73.0129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5741', 'place_name': 'East Poultney', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.5265, 'longitude': -73.2046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5742', 'place_name': 'East Wallingford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.4461, 'longitude': -72.8844, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5743', 'place_name': 'Fair Haven', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6234, 'longitude': -73.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5744', 'place_name': 'Florence', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.7093, 'longitude': -73.079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5745', 'place_name': 'Forest Dale', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.8278, 'longitude': -73.0537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5750', 'place_name': 'Hydeville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.5994, 'longitude': -73.251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5751', 'place_name': 'Killington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.6634, 'longitude': -72.7963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5757', 'place_name': 'Middletown Springs', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.4856, 'longitude': -73.1182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5758', 'place_name': 'Mount Holly', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.4487, 'longitude': -72.7956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5759', 'place_name': 'North Clarendon', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.5522, 'longitude': -72.9561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5761', 'place_name': 'Pawlet', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.3587, 'longitude': -73.1444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5762', 'place_name': 'Pittsfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.7723, 'longitude': -72.8129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5763', 'place_name': 'Pittsford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.7152, 'longitude': -73.0135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5764', 'place_name': 'Poultney', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.5332, 'longitude': -73.2253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5765', 'place_name': 'Proctor', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.658, 'longitude': -73.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5773', 'place_name': 'Wallingford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.4573, 'longitude': -72.9877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5774', 'place_name': 'Wells', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.4305, 'longitude': -73.2027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5775', 'place_name': 'West Pawlet', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.3667, 'longitude': -73.2313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5777', 'place_name': 'West Rutland', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Rutland', 'locality_code': '21', 'latitude': 43.5781, 'longitude': -73.0424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5601', 'place_name': 'Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1991, 'longitude': -72.5596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5602', 'place_name': 'Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2641, 'longitude': -72.577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5603', 'place_name': 'Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2601, 'longitude': -72.5754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5604', 'place_name': 'Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2595, 'longitude': -72.585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5609', 'place_name': 'Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2595, 'longitude': -72.585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5620', 'place_name': 'Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2595, 'longitude': -72.585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5633', 'place_name': 'Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2595, 'longitude': -72.585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5640', 'place_name': 'Adamant', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.3575, 'longitude': -72.5046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5641', 'place_name': 'Barre', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1945, 'longitude': -72.4936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5647', 'place_name': 'Cabot', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.4042, 'longitude': -72.3064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5648', 'place_name': 'Calais', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.3934, 'longitude': -72.4741, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '5649', 'place_name': 'East Barre', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1576, 'longitude': -72.4533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5650', 'place_name': 'East Calais', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.38, 'longitude': -72.4419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5651', 'place_name': 'East Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2828, 'longitude': -72.4926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5654', 'place_name': 'Graniteville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1512, 'longitude': -72.4929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5658', 'place_name': 'Marshfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.3509, 'longitude': -72.354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5660', 'place_name': 'Moretown', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2596, 'longitude': -72.7494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5663', 'place_name': 'Northfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1512, 'longitude': -72.6565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5664', 'place_name': 'Northfield Falls', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.172, 'longitude': -72.6509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5666', 'place_name': 'North Montpelier', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2595, 'longitude': -72.585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5667', 'place_name': 'Plainfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.2622, 'longitude': -72.4224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5670', 'place_name': 'South Barre', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1757, 'longitude': -72.5025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5671', 'place_name': 'Waterbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.3378, 'longitude': -72.7562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5673', 'place_name': 'Waitsfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1889, 'longitude': -72.8283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5674', 'place_name': 'Warren', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.111, 'longitude': -72.8609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5676', 'place_name': 'Waterbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.3451, 'longitude': -72.7798, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5677', 'place_name': 'Waterbury Center', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.3828, 'longitude': -72.708, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5678', 'place_name': 'Websterville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.1558, 'longitude': -72.4658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5681', 'place_name': 'Woodbury', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.4548, 'longitude': -72.4036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5682', 'place_name': 'Worcester', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Washington', 'locality_code': '23', 'latitude': 44.3944, 'longitude': -72.5609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5101', 'place_name': 'Bellows Falls', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.1482, 'longitude': -72.4664, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5141', 'place_name': 'Cambridgeport', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.1515, 'longitude': -72.5604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5146', 'place_name': 'Grafton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.1601, 'longitude': -72.5972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5148', 'place_name': 'Londonderry', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.2281, 'longitude': -72.788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5154', 'place_name': 'Saxtons River', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.1379, 'longitude': -72.5098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5155', 'place_name': 'South Londonderry', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.1699, 'longitude': -72.8515, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5158', 'place_name': 'Westminster', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.0826, 'longitude': -72.4749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5159', 'place_name': 'Westminster Station', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.094, 'longitude': -72.4565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5301', 'place_name': 'Brattleboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.8574, 'longitude': -72.5933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5302', 'place_name': 'Brattleboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.8509, 'longitude': -72.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5303', 'place_name': 'Brattleboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.8509, 'longitude': -72.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5304', 'place_name': 'Brattleboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.8509, 'longitude': -72.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5341', 'place_name': 'East Dover', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.9505, 'longitude': -72.783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5342', 'place_name': 'Jacksonville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.7778, 'longitude': -72.8071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5343', 'place_name': 'Jamaica', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.1042, 'longitude': -72.7944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5344', 'place_name': 'Marlboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.9947, 'longitude': -72.7204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5345', 'place_name': 'Newfane', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.9704, 'longitude': -72.6781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5346', 'place_name': 'Putney', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.0356, 'longitude': -72.5123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5351', 'place_name': 'South Newfane', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.9391, 'longitude': -72.7292, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5353', 'place_name': 'Townshend', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.0622, 'longitude': -72.6687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5354', 'place_name': 'Vernon', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.7565, 'longitude': -72.5115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5355', 'place_name': 'Wardsboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.0326, 'longitude': -72.8077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5356', 'place_name': 'West Dover', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.9535, 'longitude': -72.8687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5357', 'place_name': 'West Dummerston', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.9265, 'longitude': -72.6154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5358', 'place_name': 'West Halifax', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.7761, 'longitude': -72.7501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5359', 'place_name': 'West Townshend', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.13, 'longitude': -72.721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5360', 'place_name': 'West Wardsboro', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 43.0472, 'longitude': -72.8805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5361', 'place_name': 'Whitingham', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.7892, 'longitude': -72.8851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5362', 'place_name': 'Williamsville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.9364, 'longitude': -72.6611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5363', 'place_name': 'Wilmington', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windham', 'locality_code': '25', 'latitude': 42.8812, 'longitude': -72.8613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5001', 'place_name': 'White River Junction', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.6722, 'longitude': -72.3813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5009', 'place_name': 'White River Junction', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.649, 'longitude': -72.3193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5030', 'place_name': 'Ascutney', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.4107, 'longitude': -72.4298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5031', 'place_name': 'Barnard', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.7287, 'longitude': -72.619, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5032', 'place_name': 'Bethel', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.8195, 'longitude': -72.6528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5034', 'place_name': 'Bridgewater', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.5804, 'longitude': -72.6467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5035', 'place_name': 'Bridgewater Corners', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.5998, 'longitude': -72.6752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5037', 'place_name': 'Brownsville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.4646, 'longitude': -72.4944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5047', 'place_name': 'Hartford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.6721, 'longitude': -72.3555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5048', 'place_name': 'Hartland', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.5708, 'longitude': -72.4131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5049', 'place_name': 'Hartland Four Corners', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.5465, 'longitude': -72.4245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5052', 'place_name': 'North Hartland', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.5967, 'longitude': -72.3526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5053', 'place_name': 'North Pomfret', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.7204, 'longitude': -72.4943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5055', 'place_name': 'Norwich', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.7404, 'longitude': -72.3016, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5056', 'place_name': 'Plymouth', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.4987, 'longitude': -72.7107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5059', 'place_name': 'Quechee', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.6462, 'longitude': -72.4184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5062', 'place_name': 'Reading', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.4793, 'longitude': -72.5704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5065', 'place_name': 'Sharon', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.7748, 'longitude': -72.4243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5067', 'place_name': 'South Pomfret', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.6797, 'longitude': -72.5349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5068', 'place_name': 'South Royalton', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.8089, 'longitude': -72.5232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5071', 'place_name': 'South Woodstock', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.5601, 'longitude': -72.5384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5073', 'place_name': 'Taftsville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.6309, 'longitude': -72.4891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5084', 'place_name': 'West Hartford', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.7123, 'longitude': -72.4176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5088', 'place_name': 'Wilder', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.6735, 'longitude': -72.312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5089', 'place_name': 'Windsor', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.476, 'longitude': -72.411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5091', 'place_name': 'Woodstock', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.6248, 'longitude': -72.5385, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5142', 'place_name': 'Cavendish', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.3766, 'longitude': -72.6092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5143', 'place_name': 'Chester', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.2831, 'longitude': -72.6031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5149', 'place_name': 'Ludlow', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.3929, 'longitude': -72.7002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5150', 'place_name': 'North Springfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.338, 'longitude': -72.5277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5151', 'place_name': 'Perkinsville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.3879, 'longitude': -72.5038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5153', 'place_name': 'Proctorsville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.3823, 'longitude': -72.6384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5156', 'place_name': 'Springfield', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.3034, 'longitude': -72.4778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5161', 'place_name': 'Weston', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.2941, 'longitude': -72.7935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5746', 'place_name': 'Gaysville', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.7784, 'longitude': -72.699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5767', 'place_name': 'Rochester', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.8804, 'longitude': -72.8159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '5772', 'place_name': 'Stockbridge', 'state': 'Vermont', 'state_ab': 'VT', 'county': 'Windsor', 'locality_code': '27', 'latitude': 43.7738, 'longitude': -72.7814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99105', 'place_name': 'Benge', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Adams', 'locality_code': '1', 'latitude': 46.8591, 'longitude': -118.1611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99169', 'place_name': 'Ritzville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Adams', 'locality_code': '1', 'latitude': 47.1315, 'longitude': -118.3958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99341', 'place_name': 'Lind', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Adams', 'locality_code': '1', 'latitude': 46.956, 'longitude': -118.7061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99344', 'place_name': 'Othello', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Adams', 'locality_code': '1', 'latitude': 46.8527, 'longitude': -118.9932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99371', 'place_name': 'Washtucna', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Adams', 'locality_code': '1', 'latitude': 46.8209, 'longitude': -118.2862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99401', 'place_name': 'Anatone', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Asotin', 'locality_code': '3', 'latitude': 46.1285, 'longitude': -117.0883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99402', 'place_name': 'Asotin', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Asotin', 'locality_code': '3', 'latitude': 46.1343, 'longitude': -117.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99403', 'place_name': 'Clarkston', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Asotin', 'locality_code': '3', 'latitude': 46.3946, 'longitude': -117.0645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99320', 'place_name': 'Benton City', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.2806, 'longitude': -119.4913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99336', 'place_name': 'Kennewick', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.2109, 'longitude': -119.168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99337', 'place_name': 'Kennewick', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.1814, 'longitude': -119.1383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99338', 'place_name': 'Kennewick', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.156, 'longitude': -119.264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99345', 'place_name': 'Paterson', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 45.9911, 'longitude': -119.7559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99346', 'place_name': 'Plymouth', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 45.9301, 'longitude': -119.4023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99350', 'place_name': 'Prosser', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.2232, 'longitude': -119.771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99352', 'place_name': 'Richland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.2522, 'longitude': -119.288, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99353', 'place_name': 'West Richland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.3153, 'longitude': -119.3714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99354', 'place_name': 'Richland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Benton', 'locality_code': '5', 'latitude': 46.3257, 'longitude': -119.3067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98801', 'place_name': 'Wenatchee', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.4253, 'longitude': -120.3273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98807', 'place_name': 'Wenatchee', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.4235, 'longitude': -120.3103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98811', 'place_name': 'Ardenvoir', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.7373, 'longitude': -120.369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98815', 'place_name': 'Cashmere', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.5173, 'longitude': -120.5033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98816', 'place_name': 'Chelan', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.8483, 'longitude': -120.0273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98817', 'place_name': 'Chelan Falls', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.8015, 'longitude': -119.9859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98821', 'place_name': 'Dryden', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.5412, 'longitude': -120.5609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98822', 'place_name': 'Entiat', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.7057, 'longitude': -120.276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98826', 'place_name': 'Leavenworth', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.6438, 'longitude': -120.6748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98828', 'place_name': 'Malaga', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.3553, 'longitude': -120.2086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98831', 'place_name': 'Manson', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.8958, 'longitude': -120.149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98836', 'place_name': 'Monitor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.4852, 'longitude': -120.4158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98847', 'place_name': 'Peshastin', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 47.5458, 'longitude': -120.5961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98852', 'place_name': 'Stehekin', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Chelan', 'locality_code': '7', 'latitude': 48.3093, 'longitude': -120.6565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98305', 'place_name': 'Beaver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.0673, 'longitude': -124.3054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98324', 'place_name': 'Carlsborg', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.0906, 'longitude': -123.1721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98326', 'place_name': 'Clallam Bay', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.2255, 'longitude': -124.2015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98331', 'place_name': 'Forks', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 47.9287, 'longitude': -124.3989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98343', 'place_name': 'Joyce', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.1362, 'longitude': -123.7354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98350', 'place_name': 'La Push', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 47.9052, 'longitude': -124.6261, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98357', 'place_name': 'Neah Bay', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.328, 'longitude': -124.6151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98362', 'place_name': 'Port Angeles', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.1065, 'longitude': -123.4384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98363', 'place_name': 'Port Angeles', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.0557, 'longitude': -123.9178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98381', 'place_name': 'Sekiu', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.3032, 'longitude': -124.4685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98382', 'place_name': 'Sequim', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clallam', 'locality_code': '9', 'latitude': 48.0881, 'longitude': -123.1198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98601', 'place_name': 'Amboy', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.9195, 'longitude': -122.4574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98604', 'place_name': 'Battle Ground', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.7907, 'longitude': -122.5318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98606', 'place_name': 'Brush Prairie', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.7304, 'longitude': -122.4843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98607', 'place_name': 'Camas', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6058, 'longitude': -122.4142, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98622', 'place_name': 'Heisson', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.8248, 'longitude': -122.4912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98629', 'place_name': 'La Center', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.8806, 'longitude': -122.624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98642', 'place_name': 'Ridgefield', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.7846, 'longitude': -122.6934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98660', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6418, 'longitude': -122.6801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98661', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6418, 'longitude': -122.6251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98662', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6914, 'longitude': -122.5805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98663', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6514, 'longitude': -122.6604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98664', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6231, 'longitude': -122.5767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98665', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6892, 'longitude': -122.6616, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98666', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6387, 'longitude': -122.6615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98668', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6387, 'longitude': -122.6615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98671', 'place_name': 'Washougal', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.5959, 'longitude': -122.3104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98675', 'place_name': 'Yacolt', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.8622, 'longitude': -122.4275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98682', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6644, 'longitude': -122.5212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98683', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6032, 'longitude': -122.5133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98684', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6359, 'longitude': -122.5155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98685', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.7162, 'longitude': -122.6899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98686', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.712, 'longitude': -122.6322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98687', 'place_name': 'Vancouver', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Clark', 'locality_code': '11', 'latitude': 45.6387, 'longitude': -122.6615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99328', 'place_name': 'Dayton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Columbia', 'locality_code': '13', 'latitude': 46.3075, 'longitude': -117.9738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99359', 'place_name': 'Starbuck', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Columbia', 'locality_code': '13', 'latitude': 46.5128, 'longitude': -118.1024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98581', 'place_name': 'Ryderwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.3752, 'longitude': -123.0431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98603', 'place_name': 'Ariel', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 45.9952, 'longitude': -122.4677, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98609', 'place_name': 'Carrolls', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.0715, 'longitude': -122.8648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98611', 'place_name': 'Castle Rock', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.2783, 'longitude': -122.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98616', 'place_name': 'Cougar', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.0515, 'longitude': -122.2995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98625', 'place_name': 'Kalama', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.0112, 'longitude': -122.8166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98626', 'place_name': 'Kelso', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.1485, 'longitude': -122.887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98632', 'place_name': 'Longview', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.1514, 'longitude': -122.9634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98645', 'place_name': 'Silverlake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.3163, 'longitude': -122.7649, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98649', 'place_name': 'Toutle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 46.2956, 'longitude': -122.6477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98674', 'place_name': 'Woodland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Cowlitz', 'locality_code': '15', 'latitude': 45.9219, 'longitude': -122.7126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98802', 'place_name': 'East Wenatchee', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Douglas', 'locality_code': '17', 'latitude': 47.4186, 'longitude': -120.2731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98813', 'place_name': 'Bridgeport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Douglas', 'locality_code': '17', 'latitude': 48.0082, 'longitude': -119.6712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98830', 'place_name': 'Mansfield', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Douglas', 'locality_code': '17', 'latitude': 47.9021, 'longitude': -119.4053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98843', 'place_name': 'Orondo', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Douglas', 'locality_code': '17', 'latitude': 47.6969, 'longitude': -120.1721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98845', 'place_name': 'Palisades', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Douglas', 'locality_code': '17', 'latitude': 47.419, 'longitude': -119.9145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98850', 'place_name': 'Rock Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Douglas', 'locality_code': '17', 'latitude': 47.3706, 'longitude': -120.1378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98858', 'place_name': 'Waterville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Douglas', 'locality_code': '17', 'latitude': 47.6295, 'longitude': -119.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99107', 'place_name': 'Boyds', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.8427, 'longitude': -118.1828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99118', 'place_name': 'Curlew', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.9108, 'longitude': -118.6452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99121', 'place_name': 'Danville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.9725, 'longitude': -118.4884, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99138', 'place_name': 'Inchelium', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.2924, 'longitude': -118.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99140', 'place_name': 'Keller', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.0236, 'longitude': -118.6547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99146', 'place_name': 'Laurier', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.9753, 'longitude': -118.2208, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99150', 'place_name': 'Malo', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.811, 'longitude': -118.6044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99160', 'place_name': 'Orient', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.866, 'longitude': -118.2028, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99166', 'place_name': 'Republic', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Ferry', 'locality_code': '19', 'latitude': 48.6704, 'longitude': -118.6999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99301', 'place_name': 'Pasco', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Franklin', 'locality_code': '21', 'latitude': 46.2492, 'longitude': -119.1044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99302', 'place_name': 'Pasco', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Franklin', 'locality_code': '21', 'latitude': 46.235, 'longitude': -119.0943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99326', 'place_name': 'Connell', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Franklin', 'locality_code': '21', 'latitude': 46.6643, 'longitude': -118.8545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99330', 'place_name': 'Eltopia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Franklin', 'locality_code': '21', 'latitude': 46.475, 'longitude': -119.1013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99335', 'place_name': 'Kahlotus', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Franklin', 'locality_code': '21', 'latitude': 46.6779, 'longitude': -118.5337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99343', 'place_name': 'Mesa', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Franklin', 'locality_code': '21', 'latitude': 46.5782, 'longitude': -119.1373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99347', 'place_name': 'Pomeroy', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Garfield', 'locality_code': '23', 'latitude': 46.4698, 'longitude': -117.5993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98823', 'place_name': 'Ephrata', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.2771, 'longitude': -119.5336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98824', 'place_name': 'George', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.0792, 'longitude': -119.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98832', 'place_name': 'Marlin', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.3014, 'longitude': -119.064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98837', 'place_name': 'Moses Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.1374, 'longitude': -119.2891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98848', 'place_name': 'Quincy', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.1976, 'longitude': -119.8459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98851', 'place_name': 'Soap Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.383, 'longitude': -119.486, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98853', 'place_name': 'Stratford', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.4268, 'longitude': -119.2816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98857', 'place_name': 'Warden', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 46.977, 'longitude': -119.0539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98860', 'place_name': 'Wilson Creek', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.4739, 'longitude': -119.1847, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99115', 'place_name': 'Coulee City', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.5966, 'longitude': -119.2758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99123', 'place_name': 'Electric City', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.9131, 'longitude': -119.0426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99133', 'place_name': 'Grand Coulee', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.9385, 'longitude': -118.9978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99135', 'place_name': 'Hartline', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 47.6115, 'longitude': -119.0841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99321', 'place_name': 'Beverly', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 46.8484, 'longitude': -119.9121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99349', 'place_name': 'Mattawa', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 46.731, 'longitude': -119.7783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99357', 'place_name': 'Royal City', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grant', 'locality_code': '25', 'latitude': 46.9156, 'longitude': -119.5815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98520', 'place_name': 'Aberdeen', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.9843, 'longitude': -123.7963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98526', 'place_name': 'Amanda Park', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.4859, 'longitude': -123.9206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98535', 'place_name': 'Copalis Beach', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.1126, 'longitude': -124.1738, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98536', 'place_name': 'Copalis Crossing', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.1591, 'longitude': -124.1352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98537', 'place_name': 'Cosmopolis', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.9538, 'longitude': -123.7739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98541', 'place_name': 'Elma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.0058, 'longitude': -123.3997, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98547', 'place_name': 'Grayland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.8264, 'longitude': -124.094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98550', 'place_name': 'Hoquiam', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.9823, 'longitude': -123.8842, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98552', 'place_name': 'Humptulips', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.3429, 'longitude': -123.9291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98557', 'place_name': 'Mccleary', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.0297, 'longitude': -123.273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98559', 'place_name': 'Malone', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.9589, 'longitude': -123.3268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98562', 'place_name': 'Moclips', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.2387, 'longitude': -124.2039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98563', 'place_name': 'Montesano', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.0901, 'longitude': -123.5006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98566', 'place_name': 'Neilton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.3877, 'longitude': -123.8903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98568', 'place_name': 'Oakville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.8434, 'longitude': -123.2493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98569', 'place_name': 'Ocean Shores', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.9737, 'longitude': -124.1563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98571', 'place_name': 'Pacific Beach', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.2195, 'longitude': -124.1915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98575', 'place_name': 'Quinault', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.4603, 'longitude': -123.8307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98583', 'place_name': 'Satsop', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.0022, 'longitude': -123.4836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98587', 'place_name': 'Taholah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 47.3407, 'longitude': -124.2827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98595', 'place_name': 'Westport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Grays Harbor', 'locality_code': '27', 'latitude': 46.8836, 'longitude': -124.1061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98236', 'place_name': 'Clinton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Island', 'locality_code': '29', 'latitude': 47.9508, 'longitude': -122.3916, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98239', 'place_name': 'Coupeville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Island', 'locality_code': '29', 'latitude': 48.2189, 'longitude': -122.6823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98249', 'place_name': 'Freeland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Island', 'locality_code': '29', 'latitude': 48.0342, 'longitude': -122.5641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98253', 'place_name': 'Greenbank', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Island', 'locality_code': '29', 'latitude': 48.1004, 'longitude': -122.5761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98260', 'place_name': 'Langley', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Island', 'locality_code': '29', 'latitude': 48.0187, 'longitude': -122.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98277', 'place_name': 'Oak Harbor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Island', 'locality_code': '29', 'latitude': 48.3151, 'longitude': -122.6374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98278', 'place_name': 'Oak Harbor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Island', 'locality_code': '29', 'latitude': 48.3402, 'longitude': -122.6695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98320', 'place_name': 'Brinnon', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 47.6776, 'longitude': -122.9375, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98325', 'place_name': 'Chimacum', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 47.9861, 'longitude': -122.7883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98339', 'place_name': 'Port Hadlock', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 48.0345, 'longitude': -122.7682, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98358', 'place_name': 'Nordland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 48.0432, 'longitude': -122.6926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98365', 'place_name': 'Port Ludlow', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 47.9222, 'longitude': -122.6896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98368', 'place_name': 'Port Townsend', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 48.104, 'longitude': -122.7945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98376', 'place_name': 'Quilcene', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Jefferson', 'locality_code': '31', 'latitude': 47.8324, 'longitude': -122.8583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98001', 'place_name': 'Auburn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3099, 'longitude': -122.2653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98002', 'place_name': 'Auburn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.305, 'longitude': -122.2067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98003', 'place_name': 'Federal Way', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3203, 'longitude': -122.3117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98004', 'place_name': 'Bellevue', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6155, 'longitude': -122.2072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98005', 'place_name': 'Bellevue', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.615, 'longitude': -122.1663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98006', 'place_name': 'Bellevue', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5614, 'longitude': -122.1552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98007', 'place_name': 'Bellevue', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6174, 'longitude': -122.1426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98008', 'place_name': 'Bellevue', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6115, 'longitude': -122.1162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98009', 'place_name': 'Bellevue', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6104, 'longitude': -122.2007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98010', 'place_name': 'Black Diamond', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3114, 'longitude': -122.0053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98011', 'place_name': 'Bothell', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7497, 'longitude': -122.2159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98013', 'place_name': 'Burton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.389, 'longitude': -122.4607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98014', 'place_name': 'Carnation', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.638, 'longitude': -121.9111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98015', 'place_name': 'Bellevue', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6104, 'longitude': -122.2007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98019', 'place_name': 'Duvall', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.725, 'longitude': -121.9369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98022', 'place_name': 'Enumclaw', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.2665, 'longitude': -122.0314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98023', 'place_name': 'Federal Way', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3104, 'longitude': -122.3612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98024', 'place_name': 'Fall City', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5682, 'longitude': -121.8896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98025', 'place_name': 'Hobart', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4218, 'longitude': -121.9729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98027', 'place_name': 'Issaquah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4974, 'longitude': -122.0107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98028', 'place_name': 'Kenmore', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7542, 'longitude': -122.2475, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98029', 'place_name': 'Issaquah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5585, 'longitude': -122.0055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98030', 'place_name': 'Kent', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3866, 'longitude': -122.2109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98031', 'place_name': 'Kent', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.388, 'longitude': -122.1932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98032', 'place_name': 'Kent', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3776, 'longitude': -122.2854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98033', 'place_name': 'Kirkland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6786, 'longitude': -122.1894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98034', 'place_name': 'Kirkland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7188, 'longitude': -122.1966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98035', 'place_name': 'Kent', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3809, 'longitude': -122.2348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98038', 'place_name': 'Maple Valley', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3845, 'longitude': -122.0574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98039', 'place_name': 'Medina', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6269, 'longitude': -122.2314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98040', 'place_name': 'Mercer Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5603, 'longitude': -122.2281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98041', 'place_name': 'Bothell', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7623, 'longitude': -122.2054, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98042', 'place_name': 'Kent', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.368, 'longitude': -122.1206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98045', 'place_name': 'North Bend', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4755, 'longitude': -121.7571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98047', 'place_name': 'Pacific', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.2666, 'longitude': -122.2435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98050', 'place_name': 'Preston', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.536, 'longitude': -121.9312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98051', 'place_name': 'Ravensdale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3407, 'longitude': -121.8874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98052', 'place_name': 'Redmond', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6718, 'longitude': -122.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98053', 'place_name': 'Redmond', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6462, 'longitude': -122.0386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98055', 'place_name': 'Renton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4648, 'longitude': -122.2075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98056', 'place_name': 'Renton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5073, 'longitude': -122.1819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98057', 'place_name': 'Renton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4714, 'longitude': -122.2203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98058', 'place_name': 'Renton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4465, 'longitude': -122.1216, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98059', 'place_name': 'Renton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5058, 'longitude': -122.1157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98062', 'place_name': 'Seahurst', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4693, 'longitude': -122.3621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98063', 'place_name': 'Federal Way', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3223, 'longitude': -122.3126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98064', 'place_name': 'Kent', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3809, 'longitude': -122.2348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98065', 'place_name': 'Snoqualmie', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5293, 'longitude': -121.8225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98068', 'place_name': 'Snoqualmie Pass', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4452, 'longitude': -121.431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98070', 'place_name': 'Vashon', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4259, 'longitude': -122.4644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98071', 'place_name': 'Auburn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3073, 'longitude': -122.2285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98072', 'place_name': 'Woodinville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7684, 'longitude': -122.1271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98073', 'place_name': 'Redmond', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.674, 'longitude': -122.1215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98074', 'place_name': 'Sammamish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6254, 'longitude': -122.0462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98075', 'place_name': 'Sammamish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5857, 'longitude': -122.0345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98083', 'place_name': 'Kirkland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6815, 'longitude': -122.2087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98089', 'place_name': 'Kent', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3871, 'longitude': -122.2023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98092', 'place_name': 'Auburn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.2884, 'longitude': -122.098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98093', 'place_name': 'Federal Way', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.311, 'longitude': -122.1138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98101', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6114, 'longitude': -122.3305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98102', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6302, 'longitude': -122.321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98103', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6733, 'longitude': -122.3426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98104', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6036, 'longitude': -122.3256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98105', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6633, 'longitude': -122.3022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98106', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5344, 'longitude': -122.3547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98107', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6701, 'longitude': -122.3763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98108', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5413, 'longitude': -122.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98109', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6339, 'longitude': -122.3476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98111', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98112', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6301, 'longitude': -122.2972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98113', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6716, 'longitude': -122.3411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98114', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98115', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6849, 'longitude': -122.2968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98116', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5746, 'longitude': -122.3934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98117', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6873, 'longitude': -122.3772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98118', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5412, 'longitude': -122.275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98119', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6379, 'longitude': -122.3643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98121', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6151, 'longitude': -122.3447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98122', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6116, 'longitude': -122.3056, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98124', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98125', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.717, 'longitude': -122.3015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98126', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5444, 'longitude': -122.3735, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98127', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6063, 'longitude': -122.3308, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98129', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98131', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98133', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7377, 'longitude': -122.3431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98134', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5903, 'longitude': -122.3263, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98136', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5398, 'longitude': -122.3878, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98138', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98139', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6473, 'longitude': -122.3999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98141', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6157, 'longitude': -122.3445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98144', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.5846, 'longitude': -122.3005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98145', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98146', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4995, 'longitude': -122.3603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98148', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4441, 'longitude': -122.3249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98154', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98155', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7559, 'longitude': -122.3003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98158', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4497, 'longitude': -122.3076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98160', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98161', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98164', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.606, 'longitude': -122.332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98165', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7161, 'longitude': -122.3004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98166', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4511, 'longitude': -122.353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98168', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4889, 'longitude': -122.3012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98170', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6096, 'longitude': -122.3317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98174', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98175', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7161, 'longitude': -122.3004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98177', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7467, 'longitude': -122.3686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98178', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4924, 'longitude': -122.2359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98181', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98185', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98188', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.4483, 'longitude': -122.2731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98190', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98191', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6062, 'longitude': -122.3321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98194', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6024, 'longitude': -122.326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98195', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6564, 'longitude': -122.3048, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98198', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.3929, 'longitude': -122.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98199', 'place_name': 'Seattle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6488, 'longitude': -122.3964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98224', 'place_name': 'Baring', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.7671, 'longitude': -121.4814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98288', 'place_name': 'Skykomish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'King', 'locality_code': '33', 'latitude': 47.6922, 'longitude': -121.3713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98061', 'place_name': 'Rollingbay', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.6808, 'longitude': -122.5762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98110', 'place_name': 'Bainbridge Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.6478, 'longitude': -122.538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98310', 'place_name': 'Bremerton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.6019, 'longitude': -122.6299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98311', 'place_name': 'Bremerton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.6271, 'longitude': -122.6373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98312', 'place_name': 'Bremerton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5754, 'longitude': -122.6958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98314', 'place_name': 'Bremerton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5593, 'longitude': -122.6492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98315', 'place_name': 'Silverdale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.692, 'longitude': -122.7161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98322', 'place_name': 'Burley', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.4179, 'longitude': -122.631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98337', 'place_name': 'Bremerton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5686, 'longitude': -122.6373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98340', 'place_name': 'Hansville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.9061, 'longitude': -122.5655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98342', 'place_name': 'Indianola', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.7514, 'longitude': -122.5196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98345', 'place_name': 'Keyport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.698, 'longitude': -122.6255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98346', 'place_name': 'Kingston', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.8108, 'longitude': -122.5255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98353', 'place_name': 'Manchester', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5952, 'longitude': -122.6225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98359', 'place_name': 'Olalla', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.4241, 'longitude': -122.5745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98364', 'place_name': 'Port Gamble', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.8543, 'longitude': -122.5838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98366', 'place_name': 'Port Orchard', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5427, 'longitude': -122.5871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98367', 'place_name': 'Port Orchard', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.4707, 'longitude': -122.651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98370', 'place_name': 'Poulsbo', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.7423, 'longitude': -122.6277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98378', 'place_name': 'Retsil', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5459, 'longitude': -122.6112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98380', 'place_name': 'Seabeck', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5913, 'longitude': -122.8686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98383', 'place_name': 'Silverdale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.6621, 'longitude': -122.6981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98384', 'place_name': 'South Colby', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5218, 'longitude': -122.5396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98386', 'place_name': 'Southworth', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.5104, 'longitude': -122.4991, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98392', 'place_name': 'Suquamish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.7343, 'longitude': -122.5573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98393', 'place_name': 'Tracyton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kitsap', 'locality_code': '35', 'latitude': 47.6267, 'longitude': -122.65, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98922', 'place_name': 'Cle Elum', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 47.2063, 'longitude': -120.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98925', 'place_name': 'Easton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 47.233, 'longitude': -121.1772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98926', 'place_name': 'Ellensburg', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 46.9996, 'longitude': -120.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98934', 'place_name': 'Kittitas', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 46.9806, 'longitude': -120.4163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98940', 'place_name': 'Ronald', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 47.2503, 'longitude': -121.0456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98941', 'place_name': 'Roslyn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 47.2233, 'longitude': -121.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98943', 'place_name': 'South Cle Elum', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 47.1886, 'longitude': -120.9537, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98946', 'place_name': 'Thorp', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 47.0679, 'longitude': -120.6712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98950', 'place_name': 'Vantage', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Kittitas', 'locality_code': '37', 'latitude': 46.8714, 'longitude': -119.9859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98602', 'place_name': 'Appleton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.8504, 'longitude': -121.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98605', 'place_name': 'Bingen', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.7751, 'longitude': -121.6328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98613', 'place_name': 'Centerville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.7032, 'longitude': -120.946, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98617', 'place_name': 'Dallesport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.6327, 'longitude': -121.1717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98619', 'place_name': 'Glenwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 46.0071, 'longitude': -121.2885, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98620', 'place_name': 'Goldendale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.832, 'longitude': -120.813, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98623', 'place_name': 'Husum', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.8076, 'longitude': -121.4877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98628', 'place_name': 'Klickitat', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.8171, 'longitude': -121.1526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98635', 'place_name': 'Lyle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.745, 'longitude': -121.2501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98650', 'place_name': 'Trout Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.9828, 'longitude': -121.5163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98670', 'place_name': 'Wahkiacus', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.859, 'longitude': -121.1409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98672', 'place_name': 'White Salmon', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.7551, 'longitude': -121.4795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98673', 'place_name': 'Wishram', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.6573, 'longitude': -120.9667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99322', 'place_name': 'Bickleton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.9597, 'longitude': -120.1042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99356', 'place_name': 'Roosevelt', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Klickitat', 'locality_code': '39', 'latitude': 45.8514, 'longitude': -120.3543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98336', 'place_name': 'Glenoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5283, 'longitude': -122.099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98355', 'place_name': 'Mineral', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.7096, 'longitude': -122.1861, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98356', 'place_name': 'Morton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5581, 'longitude': -122.2496, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98361', 'place_name': 'Packwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.65, 'longitude': -121.6553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98377', 'place_name': 'Randle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5492, 'longitude': -121.8555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98522', 'place_name': 'Adna', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.629, 'longitude': -123.0612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98531', 'place_name': 'Centralia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.7246, 'longitude': -122.9671, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98532', 'place_name': 'Chehalis', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.6382, 'longitude': -122.9658, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98533', 'place_name': 'Cinebar', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5793, 'longitude': -122.5687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98538', 'place_name': 'Curtis', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.4956, 'longitude': -123.1468, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98539', 'place_name': 'Doty', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.6378, 'longitude': -123.2804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98542', 'place_name': 'Ethel', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5321, 'longitude': -122.7404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98544', 'place_name': 'Galvin', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.7423, 'longitude': -123.0271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98564', 'place_name': 'Mossyrock', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5131, 'longitude': -122.4789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98565', 'place_name': 'Napavine', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5745, 'longitude': -122.9082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98570', 'place_name': 'Onalaska', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.573, 'longitude': -122.7075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98572', 'place_name': 'Pe Ell', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5829, 'longitude': -123.3147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98582', 'place_name': 'Salkum', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5321, 'longitude': -122.6259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98585', 'place_name': 'Silver Creek', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.5491, 'longitude': -122.4757, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98591', 'place_name': 'Toledo', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.4396, 'longitude': -122.8266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98593', 'place_name': 'Vader', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.3985, 'longitude': -122.9585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98596', 'place_name': 'Winlock', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lewis', 'locality_code': '41', 'latitude': 46.494, 'longitude': -122.9158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99008', 'place_name': 'Edwall', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.5379, 'longitude': -117.9071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99032', 'place_name': 'Sprague', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.3247, 'longitude': -117.9897, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99103', 'place_name': 'Almira', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.7632, 'longitude': -118.9123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99117', 'place_name': 'Creston', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.7977, 'longitude': -118.5307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99122', 'place_name': 'Davenport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.6809, 'longitude': -118.1667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99134', 'place_name': 'Harrington', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.4555, 'longitude': -118.2778, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99144', 'place_name': 'Lamona', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.3778, 'longitude': -118.5043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99147', 'place_name': 'Lincoln', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.8396, 'longitude': -118.4426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99154', 'place_name': 'Mohler', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.3897, 'longitude': -118.3659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99159', 'place_name': 'Odessa', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.3395, 'longitude': -118.6983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99185', 'place_name': 'Wilbur', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 47.741, 'longitude': -118.7063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98524', 'place_name': 'Allyn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.3571, 'longitude': -122.8587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98528', 'place_name': 'Belfair', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.4325, 'longitude': -122.9289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98546', 'place_name': 'Grapeview', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.3273, 'longitude': -122.9163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98548', 'place_name': 'Hoodsport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.4235, 'longitude': -123.1739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98555', 'place_name': 'Lilliwaup', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.5128, 'longitude': -123.0631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98560', 'place_name': 'Matlock', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.2636, 'longitude': -123.4412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98584', 'place_name': 'Shelton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.2151, 'longitude': -123.1007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98588', 'place_name': 'Tahuya', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.4446, 'longitude': -123.0232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98592', 'place_name': 'Union', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Mason', 'locality_code': '45', 'latitude': 47.3368, 'longitude': -123.075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98812', 'place_name': 'Brewster', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.1206, 'longitude': -119.772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98814', 'place_name': 'Carlton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.2526, 'longitude': -120.1055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98819', 'place_name': 'Conconully', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.5469, 'longitude': -119.7526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98827', 'place_name': 'Loomis', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.8696, 'longitude': -119.6427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98829', 'place_name': 'Malott', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.248, 'longitude': -119.7525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98833', 'place_name': 'Mazama', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.5977, 'longitude': -120.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98834', 'place_name': 'Methow', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.1171, 'longitude': -120.0891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98840', 'place_name': 'Okanogan', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.3513, 'longitude': -119.6046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98841', 'place_name': 'Omak', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.4143, 'longitude': -119.5272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98844', 'place_name': 'Oroville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.9397, 'longitude': -119.4032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98846', 'place_name': 'Pateros', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.034, 'longitude': -119.9785, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98849', 'place_name': 'Riverside', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.4876, 'longitude': -119.5803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98855', 'place_name': 'Tonasket', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.7194, 'longitude': -119.3943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98856', 'place_name': 'Twisp', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.3632, 'longitude': -120.135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98859', 'place_name': 'Wauconda', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.8224, 'longitude': -118.9469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98862', 'place_name': 'Winthrop', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.4756, 'longitude': -120.1805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99116', 'place_name': 'Coulee Dam', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.0379, 'longitude': -118.9419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99124', 'place_name': 'Elmer City', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 47.9979, 'longitude': -118.9545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99155', 'place_name': 'Nespelem', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Okanogan', 'locality_code': '47', 'latitude': 48.1434, 'longitude': -119.0094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98527', 'place_name': 'Bay Center', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.6315, 'longitude': -123.9549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98554', 'place_name': 'Lebam', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.5614, 'longitude': -123.5479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98561', 'place_name': 'Menlo', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.6215, 'longitude': -123.6471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98577', 'place_name': 'Raymond', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.671, 'longitude': -123.6929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98586', 'place_name': 'South Bend', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.6544, 'longitude': -123.8203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98590', 'place_name': 'Tokeland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.7065, 'longitude': -123.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98614', 'place_name': 'Chinook', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.2729, 'longitude': -123.9454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98624', 'place_name': 'Ilwaco', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.3142, 'longitude': -124.0282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98631', 'place_name': 'Long Beach', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.3774, 'longitude': -124.047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98637', 'place_name': 'Nahcotta', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.4984, 'longitude': -124.0335, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98638', 'place_name': 'Naselle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.3528, 'longitude': -123.8044, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98640', 'place_name': 'Ocean Park', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.5029, 'longitude': -124.0436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98641', 'place_name': 'Oysterville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.549, 'longitude': -124.0282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98644', 'place_name': 'Seaview', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pacific', 'locality_code': '49', 'latitude': 46.3308, 'longitude': -124.0455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99119', 'place_name': 'Cusick', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pend Oreille', 'locality_code': '51', 'latitude': 48.3915, 'longitude': -117.3295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99139', 'place_name': 'Ione', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pend Oreille', 'locality_code': '51', 'latitude': 48.741, 'longitude': -117.4172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99152', 'place_name': 'Metaline', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pend Oreille', 'locality_code': '51', 'latitude': 48.8496, 'longitude': -117.3963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99153', 'place_name': 'Metaline Falls', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pend Oreille', 'locality_code': '51', 'latitude': 48.8597, 'longitude': -117.3633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99156', 'place_name': 'Newport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pend Oreille', 'locality_code': '51', 'latitude': 48.1695, 'longitude': -117.1508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99180', 'place_name': 'Usk', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pend Oreille', 'locality_code': '51', 'latitude': 48.296, 'longitude': -117.3189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98303', 'place_name': 'Anderson Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1563, 'longitude': -122.7067, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98304', 'place_name': 'Ashford', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.7531, 'longitude': -121.9898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98321', 'place_name': 'Buckley', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1524, 'longitude': -122.0621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98323', 'place_name': 'Carbonado', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0802, 'longitude': -122.0513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98327', 'place_name': 'Dupont', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0968, 'longitude': -122.6312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98328', 'place_name': 'Eatonville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.8708, 'longitude': -122.2696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98329', 'place_name': 'Gig Harbor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.3786, 'longitude': -122.7, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98330', 'place_name': 'Elbe', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.7777, 'longitude': -122.2023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98332', 'place_name': 'Gig Harbor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.3607, 'longitude': -122.6001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98333', 'place_name': 'Fox Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.248, 'longitude': -122.629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98335', 'place_name': 'Gig Harbor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.3002, 'longitude': -122.6084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98338', 'place_name': 'Graham', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0246, 'longitude': -122.2936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98344', 'place_name': 'Kapowsin', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.9899, 'longitude': -122.2226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98348', 'place_name': 'La Grande', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.8343, 'longitude': -122.3187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98349', 'place_name': 'Lakebay', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2886, 'longitude': -122.7776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98351', 'place_name': 'Longbranch', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2007, 'longitude': -122.7561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98352', 'place_name': 'Sumner', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0662, 'longitude': -122.1132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98354', 'place_name': 'Milton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2483, 'longitude': -122.3155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98360', 'place_name': 'Orting', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0822, 'longitude': -122.186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98371', 'place_name': 'Puyallup', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1991, 'longitude': -122.3151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98372', 'place_name': 'Puyallup', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2042, 'longitude': -122.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98373', 'place_name': 'Puyallup', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1284, 'longitude': -122.3219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98374', 'place_name': 'Puyallup', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1424, 'longitude': -122.2652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98375', 'place_name': 'Puyallup', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1037, 'longitude': -122.3235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98385', 'place_name': 'South Prairie', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1383, 'longitude': -122.0968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98387', 'place_name': 'Spanaway', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0732, 'longitude': -122.3943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98388', 'place_name': 'Steilacoom', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1704, 'longitude': -122.5888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98390', 'place_name': 'Sumner', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2099, 'longitude': -122.228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98391', 'place_name': 'Bonney Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.143, 'longitude': -122.1644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98394', 'place_name': 'Vaughn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.3309, 'longitude': -122.7736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98395', 'place_name': 'Wauna', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.379, 'longitude': -122.6426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98396', 'place_name': 'Wilkeson', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1095, 'longitude': -122.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98397', 'place_name': 'Longmire', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.7498, 'longitude': -121.8126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98398', 'place_name': 'Paradise Inn', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0662, 'longitude': -122.1132, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98401', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2537, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98402', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2545, 'longitude': -122.4405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98403', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2643, 'longitude': -122.4575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98404', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2113, 'longitude': -122.4126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98405', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2484, 'longitude': -122.4643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98406', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2632, 'longitude': -122.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98407', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2825, 'longitude': -122.5039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98408', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2073, 'longitude': -122.4444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98409', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2038, 'longitude': -122.4825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98411', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98412', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98413', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98415', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98416', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2646, 'longitude': -122.4821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98417', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2061, 'longitude': -122.4822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98418', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2232, 'longitude': -122.4465, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98419', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2061, 'longitude': -122.4822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98421', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2664, 'longitude': -122.4015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98422', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2948, 'longitude': -122.3983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98424', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2325, 'longitude': -122.3594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98430', 'place_name': 'Camp Murray', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.0662, 'longitude': -122.1132, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98431', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98433', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1125, 'longitude': -122.5891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98438', 'place_name': 'Mcchord Afb', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2258, 'longitude': -122.469, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98439', 'place_name': 'Lakewood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1287, 'longitude': -122.5103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98443', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2044, 'longitude': -122.3728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98444', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1464, 'longitude': -122.4572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98445', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1291, 'longitude': -122.4094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98446', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1285, 'longitude': -122.3736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98447', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1441, 'longitude': -122.4434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98448', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2061, 'longitude': -122.4822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98464', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98465', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2491, 'longitude': -122.5273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98466', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.228, 'longitude': -122.5396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98467', 'place_name': 'University Place', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2033, 'longitude': -122.5688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98471', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98481', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98490', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2061, 'longitude': -122.4822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98493', 'place_name': 'Tacoma', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.2529, 'longitude': -122.4443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98496', 'place_name': 'Lakewood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1666, 'longitude': -122.5089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98497', 'place_name': 'Lakewood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1718, 'longitude': -122.5185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98498', 'place_name': 'Lakewood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1591, 'longitude': -122.5485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98499', 'place_name': 'Lakewood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 47.1677, 'longitude': -122.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98558', 'place_name': 'Mckenna', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.9348, 'longitude': -122.5565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98580', 'place_name': 'Roy', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Pierce', 'locality_code': '53', 'latitude': 46.956, 'longitude': -122.4483, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98222', 'place_name': 'Blakely Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.5618, 'longitude': -122.812, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98243', 'place_name': 'Deer Harbor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.6201, 'longitude': -122.9999, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98245', 'place_name': 'Eastsound', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.6968, 'longitude': -122.9055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98250', 'place_name': 'Friday Harbor', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.5454, 'longitude': -123.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98261', 'place_name': 'Lopez Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.4988, 'longitude': -122.8743, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98279', 'place_name': 'Olga', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.6195, 'longitude': -122.8355, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98280', 'place_name': 'Orcas', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.5979, 'longitude': -122.9446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98286', 'place_name': 'Shaw Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.5578, 'longitude': -122.9837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98297', 'place_name': 'Waldron', 'state': 'Washington', 'state_ab': 'WA', 'county': 'San Juan', 'locality_code': '55', 'latitude': 48.6876, 'longitude': -123.0369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98221', 'place_name': 'Anacortes', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.5004, 'longitude': -122.6309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98232', 'place_name': 'Bow', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.562, 'longitude': -122.4134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98233', 'place_name': 'Burlington', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.4786, 'longitude': -122.3345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98235', 'place_name': 'Clearlake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.4701, 'longitude': -122.2388, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98237', 'place_name': 'Concrete', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.531, 'longitude': -121.6643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98238', 'place_name': 'Conway', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.34, 'longitude': -122.3456, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98255', 'place_name': 'Hamilton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.5255, 'longitude': -121.9887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98257', 'place_name': 'La Conner', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.4093, 'longitude': -122.5313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98263', 'place_name': 'Lyman', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.5345, 'longitude': -122.0586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98267', 'place_name': 'Marblemount', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.4435, 'longitude': -121.3163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98273', 'place_name': 'Mount Vernon', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.4352, 'longitude': -122.2082, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98274', 'place_name': 'Mount Vernon', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.3643, 'longitude': -122.1403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98283', 'place_name': 'Rockport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.4704, 'longitude': -121.5554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98284', 'place_name': 'Sedro Woolley', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skagit', 'locality_code': '57', 'latitude': 48.5274, 'longitude': -122.2329, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98610', 'place_name': 'Carson', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skamania', 'locality_code': '59', 'latitude': 45.7493, 'longitude': -121.8351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98639', 'place_name': 'North Bonneville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skamania', 'locality_code': '59', 'latitude': 45.6373, 'longitude': -121.9712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98648', 'place_name': 'Stevenson', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skamania', 'locality_code': '59', 'latitude': 45.6882, 'longitude': -121.9093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98651', 'place_name': 'Underwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Skamania', 'locality_code': '59', 'latitude': 45.7409, 'longitude': -121.5974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98012', 'place_name': 'Bothell', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8401, 'longitude': -122.1972, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98020', 'place_name': 'Edmonds', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8061, 'longitude': -122.3724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98021', 'place_name': 'Bothell', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.7918, 'longitude': -122.2243, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98026', 'place_name': 'Edmonds', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8353, 'longitude': -122.327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98036', 'place_name': 'Lynnwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8049, 'longitude': -122.2855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98037', 'place_name': 'Lynnwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8392, 'longitude': -122.2855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98043', 'place_name': 'Mountlake Terrace', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.7933, 'longitude': -122.3076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98046', 'place_name': 'Lynnwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8209, 'longitude': -122.3151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98077', 'place_name': 'Woodinville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.7529, 'longitude': -122.0582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98082', 'place_name': 'Mill Creek', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8601, 'longitude': -122.2043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98087', 'place_name': 'Lynnwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.862, 'longitude': -122.2532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98201', 'place_name': 'Everett', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.9884, 'longitude': -122.2006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98203', 'place_name': 'Everett', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.9419, 'longitude': -122.2218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98204', 'place_name': 'Everett', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.9017, 'longitude': -122.2472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98206', 'place_name': 'Everett', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8599, 'longitude': -122.2848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98207', 'place_name': 'Everett', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.979, 'longitude': -122.2021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98208', 'place_name': 'Everett', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8948, 'longitude': -122.1987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98213', 'place_name': 'Everett', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.9451, 'longitude': -122.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98223', 'place_name': 'Arlington', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.1829, 'longitude': -122.1121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98241', 'place_name': 'Darrington', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.2395, 'longitude': -121.5892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98251', 'place_name': 'Gold Bar', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8331, 'longitude': -121.6365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98252', 'place_name': 'Granite Falls', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.079, 'longitude': -121.9428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98256', 'place_name': 'Index', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8118, 'longitude': -121.5497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98258', 'place_name': 'Lake Stevens', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.0171, 'longitude': -122.0672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98259', 'place_name': 'North Lakewood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.152, 'longitude': -122.2074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98270', 'place_name': 'Marysville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.0656, 'longitude': -122.1562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98271', 'place_name': 'Marysville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.0966, 'longitude': -122.198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98272', 'place_name': 'Monroe', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8585, 'longitude': -121.9474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98275', 'place_name': 'Mukilteo', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.9199, 'longitude': -122.3019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98282', 'place_name': 'Camano Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.1761, 'longitude': -122.521, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '98287', 'place_name': 'Silvana', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.2023, 'longitude': -122.2538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98290', 'place_name': 'Snohomish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8954, 'longitude': -122.0716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98291', 'place_name': 'Snohomish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.9095, 'longitude': -122.0501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98292', 'place_name': 'Stanwood', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 48.2011, 'longitude': -122.378, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98293', 'place_name': 'Startup', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8703, 'longitude': -121.7685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98294', 'place_name': 'Sultan', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8589, 'longitude': -121.7369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98296', 'place_name': 'Snohomish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Snohomish', 'locality_code': '61', 'latitude': 47.8579, 'longitude': -122.092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99001', 'place_name': 'Airway Heights', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6438, 'longitude': -117.5921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99003', 'place_name': 'Chattaroy', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.9192, 'longitude': -117.2921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99004', 'place_name': 'Cheney', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.4943, 'longitude': -117.5834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99005', 'place_name': 'Colbert', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.8411, 'longitude': -117.3759, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99006', 'place_name': 'Deer Park', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.9543, 'longitude': -117.4769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99009', 'place_name': 'Elk', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 48.0205, 'longitude': -117.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99011', 'place_name': 'Fairchild Air Force Base', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6332, 'longitude': -117.6546, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99012', 'place_name': 'Fairfield', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.3987, 'longitude': -117.1921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99014', 'place_name': 'Four Lakes', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.5599, 'longitude': -117.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99016', 'place_name': 'Greenacres', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6584, 'longitude': -117.1568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99018', 'place_name': 'Latah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.2999, 'longitude': -117.1395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99019', 'place_name': 'Liberty Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6517, 'longitude': -117.0838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99020', 'place_name': 'Marshall', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.5649, 'longitude': -117.4994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99021', 'place_name': 'Mead', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.7933, 'longitude': -117.3117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99022', 'place_name': 'Medical Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.615, 'longitude': -117.704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99023', 'place_name': 'Mica', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.5538, 'longitude': -117.1637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99025', 'place_name': 'Newman Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.7274, 'longitude': -117.064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99026', 'place_name': 'Nine Mile Falls', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.8019, 'longitude': -117.5894, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99027', 'place_name': 'Otis Orchards', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.7027, 'longitude': -117.1121, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99029', 'place_name': 'Reardan', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.7054, 'longitude': -117.8663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99030', 'place_name': 'Rockford', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.4528, 'longitude': -117.1318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99031', 'place_name': 'Spangle', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.4338, 'longitude': -117.3827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99036', 'place_name': 'Valleyford', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.5292, 'longitude': -117.2686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99037', 'place_name': 'Veradale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6421, 'longitude': -117.1977, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99039', 'place_name': 'Waverly', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.3427, 'longitude': -117.228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99201', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6665, 'longitude': -117.4365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99202', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6547, 'longitude': -117.381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99203', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6294, 'longitude': -117.4041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99204', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6501, 'longitude': -117.4298, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99205', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6964, 'longitude': -117.4399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99206', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6496, 'longitude': -117.2581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99207', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6977, 'longitude': -117.3746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99208', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.7374, 'longitude': -117.4352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99209', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6597, 'longitude': -117.4291, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99210', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99211', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99212', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6686, 'longitude': -117.3049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99213', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6567, 'longitude': -117.2825, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99214', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99215', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99216', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6634, 'longitude': -117.2193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99217', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.738, 'longitude': -117.2557, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99218', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.7556, 'longitude': -117.4146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99219', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99220', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99223', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6156, 'longitude': -117.3622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99224', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6289, 'longitude': -117.5513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99228', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99251', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99252', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99256', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99258', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99260', 'place_name': 'Spokane', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Spokane', 'locality_code': '63', 'latitude': 47.6536, 'longitude': -117.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99013', 'place_name': 'Ford', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 47.9169, 'longitude': -117.8119, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99034', 'place_name': 'Tumtum', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 47.8941, 'longitude': -117.7536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99040', 'place_name': 'Wellpinit', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 47.8697, 'longitude': -117.9856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99101', 'place_name': 'Addy', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.3364, 'longitude': -117.9579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99109', 'place_name': 'Chewelah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.2876, 'longitude': -117.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99110', 'place_name': 'Clayton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.0071, 'longitude': -117.5579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99114', 'place_name': 'Colville', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.578, 'longitude': -117.8645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99126', 'place_name': 'Evans', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.7458, 'longitude': -118.0001, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99129', 'place_name': 'Fruitland', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 47.9797, 'longitude': -118.2159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99131', 'place_name': 'Gifford', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.2685, 'longitude': -118.1136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99137', 'place_name': 'Hunters', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.1333, 'longitude': -118.1525, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99141', 'place_name': 'Kettle Falls', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.6364, 'longitude': -118.0548, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99148', 'place_name': 'Loon Lake', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.0784, 'longitude': -117.6325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99151', 'place_name': 'Marcus', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.6632, 'longitude': -118.0683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99157', 'place_name': 'Northport', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.9247, 'longitude': -117.7931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99167', 'place_name': 'Rice', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.4062, 'longitude': -118.1249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99173', 'place_name': 'Springdale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.0022, 'longitude': -117.829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99181', 'place_name': 'Valley', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Stevens', 'locality_code': '65', 'latitude': 48.1351, 'longitude': -117.761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98501', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.0129, 'longitude': -122.8763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98502', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.1043, 'longitude': -123.0552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98503', 'place_name': 'Lacey', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.024, 'longitude': -122.7827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98504', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.0379, 'longitude': -122.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98505', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.0654, 'longitude': -122.9762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98506', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.1042, 'longitude': -122.87, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98507', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.0379, 'longitude': -122.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98508', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.0379, 'longitude': -122.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98509', 'place_name': 'Lacey', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.9781, 'longitude': -122.7024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98511', 'place_name': 'Tumwater', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.9616, 'longitude': -123.0283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98512', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.9498, 'longitude': -123.0212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98513', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.9939, 'longitude': -122.743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98516', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.1126, 'longitude': -122.7794, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98530', 'place_name': 'Bucoda', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.7982, 'longitude': -122.8718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98540', 'place_name': 'East Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.9781, 'longitude': -122.7024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98556', 'place_name': 'Littlerock', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.9024, 'longitude': -123.017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98576', 'place_name': 'Rainier', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.8829, 'longitude': -122.6795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98579', 'place_name': 'Rochester', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.8193, 'longitude': -123.0406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98589', 'place_name': 'Tenino', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.8641, 'longitude': -122.8493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98597', 'place_name': 'Yelm', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 46.9206, 'longitude': -122.588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98599', 'place_name': 'Olympia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Thurston', 'locality_code': '67', 'latitude': 47.0379, 'longitude': -122.9007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98612', 'place_name': 'Cathlamet', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Wahkiakum', 'locality_code': '69', 'latitude': 46.1954, 'longitude': -123.3627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98621', 'place_name': 'Grays River', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Wahkiakum', 'locality_code': '69', 'latitude': 46.3535, 'longitude': -123.5888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98643', 'place_name': 'Rosburg', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Wahkiakum', 'locality_code': '69', 'latitude': 46.3071, 'longitude': -123.6571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98647', 'place_name': 'Skamokawa', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Wahkiakum', 'locality_code': '69', 'latitude': 46.2952, 'longitude': -123.4332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99323', 'place_name': 'Burbank', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.1966, 'longitude': -118.9017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99324', 'place_name': 'College Place', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.0471, 'longitude': -118.4093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99329', 'place_name': 'Dixie', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.1408, 'longitude': -118.1531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99348', 'place_name': 'Prescott', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.3539, 'longitude': -118.4097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99360', 'place_name': 'Touchet', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.0903, 'longitude': -118.663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99361', 'place_name': 'Waitsburg', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.2691, 'longitude': -118.1447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99362', 'place_name': 'Walla Walla', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.0614, 'longitude': -118.3315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99363', 'place_name': 'Wallula', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Walla Walla', 'locality_code': '71', 'latitude': 46.0846, 'longitude': -118.9061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98220', 'place_name': 'Acme', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.6752, 'longitude': -122.1914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98225', 'place_name': 'Bellingham', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.749, 'longitude': -122.4887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98226', 'place_name': 'Bellingham', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.7974, 'longitude': -122.4448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98227', 'place_name': 'Bellingham', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.7596, 'longitude': -122.4882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98228', 'place_name': 'Bellingham', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.7596, 'longitude': -122.4882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98229', 'place_name': 'Bellingham', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.6952, 'longitude': -122.4124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98230', 'place_name': 'Blaine', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9636, 'longitude': -122.7323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98231', 'place_name': 'Blaine', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9937, 'longitude': -122.7471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98240', 'place_name': 'Custer', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9374, 'longitude': -122.6226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98244', 'place_name': 'Deming', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.8018, 'longitude': -122.0918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98247', 'place_name': 'Everson', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9045, 'longitude': -122.3325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98248', 'place_name': 'Ferndale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.8625, 'longitude': -122.5953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98262', 'place_name': 'Lummi Island', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.7128, 'longitude': -122.6823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98264', 'place_name': 'Lynden', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9372, 'longitude': -122.4592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98266', 'place_name': 'Maple Falls', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9533, 'longitude': -122.1283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98276', 'place_name': 'Nooksack', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9276, 'longitude': -122.3215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98281', 'place_name': 'Point Roberts', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9879, 'longitude': -123.0555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98295', 'place_name': 'Sumas', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whatcom', 'locality_code': '73', 'latitude': 48.9708, 'longitude': -122.2074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99017', 'place_name': 'Lamont', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.1887, 'longitude': -117.8755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99033', 'place_name': 'Tekoa', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.2271, 'longitude': -117.0819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99102', 'place_name': 'Albion', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.792, 'longitude': -117.2503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99104', 'place_name': 'Belmont', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.0793, 'longitude': -117.177, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99111', 'place_name': 'Colfax', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.88, 'longitude': -117.367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99113', 'place_name': 'Colton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.5901, 'longitude': -117.1692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99125', 'place_name': 'Endicott', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.9364, 'longitude': -117.723, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99128', 'place_name': 'Farmington', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.0847, 'longitude': -117.0763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99130', 'place_name': 'Garfield', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.9946, 'longitude': -117.1523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99136', 'place_name': 'Hay', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.6973, 'longitude': -117.9417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99143', 'place_name': 'Lacrosse', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.7717, 'longitude': -117.7703, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '99149', 'place_name': 'Malden', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.2288, 'longitude': -117.4727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99158', 'place_name': 'Oakesdale', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.1282, 'longitude': -117.2427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99161', 'place_name': 'Palouse', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.9076, 'longitude': -117.0855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99163', 'place_name': 'Pullman', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.7352, 'longitude': -117.1729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99164', 'place_name': 'Pullman', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.7313, 'longitude': -117.1796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99170', 'place_name': 'Rosalia', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.2218, 'longitude': -117.4147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99171', 'place_name': 'Saint John', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.0755, 'longitude': -117.573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99174', 'place_name': 'Steptoe', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.006, 'longitude': -117.356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99176', 'place_name': 'Thornton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 47.1253, 'longitude': -117.3864, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99179', 'place_name': 'Uniontown', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.5258, 'longitude': -117.0908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '99333', 'place_name': 'Hooper', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Whitman', 'locality_code': '75', 'latitude': 46.7543, 'longitude': -118.148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98901', 'place_name': 'Yakima', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.6021, 'longitude': -120.5059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98902', 'place_name': 'Yakima', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.5934, 'longitude': -120.5311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98903', 'place_name': 'Yakima', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.5445, 'longitude': -120.7444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98904', 'place_name': 'Yakima', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.5645, 'longitude': -120.6947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98907', 'place_name': 'Yakima', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.6288, 'longitude': -120.574, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98908', 'place_name': 'Yakima', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.6165, 'longitude': -120.7094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98909', 'place_name': 'Yakima', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.6021, 'longitude': -120.5059, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98920', 'place_name': 'Brownstown', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.4043, 'longitude': -120.607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98921', 'place_name': 'Buena', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.4287, 'longitude': -120.3134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98923', 'place_name': 'Cowiche', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.6661, 'longitude': -120.7149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98930', 'place_name': 'Grandview', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.2538, 'longitude': -119.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98932', 'place_name': 'Granger', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.348, 'longitude': -120.1818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98933', 'place_name': 'Harrah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.4104, 'longitude': -120.5736, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98935', 'place_name': 'Mabton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.2121, 'longitude': -120.0151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98936', 'place_name': 'Moxee', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.5542, 'longitude': -120.3685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98937', 'place_name': 'Naches', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.8058, 'longitude': -120.9921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98938', 'place_name': 'Outlook', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.3525, 'longitude': -120.097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98939', 'place_name': 'Parker', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.501, 'longitude': -120.4653, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98942', 'place_name': 'Selah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.6767, 'longitude': -120.5408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98944', 'place_name': 'Sunnyside', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.3213, 'longitude': -120.0126, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98947', 'place_name': 'Tieton', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.7063, 'longitude': -120.7473, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98948', 'place_name': 'Toppenish', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.3751, 'longitude': -120.3305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98951', 'place_name': 'Wapato', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.4507, 'longitude': -120.4265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98952', 'place_name': 'White Swan', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.3716, 'longitude': -120.7453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '98953', 'place_name': 'Zillah', 'state': 'Washington', 'state_ab': 'WA', 'county': 'Yakima', 'locality_code': '77', 'latitude': 46.4158, 'longitude': -120.2662, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53910', 'place_name': 'Adams', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Adams', 'locality_code': '1', 'latitude': 43.8967, 'longitude': -89.8219, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53927', 'place_name': 'Dellwood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Adams', 'locality_code': '1', 'latitude': 43.9555, 'longitude': -89.9418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53934', 'place_name': 'Friendship', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Adams', 'locality_code': '1', 'latitude': 43.9896, 'longitude': -89.8149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53936', 'place_name': 'Grand Marsh', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Adams', 'locality_code': '1', 'latitude': 43.8869, 'longitude': -89.7062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54613', 'place_name': 'Arkdale', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Adams', 'locality_code': '1', 'latitude': 44.0529, 'longitude': -89.8962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54514', 'place_name': 'Butternut', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.0184, 'longitude': -90.4821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54517', 'place_name': 'Clam Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.1638, 'longitude': -90.9024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54527', 'place_name': 'Glidden', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.1337, 'longitude': -90.5889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54546', 'place_name': 'Mellen', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.3007, 'longitude': -90.6552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54806', 'place_name': 'Ashland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.5586, 'longitude': -90.7388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54846', 'place_name': 'High Bridge', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.3796, 'longitude': -90.7383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54850', 'place_name': 'La Pointe', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.8467, 'longitude': -90.6036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54855', 'place_name': 'Marengo', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.4071, 'longitude': -90.84, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54861', 'place_name': 'Odanah', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ashland', 'locality_code': '3', 'latitude': 46.5608, 'longitude': -90.6197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54728', 'place_name': 'Chetek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.317, 'longitude': -91.6542, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54733', 'place_name': 'Dallas', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.2549, 'longitude': -91.8368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54762', 'place_name': 'Prairie Farm', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.2462, 'longitude': -91.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54805', 'place_name': 'Almena', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.4195, 'longitude': -92.0027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54812', 'place_name': 'Barron', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.4005, 'longitude': -91.85, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54813', 'place_name': 'Barronett', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.619, 'longitude': -92.0196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54818', 'place_name': 'Brill', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.6027, 'longitude': -91.6721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54822', 'place_name': 'Cameron', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.4038, 'longitude': -91.731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54826', 'place_name': 'Comstock', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.4911, 'longitude': -92.086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54829', 'place_name': 'Cumberland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.5403, 'longitude': -92.0297, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54841', 'place_name': 'Haugen', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.6067, 'longitude': -91.7786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54857', 'place_name': 'Mikana', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.5919, 'longitude': -91.6013, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54868', 'place_name': 'Rice Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.5061, 'longitude': -91.7382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54889', 'place_name': 'Turtle Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Barron', 'locality_code': '5', 'latitude': 45.4213, 'longitude': -92.1781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54814', 'place_name': 'Bayfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.8354, 'longitude': -90.8217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54816', 'place_name': 'Benoit', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.5019, 'longitude': -91.0769, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54821', 'place_name': 'Cable', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.2172, 'longitude': -91.2244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54827', 'place_name': 'Cornucopia', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.8372, 'longitude': -91.0974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54832', 'place_name': 'Drummond', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.3119, 'longitude': -91.2856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54839', 'place_name': 'Grand View', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.3577, 'longitude': -91.1075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54844', 'place_name': 'Herbster', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.8213, 'longitude': -91.2332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54847', 'place_name': 'Iron River', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.579, 'longitude': -91.4211, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54856', 'place_name': 'Mason', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.4399, 'longitude': -91.1318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54865', 'place_name': 'Port Wing', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.762, 'longitude': -91.392, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54891', 'place_name': 'Washburn', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Bayfield', 'locality_code': '7', 'latitude': 46.6806, 'longitude': -90.9095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54115', 'place_name': 'De Pere', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.4388, 'longitude': -88.0806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54126', 'place_name': 'Greenleaf', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.2937, 'longitude': -88.0275, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54162', 'place_name': 'Pulaski', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.6611, 'longitude': -88.2634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54173', 'place_name': 'Suamico', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.6435, 'longitude': -88.0317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54180', 'place_name': 'Wrightstown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.3264, 'longitude': -88.1749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54208', 'place_name': 'Denmark', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.3594, 'longitude': -87.827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54229', 'place_name': 'New Franken', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.5592, 'longitude': -87.8235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54301', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.482, 'longitude': -88.0205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54302', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.5025, 'longitude': -87.9771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54303', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.5522, 'longitude': -88.0788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54304', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.4975, 'longitude': -88.0324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54305', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.4601, 'longitude': -88.0074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54306', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.5192, 'longitude': -88.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54307', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.4601, 'longitude': -88.0074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54308', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.5192, 'longitude': -88.0198, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54311', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.4914, 'longitude': -87.9267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54313', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.5463, 'longitude': -88.1021, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54324', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.4601, 'longitude': -88.0074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54344', 'place_name': 'Green Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Brown', 'locality_code': '9', 'latitude': 44.425, 'longitude': -88.1113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54610', 'place_name': 'Alma', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Buffalo', 'locality_code': '11', 'latitude': 44.4294, 'longitude': -91.8079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54622', 'place_name': 'Cochrane', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Buffalo', 'locality_code': '11', 'latitude': 44.2672, 'longitude': -91.7715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54629', 'place_name': 'Fountain City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Buffalo', 'locality_code': '11', 'latitude': 44.1364, 'longitude': -91.6779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54743', 'place_name': 'Gilmanton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Buffalo', 'locality_code': '11', 'latitude': 44.4708, 'longitude': -91.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54755', 'place_name': 'Mondovi', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Buffalo', 'locality_code': '11', 'latitude': 44.4877, 'longitude': -91.6807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54756', 'place_name': 'Nelson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Buffalo', 'locality_code': '11', 'latitude': 44.4295, 'longitude': -92.0007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54830', 'place_name': 'Danbury', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Burnett', 'locality_code': '13', 'latitude': 45.9726, 'longitude': -92.293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54840', 'place_name': 'Grantsburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Burnett', 'locality_code': '13', 'latitude': 45.7953, 'longitude': -92.6935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54845', 'place_name': 'Hertel', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Burnett', 'locality_code': '13', 'latitude': 45.8076, 'longitude': -92.1404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54872', 'place_name': 'Siren', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Burnett', 'locality_code': '13', 'latitude': 45.7821, 'longitude': -92.3892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54893', 'place_name': 'Webster', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Burnett', 'locality_code': '13', 'latitude': 45.874, 'longitude': -92.3227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53014', 'place_name': 'Chilton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.0242, 'longitude': -88.1827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53061', 'place_name': 'New Holstein', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 43.9446, 'longitude': -88.0911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53062', 'place_name': 'New Holstein', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.0679, 'longitude': -88.2231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53088', 'place_name': 'Stockbridge', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.0717, 'longitude': -88.299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54110', 'place_name': 'Brillion', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.1779, 'longitude': -88.0833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54123', 'place_name': 'Forest Junction', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.2125, 'longitude': -88.1443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54129', 'place_name': 'Hilbert', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.1271, 'longitude': -88.207, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54160', 'place_name': 'Potter', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.1199, 'longitude': -88.0965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54169', 'place_name': 'Sherwood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Calumet', 'locality_code': '15', 'latitude': 44.1764, 'longitude': -88.2779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54724', 'place_name': 'Bloomer', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 45.1025, 'longitude': -91.49, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54726', 'place_name': 'Boyd', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 44.9437, 'longitude': -91.0294, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54727', 'place_name': 'Cadott', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 44.963, 'longitude': -91.1699, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54729', 'place_name': 'Chippewa Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 44.9369, 'longitude': -91.3929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54732', 'place_name': 'Cornell', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 45.1619, 'longitude': -91.1733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54745', 'place_name': 'Holcombe', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 45.2513, 'longitude': -91.133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54748', 'place_name': 'Jim Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 45.0889, 'longitude': -91.2568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54757', 'place_name': 'New Auburn', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 45.2356, 'longitude': -91.5197, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54768', 'place_name': 'Stanley', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 44.9689, 'longitude': -90.9389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54774', 'place_name': 'Chippewa Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Chippewa', 'locality_code': '17', 'latitude': 44.9369, 'longitude': -91.3929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54405', 'place_name': 'Abbotsford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.9641, 'longitude': -90.2994, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54420', 'place_name': 'Chili', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.6301, 'longitude': -90.36, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54421', 'place_name': 'Colby', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.9117, 'longitude': -90.3144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54422', 'place_name': 'Curtiss', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.9602, 'longitude': -90.4592, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54425', 'place_name': 'Dorchester', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 45.0042, 'longitude': -90.3596, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54436', 'place_name': 'Granton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.5606, 'longitude': -90.4484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54437', 'place_name': 'Greenwood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.7404, 'longitude': -90.6229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54446', 'place_name': 'Loyal', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.7272, 'longitude': -90.4922, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54456', 'place_name': 'Neillsville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.5494, 'longitude': -90.6112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54460', 'place_name': 'Owen', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.9578, 'longitude': -90.5469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54493', 'place_name': 'Willard', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.7274, 'longitude': -90.7499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54498', 'place_name': 'Withee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.9757, 'longitude': -90.6049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54746', 'place_name': 'Humbird', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.5367, 'longitude': -90.8883, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54771', 'place_name': 'Thorp', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Clark', 'locality_code': '19', 'latitude': 44.9573, 'longitude': -90.8029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53555', 'place_name': 'Lodi', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.327, 'longitude': -89.5554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53901', 'place_name': 'Portage', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.5501, 'longitude': -89.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53911', 'place_name': 'Arlington', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.3269, 'longitude': -89.3631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53923', 'place_name': 'Cambria', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.5724, 'longitude': -89.1156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53925', 'place_name': 'Columbus', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.3315, 'longitude': -89.0271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53928', 'place_name': 'Doylestown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.4266, 'longitude': -89.1491, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53932', 'place_name': 'Fall River', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.4008, 'longitude': -89.0625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53935', 'place_name': 'Friesland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.5901, 'longitude': -89.0593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53954', 'place_name': 'Pardeeville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.534, 'longitude': -89.3265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53955', 'place_name': 'Poynette', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.4013, 'longitude': -89.4189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53957', 'place_name': 'Randolph', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.5352, 'longitude': -89.0068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53960', 'place_name': 'Rio', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.4231, 'longitude': -89.2354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53965', 'place_name': 'Wisconsin Dells', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.6508, 'longitude': -89.7665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53969', 'place_name': 'Wyocena', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Columbia', 'locality_code': '21', 'latitude': 43.4989, 'longitude': -89.305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53821', 'place_name': 'Prairie Du Chien', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.0426, 'longitude': -91.1193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53826', 'place_name': 'Wauzeka', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.1143, 'longitude': -90.9239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54626', 'place_name': 'Eastman', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.1959, 'longitude': -91.0193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54628', 'place_name': 'Ferryville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.3959, 'longitude': -91.0446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54631', 'place_name': 'Gays Mills', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.2936, 'longitude': -90.8676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54640', 'place_name': 'Lynxville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.2464, 'longitude': -91.0562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54645', 'place_name': 'Mount Sterling', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.3153, 'longitude': -90.9287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54654', 'place_name': 'Seneca', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.265, 'longitude': -90.9585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54655', 'place_name': 'Soldiers Grove', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.3919, 'longitude': -90.7663, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54657', 'place_name': 'Steuben', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Crawford', 'locality_code': '23', 'latitude': 43.1955, 'longitude': -90.8609, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53508', 'place_name': 'Belleville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 42.8669, 'longitude': -89.5377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53515', 'place_name': 'Black Earth', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1322, 'longitude': -89.739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53517', 'place_name': 'Blue Mounds', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.005, 'longitude': -89.8345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53523', 'place_name': 'Cambridge', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 42.9918, 'longitude': -89.0209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53527', 'place_name': 'Cottage Grove', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0784, 'longitude': -89.2017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53528', 'place_name': 'Cross Plains', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1132, 'longitude': -89.6397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53529', 'place_name': 'Dane', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.2424, 'longitude': -89.5117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53531', 'place_name': 'Deerfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0571, 'longitude': -89.0862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53532', 'place_name': 'Deforest', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.2478, 'longitude': -89.3437, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '53558', 'place_name': 'Mc Farland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0107, 'longitude': -89.2948, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '53559', 'place_name': 'Marshall', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1636, 'longitude': -89.0753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53560', 'place_name': 'Mazomanie', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1847, 'longitude': -89.7636, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53562', 'place_name': 'Middleton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1052, 'longitude': -89.5073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53571', 'place_name': 'Morrisonville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.2773, 'longitude': -89.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53572', 'place_name': 'Mount Horeb', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.002, 'longitude': -89.7414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53575', 'place_name': 'Oregon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 42.9295, 'longitude': -89.387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53589', 'place_name': 'Stoughton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 42.929, 'longitude': -89.224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53590', 'place_name': 'Sun Prairie', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1869, 'longitude': -89.2227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53593', 'place_name': 'Verona', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 42.9999, 'longitude': -89.5522, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53596', 'place_name': 'Sun Prairie', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1924, 'longitude': -89.2629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53597', 'place_name': 'Waunakee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1818, 'longitude': -89.4532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53598', 'place_name': 'Windsor', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.2078, 'longitude': -89.3418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53701', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53702', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53703', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0775, 'longitude': -89.3831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53704', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1205, 'longitude': -89.3523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53705', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.073, 'longitude': -89.4528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53706', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0769, 'longitude': -89.4094, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53707', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53708', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53711', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0356, 'longitude': -89.4526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53713', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0372, 'longitude': -89.3971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53714', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0977, 'longitude': -89.3118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53715', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0653, 'longitude': -89.4, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53716', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0631, 'longitude': -89.3133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53717', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0736, 'longitude': -89.508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53718', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0984, 'longitude': -89.2734, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53719', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0321, 'longitude': -89.4993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53725', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53726', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53744', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53774', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0469, 'longitude': -89.374, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53777', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53778', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53779', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0982, 'longitude': -89.3242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53782', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53783', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.1596, 'longitude': -89.2852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53784', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0489, 'longitude': -89.3384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53785', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53786', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53788', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0767, 'longitude': -89.3763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53789', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53790', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53791', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53792', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53793', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53794', 'place_name': 'Madison', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dane', 'locality_code': '25', 'latitude': 43.0696, 'longitude': -89.4239, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53003', 'place_name': 'Ashippun', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.2119, 'longitude': -88.5162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53006', 'place_name': 'Brownsville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.6028, 'longitude': -88.523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53016', 'place_name': 'Clyman', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.3107, 'longitude': -88.7144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53032', 'place_name': 'Horicon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.4469, 'longitude': -88.631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53034', 'place_name': 'Hustisford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.3305, 'longitude': -88.603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53035', 'place_name': 'Iron Ridge', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.3934, 'longitude': -88.5441, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53039', 'place_name': 'Juneau', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.3792, 'longitude': -88.6845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53047', 'place_name': 'Lebanon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.2568, 'longitude': -88.6281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53048', 'place_name': 'Lomira', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.5795, 'longitude': -88.4513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53050', 'place_name': 'Mayville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.5045, 'longitude': -88.5451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53059', 'place_name': 'Neosho', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.2978, 'longitude': -88.5205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53078', 'place_name': 'Rubicon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.3121, 'longitude': -88.4528, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53091', 'place_name': 'Theresa', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.5045, 'longitude': -88.4478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53098', 'place_name': 'Watertown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.2764, 'longitude': -88.7154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53099', 'place_name': 'Woodland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.3703, 'longitude': -88.5187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53557', 'place_name': 'Lowell', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.342, 'longitude': -88.7873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53579', 'place_name': 'Reeseville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.3013, 'longitude': -88.8571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53916', 'place_name': 'Beaver Dam', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.4616, 'longitude': -88.8407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53922', 'place_name': 'Burnett', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.5116, 'longitude': -88.7176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53933', 'place_name': 'Fox Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.5815, 'longitude': -88.9041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53956', 'place_name': 'Randolph', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.5397, 'longitude': -89.003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53963', 'place_name': 'Waupun', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dodge', 'locality_code': '27', 'latitude': 43.6324, 'longitude': -88.7373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54202', 'place_name': 'Baileys Harbor', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 45.0565, 'longitude': -87.1676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54204', 'place_name': 'Brussels', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 44.7476, 'longitude': -87.6225, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54209', 'place_name': 'Egg Harbor', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 45.01, 'longitude': -87.2805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54210', 'place_name': 'Ellison Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 45.2572, 'longitude': -87.0512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54211', 'place_name': 'Ephraim', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 45.1592, 'longitude': -87.171, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54212', 'place_name': 'Fish Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 45.1155, 'longitude': -87.2064, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54213', 'place_name': 'Forestville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 44.6996, 'longitude': -87.5215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54226', 'place_name': 'Maplewood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 44.7475, 'longitude': -87.4793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54234', 'place_name': 'Sister Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 45.1875, 'longitude': -87.1139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54235', 'place_name': 'Sturgeon Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 44.8438, 'longitude': -87.3753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54246', 'place_name': 'Washington Island', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Door', 'locality_code': '29', 'latitude': 45.3738, 'longitude': -86.8975, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '54820', 'place_name': 'Brule', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.5763, 'longitude': -91.5539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54836', 'place_name': 'Foxboro', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.4875, 'longitude': -92.1493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54838', 'place_name': 'Gordon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.2336, 'longitude': -91.8033, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54842', 'place_name': 'Hawthorne', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.503, 'longitude': -91.8607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54849', 'place_name': 'Lake Nebagamon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.5023, 'longitude': -91.7402, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54854', 'place_name': 'Maple', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.6206, 'longitude': -91.702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54864', 'place_name': 'Poplar', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.5771, 'longitude': -91.8253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54873', 'place_name': 'Solon Springs', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.4173, 'longitude': -91.811, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54874', 'place_name': 'South Range', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.5688, 'longitude': -91.9352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54880', 'place_name': 'Superior', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.7016, 'longitude': -92.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54890', 'place_name': 'Wascott', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Douglas', 'locality_code': '31', 'latitude': 46.1724, 'longitude': -91.7982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54725', 'place_name': 'Boyceville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 45.0642, 'longitude': -92.0248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54730', 'place_name': 'Colfax', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 44.9993, 'longitude': -91.7357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54734', 'place_name': 'Downing', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 45.103, 'longitude': -92.1134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54735', 'place_name': 'Downsville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 44.7747, 'longitude': -91.9321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54737', 'place_name': 'Eau Galle', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 44.7152, 'longitude': -91.9822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54739', 'place_name': 'Elk Mound', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 44.867, 'longitude': -91.6752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54749', 'place_name': 'Knapp', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 44.9545, 'longitude': -92.0752, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54751', 'place_name': 'Menomonie', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 44.8718, 'longitude': -91.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54763', 'place_name': 'Ridgeland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 45.1868, 'longitude': -91.879, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54764', 'place_name': 'Rock Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 44.7186, 'longitude': -91.6899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54765', 'place_name': 'Sand Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 45.1669, 'longitude': -91.6863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54772', 'place_name': 'Wheeler', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Dunn', 'locality_code': '33', 'latitude': 45.0719, 'longitude': -91.8871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54701', 'place_name': 'Eau Claire', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Eau Claire', 'locality_code': '35', 'latitude': 44.784, 'longitude': -91.4877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54702', 'place_name': 'Eau Claire', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Eau Claire', 'locality_code': '35', 'latitude': 44.8113, 'longitude': -91.4985, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54703', 'place_name': 'Eau Claire', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Eau Claire', 'locality_code': '35', 'latitude': 44.8346, 'longitude': -91.5159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54720', 'place_name': 'Altoona', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Eau Claire', 'locality_code': '35', 'latitude': 44.8021, 'longitude': -91.4382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54722', 'place_name': 'Augusta', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Eau Claire', 'locality_code': '35', 'latitude': 44.6947, 'longitude': -91.1232, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54741', 'place_name': 'Fairchild', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Eau Claire', 'locality_code': '35', 'latitude': 44.5963, 'longitude': -90.9906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54742', 'place_name': 'Fall Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Eau Claire', 'locality_code': '35', 'latitude': 44.7684, 'longitude': -91.2856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54120', 'place_name': 'Fence', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Florence', 'locality_code': '37', 'latitude': 45.7444, 'longitude': -88.4243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54121', 'place_name': 'Florence', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Florence', 'locality_code': '37', 'latitude': 45.9027, 'longitude': -88.2289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54542', 'place_name': 'Long Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Florence', 'locality_code': '37', 'latitude': 45.9138, 'longitude': -88.6235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53010', 'place_name': 'Campbellsport', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.6042, 'longitude': -88.2729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53019', 'place_name': 'Eden', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.6959, 'longitude': -88.3266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53049', 'place_name': 'Malone', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.8753, 'longitude': -88.2871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53057', 'place_name': 'Mount Calvary', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.8142, 'longitude': -88.2399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53065', 'place_name': 'Oakfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.6864, 'longitude': -88.5569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53079', 'place_name': 'Saint Cloud', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.8074, 'longitude': -88.1845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53919', 'place_name': 'Brandon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.7258, 'longitude': -88.7841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53931', 'place_name': 'Fairwater', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.7475, 'longitude': -88.8665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54932', 'place_name': 'Eldorado', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.8415, 'longitude': -88.6388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54935', 'place_name': 'Fond Du Lac', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.7742, 'longitude': -88.4352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54936', 'place_name': 'Fond Du Lac', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.775, 'longitude': -88.4388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54937', 'place_name': 'Fond Du Lac', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.765, 'longitude': -88.6057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54971', 'place_name': 'Ripon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.8454, 'longitude': -88.8424, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54974', 'place_name': 'Rosendale', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.7889, 'longitude': -88.6417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54979', 'place_name': 'Van Dyne', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Fond du Lac', 'locality_code': '39', 'latitude': 43.8734, 'longitude': -88.51, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54103', 'place_name': 'Armstrong Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Forest', 'locality_code': '41', 'latitude': 45.6726, 'longitude': -88.4908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54511', 'place_name': 'Argonne', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Forest', 'locality_code': '41', 'latitude': 45.7118, 'longitude': -88.8104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54520', 'place_name': 'Crandon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Forest', 'locality_code': '41', 'latitude': 45.5416, 'longitude': -88.9116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54541', 'place_name': 'Laona', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Forest', 'locality_code': '41', 'latitude': 45.5534, 'longitude': -88.6715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54566', 'place_name': 'Wabeno', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Forest', 'locality_code': '41', 'latitude': 45.4332, 'longitude': -88.6625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53518', 'place_name': 'Blue River', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 43.2366, 'longitude': -90.5873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53554', 'place_name': 'Livingston', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.9044, 'longitude': -90.442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53569', 'place_name': 'Montfort', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.9757, 'longitude': -90.4447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53573', 'place_name': 'Muscoda', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 43.2074, 'longitude': -90.457, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53801', 'place_name': 'Bagley', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.9207, 'longitude': -91.0685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53802', 'place_name': 'Beetown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.795, 'longitude': -90.8854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53804', 'place_name': 'Bloomington', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.8726, 'longitude': -90.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53805', 'place_name': 'Boscobel', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 43.1393, 'longitude': -90.7061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53806', 'place_name': 'Cassville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.7288, 'longitude': -90.9608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53807', 'place_name': 'Cuba City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.5991, 'longitude': -90.4749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53808', 'place_name': 'Dickeyville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.6263, 'longitude': -90.5931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53809', 'place_name': 'Fennimore', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.9886, 'longitude': -90.655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53810', 'place_name': 'Glen Haven', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.8204, 'longitude': -91.0005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53811', 'place_name': 'Hazel Green', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.5359, 'longitude': -90.5118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53812', 'place_name': 'Kieler', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.5814, 'longitude': -90.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53813', 'place_name': 'Lancaster', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.8445, 'longitude': -90.7109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53816', 'place_name': 'Mount Hope', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.9689, 'longitude': -90.8665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53817', 'place_name': 'Patch Grove', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.9422, 'longitude': -90.9646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53818', 'place_name': 'Platteville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.7393, 'longitude': -90.4854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53820', 'place_name': 'Potosi', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.6884, 'longitude': -90.7002, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53824', 'place_name': 'Sinsinawa', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.5236, 'longitude': -90.5393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53825', 'place_name': 'Stitzer', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 42.9214, 'longitude': -90.6079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53827', 'place_name': 'Woodman', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Grant', 'locality_code': '43', 'latitude': 43.0577, 'longitude': -90.8245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53502', 'place_name': 'Albany', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.7155, 'longitude': -89.4357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53520', 'place_name': 'Brodhead', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.6111, 'longitude': -89.3714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53521', 'place_name': 'Brooklyn', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.8423, 'longitude': -89.3818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53522', 'place_name': 'Browntown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.5579, 'longitude': -89.7816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53550', 'place_name': 'Juda', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.5679, 'longitude': -89.5026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53566', 'place_name': 'Monroe', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.5991, 'longitude': -89.6403, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53570', 'place_name': 'Monticello', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.7415, 'longitude': -89.6081, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53574', 'place_name': 'New Glarus', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green', 'locality_code': '45', 'latitude': 42.8143, 'longitude': -89.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53926', 'place_name': 'Dalton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green Lake', 'locality_code': '47', 'latitude': 43.6718, 'longitude': -89.1918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53939', 'place_name': 'Kingston', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green Lake', 'locality_code': '47', 'latitude': 43.6911, 'longitude': -89.1302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53946', 'place_name': 'Markesan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green Lake', 'locality_code': '47', 'latitude': 43.714, 'longitude': -89.007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53947', 'place_name': 'Marquette', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green Lake', 'locality_code': '47', 'latitude': 43.7459, 'longitude': -89.1397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54923', 'place_name': 'Berlin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green Lake', 'locality_code': '47', 'latitude': 43.9769, 'longitude': -88.949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54941', 'place_name': 'Green Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green Lake', 'locality_code': '47', 'latitude': 43.8444, 'longitude': -88.9685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54968', 'place_name': 'Princeton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Green Lake', 'locality_code': '47', 'latitude': 43.8438, 'longitude': -89.1249, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53503', 'place_name': 'Arena', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 43.1521, 'longitude': -89.9386, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53506', 'place_name': 'Avoca', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 43.1571, 'longitude': -90.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53507', 'place_name': 'Barneveld', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 43.0158, 'longitude': -89.9042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53526', 'place_name': 'Cobb', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.966, 'longitude': -90.3324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53533', 'place_name': 'Dodgeville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.9698, 'longitude': -90.1404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53535', 'place_name': 'Edmund', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.9675, 'longitude': -90.2646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53543', 'place_name': 'Highland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 43.0524, 'longitude': -90.365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53544', 'place_name': 'Hollandale', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.8773, 'longitude': -89.913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53553', 'place_name': 'Linden', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.9184, 'longitude': -90.2797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53565', 'place_name': 'Mineral Point', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.8547, 'longitude': -90.1646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53580', 'place_name': 'Rewey', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.8594, 'longitude': -90.3804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53582', 'place_name': 'Ridgeway', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 43.0077, 'longitude': -89.9889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53595', 'place_name': 'Dodgeville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iowa', 'locality_code': '49', 'latitude': 42.9761, 'longitude': -90.1413, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54525', 'place_name': 'Gile', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iron', 'locality_code': '51', 'latitude': 46.4283, 'longitude': -90.2252, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54534', 'place_name': 'Hurley', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iron', 'locality_code': '51', 'latitude': 46.4448, 'longitude': -90.1975, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54536', 'place_name': 'Iron Belt', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iron', 'locality_code': '51', 'latitude': 46.3955, 'longitude': -90.3245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54547', 'place_name': 'Mercer', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iron', 'locality_code': '51', 'latitude': 46.1696, 'longitude': -90.0679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54550', 'place_name': 'Montreal', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iron', 'locality_code': '51', 'latitude': 46.428, 'longitude': -90.246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54559', 'place_name': 'Saxon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iron', 'locality_code': '51', 'latitude': 46.4959, 'longitude': -90.4383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54565', 'place_name': 'Upson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Iron', 'locality_code': '51', 'latitude': 46.3761, 'longitude': -90.4051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54611', 'place_name': 'Alma Center', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jackson', 'locality_code': '53', 'latitude': 44.4452, 'longitude': -90.9356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54615', 'place_name': 'Black River Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jackson', 'locality_code': '53', 'latitude': 44.2954, 'longitude': -90.8313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54635', 'place_name': 'Hixton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jackson', 'locality_code': '53', 'latitude': 44.4038, 'longitude': -91.0442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54642', 'place_name': 'Melrose', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jackson', 'locality_code': '53', 'latitude': 44.1382, 'longitude': -91.0445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54643', 'place_name': 'Millston', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jackson', 'locality_code': '53', 'latitude': 44.1869, 'longitude': -90.6358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54659', 'place_name': 'Taylor', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jackson', 'locality_code': '53', 'latitude': 44.2899, 'longitude': -91.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54754', 'place_name': 'Merrillan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jackson', 'locality_code': '53', 'latitude': 44.4369, 'longitude': -90.8105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53036', 'place_name': 'Ixonia', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 43.1477, 'longitude': -88.5886, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53038', 'place_name': 'Johnson Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 43.0751, 'longitude': -88.7836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53094', 'place_name': 'Watertown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 43.193, 'longitude': -88.7185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53137', 'place_name': 'Helenville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 43.009, 'longitude': -88.6726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53156', 'place_name': 'Palmyra', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 42.8793, 'longitude': -88.5903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53178', 'place_name': 'Sullivan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 42.9982, 'longitude': -88.6026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53538', 'place_name': 'Fort Atkinson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 42.9229, 'longitude': -88.8467, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53549', 'place_name': 'Jefferson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 43.0006, 'longitude': -88.8078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53551', 'place_name': 'Lake Mills', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 43.0816, 'longitude': -88.9133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53594', 'place_name': 'Waterloo', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Jefferson', 'locality_code': '55', 'latitude': 43.1832, 'longitude': -88.9838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53929', 'place_name': 'Elroy', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.7516, 'longitude': -90.2889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53944', 'place_name': 'Lyndon Station', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.6899, 'longitude': -89.8915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53948', 'place_name': 'Mauston', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.7934, 'longitude': -90.0641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53950', 'place_name': 'New Lisbon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.8877, 'longitude': -90.1524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53962', 'place_name': 'Union Center', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.6853, 'longitude': -90.2668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53968', 'place_name': 'Wonewoc', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.6285, 'longitude': -90.2394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54618', 'place_name': 'Camp Douglas', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.9885, 'longitude': -90.2393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54637', 'place_name': 'Hustler', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 43.8801, 'longitude': -90.2729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54641', 'place_name': 'Mather', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 44.1427, 'longitude': -90.3087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54646', 'place_name': 'Necedah', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Juneau', 'locality_code': '57', 'latitude': 44.0345, 'longitude': -90.06, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53101', 'place_name': 'Bassett', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5406, 'longitude': -88.2279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53102', 'place_name': 'Benet Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5001, 'longitude': -88.08, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53104', 'place_name': 'Bristol', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5325, 'longitude': -88.0478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53109', 'place_name': 'Camp Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.536, 'longitude': -88.1444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53140', 'place_name': 'Kenosha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.6052, 'longitude': -87.8299, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53141', 'place_name': 'Kenosha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5847, 'longitude': -87.8212, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53142', 'place_name': 'Kenosha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.556, 'longitude': -87.8705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53143', 'place_name': 'Kenosha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5617, 'longitude': -87.8301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53144', 'place_name': 'Kenosha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.6058, 'longitude': -87.8762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53152', 'place_name': 'New Munster', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5746, 'longitude': -88.2326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53158', 'place_name': 'Pleasant Prairie', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5293, 'longitude': -87.8855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53159', 'place_name': 'Powers Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5557, 'longitude': -88.2969, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53168', 'place_name': 'Salem', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5709, 'longitude': -88.1287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53170', 'place_name': 'Silver Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.552, 'longitude': -88.1608, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53171', 'place_name': 'Somers', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.6423, 'longitude': -87.9032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53179', 'place_name': 'Trevor', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5201, 'longitude': -88.1387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53181', 'place_name': 'Twin Lakes', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5232, 'longitude': -88.2573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53192', 'place_name': 'Wilmot', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5128, 'longitude': -88.182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53194', 'place_name': 'Woodworth', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kenosha', 'locality_code': '59', 'latitude': 42.5581, 'longitude': -88.0012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54201', 'place_name': 'Algoma', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kewaunee', 'locality_code': '61', 'latitude': 44.6101, 'longitude': -87.4578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54205', 'place_name': 'Casco', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kewaunee', 'locality_code': '61', 'latitude': 44.5833, 'longitude': -87.6231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54216', 'place_name': 'Kewaunee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kewaunee', 'locality_code': '61', 'latitude': 44.4401, 'longitude': -87.5594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54217', 'place_name': 'Luxemburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Kewaunee', 'locality_code': '61', 'latitude': 44.5506, 'longitude': -87.7156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54601', 'place_name': 'La Crosse', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.7989, 'longitude': -91.2175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54602', 'place_name': 'La Crosse', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.9077, 'longitude': -91.1676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54603', 'place_name': 'La Crosse', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.8487, 'longitude': -91.2484, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54614', 'place_name': 'Bangor', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.8687, 'longitude': -90.9809, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54636', 'place_name': 'Holmen', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.9761, 'longitude': -91.2497, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54644', 'place_name': 'Mindoro', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 44.0287, 'longitude': -91.0642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54650', 'place_name': 'Onalaska', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.8974, 'longitude': -91.2314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54653', 'place_name': 'Rockland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.9064, 'longitude': -90.9193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54669', 'place_name': 'West Salem', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'La Crosse', 'locality_code': '63', 'latitude': 43.9063, 'longitude': -91.0893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53504', 'place_name': 'Argyle', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.6955, 'longitude': -89.8598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53510', 'place_name': 'Belmont', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.7308, 'longitude': -90.3359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53516', 'place_name': 'Blanchardville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.8062, 'longitude': -89.8555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53530', 'place_name': 'Darlington', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.6878, 'longitude': -90.1106, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53541', 'place_name': 'Gratiot', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.5759, 'longitude': -90.0243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53586', 'place_name': 'Shullsburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.5786, 'longitude': -90.2266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53587', 'place_name': 'South Wayne', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.5822, 'longitude': -89.8888, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53599', 'place_name': 'Woodford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.6493, 'longitude': -89.8622, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53803', 'place_name': 'Benton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lafayette', 'locality_code': '65', 'latitude': 42.5545, 'longitude': -90.3508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54409', 'place_name': 'Antigo', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.1314, 'longitude': -89.1419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54418', 'place_name': 'Bryant', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.203, 'longitude': -88.9983, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54424', 'place_name': 'Deerbrook', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.2368, 'longitude': -89.1873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54428', 'place_name': 'Elcho', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.4409, 'longitude': -89.1516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54430', 'place_name': 'Elton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.1562, 'longitude': -88.8837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54462', 'place_name': 'Pearson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.3641, 'longitude': -89.0165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54464', 'place_name': 'Phlox', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.0511, 'longitude': -89.0143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54465', 'place_name': 'Pickerel', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.3567, 'longitude': -88.9137, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54485', 'place_name': 'Summit Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.3965, 'longitude': -89.2179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54491', 'place_name': 'White Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Langlade', 'locality_code': '67', 'latitude': 45.1715, 'longitude': -88.7555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54435', 'place_name': 'Gleason', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lincoln', 'locality_code': '69', 'latitude': 45.3384, 'longitude': -89.4753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54442', 'place_name': 'Irma', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lincoln', 'locality_code': '69', 'latitude': 45.3485, 'longitude': -89.6611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54452', 'place_name': 'Merrill', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lincoln', 'locality_code': '69', 'latitude': 45.1809, 'longitude': -89.6907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54487', 'place_name': 'Tomahawk', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lincoln', 'locality_code': '69', 'latitude': 45.4963, 'longitude': -89.7273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54532', 'place_name': 'Heafford Junction', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Lincoln', 'locality_code': '69', 'latitude': 45.5472, 'longitude': -89.7154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53015', 'place_name': 'Cleveland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 43.9217, 'longitude': -87.7673, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53042', 'place_name': 'Kiel', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 43.9341, 'longitude': -87.9956, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53063', 'place_name': 'Newton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 43.9836, 'longitude': -87.7848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54207', 'place_name': 'Collins', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.091, 'longitude': -87.9902, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54214', 'place_name': 'Francis Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.2, 'longitude': -87.72, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54215', 'place_name': 'Kellnersville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.2226, 'longitude': -87.8017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54220', 'place_name': 'Manitowoc', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.0971, 'longitude': -87.6823, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54221', 'place_name': 'Manitowoc', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.1323, 'longitude': -87.599, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54227', 'place_name': 'Maribel', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.2852, 'longitude': -87.8055, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54228', 'place_name': 'Mishicot', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.2609, 'longitude': -87.6447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54230', 'place_name': 'Reedsville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.1576, 'longitude': -87.966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54232', 'place_name': 'Saint Nazianz', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.0064, 'longitude': -87.9229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54240', 'place_name': 'Tisch Mills', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.3272, 'longitude': -87.6237, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54241', 'place_name': 'Two Rivers', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.166, 'longitude': -87.5855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54245', 'place_name': 'Valders', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.042, 'longitude': -87.8812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54247', 'place_name': 'Whitelaw', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Manitowoc', 'locality_code': '71', 'latitude': 44.1573, 'longitude': -87.8267, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54401', 'place_name': 'Wausau', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9654, 'longitude': -89.7066, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54402', 'place_name': 'Wausau', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9009, 'longitude': -89.7701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54403', 'place_name': 'Wausau', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9529, 'longitude': -89.5318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54408', 'place_name': 'Aniwa', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 45.0088, 'longitude': -89.3578, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54411', 'place_name': 'Athens', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9823, 'longitude': -90.0078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54417', 'place_name': 'Brokaw', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 45.0273, 'longitude': -89.6541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54426', 'place_name': 'Edgar', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9046, 'longitude': -90.0125, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54427', 'place_name': 'Eland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.8309, 'longitude': -89.2461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54429', 'place_name': 'Elderon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.7802, 'longitude': -89.2478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54432', 'place_name': 'Galloway', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.7128, 'longitude': -89.2643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54440', 'place_name': 'Hatley', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.8256, 'longitude': -89.3777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54448', 'place_name': 'Marathon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9291, 'longitude': -89.8404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54455', 'place_name': 'Mosinee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.7997, 'longitude': -89.6845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54471', 'place_name': 'Ringle', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9238, 'longitude': -89.4328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54474', 'place_name': 'Rothschild', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.8843, 'longitude': -89.6193, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54476', 'place_name': 'Schofield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.9064, 'longitude': -89.5818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54479', 'place_name': 'Spencer', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.7391, 'longitude': -90.3114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54484', 'place_name': 'Stratford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.7899, 'longitude': -90.0583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54488', 'place_name': 'Unity', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marathon', 'locality_code': '73', 'latitude': 44.8227, 'longitude': -90.3221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54102', 'place_name': 'Amberg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.4989, 'longitude': -87.9643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54104', 'place_name': 'Athelstane', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.4228, 'longitude': -88.1753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54112', 'place_name': 'Coleman', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.0722, 'longitude': -88.0587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54114', 'place_name': 'Crivitz', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.2617, 'longitude': -88.078, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54119', 'place_name': 'Dunbar', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.6009, 'longitude': -88.1067, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54125', 'place_name': 'Goodman', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.6469, 'longitude': -88.3629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54143', 'place_name': 'Marinette', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.0874, 'longitude': -87.6697, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54151', 'place_name': 'Niagara', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.7653, 'longitude': -88.0309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54156', 'place_name': 'Pembine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.6074, 'longitude': -87.9704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54157', 'place_name': 'Peshtigo', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.048, 'longitude': -87.8103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54159', 'place_name': 'Porterfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.1934, 'longitude': -87.8062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54161', 'place_name': 'Pound', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.1273, 'longitude': -88.1396, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54177', 'place_name': 'Wausaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marinette', 'locality_code': '75', 'latitude': 45.3495, 'longitude': -87.9099, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53920', 'place_name': 'Briggsville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marquette', 'locality_code': '77', 'latitude': 43.6759, 'longitude': -89.5803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53930', 'place_name': 'Endeavor', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marquette', 'locality_code': '77', 'latitude': 43.6963, 'longitude': -89.4617, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53949', 'place_name': 'Montello', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marquette', 'locality_code': '77', 'latitude': 43.769, 'longitude': -89.3586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53952', 'place_name': 'Oxford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marquette', 'locality_code': '77', 'latitude': 43.7799, 'longitude': -89.5632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53953', 'place_name': 'Packwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marquette', 'locality_code': '77', 'latitude': 43.7644, 'longitude': -89.4576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53964', 'place_name': 'Westfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marquette', 'locality_code': '77', 'latitude': 43.8968, 'longitude': -89.502, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54960', 'place_name': 'Neshkoro', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Marquette', 'locality_code': '77', 'latitude': 43.8989, 'longitude': -89.2336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54135', 'place_name': 'Keshena', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Menominee', 'locality_code': '78', 'latitude': 44.9146, 'longitude': -88.6357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54150', 'place_name': 'Neopit', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Menominee', 'locality_code': '78', 'latitude': 44.9808, 'longitude': -88.8309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53110', 'place_name': 'Cudahy', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.949, 'longitude': -87.862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53129', 'place_name': 'Greendale', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9373, 'longitude': -87.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53130', 'place_name': 'Hales Corners', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.941, 'longitude': -88.0503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53132', 'place_name': 'Franklin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9017, 'longitude': -88.0086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53154', 'place_name': 'Oak Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.8892, 'longitude': -87.9027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53172', 'place_name': 'South Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9105, 'longitude': -87.8646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53201', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0389, 'longitude': -87.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53202', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0506, 'longitude': -87.8968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53203', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0403, 'longitude': -87.9154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53204', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0158, 'longitude': -87.9317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53205', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0528, 'longitude': -87.9353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53206', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0753, 'longitude': -87.9347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53207', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9751, 'longitude': -87.8947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53208', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0488, 'longitude': -87.9625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53209', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.1188, 'longitude': -87.9478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53210', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0685, 'longitude': -87.9715, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53211', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.082, 'longitude': -87.8895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53212', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0712, 'longitude': -87.9084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53213', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0488, 'longitude': -88.0015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53214', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0215, 'longitude': -88.0176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53215', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.006, 'longitude': -87.9429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53216', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0859, 'longitude': -87.9742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53217', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.1409, 'longitude': -87.9073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53218', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.1122, 'longitude': -87.9932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53219', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9959, 'longitude': -87.9944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53220', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9559, 'longitude': -87.9933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53221', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9549, 'longitude': -87.9447, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53222', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0828, 'longitude': -88.0269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53223', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.1624, 'longitude': -87.9898, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53224', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.1594, 'longitude': -88.0327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53225', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.1154, 'longitude': -88.0346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53226', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0493, 'longitude': -88.0414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53227', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9949, 'longitude': -88.0364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53228', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9676, 'longitude': -88.0434, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53233', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0407, 'longitude': -87.9357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53234', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0389, 'longitude': -87.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53235', 'place_name': 'Saint Francis', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 42.9731, 'longitude': -87.8687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53237', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0389, 'longitude': -87.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53259', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0387, 'longitude': -87.9139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53263', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0746, 'longitude': -88.0604, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53267', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.044, 'longitude': -87.9098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53268', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0385, 'longitude': -87.9096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53274', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0389, 'longitude': -87.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53278', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0389, 'longitude': -87.9024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53288', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0406, 'longitude': -87.9098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53290', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0373, 'longitude': -87.914, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53293', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0408, 'longitude': -87.9191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53295', 'place_name': 'Milwaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Milwaukee', 'locality_code': '79', 'latitude': 43.0389, 'longitude': -87.9065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54619', 'place_name': 'Cashton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 43.7456, 'longitude': -90.7612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54620', 'place_name': 'Cataract', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 44.0876, 'longitude': -90.8423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54638', 'place_name': 'Kendall', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 43.7922, 'longitude': -90.3685, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54648', 'place_name': 'Norwalk', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 43.8128, 'longitude': -90.6801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54649', 'place_name': 'Oakdale', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 43.9715, 'longitude': -90.3612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54656', 'place_name': 'Sparta', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 43.954, 'longitude': -90.8146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54660', 'place_name': 'Tomah', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 43.9838, 'longitude': -90.4733, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54662', 'place_name': 'Tunnel City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 44.0031, 'longitude': -90.562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54666', 'place_name': 'Warrens', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 44.157, 'longitude': -90.4967, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54670', 'place_name': 'Wilton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Monroe', 'locality_code': '81', 'latitude': 43.8322, 'longitude': -90.5162, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54101', 'place_name': 'Abrams', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 44.7869, 'longitude': -88.0571, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54124', 'place_name': 'Gillett', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 44.9018, 'longitude': -88.3242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54138', 'place_name': 'Lakewood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 45.3163, 'longitude': -88.5032, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54139', 'place_name': 'Lena', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 44.956, 'longitude': -88.075, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54141', 'place_name': 'Little Suamico', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 44.7175, 'longitude': -88.0093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54149', 'place_name': 'Mountain', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 45.1991, 'longitude': -88.4583, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54153', 'place_name': 'Oconto', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 44.8914, 'longitude': -87.8917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54154', 'place_name': 'Oconto Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 44.8755, 'longitude': -88.1555, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54171', 'place_name': 'Sobieski', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 44.7105, 'longitude': -88.1076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54174', 'place_name': 'Suring', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 45.0186, 'longitude': -88.3628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54175', 'place_name': 'Townsend', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oconto', 'locality_code': '83', 'latitude': 45.3148, 'longitude': -88.6107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54463', 'place_name': 'Pelican Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.5049, 'longitude': -89.1817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54501', 'place_name': 'Rhinelander', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.7045, 'longitude': -89.3866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54529', 'place_name': 'Harshaw', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.6762, 'longitude': -89.6503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54531', 'place_name': 'Hazelhurst', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.7745, 'longitude': -89.7478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54539', 'place_name': 'Lake Tomahawk', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.8035, 'longitude': -89.5856, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54543', 'place_name': 'Mc Naughton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.7229, 'longitude': -89.5573, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '54548', 'place_name': 'Minocqua', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.8719, 'longitude': -89.758, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54562', 'place_name': 'Three Lakes', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.8046, 'longitude': -89.1328, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54564', 'place_name': 'Tripoli', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.5814, 'longitude': -89.9852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54568', 'place_name': 'Woodruff', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Oneida', 'locality_code': '85', 'latitude': 45.9186, 'longitude': -89.6954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54106', 'place_name': 'Black Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.4702, 'longitude': -88.4547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54113', 'place_name': 'Combined Locks', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.2666, 'longitude': -88.3133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54130', 'place_name': 'Kaukauna', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.2956, 'longitude': -88.2717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54131', 'place_name': 'Freedom', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.4163, 'longitude': -88.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54136', 'place_name': 'Kimberly', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.2701, 'longitude': -88.3384, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54140', 'place_name': 'Little Chute', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.2842, 'longitude': -88.312, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54152', 'place_name': 'Nichols', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.5668, 'longitude': -88.4582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54155', 'place_name': 'Oneida', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.5166, 'longitude': -88.1859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54165', 'place_name': 'Seymour', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.5091, 'longitude': -88.3172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54170', 'place_name': 'Shiocton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.4972, 'longitude': -88.5562, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54911', 'place_name': 'Appleton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.2773, 'longitude': -88.3976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54912', 'place_name': 'Appleton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.4163, 'longitude': -88.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54913', 'place_name': 'Appleton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.3456, 'longitude': -88.4343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54914', 'place_name': 'Appleton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.271, 'longitude': -88.4326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54915', 'place_name': 'Appleton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.2425, 'longitude': -88.3564, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54919', 'place_name': 'Appleton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.4163, 'longitude': -88.4649, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54922', 'place_name': 'Bear Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.5348, 'longitude': -88.7404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54931', 'place_name': 'Dale', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.273, 'longitude': -88.6784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54942', 'place_name': 'Greenville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.3003, 'longitude': -88.5365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54944', 'place_name': 'Hortonville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Outagamie', 'locality_code': '87', 'latitude': 44.3273, 'longitude': -88.6281, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53004', 'place_name': 'Belgium', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.4995, 'longitude': -87.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53012', 'place_name': 'Cedarburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.3034, 'longitude': -88.0029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53021', 'place_name': 'Fredonia', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.477, 'longitude': -87.9612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53024', 'place_name': 'Grafton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.3231, 'longitude': -87.9521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53074', 'place_name': 'Port Washington', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.3955, 'longitude': -87.8797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53080', 'place_name': 'Saukville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.3913, 'longitude': -87.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53092', 'place_name': 'Mequon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.2364, 'longitude': -87.9845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53097', 'place_name': 'Mequon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Ozaukee', 'locality_code': '89', 'latitude': 43.2461, 'longitude': -88.0046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54721', 'place_name': 'Arkansaw', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pepin', 'locality_code': '91', 'latitude': 44.6267, 'longitude': -92.0566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54736', 'place_name': 'Durand', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pepin', 'locality_code': '91', 'latitude': 44.63, 'longitude': -91.9295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54759', 'place_name': 'Pepin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pepin', 'locality_code': '91', 'latitude': 44.4587, 'longitude': -92.1394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54769', 'place_name': 'Stockholm', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pepin', 'locality_code': '91', 'latitude': 44.5084, 'longitude': -92.2326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54003', 'place_name': 'Beldenville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.7721, 'longitude': -92.4372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54010', 'place_name': 'East Ellsworth', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.7348, 'longitude': -92.4655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54011', 'place_name': 'Ellsworth', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.7302, 'longitude': -92.489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54014', 'place_name': 'Hager City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.627, 'longitude': -92.5501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54021', 'place_name': 'Prescott', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.7476, 'longitude': -92.7535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54022', 'place_name': 'River Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.855, 'longitude': -92.6313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54723', 'place_name': 'Bay City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.6166, 'longitude': -92.4469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54740', 'place_name': 'Elmwood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.7561, 'longitude': -92.2022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54750', 'place_name': 'Maiden Rock', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.6086, 'longitude': -92.2782, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54761', 'place_name': 'Plum City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.636, 'longitude': -92.1837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54767', 'place_name': 'Spring Valley', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Pierce', 'locality_code': '93', 'latitude': 44.8356, 'longitude': -92.2906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54001', 'place_name': 'Amery', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.3486, 'longitude': -92.4014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54004', 'place_name': 'Clayton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.3063, 'longitude': -92.1395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54005', 'place_name': 'Clear Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.2365, 'longitude': -92.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54006', 'place_name': 'Cushing', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.5604, 'longitude': -92.6241, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54009', 'place_name': 'Dresser', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.3546, 'longitude': -92.5623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54020', 'place_name': 'Osceola', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.3218, 'longitude': -92.6971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54024', 'place_name': 'Saint Croix Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.5097, 'longitude': -92.6117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54026', 'place_name': 'Star Prairie', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.2013, 'longitude': -92.5514, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54810', 'place_name': 'Balsam Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.4588, 'longitude': -92.415, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54824', 'place_name': 'Centuria', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.4484, 'longitude': -92.5477, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54837', 'place_name': 'Frederic', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.6729, 'longitude': -92.3545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54853', 'place_name': 'Luck', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.5568, 'longitude': -92.4164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54858', 'place_name': 'Milltown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Polk', 'locality_code': '95', 'latitude': 45.5271, 'longitude': -92.5017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54406', 'place_name': 'Amherst', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.4231, 'longitude': -89.3035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54407', 'place_name': 'Amherst Junction', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.5065, 'longitude': -89.3038, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54423', 'place_name': 'Custer', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.5662, 'longitude': -89.4153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54443', 'place_name': 'Junction City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.5963, 'longitude': -89.7438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54458', 'place_name': 'Nelsonville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.495, 'longitude': -89.3098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54467', 'place_name': 'Plover', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.4507, 'longitude': -89.5428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54473', 'place_name': 'Rosholt', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.6622, 'longitude': -89.3356, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54481', 'place_name': 'Stevens Point', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.5212, 'longitude': -89.5588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54482', 'place_name': 'Stevens Point', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.5563, 'longitude': -89.5182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54492', 'place_name': 'Stevens Point', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.5094, 'longitude': -89.5286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54909', 'place_name': 'Almond', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.2898, 'longitude': -89.3584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54921', 'place_name': 'Bancroft', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Portage', 'locality_code': '97', 'latitude': 44.3065, 'longitude': -89.5304, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54459', 'place_name': 'Ogema', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.4392, 'longitude': -90.2565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54513', 'place_name': 'Brantwood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.5514, 'longitude': -90.116, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54515', 'place_name': 'Catawba', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.5081, 'longitude': -90.5146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54524', 'place_name': 'Fifield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.8143, 'longitude': -90.453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54537', 'place_name': 'Kennan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.535, 'longitude': -90.591, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54552', 'place_name': 'Park Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.9363, 'longitude': -90.4246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54555', 'place_name': 'Phillips', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.6975, 'longitude': -90.4041, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54556', 'place_name': 'Prentice', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Price', 'locality_code': '99', 'latitude': 45.5482, 'longitude': -90.2942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53105', 'place_name': 'Burlington', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.666, 'longitude': -88.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53108', 'place_name': 'Caledonia', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.8295, 'longitude': -87.9228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53126', 'place_name': 'Franksville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7859, 'longitude': -87.9873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53139', 'place_name': 'Kansasville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7012, 'longitude': -88.118, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53167', 'place_name': 'Rochester', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7414, 'longitude': -88.2243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53177', 'place_name': 'Sturtevant', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.6967, 'longitude': -87.9031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53182', 'place_name': 'Union Grove', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.6896, 'longitude': -88.039, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53185', 'place_name': 'Waterford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7632, 'longitude': -88.1974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53401', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7272, 'longitude': -87.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53402', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7726, 'longitude': -87.796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53403', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.706, 'longitude': -87.8014, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53404', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7433, 'longitude': -87.8053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53405', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7161, 'longitude': -87.8233, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53406', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7242, 'longitude': -87.8551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53407', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7312, 'longitude': -87.7828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53408', 'place_name': 'Racine', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Racine', 'locality_code': '101', 'latitude': 42.7272, 'longitude': -87.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53540', 'place_name': 'Gotham', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Richland', 'locality_code': '103', 'latitude': 43.2233, 'longitude': -90.2915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53556', 'place_name': 'Lone Rock', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Richland', 'locality_code': '103', 'latitude': 43.2208, 'longitude': -90.2352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53581', 'place_name': 'Richland Center', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Richland', 'locality_code': '103', 'latitude': 43.3661, 'longitude': -90.4302, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53584', 'place_name': 'Sextonville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Richland', 'locality_code': '103', 'latitude': 43.2794, 'longitude': -90.2876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53924', 'place_name': 'Cazenovia', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Richland', 'locality_code': '103', 'latitude': 43.4987, 'longitude': -90.2796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53501', 'place_name': 'Afton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.6055, 'longitude': -89.0704, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53505', 'place_name': 'Avalon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.6593, 'longitude': -88.8307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53511', 'place_name': 'Beloit', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.562, 'longitude': -89.086, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53512', 'place_name': 'Beloit', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.5083, 'longitude': -89.0318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53525', 'place_name': 'Clinton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.5535, 'longitude': -88.8705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53534', 'place_name': 'Edgerton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.8386, 'longitude': -89.0642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53536', 'place_name': 'Evansville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.7732, 'longitude': -89.2877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53537', 'place_name': 'Footville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.6726, 'longitude': -89.2112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53542', 'place_name': 'Hanover', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.6323, 'longitude': -89.1594, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53545', 'place_name': 'Janesville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.7355, 'longitude': -89.0405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53546', 'place_name': 'Janesville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.6683, 'longitude': -89.0025, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53547', 'place_name': 'Janesville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.7294, 'longitude': -89.0301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53548', 'place_name': 'Janesville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.6854, 'longitude': -89.1287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53563', 'place_name': 'Milton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.7791, 'longitude': -88.9531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53576', 'place_name': 'Orfordville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rock', 'locality_code': '105', 'latitude': 42.6278, 'longitude': -89.2533, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54526', 'place_name': 'Glen Flora', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.4862, 'longitude': -90.8479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54530', 'place_name': 'Hawkins', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.5241, 'longitude': -90.7114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54563', 'place_name': 'Tony', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.4741, 'longitude': -90.9869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54731', 'place_name': 'Conrath', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.3533, 'longitude': -91.0621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54766', 'place_name': 'Sheldon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.3182, 'longitude': -90.9141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54819', 'place_name': 'Bruce', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.4479, 'longitude': -91.2906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54848', 'place_name': 'Ladysmith', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.4719, 'longitude': -91.1088, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54895', 'place_name': 'Weyerhaeuser', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Rusk', 'locality_code': '107', 'latitude': 45.4263, 'longitude': -91.4289, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54002', 'place_name': 'Baldwin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 44.9657, 'longitude': -92.3655, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54007', 'place_name': 'Deer Park', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 45.169, 'longitude': -92.3585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54013', 'place_name': 'Glenwood City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 45.0623, 'longitude': -92.1816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54015', 'place_name': 'Hammond', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 44.967, 'longitude': -92.4472, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54016', 'place_name': 'Hudson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 44.9842, 'longitude': -92.7271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54017', 'place_name': 'New Richmond', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 45.123, 'longitude': -92.5366, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54023', 'place_name': 'Roberts', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 44.9874, 'longitude': -92.5598, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54025', 'place_name': 'Somerset', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 45.1331, 'longitude': -92.6865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54027', 'place_name': 'Wilson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 44.9466, 'longitude': -92.1965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54028', 'place_name': 'Woodville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 44.9408, 'longitude': -92.2848, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54082', 'place_name': 'Houlton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'St. Croix', 'locality_code': '109', 'latitude': 45.0655, 'longitude': -92.7572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53561', 'place_name': 'Merrimac', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.3855, 'longitude': -89.6323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53577', 'place_name': 'Plain', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.2927, 'longitude': -90.0558, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53578', 'place_name': 'Prairie Du Sac', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.2956, 'longitude': -89.7452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53583', 'place_name': 'Sauk City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.2686, 'longitude': -89.7418, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53588', 'place_name': 'Spring Green', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.1883, 'longitude': -90.0676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53913', 'place_name': 'Baraboo', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.4825, 'longitude': -89.7462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53937', 'place_name': 'Hillpoint', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.3951, 'longitude': -90.1588, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '53940', 'place_name': 'Lake Delton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.5939, 'longitude': -89.7912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53941', 'place_name': 'La Valle', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.5699, 'longitude': -90.128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53942', 'place_name': 'Lime Ridge', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.4682, 'longitude': -90.1615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53943', 'place_name': 'Loganville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.405, 'longitude': -90.0337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53951', 'place_name': 'North Freedom', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.4106, 'longitude': -89.849, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53958', 'place_name': 'Reedsburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.3938, 'longitude': -89.9559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53959', 'place_name': 'Reedsburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.5316, 'longitude': -89.9959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53961', 'place_name': 'Rock Springs', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sauk', 'locality_code': '111', 'latitude': 43.4681, 'longitude': -89.9218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54828', 'place_name': 'Couderay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.838, 'longitude': -91.2918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54834', 'place_name': 'Edgewater', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.7424, 'longitude': -91.4765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54835', 'place_name': 'Exeland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.6753, 'longitude': -91.2238, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54843', 'place_name': 'Hayward', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.9552, 'longitude': -91.2783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54862', 'place_name': 'Ojibwa', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.7854, 'longitude': -91.1109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54867', 'place_name': 'Radisson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.7734, 'longitude': -91.2262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54876', 'place_name': 'Stone Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.8337, 'longitude': -91.5093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54896', 'place_name': 'Winter', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sawyer', 'locality_code': '113', 'latitude': 45.8327, 'longitude': -91.0144, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54107', 'place_name': 'Bonduel', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.6992, 'longitude': -88.4543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54111', 'place_name': 'Cecil', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.811, 'longitude': -88.4183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54127', 'place_name': 'Green Valley', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.7964, 'longitude': -88.2696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54128', 'place_name': 'Gresham', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.853, 'longitude': -88.7887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54137', 'place_name': 'Krakow', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.7635, 'longitude': -88.2593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54166', 'place_name': 'Shawano', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.7851, 'longitude': -88.6036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54182', 'place_name': 'Zachow', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.7315, 'longitude': -88.3698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54414', 'place_name': 'Birnamwood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.9269, 'longitude': -89.2124, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54416', 'place_name': 'Bowler', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.9337, 'longitude': -88.9761, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54450', 'place_name': 'Mattoon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 45.0062, 'longitude': -89.0474, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54486', 'place_name': 'Tigerton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.7299, 'longitude': -89.0569, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54499', 'place_name': 'Wittenberg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.8232, 'longitude': -89.1665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54928', 'place_name': 'Caroline', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.7276, 'longitude': -88.8887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54948', 'place_name': 'Leopolis', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.7812, 'longitude': -88.8722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54978', 'place_name': 'Tilleda', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Shawano', 'locality_code': '115', 'latitude': 44.796, 'longitude': -88.8984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53001', 'place_name': 'Adell', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.6151, 'longitude': -88.0254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53011', 'place_name': 'Cascade', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.6591, 'longitude': -88.0947, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53013', 'place_name': 'Cedar Grove', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.5751, 'longitude': -87.8401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53020', 'place_name': 'Elkhart Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.8436, 'longitude': -87.9767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53023', 'place_name': 'Glenbeulah', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.7666, 'longitude': -88.1049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53026', 'place_name': 'Greenbush', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.7767, 'longitude': -88.084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53031', 'place_name': 'Hingham', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.6394, 'longitude': -87.9157, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53044', 'place_name': 'Kohler', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.7381, 'longitude': -87.7867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53070', 'place_name': 'Oostburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.6229, 'longitude': -87.797, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53073', 'place_name': 'Plymouth', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.7526, 'longitude': -87.9779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53075', 'place_name': 'Random Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.5672, 'longitude': -87.9816, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53081', 'place_name': 'Sheboygan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.741, 'longitude': -87.7247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53082', 'place_name': 'Sheboygan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.7183, 'longitude': -87.6187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53083', 'place_name': 'Sheboygan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.8176, 'longitude': -87.766, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53085', 'place_name': 'Sheboygan Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.7266, 'longitude': -87.8242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53093', 'place_name': 'Waldo', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Sheboygan', 'locality_code': '117', 'latitude': 43.6571, 'longitude': -87.9722, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54433', 'place_name': 'Gilman', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.1891, 'longitude': -90.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54434', 'place_name': 'Jump River', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.353, 'longitude': -90.8012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54439', 'place_name': 'Hannibal', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.2525, 'longitude': -90.789, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54447', 'place_name': 'Lublin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.0739, 'longitude': -90.7337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54451', 'place_name': 'Medford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.1512, 'longitude': -90.3503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54470', 'place_name': 'Rib Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.2984, 'longitude': -90.1763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54480', 'place_name': 'Stetsonville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.0792, 'longitude': -90.2829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54490', 'place_name': 'Westboro', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Taylor', 'locality_code': '119', 'latitude': 45.3445, 'longitude': -90.3072, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54612', 'place_name': 'Arcadia', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.2539, 'longitude': -91.4805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54616', 'place_name': 'Blair', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.2968, 'longitude': -91.2235, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54625', 'place_name': 'Dodge', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.1431, 'longitude': -91.5204, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54627', 'place_name': 'Ettrick', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.1724, 'longitude': -91.2635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54630', 'place_name': 'Galesville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.0888, 'longitude': -91.3588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54661', 'place_name': 'Trempealeau', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.0218, 'longitude': -91.4282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54738', 'place_name': 'Eleva', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.5985, 'longitude': -91.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54747', 'place_name': 'Independence', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.3959, 'longitude': -91.4535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54758', 'place_name': 'Osseo', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.5599, 'longitude': -91.2191, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54760', 'place_name': 'Pigeon Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.4249, 'longitude': -91.2074, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54770', 'place_name': 'Strum', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.5674, 'longitude': -91.3833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54773', 'place_name': 'Whitehall', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Trempealeau', 'locality_code': '121', 'latitude': 44.3827, 'longitude': -91.303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54621', 'place_name': 'Chaseburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.6794, 'longitude': -91.0799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54623', 'place_name': 'Coon Valley', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.7218, 'longitude': -91.0143, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54624', 'place_name': 'De Soto', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.4807, 'longitude': -91.1333, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54632', 'place_name': 'Genoa', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.5641, 'longitude': -91.1461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54634', 'place_name': 'Hillsboro', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.5966, 'longitude': -90.4266, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54639', 'place_name': 'La Farge', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.6, 'longitude': -90.6365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54651', 'place_name': 'Ontario', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.7172, 'longitude': -90.6205, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54652', 'place_name': 'Readstown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.4508, 'longitude': -90.7579, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54658', 'place_name': 'Stoddard', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.6912, 'longitude': -91.1919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54664', 'place_name': 'Viola', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.5048, 'longitude': -90.6554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54665', 'place_name': 'Viroqua', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.5442, 'longitude': -90.8939, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54667', 'place_name': 'Westby', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vernon', 'locality_code': '123', 'latitude': 43.6631, 'longitude': -90.874, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54512', 'place_name': 'Boulder Junction', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 46.1112, 'longitude': -89.6325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54519', 'place_name': 'Conover', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 46.044, 'longitude': -89.2389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54521', 'place_name': 'Eagle River', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 45.9161, 'longitude': -89.2531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54538', 'place_name': 'Lac Du Flambeau', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 45.9718, 'longitude': -89.8901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54540', 'place_name': 'Land O Lakes', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 46.1563, 'longitude': -89.3218, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54545', 'place_name': 'Manitowish Waters', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 46.1551, 'longitude': -89.8455, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54554', 'place_name': 'Phelps', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 46.0645, 'longitude': -89.0815, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54557', 'place_name': 'Presque Isle', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 46.2, 'longitude': -89.7387, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54558', 'place_name': 'Saint Germain', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 45.9183, 'longitude': -89.4866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54560', 'place_name': 'Sayner', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 45.9867, 'longitude': -89.5194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54561', 'place_name': 'Star Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Vilas', 'locality_code': '125', 'latitude': 46.0613, 'longitude': -89.4858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53114', 'place_name': 'Darien', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.5973, 'longitude': -88.7508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53115', 'place_name': 'Delavan', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.6227, 'longitude': -88.6277, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53120', 'place_name': 'East Troy', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.8035, 'longitude': -88.4092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53121', 'place_name': 'Elkhorn', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.7009, 'longitude': -88.5462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53125', 'place_name': 'Fontana', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.5429, 'longitude': -88.5684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53128', 'place_name': 'Genoa City', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.5323, 'longitude': -88.3485, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53138', 'place_name': 'Honey Creek', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.7483, 'longitude': -88.3079, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53147', 'place_name': 'Lake Geneva', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.5881, 'longitude': -88.4554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53148', 'place_name': 'Lyons', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.6487, 'longitude': -88.359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53157', 'place_name': 'Pell Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.54, 'longitude': -88.3582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53176', 'place_name': 'Springfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.636, 'longitude': -88.416, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53184', 'place_name': 'Walworth', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.535, 'longitude': -88.6027, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53190', 'place_name': 'Whitewater', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.8272, 'longitude': -88.7429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53191', 'place_name': 'Williams Bay', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.5767, 'longitude': -88.5431, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53195', 'place_name': 'Zenda', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.5136, 'longitude': -88.4843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53585', 'place_name': 'Sharon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Walworth', 'locality_code': '127', 'latitude': 42.5194, 'longitude': -88.7265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54801', 'place_name': 'Spooner', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washburn', 'locality_code': '129', 'latitude': 45.8505, 'longitude': -91.9155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54817', 'place_name': 'Birchwood', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washburn', 'locality_code': '129', 'latitude': 45.6403, 'longitude': -91.5776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54859', 'place_name': 'Minong', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washburn', 'locality_code': '129', 'latitude': 46.1044, 'longitude': -91.8506, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54870', 'place_name': 'Sarona', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washburn', 'locality_code': '129', 'latitude': 45.7085, 'longitude': -91.7621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54871', 'place_name': 'Shell Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washburn', 'locality_code': '129', 'latitude': 45.7536, 'longitude': -91.9606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54875', 'place_name': 'Springbrook', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washburn', 'locality_code': '129', 'latitude': 45.9452, 'longitude': -91.6754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54888', 'place_name': 'Trego', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washburn', 'locality_code': '129', 'latitude': 45.9516, 'longitude': -91.8581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53002', 'place_name': 'Allenton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.4681, 'longitude': -88.3539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53017', 'place_name': 'Colgate', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.1998, 'longitude': -88.2406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53022', 'place_name': 'Germantown', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.2189, 'longitude': -88.1165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53027', 'place_name': 'Hartford', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.3157, 'longitude': -88.3707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53033', 'place_name': 'Hubertus', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.2343, 'longitude': -88.2311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53037', 'place_name': 'Jackson', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.3252, 'longitude': -88.1626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53040', 'place_name': 'Kewaskum', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.5214, 'longitude': -88.1925, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53060', 'place_name': 'Newburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.4338, 'longitude': -88.0623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53076', 'place_name': 'Richfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.2739, 'longitude': -88.2155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53086', 'place_name': 'Slinger', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.3322, 'longitude': -88.2824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53090', 'place_name': 'West Bend', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.4438, 'longitude': -88.1963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53095', 'place_name': 'West Bend', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Washington', 'locality_code': '131', 'latitude': 43.4224, 'longitude': -88.1845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53005', 'place_name': 'Brookfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0622, 'longitude': -88.098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53007', 'place_name': 'Butler', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1054, 'longitude': -88.071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53008', 'place_name': 'Brookfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0606, 'longitude': -88.1065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53018', 'place_name': 'Delafield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.05, 'longitude': -88.3972, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53029', 'place_name': 'Hartland', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1172, 'longitude': -88.3446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53045', 'place_name': 'Brookfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0668, 'longitude': -88.1469, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53046', 'place_name': 'Lannon', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1497, 'longitude': -88.1639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53051', 'place_name': 'Menomonee Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1602, 'longitude': -88.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53052', 'place_name': 'Menomonee Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1789, 'longitude': -88.1173, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53056', 'place_name': 'Merton', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.146, 'longitude': -88.3097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53058', 'place_name': 'Nashotah', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1118, 'longitude': -88.4089, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53064', 'place_name': 'North Lake', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1561, 'longitude': -88.3707, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53066', 'place_name': 'Oconomowoc', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1095, 'longitude': -88.4862, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53069', 'place_name': 'Okauchee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.113, 'longitude': -88.4323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53072', 'place_name': 'Pewaukee', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0788, 'longitude': -88.2729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53089', 'place_name': 'Sussex', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.1441, 'longitude': -88.2271, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53103', 'place_name': 'Big Bend', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.8885, 'longitude': -88.2122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53118', 'place_name': 'Dousman', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0142, 'longitude': -88.4726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53119', 'place_name': 'Eagle', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.8809, 'longitude': -88.4674, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53122', 'place_name': 'Elm Grove', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0479, 'longitude': -88.0854, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53127', 'place_name': 'Genesee Depot', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.9601, 'longitude': -88.3745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53146', 'place_name': 'New Berlin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.974, 'longitude': -88.1553, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53149', 'place_name': 'Mukwonago', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.8821, 'longitude': -88.3451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53150', 'place_name': 'Muskego', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.9047, 'longitude': -88.1214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53151', 'place_name': 'New Berlin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.9822, 'longitude': -88.0946, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53153', 'place_name': 'North Prairie', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.9385, 'longitude': -88.395, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53183', 'place_name': 'Wales', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0088, 'longitude': -88.3787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53186', 'place_name': 'Waukesha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.9993, 'longitude': -88.2196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53187', 'place_name': 'Waukesha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0117, 'longitude': -88.2315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53188', 'place_name': 'Waukesha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 43.0128, 'longitude': -88.2705, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '53189', 'place_name': 'Waukesha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waukesha', 'locality_code': '133', 'latitude': 42.9516, 'longitude': -88.2963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54926', 'place_name': 'Big Falls', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.6178, 'longitude': -89.0166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54929', 'place_name': 'Clintonville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.6364, 'longitude': -88.743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54933', 'place_name': 'Embarrass', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.6686, 'longitude': -88.7043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54940', 'place_name': 'Fremont', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.2379, 'longitude': -88.8449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54945', 'place_name': 'Iola', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.5322, 'longitude': -89.1373, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54946', 'place_name': 'King', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.3365, 'longitude': -89.1463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54949', 'place_name': 'Manawa', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.4701, 'longitude': -88.9164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54950', 'place_name': 'Marion', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.6794, 'longitude': -88.8767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54961', 'place_name': 'New London', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.3928, 'longitude': -88.7554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54962', 'place_name': 'Ogdensburg', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.4268, 'longitude': -88.9932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54969', 'place_name': 'Readfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.27, 'longitude': -88.7755, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54977', 'place_name': 'Scandinavia', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.4604, 'longitude': -89.165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54981', 'place_name': 'Waupaca', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.3481, 'longitude': -89.1101, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54983', 'place_name': 'Weyauwega', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.321, 'longitude': -88.941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54990', 'place_name': 'Iola', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waupaca', 'locality_code': '135', 'latitude': 44.508, 'longitude': -89.1307, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54930', 'place_name': 'Coloma', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.0275, 'longitude': -89.4943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54943', 'place_name': 'Hancock', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.1297, 'longitude': -89.5344, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54965', 'place_name': 'Pine River', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.1604, 'longitude': -89.0404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54966', 'place_name': 'Plainfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.2091, 'longitude': -89.4559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54967', 'place_name': 'Poy Sippi', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.131, 'longitude': -88.9836, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54970', 'place_name': 'Redgranite', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.0438, 'longitude': -89.0981, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54976', 'place_name': 'Saxeville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.1761, 'longitude': -89.1146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54982', 'place_name': 'Wautoma', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.0656, 'longitude': -89.2666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54984', 'place_name': 'Wild Rose', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Waushara', 'locality_code': '137', 'latitude': 44.1834, 'longitude': -89.1953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54901', 'place_name': 'Oshkosh', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.022, 'longitude': -88.5436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54902', 'place_name': 'Oshkosh', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 43.9946, 'longitude': -88.526, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54903', 'place_name': 'Oshkosh', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.0686, 'longitude': -88.6449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54904', 'place_name': 'Oshkosh', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.0304, 'longitude': -88.607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54906', 'place_name': 'Oshkosh', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.0686, 'longitude': -88.6449, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54927', 'place_name': 'Butte Des Morts', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.1031, 'longitude': -88.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54934', 'place_name': 'Eureka', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.0032, 'longitude': -88.8397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54947', 'place_name': 'Larsen', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.1984, 'longitude': -88.6963, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54952', 'place_name': 'Menasha', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.2112, 'longitude': -88.4175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54956', 'place_name': 'Neenah', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.1811, 'longitude': -88.4792, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54957', 'place_name': 'Neenah', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.1858, 'longitude': -88.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54963', 'place_name': 'Omro', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.0357, 'longitude': -88.7519, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54964', 'place_name': 'Pickett', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 43.9009, 'longitude': -88.7135, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54980', 'place_name': 'Waukau', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 43.9886, 'longitude': -88.7712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54985', 'place_name': 'Winnebago', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.0706, 'longitude': -88.5178, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54986', 'place_name': 'Winneconne', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Winnebago', 'locality_code': '139', 'latitude': 44.1187, 'longitude': -88.7214, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54404', 'place_name': 'Marshfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.6689, 'longitude': -90.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54410', 'place_name': 'Arpin', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.5419, 'longitude': -90.037, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54412', 'place_name': 'Auburndale', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.6378, 'longitude': -90.0136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54413', 'place_name': 'Babcock', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.3031, 'longitude': -90.0986, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54415', 'place_name': 'Blenker', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.6191, 'longitude': -89.9186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54441', 'place_name': 'Hewitt', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.6437, 'longitude': -90.1031, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54449', 'place_name': 'Marshfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.6615, 'longitude': -90.1784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54454', 'place_name': 'Milladore', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.6044, 'longitude': -89.8875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54457', 'place_name': 'Nekoosa', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.282, 'longitude': -89.8814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54466', 'place_name': 'Pittsville', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.4375, 'longitude': -90.1892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54469', 'place_name': 'Port Edwards', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.3497, 'longitude': -89.8652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54472', 'place_name': 'Marshfield', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.6689, 'longitude': -90.1718, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54475', 'place_name': 'Rudolph', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.4741, 'longitude': -89.8003, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54489', 'place_name': 'Vesper', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.4677, 'longitude': -89.9826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54494', 'place_name': 'Wisconsin Rapids', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.3758, 'longitude': -89.8062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '54495', 'place_name': 'Wisconsin Rapids', 'state': 'Wisconsin', 'state_ab': 'WI', 'county': 'Wood', 'locality_code': '141', 'latitude': 44.3881, 'longitude': -89.9228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26238', 'place_name': 'Volga', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Barbour', 'locality_code': '1', 'latitude': 39.0784, 'longitude': -80.1354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26250', 'place_name': 'Belington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Barbour', 'locality_code': '1', 'latitude': 39.0244, 'longitude': -79.9495, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26275', 'place_name': 'Junior', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Barbour', 'locality_code': '1', 'latitude': 38.9784, 'longitude': -79.9494, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26349', 'place_name': 'Galloway', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Barbour', 'locality_code': '1', 'latitude': 39.2318, 'longitude': -80.122, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26405', 'place_name': 'Moatsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Barbour', 'locality_code': '1', 'latitude': 39.2234, 'longitude': -79.9017, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26416', 'place_name': 'Philippi', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Barbour', 'locality_code': '1', 'latitude': 39.1613, 'longitude': -80.0492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25401', 'place_name': 'Martinsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.4567, 'longitude': -77.9727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25402', 'place_name': 'Martinsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.4562, 'longitude': -77.9639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25403', 'place_name': 'Martinsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.5227, 'longitude': -77.9747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25404', 'place_name': 'Martinsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.4852, 'longitude': -77.8954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25405', 'place_name': 'Martinsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.4092, 'longitude': -77.9615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25413', 'place_name': 'Bunker Hill', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.3276, 'longitude': -78.0487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25419', 'place_name': 'Falling Waters', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.5865, 'longitude': -77.8852, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25420', 'place_name': 'Gerrardstown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.378, 'longitude': -78.1141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25421', 'place_name': 'Glengary', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.3813, 'longitude': -78.1435, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25427', 'place_name': 'Hedgesville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.5214, 'longitude': -78.0912, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25428', 'place_name': 'Inwood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.3701, 'longitude': -78.0242, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25440', 'place_name': 'Ridgeway', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Berkeley', 'locality_code': '3', 'latitude': 39.2973, 'longitude': -78.0717, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25009', 'place_name': 'Ashford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.1823, 'longitude': -81.7113, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25021', 'place_name': 'Bim', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9218, 'longitude': -81.6893, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25024', 'place_name': 'Bloomingrose', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.1412, 'longitude': -81.6367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25028', 'place_name': 'Bob White', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9543, 'longitude': -81.7185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25049', 'place_name': 'Comfort', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.1372, 'longitude': -81.5962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25051', 'place_name': 'Costa', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.1591, 'longitude': -81.7092, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25053', 'place_name': 'Danville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0809, 'longitude': -81.834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25081', 'place_name': 'Foster', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0908, 'longitude': -81.7659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25093', 'place_name': 'Gordon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.987, 'longitude': -81.6954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25108', 'place_name': 'Hewett', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9581, 'longitude': -81.8509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25114', 'place_name': 'Jeffrey', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9715, 'longitude': -81.8215, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25130', 'place_name': 'Madison', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0444, 'longitude': -81.7938, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25142', 'place_name': 'Nellis', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.153, 'longitude': -81.7321, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25148', 'place_name': 'Orgas', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0492, 'longitude': -81.5688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25149', 'place_name': 'Ottawa', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9587, 'longitude': -81.8165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25154', 'place_name': 'Peytona', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.125, 'longitude': -81.7018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25165', 'place_name': 'Racine', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.141, 'longitude': -81.6588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25169', 'place_name': 'Ridgeview', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.1486, 'longitude': -81.7725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25181', 'place_name': 'Seth', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0971, 'longitude': -81.6393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25193', 'place_name': 'Sylvester', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0091, 'longitude': -81.5492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25203', 'place_name': 'Turtle Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0298, 'longitude': -81.8729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25204', 'place_name': 'Twilight', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.926, 'longitude': -81.6141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25205', 'place_name': 'Uneeda', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.0357, 'longitude': -81.7807, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25206', 'place_name': 'Van', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9712, 'longitude': -81.7022, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25208', 'place_name': 'Wharton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9034, 'longitude': -81.6773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25209', 'place_name': 'Whitesville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 37.9916, 'longitude': -81.5422, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25529', 'place_name': 'Julian', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Boone', 'locality_code': '5', 'latitude': 38.1264, 'longitude': -81.8642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26335', 'place_name': 'Burnsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.7775, 'longitude': -80.657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26601', 'place_name': 'Sutton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.6541, 'longitude': -80.676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26615', 'place_name': 'Copen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.8376, 'longitude': -80.7295, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26619', 'place_name': 'Exchange', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.7358, 'longitude': -80.7324, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '26621', 'place_name': 'Flatwoods', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.7232, 'longitude': -80.6498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26623', 'place_name': 'Frametown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.6305, 'longitude': -80.8589, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26624', 'place_name': 'Gassaway', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.6862, 'longitude': -80.7863, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26627', 'place_name': 'Heaters', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.7621, 'longitude': -80.6406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26629', 'place_name': 'Little Birch', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.579, 'longitude': -80.7068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26631', 'place_name': 'Napier', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Braxton', 'locality_code': '7', 'latitude': 38.7909, 'longitude': -80.5887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26030', 'place_name': 'Beech Bottom', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Brooke', 'locality_code': '9', 'latitude': 40.2259, 'longitude': -80.6513, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26032', 'place_name': 'Bethany', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Brooke', 'locality_code': '9', 'latitude': 40.2107, 'longitude': -80.5503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26035', 'place_name': 'Colliers', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Brooke', 'locality_code': '9', 'latitude': 40.3484, 'longitude': -80.5493, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26037', 'place_name': 'Follansbee', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Brooke', 'locality_code': '9', 'latitude': 40.3296, 'longitude': -80.585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26058', 'place_name': 'Short Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Brooke', 'locality_code': '9', 'latitude': 40.1856, 'longitude': -80.6745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26070', 'place_name': 'Wellsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Brooke', 'locality_code': '9', 'latitude': 40.2548, 'longitude': -80.5961, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26075', 'place_name': 'Windsor Heights', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Brooke', 'locality_code': '9', 'latitude': 40.1927, 'longitude': -80.6659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25504', 'place_name': 'Barboursville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.3893, 'longitude': -82.296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25510', 'place_name': 'Culloden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4198, 'longitude': -82.069, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25537', 'place_name': 'Lesage', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.477, 'longitude': -82.2957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25541', 'place_name': 'Milton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.414, 'longitude': -82.1458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25545', 'place_name': 'Ona', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4529, 'longitude': -82.2181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25559', 'place_name': 'Salt Rock', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.3265, 'longitude': -82.247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25701', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4097, 'longitude': -82.4423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25702', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4286, 'longitude': -82.3911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25703', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4211, 'longitude': -82.4227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25704', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.3849, 'longitude': -82.5036, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25705', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4096, 'longitude': -82.369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25706', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25707', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25708', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25710', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25711', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25712', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25713', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25714', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25715', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25716', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25717', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25718', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25719', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25720', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25721', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25722', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25723', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25724', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25725', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25726', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25727', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25728', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25729', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25755', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4221, 'longitude': -82.4317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25770', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25771', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25772', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25773', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25774', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25775', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25776', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25777', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25778', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25779', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Cabell', 'locality_code': '11', 'latitude': 38.4134, 'longitude': -82.2774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25234', 'place_name': 'Arnoldsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.8227, 'longitude': -81.1551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25235', 'place_name': 'Chloe', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.6686, 'longitude': -81.0944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25261', 'place_name': 'Millstone', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.8015, 'longitude': -81.0962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25268', 'place_name': 'Orma', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.7481, 'longitude': -81.0998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26136', 'place_name': 'Big Bend', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.9719, 'longitude': -81.136, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '26137', 'place_name': 'Big Springs', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.9854, 'longitude': -81.0721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26147', 'place_name': 'Grantsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.9324, 'longitude': -81.0763, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26151', 'place_name': 'Mount Zion', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Calhoun', 'locality_code': '13', 'latitude': 38.8286, 'longitude': -81.1322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25019', 'place_name': 'Bickmore', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.3729, 'longitude': -81.0868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25030', 'place_name': 'Bomont', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.4498, 'longitude': -81.2323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25043', 'place_name': 'Clay', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.4764, 'longitude': -81.0696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25063', 'place_name': 'Duck', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.5647, 'longitude': -80.9764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25088', 'place_name': 'Glen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.3943, 'longitude': -81.2426, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25111', 'place_name': 'Indore', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.3498, 'longitude': -81.1269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25113', 'place_name': 'Ivydale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.5357, 'longitude': -81.0348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25125', 'place_name': 'Lizemores', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.3366, 'longitude': -81.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25133', 'place_name': 'Maysel', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.4939, 'longitude': -81.1227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25141', 'place_name': 'Nebo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.6271, 'longitude': -81.0257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25164', 'place_name': 'Procious', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.4912, 'longitude': -81.1989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25211', 'place_name': 'Widen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.4662, 'longitude': -80.8573, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25285', 'place_name': 'Wallback', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.5432, 'longitude': -81.1114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26617', 'place_name': 'Dille', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Clay', 'locality_code': '15', 'latitude': 38.489, 'longitude': -80.8257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26339', 'place_name': 'Center Point', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Doddridge', 'locality_code': '17', 'latitude': 39.4125, 'longitude': -80.6352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26411', 'place_name': 'New Milton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Doddridge', 'locality_code': '17', 'latitude': 39.1899, 'longitude': -80.7076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26436', 'place_name': 'Smithburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Doddridge', 'locality_code': '17', 'latitude': 39.2893, 'longitude': -80.7343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26456', 'place_name': 'West Union', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Doddridge', 'locality_code': '17', 'latitude': 39.2762, 'longitude': -80.7911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25002', 'place_name': 'Alloy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1376, 'longitude': -81.2743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25031', 'place_name': 'Boomer', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1519, 'longitude': -81.2656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25036', 'place_name': 'Cannelton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1943, 'longitude': -81.2959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25040', 'place_name': 'Charlton Heights', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1237, 'longitude': -81.234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25057', 'place_name': 'Deep Water', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1268, 'longitude': -81.2637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25085', 'place_name': 'Gauley Bridge', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1689, 'longitude': -81.196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25090', 'place_name': 'Glen Ferris', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1532, 'longitude': -81.2148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25115', 'place_name': 'Kanawha Falls', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1426, 'longitude': -81.2065, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25118', 'place_name': 'Kimberly', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1249, 'longitude': -81.3217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25119', 'place_name': 'Kincaid', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0407, 'longitude': -81.2701, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25136', 'place_name': 'Montgomery', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1725, 'longitude': -81.3222, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25139', 'place_name': 'Mount Carbon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1399, 'longitude': -81.2931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25152', 'place_name': 'Page', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0529, 'longitude': -81.2698, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25161', 'place_name': 'Powellton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.099, 'longitude': -81.324, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25173', 'place_name': 'Robson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0973, 'longitude': -81.2488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25185', 'place_name': 'Mount Olive', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.2379, 'longitude': -81.2334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25186', 'place_name': 'Smithers', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1812, 'longitude': -81.3071, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25812', 'place_name': 'Ansted', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1369, 'longitude': -81.0955, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25831', 'place_name': 'Danese', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.9567, 'longitude': -80.9379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25833', 'place_name': 'Dothan', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0413, 'longitude': -81.0648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25837', 'place_name': 'Edmond', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0544, 'longitude': -81.0326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25840', 'place_name': 'Fayetteville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.064, 'longitude': -81.0943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25846', 'place_name': 'Glen Jean', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.9265, 'longitude': -81.1501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25854', 'place_name': 'Hico', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1094, 'longitude': -80.9638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25855', 'place_name': 'Hilltop', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.9429, 'longitude': -81.1509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25862', 'place_name': 'Lansing', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0869, 'longitude': -81.0588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25864', 'place_name': 'Layland', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.8893, 'longitude': -80.9712, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25866', 'place_name': 'Lochgelly', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0107, 'longitude': -81.1451, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25868', 'place_name': 'Lookout', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0654, 'longitude': -80.9684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25879', 'place_name': 'Minden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.9758, 'longitude': -81.115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25880', 'place_name': 'Mount Hope', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.8782, 'longitude': -81.2058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25888', 'place_name': 'Mount Hope', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.893, 'longitude': -81.1668, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25901', 'place_name': 'Oak Hill', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.9723, 'longitude': -81.1487, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25904', 'place_name': 'Pax', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.911, 'longitude': -81.2648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25907', 'place_name': 'Prince', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.8532, 'longitude': -81.0817, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25917', 'place_name': 'Scarbro', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.9488, 'longitude': -81.1531, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25936', 'place_name': 'Thurmond', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.9554, 'longitude': -81.0714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25938', 'place_name': 'Victor', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1402, 'longitude': -81.0322, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25942', 'place_name': 'Winona', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.0465, 'longitude': -80.9923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25976', 'place_name': 'Meadow Bridge', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.878, 'longitude': -80.8521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25986', 'place_name': 'Spring Dale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 37.8798, 'longitude': -80.8034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26680', 'place_name': 'Nallen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Fayette', 'locality_code': '19', 'latitude': 38.1107, 'longitude': -80.877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25267', 'place_name': 'Normantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 38.8802, 'longitude': -80.9419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26342', 'place_name': 'Coxs Mills', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 39.0301, 'longitude': -80.8498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26351', 'place_name': 'Glenville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 38.9409, 'longitude': -80.8313, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26384', 'place_name': 'Linn', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 38.9573, 'longitude': -80.73, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26430', 'place_name': 'Sand Fork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 38.914, 'longitude': -80.7498, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26443', 'place_name': 'Troy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 39.0839, 'longitude': -80.7549, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26611', 'place_name': 'Cedarville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 38.8451, 'longitude': -80.8323, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26636', 'place_name': 'Rosedale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 38.7393, 'longitude': -80.9429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26638', 'place_name': 'Shock', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Gilmer', 'locality_code': '21', 'latitude': 38.7617, 'longitude': -81.0045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26707', 'place_name': 'Bayard', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Grant', 'locality_code': '23', 'latitude': 39.2729, 'longitude': -79.3645, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26720', 'place_name': 'Gormania', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Grant', 'locality_code': '23', 'latitude': 39.2803, 'longitude': -79.3296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26731', 'place_name': 'Lahmansville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Grant', 'locality_code': '23', 'latitude': 39.1642, 'longitude': -79.0433, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26739', 'place_name': 'Mount Storm', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Grant', 'locality_code': '23', 'latitude': 39.2652, 'longitude': -79.2255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26833', 'place_name': 'Maysville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Grant', 'locality_code': '23', 'latitude': 39.0712, 'longitude': -79.1937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26847', 'place_name': 'Petersburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Grant', 'locality_code': '23', 'latitude': 38.9908, 'longitude': -79.1293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26855', 'place_name': 'Cabins', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Grant', 'locality_code': '23', 'latitude': 38.9512, 'longitude': -79.2783, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24901', 'place_name': 'Lewisburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.8083, 'longitude': -80.4407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24902', 'place_name': 'Fairlea', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.7747, 'longitude': -80.4615, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24910', 'place_name': 'Alderson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.7371, 'longitude': -80.661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24916', 'place_name': 'Asbury', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.8313, 'longitude': -80.5747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24925', 'place_name': 'Caldwell', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.7807, 'longitude': -80.394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24931', 'place_name': 'Crawley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.9397, 'longitude': -80.6309, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24938', 'place_name': 'Frankford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.9154, 'longitude': -80.3353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24943', 'place_name': 'Grassy Meadows', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.8268, 'longitude': -80.7209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24957', 'place_name': 'Maxwelton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.8765, 'longitude': -80.4192, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24966', 'place_name': 'Renick', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.9922, 'longitude': -80.3653, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '24970', 'place_name': 'Ronceverte', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.7418, 'longitude': -80.4626, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24977', 'place_name': 'Smoot', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.8772, 'longitude': -80.668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24986', 'place_name': 'White Sulphur Springs', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.7827, 'longitude': -80.3129, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24991', 'place_name': 'Williamsburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.9701, 'longitude': -80.4923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25958', 'place_name': 'Charmco', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 38.0023, 'longitude': -80.737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25962', 'place_name': 'Rainelle', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.9661, 'longitude': -80.7821, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25972', 'place_name': 'Leslie', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 38.0446, 'longitude': -80.7229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25981', 'place_name': 'Quinwood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 38.0576, 'longitude': -80.7068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25984', 'place_name': 'Rupert', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Greenbrier', 'locality_code': '25', 'latitude': 37.9685, 'longitude': -80.6696, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25431', 'place_name': 'Levels', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.4976, 'longitude': -78.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25437', 'place_name': 'Points', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.4401, 'longitude': -78.6103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25444', 'place_name': 'Slanesville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.3732, 'longitude': -78.5228, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26704', 'place_name': 'Augusta', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.2998, 'longitude': -78.5931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26711', 'place_name': 'Capon Bridge', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.2802, 'longitude': -78.4644, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26714', 'place_name': 'Delray', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.1945, 'longitude': -78.6042, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26722', 'place_name': 'Green Spring', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.5029, 'longitude': -78.6272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26755', 'place_name': 'Rio', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.1847, 'longitude': -78.727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26757', 'place_name': 'Romney', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.3424, 'longitude': -78.7481, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26761', 'place_name': 'Shanks', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.2849, 'longitude': -78.6995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26763', 'place_name': 'Springfield', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.463, 'longitude': -78.695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26808', 'place_name': 'High View', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.2225, 'longitude': -78.4425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26817', 'place_name': 'Bloomery', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.3604, 'longitude': -78.3917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26823', 'place_name': 'Capon Springs', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.1362, 'longitude': -78.4845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26852', 'place_name': 'Purgitsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.2681, 'longitude': -78.906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26865', 'place_name': 'Yellow Spring', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hampshire', 'locality_code': '27', 'latitude': 39.1823, 'longitude': -78.5095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26034', 'place_name': 'Chester', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hancock', 'locality_code': '29', 'latitude': 40.5981, 'longitude': -80.5584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26047', 'place_name': 'New Cumberland', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hancock', 'locality_code': '29', 'latitude': 40.5228, 'longitude': -80.5901, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26050', 'place_name': 'Newell', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hancock', 'locality_code': '29', 'latitude': 40.614, 'longitude': -80.6011, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26056', 'place_name': 'New Manchester', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hancock', 'locality_code': '29', 'latitude': 40.5315, 'longitude': -80.5801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26062', 'place_name': 'Weirton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hancock', 'locality_code': '29', 'latitude': 40.4137, 'longitude': -80.5683, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26801', 'place_name': 'Baker', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 39.0656, 'longitude': -78.7748, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26810', 'place_name': 'Lost City', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 38.9812, 'longitude': -78.7448, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26812', 'place_name': 'Mathias', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 38.8744, 'longitude': -78.8814, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26818', 'place_name': 'Fisher', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 39.075, 'longitude': -79.0342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26836', 'place_name': 'Moorefield', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 38.9907, 'longitude': -78.9745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26838', 'place_name': 'Milam', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 38.8125, 'longitude': -79.0729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26845', 'place_name': 'Old Fields', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 39.1502, 'longitude': -78.9509, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26851', 'place_name': 'Wardensville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Hardy', 'locality_code': '31', 'latitude': 39.0562, 'longitude': -78.6175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26301', 'place_name': 'Clarksburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2874, 'longitude': -80.3419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26302', 'place_name': 'Clarksburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2677, 'longitude': -80.3077, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26306', 'place_name': 'Clarksburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2852, 'longitude': -80.3853, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26323', 'place_name': 'Anmoore', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2587, 'longitude': -80.2875, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26330', 'place_name': 'Bridgeport', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2954, 'longitude': -80.2427, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26361', 'place_name': 'Gypsy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.3687, 'longitude': -80.3179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26366', 'place_name': 'Haywood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.3812, 'longitude': -80.3359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26369', 'place_name': 'Hepzibah', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.3312, 'longitude': -80.3325, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26385', 'place_name': 'Lost Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.1725, 'longitude': -80.3777, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26386', 'place_name': 'Lumberport', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.3781, 'longitude': -80.3676, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26404', 'place_name': 'Meadowbrook', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.3518, 'longitude': -80.3187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26408', 'place_name': 'Mount Clare', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2107, 'longitude': -80.2899, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26422', 'place_name': 'Reynoldsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2884, 'longitude': -80.4348, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26426', 'place_name': 'Salem', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.2829, 'longitude': -80.559, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26431', 'place_name': 'Shinnston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.3888, 'longitude': -80.2834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26438', 'place_name': 'Spelter', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.3465, 'longitude': -80.3206, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26448', 'place_name': 'Wallace', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.4117, 'longitude': -80.4865, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26451', 'place_name': 'West Milford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.1996, 'longitude': -80.4026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26463', 'place_name': 'Wyatt', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.4351, 'longitude': -80.3534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26568', 'place_name': 'Enterprise', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Harrison', 'locality_code': '33', 'latitude': 39.4209, 'longitude': -80.2779, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25231', 'place_name': 'Advent', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.6104, 'longitude': -81.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25239', 'place_name': 'Cottageville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.8633, 'longitude': -81.8186, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25241', 'place_name': 'Evans', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.8113, 'longitude': -81.7909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25244', 'place_name': 'Gay', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.7706, 'longitude': -81.5532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25245', 'place_name': 'Given', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.707, 'longitude': -81.7223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25248', 'place_name': 'Kenna', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.6232, 'longitude': -81.6217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25252', 'place_name': 'Le Roy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.8888, 'longitude': -81.5326, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25262', 'place_name': 'Millwood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.8962, 'longitude': -81.8248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25264', 'place_name': 'Mount Alto', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.8639, 'longitude': -81.8784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25271', 'place_name': 'Ripley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.809, 'longitude': -81.702, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25275', 'place_name': 'Sandyville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.9093, 'longitude': -81.6543, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26164', 'place_name': 'Ravenswood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jackson', 'locality_code': '35', 'latitude': 38.9468, 'longitude': -81.7524, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25410', 'place_name': 'Bakerton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.3159, 'longitude': -77.8772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25414', 'place_name': 'Charles Town', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.2771, 'longitude': -77.8563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25423', 'place_name': 'Halltown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.314, 'longitude': -77.7978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25425', 'place_name': 'Harpers Ferry', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.3153, 'longitude': -77.7694, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25430', 'place_name': 'Kearneysville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.322, 'longitude': -77.9588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25432', 'place_name': 'Millville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.294, 'longitude': -77.7858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25438', 'place_name': 'Ranson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.2995, 'longitude': -77.8606, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25441', 'place_name': 'Rippon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.3159, 'longitude': -77.8772, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25442', 'place_name': 'Shenandoah Junction', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.3716, 'longitude': -77.8229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25443', 'place_name': 'Shepherdstown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.4311, 'longitude': -77.8158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25446', 'place_name': 'Summit Point', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Jefferson', 'locality_code': '37', 'latitude': 39.2338, 'longitude': -77.9586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25003', 'place_name': 'Alum Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2868, 'longitude': -81.8051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25015', 'place_name': 'Belle', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2324, 'longitude': -81.5024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25025', 'place_name': 'Blount', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3121, 'longitude': -81.4052, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25026', 'place_name': 'Blue Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4908, 'longitude': -81.3928, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25035', 'place_name': 'Cabin Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.193, 'longitude': -81.4984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25039', 'place_name': 'Cedar Grove', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2212, 'longitude': -81.4279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25045', 'place_name': 'Clendenin', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4539, 'longitude': -81.3572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25054', 'place_name': 'Dawes', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.1429, 'longitude': -81.4521, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25061', 'place_name': 'Drybranch', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25064', 'place_name': 'Dunbar', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3683, 'longitude': -81.7425, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25067', 'place_name': 'East Bank', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2099, 'longitude': -81.4381, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25071', 'place_name': 'Elkview', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4429, 'longitude': -81.4804, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25075', 'place_name': 'Eskdale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.0505, 'longitude': -81.4227, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25079', 'place_name': 'Falling Rock', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4951, 'longitude': -81.3984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25083', 'place_name': 'Gallagher', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.0704, 'longitude': -81.3625, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25086', 'place_name': 'Glasgow', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2154, 'longitude': -81.4246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25102', 'place_name': 'Handley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.1879, 'longitude': -81.3657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25103', 'place_name': 'Hansford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.207, 'longitude': -81.3929, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25107', 'place_name': 'Hernshaw', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.1942, 'longitude': -81.613, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25110', 'place_name': 'Hugheston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2095, 'longitude': -81.3726, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25112', 'place_name': 'Institute', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3837, 'longitude': -81.7654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25126', 'place_name': 'London', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.196, 'longitude': -81.3714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25132', 'place_name': 'Mammoth', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2634, 'longitude': -81.3721, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25134', 'place_name': 'Miami', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.1523, 'longitude': -81.4479, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25143', 'place_name': 'Nitro', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4193, 'longitude': -81.8293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25156', 'place_name': 'Pinch', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.402, 'longitude': -81.4611, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25160', 'place_name': 'Pond Gap', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2904, 'longitude': -81.2866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25162', 'place_name': 'Pratt', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2101, 'longitude': -81.3851, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25177', 'place_name': 'Saint Albans', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3774, 'longitude': -81.8305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25201', 'place_name': 'Tad', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3334, 'longitude': -81.4943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25202', 'place_name': 'Tornado', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3357, 'longitude': -81.8476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25214', 'place_name': 'Winifrede', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.1852, 'longitude': -81.5587, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25301', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.349, 'longitude': -81.6306, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25302', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4015, 'longitude': -81.5841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25303', 'place_name': 'South Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3684, 'longitude': -81.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25304', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3173, 'longitude': -81.5903, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25305', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3358, 'longitude': -81.6123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25306', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3175, 'longitude': -81.5274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25309', 'place_name': 'South Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3684, 'longitude': -81.6996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25311', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.349, 'longitude': -81.5993, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25312', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4096, 'longitude': -81.6747, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25313', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.4142, 'longitude': -81.7582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25314', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3274, 'longitude': -81.669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25315', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2351, 'longitude': -81.5536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25317', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3356, 'longitude': -81.6138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25320', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.5428, 'longitude': -81.6334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25321', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25322', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25323', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25324', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25325', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25326', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25327', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25328', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25329', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25330', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25331', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25332', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25333', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25334', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25335', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25336', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25337', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25338', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25339', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25350', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25356', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25357', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25358', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25360', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25361', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25362', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25364', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25365', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.2968, 'longitude': -81.5547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25375', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25387', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25389', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.354, 'longitude': -81.6394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25392', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25396', 'place_name': 'Charleston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Kanawha', 'locality_code': '39', 'latitude': 38.3498, 'longitude': -81.6326, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26321', 'place_name': 'Alum Bridge', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 39.0425, 'longitude': -80.6882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26338', 'place_name': 'Camden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 39.0893, 'longitude': -80.5915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26343', 'place_name': 'Crawford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 38.872, 'longitude': -80.4368, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26372', 'place_name': 'Horner', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 38.9726, 'longitude': -80.3656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26376', 'place_name': 'Ireland', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 38.7763, 'longitude': -80.4567, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26378', 'place_name': 'Jane Lew', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 39.11, 'longitude': -80.4311, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26412', 'place_name': 'Orlando', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 38.8712, 'longitude': -80.5937, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26447', 'place_name': 'Walkersville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 38.8507, 'longitude': -80.4802, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26452', 'place_name': 'Weston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lewis', 'locality_code': '41', 'latitude': 39.0411, 'longitude': -80.4737, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25501', 'place_name': 'Alkol', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.1609, 'longitude': -81.984, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25506', 'place_name': 'Branchland', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2694, 'longitude': -82.2684, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25521', 'place_name': 'Griffithsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2197, 'longitude': -81.9995, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25523', 'place_name': 'Hamlin', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2896, 'longitude': -82.1047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25524', 'place_name': 'Harts', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.0341, 'longitude': -82.1008, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25540', 'place_name': 'Midkiff', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.1762, 'longitude': -82.1788, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25544', 'place_name': 'Myra', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2198, 'longitude': -82.1351, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25557', 'place_name': 'Ranger', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.097, 'longitude': -82.1633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25564', 'place_name': 'Sod', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2559, 'longitude': -81.891, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25565', 'place_name': 'Spurlockville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.1057, 'longitude': -82.0272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25567', 'place_name': 'Sumerco', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2312, 'longitude': -81.9115, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25571', 'place_name': 'West Hamlin', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2886, 'longitude': -82.1843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25572', 'place_name': 'Woodville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.1615, 'longitude': -81.8921, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25573', 'place_name': 'Yawkey', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Lincoln', 'locality_code': '43', 'latitude': 38.2193, 'longitude': -81.9568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25022', 'place_name': 'Blair', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8784, 'longitude': -81.8279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25047', 'place_name': 'Clothier', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.9468, 'longitude': -81.8104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25076', 'place_name': 'Ethel', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8665, 'longitude': -81.9123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25121', 'place_name': 'Lake', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.9204, 'longitude': -81.9034, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25183', 'place_name': 'Sharples', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.9204, 'longitude': -81.8293, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25505', 'place_name': 'Big Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 38.0043, 'longitude': -82.0401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25508', 'place_name': 'Chapmanville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.9737, 'longitude': -82.0174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25547', 'place_name': 'Pecks Mill', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.9298, 'longitude': -81.9654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25601', 'place_name': 'Logan', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8487, 'longitude': -81.9935, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25606', 'place_name': 'Accoville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7687, 'longitude': -81.8371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25607', 'place_name': 'Amherstdale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7959, 'longitude': -81.7833, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25611', 'place_name': 'Bruno', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.6907, 'longitude': -81.869, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25612', 'place_name': 'Chauncey', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7662, 'longitude': -81.9876, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25614', 'place_name': 'Cora', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8332, 'longitude': -81.9024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25617', 'place_name': 'Davin', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7265, 'longitude': -81.8057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25624', 'place_name': 'Henlawson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.9023, 'longitude': -81.9882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25625', 'place_name': 'Holden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.83, 'longitude': -82.0585, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25628', 'place_name': 'Kistler', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7562, 'longitude': -81.8601, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25630', 'place_name': 'Lorado', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7957, 'longitude': -81.7148, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25632', 'place_name': 'Lyburn', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7656, 'longitude': -81.9217, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25634', 'place_name': 'Mallory', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7307, 'longitude': -81.8379, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25635', 'place_name': 'Man', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7357, 'longitude': -81.8754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25637', 'place_name': 'Mount Gay', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8415, 'longitude': -82.0087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25638', 'place_name': 'Omar', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7557, 'longitude': -81.9996, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25639', 'place_name': 'Peach Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8752, 'longitude': -81.9826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25644', 'place_name': 'Sarah Ann', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7112, 'longitude': -81.9873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25646', 'place_name': 'Stollings', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8303, 'longitude': -81.9639, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25647', 'place_name': 'Switzer', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7846, 'longitude': -81.9908, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25649', 'place_name': 'Verdunville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8445, 'longitude': -82.0551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25652', 'place_name': 'Whitman', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8035, 'longitude': -82.0466, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25653', 'place_name': 'Wilkinson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.8279, 'longitude': -81.9976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25654', 'place_name': 'Yolyn', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Logan', 'locality_code': '45', 'latitude': 37.7818, 'longitude': -81.892, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24801', 'place_name': 'Welch', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4329, 'longitude': -81.5846, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24808', 'place_name': 'Anawalt', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3362, 'longitude': -81.4151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24811', 'place_name': 'Avondale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4126, 'longitude': -81.7843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24813', 'place_name': 'Bartley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3407, 'longitude': -81.7376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24815', 'place_name': 'Berwind', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.2687, 'longitude': -81.6668, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24816', 'place_name': 'Big Sandy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4643, 'longitude': -81.6982, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24817', 'place_name': 'Bradshaw', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3518, 'longitude': -81.7987, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24826', 'place_name': 'Cucumber', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.2779, 'longitude': -81.6268, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24828', 'place_name': 'Davy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4784, 'longitude': -81.6534, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24829', 'place_name': 'Eckman', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3752, 'longitude': -81.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24830', 'place_name': 'Elbert', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3354, 'longitude': -81.5393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24831', 'place_name': 'Elkhorn', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3857, 'longitude': -81.4109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24836', 'place_name': 'Gary', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3658, 'longitude': -81.5544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24843', 'place_name': 'Hensley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.474, 'longitude': -81.6998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24844', 'place_name': 'Iaeger', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4499, 'longitude': -81.812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24846', 'place_name': 'Isaban', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.5301, 'longitude': -81.8882, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24848', 'place_name': 'Jenkinjones', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.2937, 'longitude': -81.4259, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24850', 'place_name': 'Jolo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3324, 'longitude': -81.8316, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24853', 'place_name': 'Kimball', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4421, 'longitude': -81.512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24855', 'place_name': 'Kyle', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4082, 'longitude': -81.4257, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24861', 'place_name': 'Maybeury', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3709, 'longitude': -81.3665, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24862', 'place_name': 'Mohawk', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.5048, 'longitude': -81.9151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24866', 'place_name': 'Newhall', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.2637, 'longitude': -81.6187, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24868', 'place_name': 'Northfork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4194, 'longitude': -81.4058, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24871', 'place_name': 'Pageton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3493, 'longitude': -81.4654, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24872', 'place_name': 'Panther', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4834, 'longitude': -81.896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24873', 'place_name': 'Paynesville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3315, 'longitude': -81.8915, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24878', 'place_name': 'Premier', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4223, 'longitude': -81.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24879', 'place_name': 'Raysal', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3244, 'longitude': -81.7614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24881', 'place_name': 'Roderfield', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.4504, 'longitude': -81.7057, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24884', 'place_name': 'Squire', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.2384, 'longitude': -81.6098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24887', 'place_name': 'Switchback', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3712, 'longitude': -81.3857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24888', 'place_name': 'Thorpe', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3687, 'longitude': -81.5165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24892', 'place_name': 'War', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3012, 'longitude': -81.6909, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24894', 'place_name': 'Warriormine', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.2929, 'longitude': -81.6971, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24895', 'place_name': 'Wilcoe', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'McDowell', 'locality_code': '47', 'latitude': 37.3752, 'longitude': -81.6539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26554', 'place_name': 'Fairmont', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.4941, 'longitude': -80.2213, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26555', 'place_name': 'Fairmont', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.5143, 'longitude': -80.2185, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26559', 'place_name': 'Barrackville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.5052, 'longitude': -80.1725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26560', 'place_name': 'Baxter', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.544, 'longitude': -80.1423, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26563', 'place_name': 'Carolina', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.4782, 'longitude': -80.272, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26566', 'place_name': 'Colfax', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.4348, 'longitude': -80.1317, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26570', 'place_name': 'Fairview', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.6103, 'longitude': -80.2529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26571', 'place_name': 'Farmington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.5029, 'longitude': -80.2566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26572', 'place_name': 'Four States', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.4798, 'longitude': -80.3098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26574', 'place_name': 'Grant Town', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.5587, 'longitude': -80.1805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26576', 'place_name': 'Idamay', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.4877, 'longitude': -80.2666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26578', 'place_name': 'Kingmont', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.4466, 'longitude': -80.1762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26582', 'place_name': 'Mannington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.522, 'longitude': -80.3552, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26585', 'place_name': 'Metz', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.6078, 'longitude': -80.4168, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26586', 'place_name': 'Montana Mines', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.5191, 'longitude': -80.0897, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '26587', 'place_name': 'Rachel', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.5225, 'longitude': -80.2957, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26588', 'place_name': 'Rivesville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.5568, 'longitude': -80.1417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26591', 'place_name': 'Worthington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marion', 'locality_code': '49', 'latitude': 39.4522, 'longitude': -80.2905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26031', 'place_name': 'Benwood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 40.0181, 'longitude': -80.7342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26033', 'place_name': 'Cameron', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 39.8227, 'longitude': -80.5669, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26036', 'place_name': 'Dallas', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 39.9783, 'longitude': -80.5508, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26038', 'place_name': 'Glen Dale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 39.9597, 'longitude': -80.7323, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '26039', 'place_name': 'Glen Easton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 39.8531, 'longitude': -80.6661, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26040', 'place_name': 'Mcmechen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 39.9881, 'longitude': -80.7315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26041', 'place_name': 'Moundsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 39.9148, 'longitude': -80.731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26055', 'place_name': 'Proctor', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Marshall', 'locality_code': '51', 'latitude': 39.7207, 'longitude': -80.7618, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25106', 'place_name': 'Henderson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.8265, 'longitude': -82.1364, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25123', 'place_name': 'Leon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.7048, 'longitude': -81.9145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25187', 'place_name': 'Southside', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.712, 'longitude': -81.9966, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25247', 'place_name': 'Hartford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 39.004, 'longitude': -81.989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25253', 'place_name': 'Letart', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.9311, 'longitude': -81.9751, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25260', 'place_name': 'Mason', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 39.0064, 'longitude': -82.0282, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25265', 'place_name': 'New Haven', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.9863, 'longitude': -81.9652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25287', 'place_name': 'West Columbia', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.9574, 'longitude': -82.0517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25502', 'place_name': 'Apple Grove', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.6575, 'longitude': -82.1068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25503', 'place_name': 'Ashton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.6032, 'longitude': -82.1123, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25515', 'place_name': 'Gallipolis Ferry', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.765, 'longitude': -82.1535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25520', 'place_name': 'Glenwood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.5909, 'longitude': -82.1773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25550', 'place_name': 'Point Pleasant', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mason', 'locality_code': '53', 'latitude': 38.8632, 'longitude': -82.1132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24701', 'place_name': 'Bluefield', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.2698, 'longitude': -81.2223, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24712', 'place_name': 'Athens', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4323, 'longitude': -80.9974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24714', 'place_name': 'Beeson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4909, 'longitude': -81.2062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24715', 'place_name': 'Bramwell', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3321, 'longitude': -81.3256, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24724', 'place_name': 'Freeman', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3309, 'longitude': -81.2998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24729', 'place_name': 'Hiawatha', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4401, 'longitude': -81.244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24731', 'place_name': 'Kegley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3971, 'longitude': -81.1318, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24732', 'place_name': 'Kellysville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3448, 'longitude': -80.9279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24733', 'place_name': 'Lashmeet', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.442, 'longitude': -81.2138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24736', 'place_name': 'Matoaka', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4201, 'longitude': -81.2432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24737', 'place_name': 'Montcalm', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3539, 'longitude': -81.2518, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24738', 'place_name': 'Nemours', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3015, 'longitude': -81.3043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24739', 'place_name': 'Princeton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3662, 'longitude': -81.1026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24740', 'place_name': 'Princeton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3799, 'longitude': -81.1175, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24747', 'place_name': 'Rock', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4142, 'longitude': -81.1784, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24751', 'place_name': 'Wolfe', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.3073, 'longitude': -81.3287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25820', 'place_name': 'Camp Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4841, 'longitude': -81.1111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25841', 'place_name': 'Flat Top', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.55, 'longitude': -81.128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25922', 'place_name': 'Spanishburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4605, 'longitude': -81.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25971', 'place_name': 'Lerona', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mercer', 'locality_code': '55', 'latitude': 37.4925, 'longitude': -80.9796, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26710', 'place_name': 'Burlington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.3376, 'longitude': -78.9181, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26717', 'place_name': 'Elk Garden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.3631, 'longitude': -79.1539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26719', 'place_name': 'Fort Ashby', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.497, 'longitude': -78.7743, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26726', 'place_name': 'Keyser', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.4527, 'longitude': -78.8926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26743', 'place_name': 'New Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.3612, 'longitude': -79.0452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26750', 'place_name': 'Piedmont', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.4799, 'longitude': -79.0489, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26753', 'place_name': 'Ridgeley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.5636, 'longitude': -78.7887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26767', 'place_name': 'Wiley Ford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mineral', 'locality_code': '57', 'latitude': 39.6133, 'longitude': -78.775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24851', 'place_name': 'Justice', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.5887, 'longitude': -81.8354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25608', 'place_name': 'Baisden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.584, 'longitude': -81.9051, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25621', 'place_name': 'Gilbert', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6366, 'longitude': -81.9501, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25650', 'place_name': 'Verner', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6634, 'longitude': -81.8504, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25651', 'place_name': 'Wharncliffe', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.5554, 'longitude': -81.9657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25661', 'place_name': 'Williamson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6902, 'longitude': -82.2642, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25665', 'place_name': 'Borderland', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.7214, 'longitude': -82.3084, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25666', 'place_name': 'Breeden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.9198, 'longitude': -82.2547, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25667', 'place_name': 'Chattaroy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.7047, 'longitude': -82.2739, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25670', 'place_name': 'Delbarton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.7189, 'longitude': -82.1931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25671', 'place_name': 'Dingess', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.8703, 'longitude': -82.1951, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25672', 'place_name': 'Edgarton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.7431, 'longitude': -82.108, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25674', 'place_name': 'Kermit', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.8642, 'longitude': -82.3741, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25676', 'place_name': 'Lenore', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.799, 'longitude': -82.2868, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25678', 'place_name': 'Matewan', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.5903, 'longitude': -82.0652, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25685', 'place_name': 'Naugatuck', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.7898, 'longitude': -82.349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25686', 'place_name': 'Newtown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.7431, 'longitude': -82.108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25688', 'place_name': 'North Matewan', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6265, 'longitude': -82.1482, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25690', 'place_name': 'Ragland', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6898, 'longitude': -82.1244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25691', 'place_name': 'Rawl', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6498, 'longitude': -82.2196, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25692', 'place_name': 'Red Jacket', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6484, 'longitude': -82.1401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25696', 'place_name': 'Varney', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Mingo', 'locality_code': '59', 'latitude': 37.6693, 'longitude': -82.1221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26501', 'place_name': 'Morgantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6099, 'longitude': -79.9831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26502', 'place_name': 'Morgantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6253, 'longitude': -79.9672, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26504', 'place_name': 'Morgantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.5785, 'longitude': -80.093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26505', 'place_name': 'Morgantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6505, 'longitude': -79.944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26506', 'place_name': 'Morgantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6453, 'longitude': -79.9627, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26507', 'place_name': 'Morgantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6808, 'longitude': -79.8365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26508', 'place_name': 'Morgantown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.5953, 'longitude': -79.9229, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26521', 'place_name': 'Blacksville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.7142, 'longitude': -80.2265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26527', 'place_name': 'Cassville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6656, 'longitude': -80.0637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26531', 'place_name': 'Dellslow', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6053, 'longitude': -79.8958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26534', 'place_name': 'Granville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6459, 'longitude': -79.9873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26541', 'place_name': 'Maidsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6884, 'longitude': -79.9801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26543', 'place_name': 'Osage', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6587, 'longitude': -80.0076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26544', 'place_name': 'Pentress', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.5785, 'longitude': -80.093, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26546', 'place_name': 'Pursglove', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6746, 'longitude': -80.035, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26590', 'place_name': 'Wana', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monongalia', 'locality_code': '61', 'latitude': 39.6735, 'longitude': -80.3183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24918', 'place_name': 'Ballard', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.498, 'longitude': -80.7614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24941', 'place_name': 'Gap Mills', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.589, 'longitude': -80.3401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24945', 'place_name': 'Greenville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.5435, 'longitude': -80.6826, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24951', 'place_name': 'Lindside', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.4817, 'longitude': -80.6203, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24963', 'place_name': 'Peterstown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.4147, 'longitude': -80.7686, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24974', 'place_name': 'Secondcreek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.6654, 'longitude': -80.454, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24976', 'place_name': 'Sinks Grove', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.6643, 'longitude': -80.5409, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24983', 'place_name': 'Union', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.5802, 'longitude': -80.5248, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24984', 'place_name': 'Waiteville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.4645, 'longitude': -80.4634, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24985', 'place_name': 'Wayside', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.5937, 'longitude': -80.7458, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24993', 'place_name': 'Wolfcreek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Monroe', 'locality_code': '63', 'latitude': 37.552, 'longitude': -80.5397, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25411', 'place_name': 'Berkeley Springs', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Morgan', 'locality_code': '65', 'latitude': 39.5526, 'longitude': -78.1877, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25422', 'place_name': 'Great Cacapon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Morgan', 'locality_code': '65', 'latitude': 39.5836, 'longitude': -78.3331, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25434', 'place_name': 'Paw Paw', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Morgan', 'locality_code': '65', 'latitude': 39.4923, 'longitude': -78.4586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25059', 'place_name': 'Dixie', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.2509, 'longitude': -81.1932, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26202', 'place_name': 'Fenwick', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.2447, 'longitude': -80.635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26205', 'place_name': 'Craigsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.3254, 'longitude': -80.6444, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26261', 'place_name': 'Richwood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.223, 'longitude': -80.5445, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26610', 'place_name': 'Birch River', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.4914, 'longitude': -80.7459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26651', 'place_name': 'Summersville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.3009, 'longitude': -80.8353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26656', 'place_name': 'Belva', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.2491, 'longitude': -81.1566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26660', 'place_name': 'Calvin', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.3368, 'longitude': -80.7145, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26662', 'place_name': 'Canvas', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.2624, 'longitude': -80.7446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26667', 'place_name': 'Drennen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.3184, 'longitude': -80.8342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26671', 'place_name': 'Gilboa', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.3184, 'longitude': -80.8342, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26675', 'place_name': 'Keslers Cross Lanes', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.2354, 'longitude': -80.9357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26676', 'place_name': 'Leivasy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.1558, 'longitude': -80.6827, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26678', 'place_name': 'Mount Lookout', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.1821, 'longitude': -80.9108, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26679', 'place_name': 'Mount Nebo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.1653, 'longitude': -80.7976, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26681', 'place_name': 'Nettie', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.209, 'longitude': -80.6953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26684', 'place_name': 'Pool', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.1637, 'longitude': -80.8643, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26690', 'place_name': 'Swiss', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.2255, 'longitude': -81.1273, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26691', 'place_name': 'Tioga', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Nicholas', 'locality_code': '67', 'latitude': 38.4045, 'longitude': -80.6667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26003', 'place_name': 'Wheeling', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ohio', 'locality_code': '69', 'latitude': 40.1027, 'longitude': -80.6476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26059', 'place_name': 'Triadelphia', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ohio', 'locality_code': '69', 'latitude': 40.0699, 'longitude': -80.5953, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26060', 'place_name': 'Valley Grove', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ohio', 'locality_code': '69', 'latitude': 40.0946, 'longitude': -80.5551, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26074', 'place_name': 'West Liberty', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ohio', 'locality_code': '69', 'latitude': 40.1698, 'longitude': -80.5958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26802', 'place_name': 'Brandywine', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.6357, 'longitude': -79.2096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26804', 'place_name': 'Circleville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.623, 'longitude': -79.5367, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26807', 'place_name': 'Franklin', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.64, 'longitude': -79.3538, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26814', 'place_name': 'Riverton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.744, 'longitude': -79.4359, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26815', 'place_name': 'Sugar Grove', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.489, 'longitude': -79.3593, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26866', 'place_name': 'Upper Tract', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.795, 'longitude': -79.2586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26884', 'place_name': 'Seneca Rocks', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.8296, 'longitude': -79.3866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26886', 'place_name': 'Onego', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pendleton', 'locality_code': '71', 'latitude': 38.8017, 'longitude': -79.4507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26134', 'place_name': 'Belmont', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pleasants', 'locality_code': '73', 'latitude': 39.3795, 'longitude': -81.2584, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26170', 'place_name': 'Saint Marys', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pleasants', 'locality_code': '73', 'latitude': 39.386, 'longitude': -81.1725, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24915', 'place_name': 'Arbovale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.4546, 'longitude': -79.7934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24920', 'place_name': 'Bartow', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.5513, 'longitude': -79.7952, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24924', 'place_name': 'Buckeye', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.186, 'longitude': -80.1345, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24927', 'place_name': 'Cass', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.388, 'longitude': -79.9906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24934', 'place_name': 'Dunmore', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.3636, 'longitude': -79.8556, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24944', 'place_name': 'Green Bank', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.4097, 'longitude': -79.8015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24946', 'place_name': 'Hillsboro', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.1109, 'longitude': -80.2641, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24954', 'place_name': 'Marlinton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.2586, 'longitude': -80.1046, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26209', 'place_name': 'Snowshoe', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.4133, 'longitude': -80.0068, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26264', 'place_name': 'Durbin', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.5457, 'longitude': -79.8251, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26291', 'place_name': 'Slatyfork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Pocahontas', 'locality_code': '75', 'latitude': 38.388, 'longitude': -79.9906, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '26374', 'place_name': 'Independence', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.4464, 'longitude': -79.8822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26410', 'place_name': 'Newburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.4027, 'longitude': -79.828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26425', 'place_name': 'Rowlesburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.313, 'longitude': -79.7049, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26444', 'place_name': 'Tunnelton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.3625, 'longitude': -79.7478, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26519', 'place_name': 'Albright', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.5701, 'longitude': -79.6358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26520', 'place_name': 'Arthurdale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.4951, 'longitude': -79.8151, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26524', 'place_name': 'Bretz', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.5423, 'longitude': -79.8006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26525', 'place_name': 'Bruceton Mills', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.6454, 'longitude': -79.6159, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26537', 'place_name': 'Kingwood', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.4819, 'longitude': -79.7063, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26542', 'place_name': 'Masontown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.5731, 'longitude': -79.7906, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26547', 'place_name': 'Reedsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.5127, 'longitude': -79.812, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26705', 'place_name': 'Aurora', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.3181, 'longitude': -79.5764, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26716', 'place_name': 'Eglon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.2925, 'longitude': -79.5109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26764', 'place_name': 'Terra Alta', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Preston', 'locality_code': '77', 'latitude': 39.4456, 'longitude': -79.5464, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25011', 'place_name': 'Bancroft', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.5086, 'longitude': -81.841, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25033', 'place_name': 'Buffalo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.6092, 'longitude': -81.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25070', 'place_name': 'Eleanor', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.5436, 'longitude': -81.9414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25082', 'place_name': 'Fraziers Bottom', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.5517, 'longitude': -82.0111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25109', 'place_name': 'Hometown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.5329, 'longitude': -81.8612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25124', 'place_name': 'Liberty', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.62, 'longitude': -81.7678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25159', 'place_name': 'Poca', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.4791, 'longitude': -81.7838, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25168', 'place_name': 'Red House', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.5463, 'longitude': -81.9045, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25213', 'place_name': 'Winfield', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.5072, 'longitude': -81.89, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25526', 'place_name': 'Hurricane', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.4257, 'longitude': -81.9943, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25560', 'place_name': 'Scott Depot', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.4501, 'longitude': -81.9005, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25569', 'place_name': 'Teays', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Putnam', 'locality_code': '79', 'latitude': 38.4754, 'longitude': -81.8805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25007', 'place_name': 'Arnett', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8334, 'longitude': -81.4301, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25008', 'place_name': 'Artie', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.94, 'longitude': -81.3545, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25044', 'place_name': 'Clear Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.9162, 'longitude': -81.3443, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25048', 'place_name': 'Colcord', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.9439, 'longitude': -81.4369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25060', 'place_name': 'Dorothy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.9622, 'longitude': -81.4968, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25062', 'place_name': 'Dry Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8749, 'longitude': -81.4412, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25140', 'place_name': 'Naoma', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8676, 'longitude': -81.4873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25174', 'place_name': 'Rock Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8547, 'longitude': -81.4184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25180', 'place_name': 'Saxon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7901, 'longitude': -81.4346, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25801', 'place_name': 'Beckley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7932, 'longitude': -81.2061, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25802', 'place_name': 'Beckley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7489, 'longitude': -81.2245, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25813', 'place_name': 'Beaver', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7516, 'longitude': -81.0731, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25817', 'place_name': 'Bolt', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7673, 'longitude': -81.4156, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25818', 'place_name': 'Bradley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8654, 'longitude': -81.194, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25823', 'place_name': 'Coal City', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.679, 'longitude': -81.2104, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25825', 'place_name': 'Cool Ridge', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6655, 'longitude': -81.0933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25827', 'place_name': 'Crab Orchard', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7385, 'longitude': -81.2536, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25832', 'place_name': 'Daniels', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7256, 'longitude': -81.1087, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25836', 'place_name': 'Eccles', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7792, 'longitude': -81.2635, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25839', 'place_name': 'Fairdale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7815, 'longitude': -81.3632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25843', 'place_name': 'Ghent', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6208, 'longitude': -81.1019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25844', 'place_name': 'Glen Daniel', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8251, 'longitude': -81.3858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25849', 'place_name': 'Glen White', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7306, 'longitude': -81.2799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25851', 'place_name': 'Harper', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8025, 'longitude': -81.2828, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25853', 'place_name': 'Helen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6375, 'longitude': -81.3138, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25857', 'place_name': 'Josephine', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6221, 'longitude': -81.2176, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25860', 'place_name': 'Lanark', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8276, 'longitude': -81.1462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25865', 'place_name': 'Lester', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7265, 'longitude': -81.3095, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25871', 'place_name': 'Mabscott', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.77, 'longitude': -81.2103, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25873', 'place_name': 'Mac Arthur', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7517, 'longitude': -81.2148, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25878', 'place_name': 'Midway', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7171, 'longitude': -81.24, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25902', 'place_name': 'Odd', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.593, 'longitude': -81.1872, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25906', 'place_name': 'Piney View', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8376, 'longitude': -81.1286, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25908', 'place_name': 'Princewick', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6724, 'longitude': -81.2561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25909', 'place_name': 'Prosperity', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8381, 'longitude': -81.2004, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25911', 'place_name': 'Raleigh', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7585, 'longitude': -81.1675, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25915', 'place_name': 'Rhodell', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6254, 'longitude': -81.2749, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25918', 'place_name': 'Shady Spring', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7416, 'longitude': -81.0149, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25919', 'place_name': 'Skelton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8005, 'longitude': -81.1806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25920', 'place_name': 'Slab Fork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6871, 'longitude': -81.334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25921', 'place_name': 'Sophia', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7076, 'longitude': -81.2507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25927', 'place_name': 'Stanaford', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.8159, 'longitude': -81.1523, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25932', 'place_name': 'Surveyor', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.7565, 'longitude': -81.3092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25989', 'place_name': 'White Oak', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Raleigh', 'locality_code': '81', 'latitude': 37.6929, 'longitude': -81.0729, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26224', 'place_name': 'Helvetia', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.7713, 'longitude': -80.1382, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26230', 'place_name': 'Pickens', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.6551, 'longitude': -80.2117, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26241', 'place_name': 'Elkins', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.9253, 'longitude': -79.8471, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26253', 'place_name': 'Beverly', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.828, 'longitude': -79.8651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26254', 'place_name': 'Bowden', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.9087, 'longitude': -79.7098, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26257', 'place_name': 'Coalton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.9144, 'longitude': -79.9767, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26259', 'place_name': 'Dailey', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.7987, 'longitude': -79.8962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26263', 'place_name': 'Dryfork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.9489, 'longitude': -79.4376, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26267', 'place_name': 'Ellamore', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.9243, 'longitude': -80.0904, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26268', 'place_name': 'Glady', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.7534, 'longitude': -79.8147, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26270', 'place_name': 'Harman', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.9234, 'longitude': -79.5246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26273', 'place_name': 'Huttonsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.6784, 'longitude': -79.9775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26276', 'place_name': 'Kerens', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 39.0299, 'longitude': -79.7754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26278', 'place_name': 'Mabie', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.8765, 'longitude': -79.9831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26280', 'place_name': 'Mill Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.7325, 'longitude': -79.9786, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26282', 'place_name': 'Monterville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.5517, 'longitude': -80.1224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26283', 'place_name': 'Montrose', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 39.0964, 'longitude': -79.7896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26285', 'place_name': 'Norton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.9318, 'longitude': -79.9656, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26293', 'place_name': 'Valley Bend', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.7718, 'longitude': -79.9253, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26294', 'place_name': 'Valley Head', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.5315, 'longitude': -80.0343, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26296', 'place_name': 'Whitmer', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Randolph', 'locality_code': '83', 'latitude': 38.7516, 'longitude': -79.5819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26148', 'place_name': 'Macfarlan', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.0806, 'longitude': -81.1776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26161', 'place_name': 'Petroleum', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.1741, 'longitude': -81.2406, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26178', 'place_name': 'Smithville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.0671, 'longitude': -81.062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26325', 'place_name': 'Auburn', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.0864, 'longitude': -80.8837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26327', 'place_name': 'Berea', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.1365, 'longitude': -80.9337, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26337', 'place_name': 'Cairo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.2325, 'longitude': -81.1554, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26346', 'place_name': 'Ellenboro', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.2969, 'longitude': -81.0621, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26362', 'place_name': 'Harrisville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.1453, 'longitude': -81.0341, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26415', 'place_name': 'Pennsboro', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.2791, 'longitude': -81.0019, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26421', 'place_name': 'Pullman', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Ritchie', 'locality_code': '85', 'latitude': 39.19, 'longitude': -80.9347, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25005', 'place_name': 'Amma', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.5687, 'longitude': -81.2657, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25243', 'place_name': 'Gandeeville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.7034, 'longitude': -81.4243, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25251', 'place_name': 'Left Hand', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.6063, 'longitude': -81.2467, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25259', 'place_name': 'Looneyville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.6641, 'longitude': -81.2822, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25266', 'place_name': 'Newton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.606, 'longitude': -81.1623, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25270', 'place_name': 'Reedy', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.8889, 'longitude': -81.4399, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25276', 'place_name': 'Spencer', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.7897, 'longitude': -81.3303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25286', 'place_name': 'Walton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Roane', 'locality_code': '87', 'latitude': 38.6023, 'longitude': -81.3958, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24935', 'place_name': 'Forest Hill', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.5608, 'longitude': -80.8111, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24962', 'place_name': 'Pence Springs', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.6621, 'longitude': -80.7202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24981', 'place_name': 'Talcott', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.6491, 'longitude': -80.7461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25951', 'place_name': 'Hinton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.664, 'longitude': -80.8678, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25966', 'place_name': 'Green Sulphur Springs', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.6485, 'longitude': -80.8774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25969', 'place_name': 'Jumping Branch', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.6188, 'longitude': -81.0018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25977', 'place_name': 'Meadow Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.8101, 'longitude': -80.9231, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25978', 'place_name': 'Nimitz', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.6286, 'longitude': -80.9446, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25979', 'place_name': 'Pipestem', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.5303, 'longitude': -80.9463, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25985', 'place_name': 'Sandstone', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Summers', 'locality_code': '89', 'latitude': 37.7599, 'longitude': -80.8716, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26347', 'place_name': 'Flemington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Taylor', 'locality_code': '91', 'latitude': 39.2665, 'longitude': -80.132, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26354', 'place_name': 'Grafton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Taylor', 'locality_code': '91', 'latitude': 39.3414, 'longitude': -80.0285, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26424', 'place_name': 'Rosemont', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Taylor', 'locality_code': '91', 'latitude': 39.2687, 'longitude': -80.1629, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26435', 'place_name': 'Simpson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Taylor', 'locality_code': '91', 'latitude': 39.2668, 'longitude': -80.0934, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26440', 'place_name': 'Thornton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Taylor', 'locality_code': '91', 'latitude': 39.3329, 'longitude': -79.9096, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26260', 'place_name': 'Davis', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tucker', 'locality_code': '93', 'latitude': 39.0882, 'longitude': -79.4563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26269', 'place_name': 'Hambleton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tucker', 'locality_code': '93', 'latitude': 39.0821, 'longitude': -79.6453, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26271', 'place_name': 'Hendricks', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tucker', 'locality_code': '93', 'latitude': 39.0748, 'longitude': -79.6303, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26287', 'place_name': 'Parsons', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tucker', 'locality_code': '93', 'latitude': 39.096, 'longitude': -79.6787, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26289', 'place_name': 'Red Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tucker', 'locality_code': '93', 'latitude': 39.1179, 'longitude': -79.5637, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26292', 'place_name': 'Thomas', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tucker', 'locality_code': '93', 'latitude': 39.1505, 'longitude': -79.503, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26146', 'place_name': 'Friendly', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tyler', 'locality_code': '95', 'latitude': 39.4961, 'longitude': -81.0572, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26149', 'place_name': 'Middlebourne', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tyler', 'locality_code': '95', 'latitude': 39.4942, 'longitude': -80.9076, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26175', 'place_name': 'Sistersville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tyler', 'locality_code': '95', 'latitude': 39.5584, 'longitude': -80.9818, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26320', 'place_name': 'Alma', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tyler', 'locality_code': '95', 'latitude': 39.4506, 'longitude': -80.8701, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '26434', 'place_name': 'Shirley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Tyler', 'locality_code': '95', 'latitude': 39.3981, 'longitude': -80.7651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26201', 'place_name': 'Buckhannon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.9755, 'longitude': -80.2407, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26210', 'place_name': 'Adrian', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.8993, 'longitude': -80.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26215', 'place_name': 'Cleveland', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.7133, 'longitude': -80.388, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26218', 'place_name': 'French Creek', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.8993, 'longitude': -80.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26219', 'place_name': 'Frenchton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.8993, 'longitude': -80.2269, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26228', 'place_name': 'Kanawha Head', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.7618, 'longitude': -80.3727, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26229', 'place_name': 'Lorentz', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 39.0109, 'longitude': -80.3023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26234', 'place_name': 'Rock Cave', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.7811, 'longitude': -80.3163, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26236', 'place_name': 'Selbyville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.754, 'longitude': -80.2365, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26237', 'place_name': 'Tallmansville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Upshur', 'locality_code': '97', 'latitude': 38.8564, 'longitude': -80.158, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25507', 'place_name': 'Ceredo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.3965, 'longitude': -82.5588, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25511', 'place_name': 'Dunlow', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.0231, 'longitude': -82.4315, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25512', 'place_name': 'East Lynn', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.1995, 'longitude': -82.3279, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25514', 'place_name': 'Fort Gay', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.1335, 'longitude': -82.5541, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25517', 'place_name': 'Genoa', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.1321, 'longitude': -82.4183, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25530', 'place_name': 'Kenova', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.3569, 'longitude': -82.5255, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25534', 'place_name': 'Kiahsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.0915, 'longitude': -82.3274, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25535', 'place_name': 'Lavalette', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.3305, 'longitude': -82.4287, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25555', 'place_name': 'Prichard', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.23, 'longitude': -82.5753, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25562', 'place_name': 'Shoals', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.3432, 'longitude': -82.4905, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25570', 'place_name': 'Wayne', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.2258, 'longitude': -82.4339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25669', 'place_name': 'Crum', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 37.9389, 'longitude': -82.4624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25699', 'place_name': 'Wilsondale', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 37.9537, 'longitude': -82.3276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25709', 'place_name': 'Huntington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wayne', 'locality_code': '99', 'latitude': 38.4192, 'longitude': -82.4452, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26203', 'place_name': 'Erbacon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.5419, 'longitude': -80.5742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26206', 'place_name': 'Cowen', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.4133, 'longitude': -80.5358, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26208', 'place_name': 'Camden On Gauley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.3871, 'longitude': -80.5907, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26217', 'place_name': 'Diana', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.5755, 'longitude': -80.432, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26222', 'place_name': 'Hacker Valley', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.6526, 'longitude': -80.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26266', 'place_name': 'Upperglade', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.4185, 'longitude': -80.4965, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26288', 'place_name': 'Webster Springs', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.4832, 'longitude': -80.4476, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26298', 'place_name': 'Bergoo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Webster', 'locality_code': '101', 'latitude': 38.4865, 'longitude': -80.3006, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26155', 'place_name': 'New Martinsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.6588, 'longitude': -80.8565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26159', 'place_name': 'Paden City', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.6044, 'longitude': -80.9265, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26162', 'place_name': 'Porters Falls', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.5798, 'longitude': -80.7762, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26167', 'place_name': 'Reader', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.5836, 'longitude': -80.7516, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26348', 'place_name': 'Folsom', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.4693, 'longitude': -80.5258, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26377', 'place_name': 'Jacksonburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.5416, 'longitude': -80.6437, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26419', 'place_name': 'Pine Grove', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.5755, 'longitude': -80.6667, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26437', 'place_name': 'Smithfield', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.5134, 'longitude': -80.5582, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26561', 'place_name': 'Big Run', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.5845, 'longitude': -80.5776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26562', 'place_name': 'Burton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.6511, 'longitude': -80.4161, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26575', 'place_name': 'Hundred', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.6917, 'longitude': -80.4746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26581', 'place_name': 'Littleton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wetzel', 'locality_code': '103', 'latitude': 39.6592, 'longitude': -80.5695, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26138', 'place_name': 'Brohard', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wirt', 'locality_code': '105', 'latitude': 39.0338, 'longitude': -81.1775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26141', 'place_name': 'Creston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wirt', 'locality_code': '105', 'latitude': 38.9378, 'longitude': -81.2369, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26143', 'place_name': 'Elizabeth', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wirt', 'locality_code': '105', 'latitude': 39.0566, 'longitude': -81.3989, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26152', 'place_name': 'Munday', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wirt', 'locality_code': '105', 'latitude': 39.0054, 'longitude': -81.2062, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26160', 'place_name': 'Palestine', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wirt', 'locality_code': '105', 'latitude': 38.9741, 'longitude': -81.428, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26101', 'place_name': 'Parkersburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2644, 'longitude': -81.5354, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26102', 'place_name': 'Parkersburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2183, 'longitude': -81.4979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26103', 'place_name': 'Parkersburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2364, 'longitude': -81.5405, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26104', 'place_name': 'Parkersburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2804, 'longitude': -81.4936, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26105', 'place_name': 'Vienna', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.3251, 'longitude': -81.5411, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26106', 'place_name': 'Parkersburg', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2183, 'longitude': -81.4979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26120', 'place_name': 'Mineral Wells', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2183, 'longitude': -81.4979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26121', 'place_name': 'Mineral Wells', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2183, 'longitude': -81.4979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26133', 'place_name': 'Belleville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.1314, 'longitude': -81.6923, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26142', 'place_name': 'Davisville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2126, 'longitude': -81.4799, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26150', 'place_name': 'Mineral Wells', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.1897, 'longitude': -81.5139, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26169', 'place_name': 'Rockport', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.0798, 'longitude': -81.5713, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26180', 'place_name': 'Walker', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.1821, 'longitude': -81.3866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26181', 'place_name': 'Washington', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.2068, 'longitude': -81.6577, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26184', 'place_name': 'Waverly', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.3157, 'longitude': -81.3819, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '26187', 'place_name': 'Williamstown', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wood', 'locality_code': '107', 'latitude': 39.3824, 'longitude': -81.4566, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24716', 'place_name': 'Bud', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5376, 'longitude': -81.3793, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24719', 'place_name': 'Covel', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.4909, 'longitude': -81.3226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24726', 'place_name': 'Herndon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5054, 'longitude': -81.3404, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24818', 'place_name': 'Brenton', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5988, 'longitude': -81.6264, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24822', 'place_name': 'Clear Fork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6309, 'longitude': -81.6829, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24823', 'place_name': 'Coal Mountain', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6696, 'longitude': -81.7284, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24827', 'place_name': 'Cyclone', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.7329, 'longitude': -81.6887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24834', 'place_name': 'Fanrock', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5532, 'longitude': -81.6305, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24839', 'place_name': 'Hanover', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.563, 'longitude': -81.8136, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24845', 'place_name': 'Ikes Fork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5221, 'longitude': -81.8043, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24847', 'place_name': 'Itmann', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5734, 'longitude': -81.4182, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24849', 'place_name': 'Jesse', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6608, 'longitude': -81.5628, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24854', 'place_name': 'Kopperston', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.744, 'longitude': -81.575, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24857', 'place_name': 'Lynco', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6982, 'longitude': -81.6771, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24859', 'place_name': 'Marianna', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6033, 'longitude': -81.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24860', 'place_name': 'Matheny', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6624, 'longitude': -81.607, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24867', 'place_name': 'New Richmond', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5701, 'longitude': -81.4887, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24869', 'place_name': 'North Spring', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5682, 'longitude': -81.8254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24870', 'place_name': 'Oceana', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.7407, 'longitude': -81.5831, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24874', 'place_name': 'Pineville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.584, 'longitude': -81.5336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24880', 'place_name': 'Rock View', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6179, 'longitude': -81.539, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24882', 'place_name': 'Simon', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6197, 'longitude': -81.7586, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '24898', 'place_name': 'Wyoming', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5823, 'longitude': -81.6018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25810', 'place_name': 'Allen Junction', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5893, 'longitude': -81.3507, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25811', 'place_name': 'Amigo', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5965, 'longitude': -81.3209, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25826', 'place_name': 'Corinne', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5729, 'longitude': -81.3565, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25845', 'place_name': 'Glen Fork', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6959, 'longitude': -81.529, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25848', 'place_name': 'Glen Rogers', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.7217, 'longitude': -81.429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25870', 'place_name': 'Maben', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6387, 'longitude': -81.394, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25875', 'place_name': 'Mc Graws', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6033, 'longitude': -81.54, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '25876', 'place_name': 'Saulsville', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6429, 'longitude': -81.4568, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25882', 'place_name': 'Mullens', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5842, 'longitude': -81.389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25913', 'place_name': 'Ravencliff', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.7141, 'longitude': -81.4895, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25916', 'place_name': 'Sabine', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.6787, 'longitude': -81.5015, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25928', 'place_name': 'Stephenson', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.5798, 'longitude': -81.3339, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '25943', 'place_name': 'Wyco', 'state': 'West Virginia', 'state_ab': 'WV', 'county': 'Wyoming', 'locality_code': '109', 'latitude': 37.599, 'longitude': -81.3429, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82051', 'place_name': 'Bosler', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.5735, 'longitude': -105.6112, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82052', 'place_name': 'Buford', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.1219, 'longitude': -105.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82055', 'place_name': 'Centennial', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.3391, 'longitude': -105.9945, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82058', 'place_name': 'Garrett', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 42.2035, 'longitude': -105.678, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '82063', 'place_name': 'Jelm', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.0578, 'longitude': -106.0133, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82070', 'place_name': 'Laramie', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.439, 'longitude': -105.801, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82071', 'place_name': 'Laramie', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.3114, 'longitude': -105.5911, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82072', 'place_name': 'Laramie', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.4247, 'longitude': -105.4781, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82073', 'place_name': 'Laramie', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.3071, 'longitude': -105.6247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82083', 'place_name': 'Rock River', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.7461, 'longitude': -105.9746, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82084', 'place_name': 'Tie Siding', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Albany', 'locality_code': '1', 'latitude': 41.0528, 'longitude': -105.4462, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82410', 'place_name': 'Basin', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.3788, 'longitude': -108.0438, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82411', 'place_name': 'Burlington', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.4442, 'longitude': -108.4327, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82412', 'place_name': 'Byron', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.7844, 'longitude': -108.544, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82420', 'place_name': 'Cowley', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.8841, 'longitude': -108.4638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82421', 'place_name': 'Deaver', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.9257, 'longitude': -108.5979, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82422', 'place_name': 'Emblem', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.5058, 'longitude': -108.3918, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82426', 'place_name': 'Greybull', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.4919, 'longitude': -108.0795, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82428', 'place_name': 'Hyattville', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.2507, 'longitude': -107.6053, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82431', 'place_name': 'Lovell', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.8336, 'longitude': -108.4141, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82432', 'place_name': 'Manderson', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.2694, 'longitude': -107.964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82434', 'place_name': 'Otto', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.4056, 'longitude': -108.3047, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82441', 'place_name': 'Shell', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Big Horn', 'locality_code': '3', 'latitude': 44.6011, 'longitude': -107.7889, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82716', 'place_name': 'Gillette', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Campbell', 'locality_code': '5', 'latitude': 44.282, 'longitude': -105.4974, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82717', 'place_name': 'Gillette', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Campbell', 'locality_code': '5', 'latitude': 44.3047, 'longitude': -105.4959, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82718', 'place_name': 'Gillette', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Campbell', 'locality_code': '5', 'latitude': 43.9282, 'longitude': -105.5492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82725', 'place_name': 'Recluse', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Campbell', 'locality_code': '5', 'latitude': 44.7861, 'longitude': -105.776, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82727', 'place_name': 'Rozet', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Campbell', 'locality_code': '5', 'latitude': 44.3058, 'longitude': -105.2459, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82731', 'place_name': 'Weston', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Campbell', 'locality_code': '5', 'latitude': 44.7705, 'longitude': -105.3581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82732', 'place_name': 'Wright', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Campbell', 'locality_code': '5', 'latitude': 43.7512, 'longitude': -105.492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82301', 'place_name': 'Rawlins', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.7951, 'longitude': -107.2349, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82321', 'place_name': 'Baggs', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.0312, 'longitude': -107.6687, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82323', 'place_name': 'Dixon', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.0445, 'longitude': -107.499, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82324', 'place_name': 'Elk Mountain', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.6874, 'longitude': -106.4146, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82325', 'place_name': 'Encampment', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.2054, 'longitude': -106.7803, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82327', 'place_name': 'Hanna', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.8726, 'longitude': -106.5283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82329', 'place_name': 'Medicine Bow', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.903, 'longitude': -106.2012, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82331', 'place_name': 'Saratoga', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.498, 'longitude': -106.754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82332', 'place_name': 'Savery', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.0395, 'longitude': -107.4234, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82334', 'place_name': 'Sinclair', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.7802, 'longitude': -107.1172, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82335', 'place_name': 'Walcott', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.7611, 'longitude': -106.845, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82615', 'place_name': 'Shirley Basin', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Carbon', 'locality_code': '7', 'latitude': 41.7169, 'longitude': -106.9992, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '82224', 'place_name': 'Lost Springs', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Converse', 'locality_code': '9', 'latitude': 43.0421, 'longitude': -104.7973, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82229', 'place_name': 'Shawnee', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Converse', 'locality_code': '9', 'latitude': 42.7477, 'longitude': -105.0097, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82633', 'place_name': 'Douglas', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Converse', 'locality_code': '9', 'latitude': 42.7626, 'longitude': -105.3855, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82637', 'place_name': 'Glenrock', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Converse', 'locality_code': '9', 'latitude': 42.7803, 'longitude': -105.8719, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82710', 'place_name': 'Aladdin', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Crook', 'locality_code': '11', 'latitude': 44.7473, 'longitude': -104.1931, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82711', 'place_name': 'Alva', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Crook', 'locality_code': '11', 'latitude': 44.6873, 'longitude': -104.4414, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82712', 'place_name': 'Beulah', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Crook', 'locality_code': '11', 'latitude': 44.5436, 'longitude': -104.0745, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82714', 'place_name': 'Devils Tower', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Crook', 'locality_code': '11', 'latitude': 44.5248, 'longitude': -104.6867, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82720', 'place_name': 'Hulett', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Crook', 'locality_code': '11', 'latitude': 44.7352, 'longitude': -104.6174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82721', 'place_name': 'Moorcroft', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Crook', 'locality_code': '11', 'latitude': 44.4154, 'longitude': -104.8389, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82729', 'place_name': 'Sundance', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Crook', 'locality_code': '11', 'latitude': 44.4058, 'longitude': -104.3837, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82310', 'place_name': 'Jeffrey City', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 42.5402, 'longitude': -107.8724, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82501', 'place_name': 'Riverton', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.0351, 'longitude': -108.2024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82510', 'place_name': 'Arapahoe', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 42.9679, 'longitude': -108.4941, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82512', 'place_name': 'Crowheart', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.3716, 'longitude': -109.296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82513', 'place_name': 'Dubois', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.5451, 'longitude': -109.6492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82514', 'place_name': 'Fort Washakie', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.0048, 'longitude': -108.8964, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82515', 'place_name': 'Hudson', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 42.9061, 'longitude': -108.5834, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82516', 'place_name': 'Kinnear', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.2678, 'longitude': -108.9334, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82520', 'place_name': 'Lander', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 42.9208, 'longitude': -108.5913, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82523', 'place_name': 'Pavillion', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.3623, 'longitude': -108.6998, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82524', 'place_name': 'Saint Stephens', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 42.9838, 'longitude': -108.4165, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82642', 'place_name': 'Lysite', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.3284, 'longitude': -107.6488, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82649', 'place_name': 'Shoshoni', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Fremont', 'locality_code': '13', 'latitude': 43.2457, 'longitude': -108.1007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82212', 'place_name': 'Fort Laramie', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 42.2133, 'longitude': -104.5226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82217', 'place_name': 'Hawk Springs', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 41.7861, 'longitude': -104.2647, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82218', 'place_name': 'Huntley', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 41.9327, 'longitude': -104.1461, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82219', 'place_name': 'Jay Em', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 42.4987, 'longitude': -104.5134, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82221', 'place_name': 'Lagrange', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 41.6423, 'longitude': -104.1974, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '82223', 'place_name': 'Lingle', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 42.1346, 'longitude': -104.332, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82240', 'place_name': 'Torrington', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 42.0624, 'longitude': -104.1917, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82243', 'place_name': 'Veteran', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 41.9821, 'longitude': -104.3709, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82244', 'place_name': 'Yoder', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Goshen', 'locality_code': '15', 'latitude': 41.912, 'longitude': -104.3535, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82430', 'place_name': 'Kirby', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Hot Springs', 'locality_code': '17', 'latitude': 43.8042, 'longitude': -108.1805, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82443', 'place_name': 'Thermopolis', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Hot Springs', 'locality_code': '17', 'latitude': 43.7758, 'longitude': -108.3839, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82639', 'place_name': 'Kaycee', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Johnson', 'locality_code': '19', 'latitude': 43.7236, 'longitude': -106.5632, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82640', 'place_name': 'Linch', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Johnson', 'locality_code': '19', 'latitude': 43.5651, 'longitude': -106.1728, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82834', 'place_name': 'Buffalo', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Johnson', 'locality_code': '19', 'latitude': 44.3485, 'longitude': -106.7073, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82840', 'place_name': 'Saddlestring', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Johnson', 'locality_code': '19', 'latitude': 44.4976, 'longitude': -106.871, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82001', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.1437, 'longitude': -104.7962, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82002', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.14, 'longitude': -104.8202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82003', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.2191, 'longitude': -104.6612, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82005', 'place_name': 'Fe Warren Afb', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.1391, 'longitude': -104.8629, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '82006', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.14, 'longitude': -104.8202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82007', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.1084, 'longitude': -104.8107, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82008', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.14, 'longitude': -104.8202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82009', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.1836, 'longitude': -104.8023, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82010', 'place_name': 'Cheyenne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.14, 'longitude': -104.8202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82050', 'place_name': 'Albin', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.4342, 'longitude': -104.1505, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82053', 'place_name': 'Burns', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.2003, 'longitude': -104.3155, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82054', 'place_name': 'Carpenter', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.0428, 'longitude': -104.2765, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82059', 'place_name': 'Granite Canon', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.0473, 'longitude': -105.1517, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '82060', 'place_name': 'Hillsdale', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.2136, 'longitude': -104.4933, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82061', 'place_name': 'Horse Creek', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.4353, 'longitude': -105.1417, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82081', 'place_name': 'Meriden', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.5424, 'longitude': -104.2866, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82082', 'place_name': 'Pine Bluffs', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Laramie', 'locality_code': '21', 'latitude': 41.1788, 'longitude': -104.0666, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83101', 'place_name': 'Kemmerer', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 41.7887, 'longitude': -110.5283, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83110', 'place_name': 'Afton', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.7128, 'longitude': -110.942, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83111', 'place_name': 'Auburn', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.8051, 'longitude': -110.9944, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83112', 'place_name': 'Bedford', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.8701, 'longitude': -110.9401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83114', 'place_name': 'Cokeville', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.058, 'longitude': -110.9164, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83116', 'place_name': 'Diamondville', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 41.7839, 'longitude': -110.54, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83118', 'place_name': 'Etna', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 43.0443, 'longitude': -111.0085, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83119', 'place_name': 'Fairview', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.6885, 'longitude': -110.9824, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83120', 'place_name': 'Freedom', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 43.0172, 'longitude': -111.0292, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '83121', 'place_name': 'Frontier', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 41.8141, 'longitude': -110.5371, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83122', 'place_name': 'Grover', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.7965, 'longitude': -110.9244, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83123', 'place_name': 'La Barge', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.2473, 'longitude': -110.2109, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83124', 'place_name': 'Opal', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 41.7795, 'longitude': -110.276, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83126', 'place_name': 'Smoot', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.6192, 'longitude': -110.9224, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83127', 'place_name': 'Thayne', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 42.933, 'longitude': -111.0114, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83128', 'place_name': 'Alpine', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Lincoln', 'locality_code': '23', 'latitude': 43.1635, 'longitude': -111.018, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82601', 'place_name': 'Casper', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.8458, 'longitude': -106.3166, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82602', 'place_name': 'Casper', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.8896, 'longitude': -106.357, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82604', 'place_name': 'Casper', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.8261, 'longitude': -106.3896, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82605', 'place_name': 'Casper', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.8666, 'longitude': -106.3131, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82609', 'place_name': 'Casper', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.8406, 'longitude': -106.2806, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82620', 'place_name': 'Alcova', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.5302, 'longitude': -106.76, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82630', 'place_name': 'Arminto', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 43.1789, 'longitude': -107.2576, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82635', 'place_name': 'Edgerton', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 43.4074, 'longitude': -106.2638, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82636', 'place_name': 'Evansville', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.8992, 'longitude': -106.1754, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82638', 'place_name': 'Hiland', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 43.1153, 'longitude': -107.3436, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82643', 'place_name': 'Midwest', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 43.4114, 'longitude': -106.28, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82644', 'place_name': 'Mills', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 42.8405, 'longitude': -106.3659, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82646', 'place_name': 'Natrona', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 43.0297, 'longitude': -106.8092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82648', 'place_name': 'Powder River', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Natrona', 'locality_code': '25', 'latitude': 43.0322, 'longitude': -106.9873, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82222', 'place_name': 'Lance Creek', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Niobrara', 'locality_code': '27', 'latitude': 43.0325, 'longitude': -104.6419, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82225', 'place_name': 'Lusk', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Niobrara', 'locality_code': '27', 'latitude': 42.766, 'longitude': -104.4651, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82227', 'place_name': 'Manville', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Niobrara', 'locality_code': '27', 'latitude': 42.73, 'longitude': -104.7024, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82242', 'place_name': 'Van Tassell', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Niobrara', 'locality_code': '27', 'latitude': 42.7033, 'longitude': -104.1408, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82190', 'place_name': 'Yellowstone National Park', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Park', 'locality_code': '29', 'latitude': 44.7957, 'longitude': -110.6137, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '82414', 'place_name': 'Cody', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Park', 'locality_code': '29', 'latitude': 44.5231, 'longitude': -109.0756, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82423', 'place_name': 'Frannie', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Park', 'locality_code': '29', 'latitude': 44.9718, 'longitude': -108.6221, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82433', 'place_name': 'Meeteetse', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Park', 'locality_code': '29', 'latitude': 44.1962, 'longitude': -108.95, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82435', 'place_name': 'Powell', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Park', 'locality_code': '29', 'latitude': 44.7561, 'longitude': -108.7773, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82440', 'place_name': 'Ralston', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Park', 'locality_code': '29', 'latitude': 44.7161, 'longitude': -108.8646, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82450', 'place_name': 'Wapiti', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Park', 'locality_code': '29', 'latitude': 44.4686, 'longitude': -109.4377, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82201', 'place_name': 'Wheatland', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Platte', 'locality_code': '31', 'latitude': 42.0495, 'longitude': -104.9679, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82210', 'place_name': 'Chugwater', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Platte', 'locality_code': '31', 'latitude': 41.7487, 'longitude': -104.8179, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82213', 'place_name': 'Glendo', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Platte', 'locality_code': '31', 'latitude': 42.5004, 'longitude': -105, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82214', 'place_name': 'Guernsey', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Platte', 'locality_code': '31', 'latitude': 42.2655, 'longitude': -104.7512, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82215', 'place_name': 'Hartville', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Platte', 'locality_code': '31', 'latitude': 42.3334, 'longitude': -104.7296, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82801', 'place_name': 'Sheridan', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.7849, 'longitude': -106.9648, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82831', 'place_name': 'Arvada', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.6899, 'longitude': -106.1092, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82832', 'place_name': 'Banner', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.6003, 'longitude': -106.7954, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82833', 'place_name': 'Big Horn', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.6531, 'longitude': -107.0247, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82835', 'place_name': 'Clearmont', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.661, 'longitude': -106.4581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82836', 'place_name': 'Dayton', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.878, 'longitude': -107.3026, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82837', 'place_name': 'Leiter', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.718, 'longitude': -106.2692, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82838', 'place_name': 'Parkman', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.965, 'longitude': -107.3254, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82839', 'place_name': 'Ranchester', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.9171, 'longitude': -107.174, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82842', 'place_name': 'Story', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.58, 'longitude': -106.8978, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82844', 'place_name': 'Wolf', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.7864, 'longitude': -107.2202, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82845', 'place_name': 'Wyarno', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sheridan', 'locality_code': '33', 'latitude': 44.7534, 'longitude': -106.6949, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82922', 'place_name': 'Bondurant', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sublette', 'locality_code': '35', 'latitude': 43.2238, 'longitude': -110.3353, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82923', 'place_name': 'Boulder', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sublette', 'locality_code': '35', 'latitude': 42.6881, 'longitude': -109.5401, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82925', 'place_name': 'Cora', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sublette', 'locality_code': '35', 'latitude': 43.1399, 'longitude': -109.9154, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82941', 'place_name': 'Pinedale', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sublette', 'locality_code': '35', 'latitude': 42.8543, 'longitude': -109.8561, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83113', 'place_name': 'Big Piney', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sublette', 'locality_code': '35', 'latitude': 42.6483, 'longitude': -110.1246, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83115', 'place_name': 'Daniel', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sublette', 'locality_code': '35', 'latitude': 42.9176, 'longitude': -110.1336, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82322', 'place_name': 'Bairoil', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 42.2327, 'longitude': -107.5633, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82336', 'place_name': 'Wamsutter', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.6583, 'longitude': -108.1517, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82901', 'place_name': 'Rock Springs', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.606, 'longitude': -109.23, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82902', 'place_name': 'Rock Springs', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.5875, 'longitude': -109.2029, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82929', 'place_name': 'Little America', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.5436, 'longitude': -109.859, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82932', 'place_name': 'Farson', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 42.0834, 'longitude': -109.4184, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82934', 'place_name': 'Granger', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.5936, 'longitude': -109.9688, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82935', 'place_name': 'Green River', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.5196, 'longitude': -109.4714, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82938', 'place_name': 'Mc Kinnon', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.0409, 'longitude': -109.8745, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '82942', 'place_name': 'Point Of Rocks', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.6802, 'longitude': -108.7857, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82943', 'place_name': 'Reliance', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.6698, 'longitude': -109.1919, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82945', 'place_name': 'Superior', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Sweetwater', 'locality_code': '37', 'latitude': 41.7643, 'longitude': -108.9681, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83001', 'place_name': 'Jackson', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.4528, 'longitude': -110.7393, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83002', 'place_name': 'Jackson', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.4799, 'longitude': -110.7624, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83011', 'place_name': 'Kelly', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.6094, 'longitude': -110.5442, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83012', 'place_name': 'Moose', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.715, 'longitude': -110.742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83013', 'place_name': 'Moran', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.9509, 'longitude': -110.5532, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83014', 'place_name': 'Wilson', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.4992, 'longitude': -110.8742, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83025', 'place_name': 'Teton Village', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.5924, 'longitude': -110.8314, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '83414', 'place_name': 'Alta', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Teton', 'locality_code': '39', 'latitude': 43.8886, 'longitude': -110.9492, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82930', 'place_name': 'Evanston', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Uinta', 'locality_code': '41', 'latitude': 41.2609, 'longitude': -110.9631, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82931', 'place_name': 'Evanston', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Uinta', 'locality_code': '41', 'latitude': 41.2619, 'longitude': -110.92, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82933', 'place_name': 'Fort Bridger', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Uinta', 'locality_code': '41', 'latitude': 41.3166, 'longitude': -110.3843, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82936', 'place_name': 'Lonetree', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Uinta', 'locality_code': '41', 'latitude': 41.0552, 'longitude': -110.1603, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82937', 'place_name': 'Lyman', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Uinta', 'locality_code': '41', 'latitude': 41.3291, 'longitude': -110.2926, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82939', 'place_name': 'Mountain View', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Uinta', 'locality_code': '41', 'latitude': 41.2335, 'longitude': -110.3372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82944', 'place_name': 'Robertson', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Uinta', 'locality_code': '41', 'latitude': 41.0993, 'longitude': -110.5007, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82401', 'place_name': 'Worland', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Washakie', 'locality_code': '43', 'latitude': 44.0138, 'longitude': -107.9563, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82442', 'place_name': 'Ten Sleep', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Washakie', 'locality_code': '43', 'latitude': 43.9978, 'longitude': -107.4153, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82701', 'place_name': 'Newcastle', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Weston', 'locality_code': '45', 'latitude': 43.8511, 'longitude': -104.2262, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82715', 'place_name': 'Four Corners', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Weston', 'locality_code': '45', 'latitude': 44.0775, 'longitude': -104.1383, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82723', 'place_name': 'Osage', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Weston', 'locality_code': '45', 'latitude': 43.999, 'longitude': -104.4226, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '82730', 'place_name': 'Upton', 'state': 'Wyoming', 'state_ab': 'WY', 'county': 'Weston', 'locality_code': '45', 'latitude': 44.0893, 'longitude': -104.6352, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '9001', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.1105, 'longitude': 15.6613, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9007', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4077, 'longitude': 8.6908, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9008', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9009', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4333, 'longitude': 7.6, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9012', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4333, 'longitude': 7.6, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9014', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4077, 'longitude': 8.6908, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9021', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4292, 'longitude': 7.6969, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9025', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.1113, 'longitude': 9.7391, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9026', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.3776, 'longitude': 9.9109, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9028', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.5431, 'longitude': 8.4497, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9031', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.7397, 'longitude': 10.1507, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9033', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0494, 'longitude': 10.2217, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9034', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.6174, 'longitude': 7.3338, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9036', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.7939, 'longitude': 9.9512, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9039', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9041', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.1374, 'longitude': 11.5755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9044', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.9817, 'longitude': 11.6139, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9046', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.6821, 'longitude': 9.0117, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9047', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.759, 'longitude': 9.5085, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9050', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 47.7611, 'longitude': 11.5589, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9052', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.2469, 'longitude': 7.3698, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9053', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 47.4926, 'longitude': 11.0865, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9054', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.443, 'longitude': 7.7716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9056', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.6328, 'longitude': 8.3592, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9057', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50, 'longitude': 8.6667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9058', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.6328, 'longitude': 8.3592, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9059', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4052, 'longitude': 7.4372, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9060', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9063', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4077, 'longitude': 8.6908, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9064', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50, 'longitude': 8.6667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9066', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.591, 'longitude': 11.0078, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9067', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.443, 'longitude': 7.7716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9068', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4759, 'longitude': 10.9886, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9069', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 53.5502, 'longitude': 8.5767, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9070', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4424, 'longitude': 10.9541, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9071', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4429, 'longitude': 11.8627, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9072', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.8699, 'longitude': 6.6969, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9073', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.7035, 'longitude': 9.6521, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9074', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.3569, 'longitude': 10.9846, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9077', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.4339, 'longitude': 8.6712, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9078', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.9624, 'longitude': 7.6257, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9079', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9080', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.6846, 'longitude': 7.1539, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9081', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.3822, 'longitude': 8.5823, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9082', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1006, 'longitude': 8.7665, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9086', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.5, 'longitude': 8.5, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9089', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.9652, 'longitude': 8.9513, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9090', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1254, 'longitude': 8.6089, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9091', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.2016, 'longitude': 9.1874, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9094', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4445, 'longitude': 7.5553, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9095', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.2231, 'longitude': 8.3639, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9096', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0826, 'longitude': 8.2493, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9097', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50, 'longitude': 8.6667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9098', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 47.8638, 'longitude': 12.0105, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9099', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4077, 'longitude': 8.6908, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9100', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.3822, 'longitude': 8.5823, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9102', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4077, 'longitude': 8.6908, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9103', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.1747, 'longitude': 6.3169, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9104', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.9675, 'longitude': 6.1176, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9107', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.1761, 'longitude': 9.5392, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9108', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.1374, 'longitude': 11.5755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9110', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.8472, 'longitude': 8.3167, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9111', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.8414, 'longitude': 7.8671, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9112', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.5106, 'longitude': 10.3187, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9114', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.7173, 'longitude': 11.9065, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9123', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.9833, 'longitude': 6.6833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9126', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.9833, 'longitude': 6.6833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9128', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.9356, 'longitude': 8.9604, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9130', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.5118, 'longitude': 7.8666, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9131', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.9356, 'longitude': 8.9604, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9132', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.9679, 'longitude': 6.5273, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9136', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.5118, 'longitude': 7.8666, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9137', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.7035, 'longitude': 9.6521, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9138', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.2249, 'longitude': 7.6104, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9139', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.8987, 'longitude': 10.9007, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9140', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4804, 'longitude': 10.3877, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9141', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.872, 'longitude': 9.7089, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9142', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.3305, 'longitude': 11.0235, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9143', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.5873, 'longitude': 8.6755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9144', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1514, 'longitude': 8.425, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9154', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.7823, 'longitude': 9.177, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9156', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.9679, 'longitude': 6.5273, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9157', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.3715, 'longitude': 10.8985, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9160', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.542, 'longitude': 9.7905, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9162', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.977, 'longitude': 9.1521, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9164', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.0094, 'longitude': 8.4044, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9165', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1342, 'longitude': 8.9142, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9166', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4891, 'longitude': 8.4669, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9169', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.5873, 'longitude': 8.6755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9171', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.9624, 'longitude': 7.6257, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9172', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 47.5981, 'longitude': 11.0669, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9173', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.204, 'longitude': 11.8484, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9175', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.8717, 'longitude': 8.6503, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9176', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.1399, 'longitude': 9.2205, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9177', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.3048, 'longitude': 10.5931, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9178', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.3715, 'longitude': 10.8985, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9180', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4131, 'longitude': 7.5702, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9182', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.6531, 'longitude': 9.9444, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9183', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.1374, 'longitude': 11.5755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9184', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.1374, 'longitude': 11.5755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9185', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.9842, 'longitude': 8.2791, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9186', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.443, 'longitude': 7.7716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9187', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.5244, 'longitude': 13.4105, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9189', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.2014, 'longitude': 7.6053, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9192', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0826, 'longitude': 8.2493, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9196', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0826, 'longitude': 8.2493, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9202', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0099, 'longitude': 8.2829, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9205', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.1727, 'longitude': 9.2491, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9211', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.8717, 'longitude': 8.6503, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9212', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50, 'longitude': 8.6667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9213', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9214', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1738, 'longitude': 7.0633, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9215', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 53.5753, 'longitude': 10.0153, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9216', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.1338, 'longitude': 10.8897, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9220', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0826, 'longitude': 8.2493, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9222', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4759, 'longitude': 10.9886, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9225', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.7397, 'longitude': 10.1507, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9226', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0494, 'longitude': 10.2217, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9227', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.443, 'longitude': 7.7716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9228', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9229', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.443, 'longitude': 7.7716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9233', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.2217, 'longitude': 6.7762, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9235', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.5244, 'longitude': 13.4105, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9237', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9239', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.1344, 'longitude': 10.0719, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9242', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.1155, 'longitude': 8.6842, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9244', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.7939, 'longitude': 9.9512, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9245', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.1374, 'longitude': 11.5755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9248', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.5873, 'longitude': 8.6755, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9249', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.2469, 'longitude': 7.3698, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9250', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4667, 'longitude': 10.7, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9251', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.2469, 'longitude': 7.3698, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9252', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.8414, 'longitude': 7.8671, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9258', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4445, 'longitude': 7.5553, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9259', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.8055, 'longitude': 13.0902, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9261', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.7391, 'longitude': 6.291, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9262', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.7144, 'longitude': 7.3078, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9263', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.443, 'longitude': 7.7716, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9264', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.3048, 'longitude': 10.5931, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9265', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.2023, 'longitude': 10.0778, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9279', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.8973, 'longitude': 9.1916, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9281', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.7995, 'longitude': 9.7981, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9305', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.6084, 'longitude': 7.1741, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9333', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.4664, 'longitude': 8.5577, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9351', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 47.7138, 'longitude': 7.6028, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9352', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.568, 'longitude': 10.8856, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9353', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0826, 'longitude': 8.2493, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9354', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 54.7843, 'longitude': 9.4396, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9355', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 53.281, 'longitude': 8.6986, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9358', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.0826, 'longitude': 8.2493, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9359', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.6884, 'longitude': 9.1677, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9360', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 49.032, 'longitude': 8.3426, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9405', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.0933, 'longitude': 1.3204, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9415', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.4406, 'longitude': -4.9954, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9418', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 58.5927, 'longitude': -3.5259, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9419', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 56.8091, 'longitude': -2.656, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9420', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.8908, 'longitude': -5.1224, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9421', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.5085, 'longitude': -0.1257, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9422', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 55.4232, 'longitude': -5.7347, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9447', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.4015, 'longitude': -1.3247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9448', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 53.4295, 'longitude': -2.6585, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9449', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.5486, 'longitude': -0.4805, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9450', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.8782, 'longitude': 0.5529, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9456', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.7082, 'longitude': -1.7813, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9459', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.2443, 'longitude': 0.7724, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9461', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.4167, 'longitude': 0.75, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9462', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.4015, 'longitude': -1.3247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9463', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.4015, 'longitude': -1.3247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9464', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.4093, 'longitude': 0.561, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9467', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.9001, 'longitude': -2.0797, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9468', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 53.9908, 'longitude': -1.5373, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9469', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.369, 'longitude': -0.2601, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9470', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.3642, 'longitude': -0.2243, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9471', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.6291, 'longitude': -0.7493, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9472', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.7193, 'longitude': -1.9714, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9494', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.9977, 'longitude': -1.2047, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9495', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.4015, 'longitude': -1.3247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9497', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.0933, 'longitude': 1.3204, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9498', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.5085, 'longitude': -0.1257, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9499', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.5085, 'longitude': -0.1257, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9508', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 19.9064, 'longitude': -75.2069, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9593', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 19.9064, 'longitude': -75.2069, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9596', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 19.9064, 'longitude': -75.2069, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9601', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 46.0706, 'longitude': 12.5947, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9602', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9604', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9605', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.6321, 'longitude': 17.9361, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9606', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 39.3103, 'longitude': 8.9696, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9609', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 41.2141, 'longitude': 13.5708, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9610', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 45.402, 'longitude': 10.2768, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9613', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 43.5443, 'longitude': 10.3262, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9618', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.85, 'longitude': 9.1667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9619', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.8522, 'longitude': 14.2681, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9620', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.8522, 'longitude': 14.2681, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9621', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.8522, 'longitude': 14.2681, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9622', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.8824, 'longitude': 14.2693, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9624', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 41.8919, 'longitude': 12.5113, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9625', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.8522, 'longitude': 14.2681, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9626', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.8522, 'longitude': 14.2681, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9627', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.4017, 'longitude': 14.9224, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9628', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 45.4299, 'longitude': 10.9844, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9629', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 45.5467, 'longitude': 11.5475, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9630', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 45.5467, 'longitude': 11.5475, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9641', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.4165, 'longitude': -3.7026, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9642', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.4165, 'longitude': -3.7026, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9643', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 41.4136, 'longitude': -2.4132, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9644', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 36.6255, 'longitude': -6.3622, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9645', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 36.6255, 'longitude': -6.3622, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9646', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 41.6561, 'longitude': -0.8773, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9647', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.6433, 'longitude': -3.3338, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9648', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9655', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9658', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9670', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 44.0575, 'longitude': 12.5653, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9680', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9681', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9682', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9683', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9694', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 36.9489, 'longitude': 14.6073, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9703', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.9467, 'longitude': 5.9708, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9704', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 76.5311, 'longitude': -68.7017, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9705', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.5758, 'longitude': 3.831, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9706', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 59.9291, 'longitude': 10.519, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9707', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 59.9127, 'longitude': 10.7461, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9708', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.5879, 'longitude': 3.8071, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9709', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 67.017, 'longitude': -50.6893, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9713', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.8483, 'longitude': 5.6889, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9714', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.8504, 'longitude': 4.3488, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9715', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.0826, 'longitude': 4.315, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9716', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 55.6947, 'longitude': 12.5832, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9717', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.8483, 'longitude': 5.6889, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9718', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.0133, 'longitude': -6.8326, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9719', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 46.0706, 'longitude': 12.5947, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9720', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.7167, 'longitude': -27.2167, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9721', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 60.1695, 'longitude': 24.9354, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9722', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 56.3067, 'longitude': 9.1683, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9723', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 60.1695, 'longitude': 24.9354, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9724', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 50.8504, 'longitude': 4.3488, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9725', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 64.0049, 'longitude': -22.5624, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9726', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.7167, 'longitude': -9.1333, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9727', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 32.3302, 'longitude': -64.74, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9728', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 64.0049, 'longitude': -22.5624, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9729', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 64.2539, 'longitude': -15.2121, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9730', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 47.2999, 'longitude': -53.9814, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9731', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 43.7632, 'longitude': -65.3235, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9732', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 46.3168, 'longitude': -79.4663, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9734', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9738', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9740', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9745', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9746', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9747', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9749', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9754', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9760', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9762', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9765', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9766', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9767', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9768', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9770', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9772', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9774', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9775', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9777', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 48.8534, 'longitude': 2.3488, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9802', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 21.2703, 'longitude': 40.4158, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9803', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9804', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9805', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 25.4, 'longitude': 49.65, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9806', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 28.3356, 'longitude': 46.1247, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9808', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9809', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 18.3, 'longitude': 42.7333, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9810', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 28.3998, 'longitude': 36.5715, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9811', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 21.5424, 'longitude': 39.198, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9812', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 33.7215, 'longitude': 73.0433, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9813', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 6.3005, 'longitude': -10.7969, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9814', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.8608, 'longitude': 67.0104, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9815', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -4.6167, 'longitude': 55.45, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9816', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 39.6492, 'longitude': 27.8861, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9817', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.3502, 'longitude': 38.3167, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9818', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 39.9086, 'longitude': 41.2769, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9819', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.4127, 'longitude': 27.1384, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9820', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 42.0268, 'longitude': 35.1625, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9821', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.4127, 'longitude': 27.1384, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9822', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 39.9199, 'longitude': 32.8543, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9823', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 39.9199, 'longitude': 32.8543, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9824', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.0017, 'longitude': 35.3289, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9825', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.9136, 'longitude': 40.2172, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9826', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 39.7767, 'longitude': 30.5206, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9827', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 41.0138, 'longitude': 28.9497, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9828', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -4.3276, 'longitude': 15.3136, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9829', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.5518, 'longitude': 32.5324, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9830', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 32.0809, 'longitude': 34.7806, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9831', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -1.2833, 'longitude': 36.8167, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9832', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 31.069, 'longitude': 34.1292, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9833', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 27.9158, 'longitude': 34.3299, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9834', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2106, 'longitude': 50.6117, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9835', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 30.0626, 'longitude': 31.2497, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9836', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.1753, 'longitude': 33.3642, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9837', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2106, 'longitude': 50.6117, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9838', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.381, 'longitude': 38.4573, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9839', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 30.0626, 'longitude': 31.2497, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9840', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.9795, 'longitude': 23.7162, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9841', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.9795, 'longitude': 23.7162, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9842', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.9795, 'longitude': 23.7162, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9843', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.1652, 'longitude': 21.4086, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9844', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.6436, 'longitude': 22.9309, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9845', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.0413, 'longitude': 23.543, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9846', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.3279, 'longitude': 25.1434, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9847', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 38.0873, 'longitude': 23.9764, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9848', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9850', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9851', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9852', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9853', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9855', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9858', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9861', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9864', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9865', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.5249, 'longitude': 24.1435, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9866', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2106, 'longitude': 50.6117, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9873', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9874', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9875', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9876', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9877', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9878', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9879', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9880', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9881', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9882', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9883', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9884', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9886', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9887', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9888', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9889', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9890', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9891', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9892', 'place_name': 'FPO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 31.9552, 'longitude': 35.945, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9893', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 30.0626, 'longitude': 31.2497, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9894', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9895', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9896', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9897', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.6877, 'longitude': 46.7218, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '9898', 'place_name': 'APO AE', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2886, 'longitude': 50.114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34002', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.9733, 'longitude': -79.5556, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34003', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.95, 'longitude': -79.55, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34004', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 9, 'longitude': -79.75, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34005', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 9.2917, 'longitude': -79.9077, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34006', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.9171, 'longitude': -79.5843, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34007', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.9395, 'longitude': -79.5491, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34008', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 9.3219, 'longitude': -79.8697, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34009', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.9667, 'longitude': -79.55, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34010', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.0818, 'longitude': -87.2068, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34011', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.9667, 'longitude': -79.55, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34020', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 9.9333, 'longitude': -84.0833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34021', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 12.1328, 'longitude': -86.2504, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34022', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.0818, 'longitude': -87.2068, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34023', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.6894, 'longitude': -89.1872, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34024', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.6407, 'longitude': -90.5133, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34030', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -22.9114, 'longitude': -43.1737, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34031', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -12.0432, 'longitude': -77.0282, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34032', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -16.5, 'longitude': -68.15, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34033', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -33.4569, 'longitude': -70.6483, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34034', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -34.6131, 'longitude': -58.3772, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34035', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -34.9033, 'longitude': -56.1882, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34036', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -25.3007, 'longitude': -57.6359, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34037', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 10.488, 'longitude': -66.8792, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34038', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 4.6097, 'longitude': -74.0818, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34039', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -0.2299, 'longitude': -78.525, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34040', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 18.4663, 'longitude': -66.1057, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34041', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 18.5001, 'longitude': -69.9886, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34042', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.3824, 'longitude': -87.6212, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34045', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 9.9333, 'longitude': -84.0833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34046', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.0818, 'longitude': -87.2068, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34050', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 18.4786, 'longitude': -67.1688, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34051', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 18.235, 'longitude': -65.6291, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34053', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 18.4269, 'longitude': -66.1846, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34054', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 17.05, 'longitude': -61.8, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34058', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 24.4333, 'longitude': -77.95, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34059', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.9395, 'longitude': -79.5491, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34060', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 9.4008, 'longitude': -79.8697, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '34061', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 8.95, 'longitude': -79.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96201', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.7167, 'longitude': 128.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96202', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.7167, 'longitude': 128.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96203', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.5339, 'longitude': 126.9775, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96204', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.5339, 'longitude': 126.9775, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96205', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.5339, 'longitude': 126.9775, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96206', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.5339, 'longitude': 126.9775, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96207', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.5339, 'longitude': 126.9775, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96208', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.8747, 'longitude': 127.7342, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96212', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.8703, 'longitude': 128.5911, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96213', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.8703, 'longitude': 128.5911, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96214', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.2342, 'longitude': 128.8811, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96216', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.78, 'longitude': 127.0615, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96218', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.8703, 'longitude': 128.5911, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96220', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 33.4017, 'longitude': 126.5461, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96224', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.9211, 'longitude': 127.0626, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96231', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 36.3214, 'longitude': 127.4197, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96236', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 33.6, 'longitude': 130.4167, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96257', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.754, 'longitude': 127.0255, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96258', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.754, 'longitude': 127.0255, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96259', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.1028, 'longitude': 129.0403, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96260', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.9925, 'longitude': 128.3979, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96261', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.2911, 'longitude': 127.0089, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96264', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.9786, 'longitude': 126.7114, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96266', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.1522, 'longitude': 127.0706, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96267', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.1522, 'longitude': 127.0706, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96269', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.0642, 'longitude': 128.7653, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96271', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 36.9622, 'longitude': 127.0311, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96272', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 36.9622, 'longitude': 127.0311, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96276', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.566, 'longitude': 126.9784, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96278', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 37.0906, 'longitude': 127.0296, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96283', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.9586, 'longitude': 126.9728, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96284', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.9586, 'longitude': 126.9728, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96306', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.4427, 'longitude': 139.3693, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96310', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.163, 'longitude': 132.22, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96313', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.4919, 'longitude': 139.475, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96318', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.6868, 'longitude': 141.3897, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96319', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 40.6868, 'longitude': 141.3897, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96321', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 33.1592, 'longitude': 129.7228, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96322', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 33.1592, 'longitude': 129.7228, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96323', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.7485, 'longitude': 139.3485, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96325', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.7485, 'longitude': 139.3485, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96326', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.7485, 'longitude': 139.3485, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96328', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.7485, 'longitude': 139.3485, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96330', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.7485, 'longitude': 139.3485, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96336', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.6895, 'longitude': 139.6917, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96337', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.6895, 'longitude': 139.6917, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96338', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.6895, 'longitude': 139.6917, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96339', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.5138, 'longitude': 139.3937, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96343', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.6895, 'longitude': 139.6917, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96347', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.4333, 'longitude': 139.65, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96348', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.4333, 'longitude': 139.65, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96349', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.2836, 'longitude': 139.6672, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96350', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 35.2836, 'longitude': 139.6672, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96362', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3, 'longitude': 127.7667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96364', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3652, 'longitude': 127.7586, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96365', 'place_name': 'APO STA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3652, 'longitude': 127.7586, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96367', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3652, 'longitude': 127.7586, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96368', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3652, 'longitude': 127.7586, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96370', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.35, 'longitude': 127.7667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96372', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2872, 'longitude': 127.7731, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96373', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3835, 'longitude': 127.8414, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96374', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2644, 'longitude': 127.7244, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96375', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2644, 'longitude': 127.7244, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96376', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.2644, 'longitude': 127.7244, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96377', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3905, 'longitude': 127.8588, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96378', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3086, 'longitude': 127.7804, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96379', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 26.3086, 'longitude': 127.7804, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96382', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 27, 'longitude': 142.1667, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96390', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -23.697, 'longitude': 133.8818, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96407', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96408', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96409', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96410', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96411', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96415', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.3312, 'longitude': 120.5898, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96419', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.1423, 'longitude': 120.9757, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96428', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.6042, 'longitude': 120.9822, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96431', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96432', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96434', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.15, 'longitude': 120.5833, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96440', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.6042, 'longitude': 120.9822, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96445', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.1423, 'longitude': 120.9757, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96447', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 16.6159, 'longitude': 120.3166, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96450', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.7944, 'longitude': 120.2714, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96451', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.7944, 'longitude': 120.2714, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96452', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.7944, 'longitude': 120.2714, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96454', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.7944, 'longitude': 120.2714, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96456', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 15.3312, 'longitude': 120.5898, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96468', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.754, 'longitude': 100.5014, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96498', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 14.7484, 'longitude': 120.965, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96505', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.88, 'longitude': -176.6581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96506', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.88, 'longitude': -176.6581, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96507', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 51.5672, 'longitude': 178.8775, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96508', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 45.7833, 'longitude': -86.7001, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96509', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 64.3006, 'longitude': -149.1128, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96510', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 64.7361, 'longitude': -156.9372, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96511', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.2322, 'longitude': 132.5666, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96512', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 52.7242, 'longitude': 174.1189, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96513', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 58.6883, 'longitude': -156.6614, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96514', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 28.228, 'longitude': -177.389, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96516', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 28.228, 'longitude': -177.389, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96517', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 34.2322, 'longitude': 132.5666, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96518', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 19.2811, 'longitude': 166.6434, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96520', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -6.2146, 'longitude': 106.8451, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96521', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 22.2783, 'longitude': 114.1747, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96522', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 22.2783, 'longitude': 114.1747, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96531', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -43.5333, 'longitude': 172.6333, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96534', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 1.2897, 'longitude': 103.8501, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96539', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.4757, 'longitude': 144.7489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96540', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.4757, 'longitude': 144.7489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96541', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.4757, 'longitude': 144.7489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96542', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.4757, 'longitude': 144.7489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96543', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.4757, 'longitude': 144.7489, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96546', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 13.754, 'longitude': 100.5014, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96548', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -23.6975, 'longitude': 133.8836, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96549', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -35.3065, 'longitude': 149.1162, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96550', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -21.9306, 'longitude': 114.1209, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96551', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -37.847, 'longitude': 144.9809, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96552', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -31.1998, 'longitude': 136.8326, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96553', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -33.8678, 'longitude': 151.2073, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96554', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -33.8678, 'longitude': 151.2073, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96556', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 19.7542, 'longitude': -155.5858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96558', 'place_name': 'APO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 19.7542, 'longitude': -155.5858, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96598', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -89.9976, 'longitude': 139.2729, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96599', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': -77.846, 'longitude': 166.676, 'accuracy': 1},
            {'country_code': 'US', 'zip_code': '96860', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 21.3448, 'longitude': -157.9774, 'accuracy': 4},
            {'country_code': 'US', 'zip_code': '96863', 'place_name': 'FPO AA', 'state': '', 'state_ab': '', 'county': '', 'locality_code': '', 'latitude': 21.4505, 'longitude': -157.768, 'accuracy': 4}
        ]
    )


def upgrade() -> None:
    if os.environ.get("TESTING"):
        add_zip_code_test_data()
    else:
        add_zip_code_data()


def downgrade() -> None:
    pass

